%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for showing about dialog            %
%                                                                %
%          Function: about                                       %
%                                                                %
%          Input:                                                %
%                       mytext: text string                      %
%          		          myimage: image name                      %
%                       mylabel: text string (optional)          %
%                       thisheight: height of dialog (optional)  %
%                       width: width of dialog (optional)        %
%                       help_topic: string with topic in help    %
%                           file (optional)                      %
%                                                                %
%          Output:                                               %
%          		          none                                     %
%                                                                %
%          This version:        May 17, 2006                     %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function about(mytext,myimage,mylabel,thisheight,width,help_topic)

if nargin==2;
   selector = 'init';
   mylabel = 'About';
elseif nargin==3;
   selector = 'init';
elseif nargin==4;
   selector = 'init';
elseif nargin==5;
   selector = 'init';
elseif nargin==6;
   selector = 'init';
else;
   selector = 'ok';
end;

if nargin<4;
   thisheight = 124;
else;
   if isnumeric(thisheight)==0;
      thisheight = 124;
   end;
end;

if nargin<5;
   width = 292;
else;
   if isnumeric(width)==0;
      width = 292;
   end;
   if width<250;
      width = 250;
   end;
end;

if nargin<6;
   help_topic = '';
end;

textheight = thisheight-54;
axesheight = (thisheight-90)/2;
if axesheight<0;
   axesheight = 0;
end;

if strcmp(selector,'init')==1;
   mycons = getstoredimages;
   curr_ini = find_inisettings;
   if curr_ini.use_toolbar_bgcolor==1;
      bgcolor = (1/255)*(round(255*get(0,'defaultuicontrolbackgroundcolor'))-[8 4 8]);
      bgcolor(1) = max(0,bgcolor(1));
      bgcolor(2) = max(0,bgcolor(2));
      bgcolor(3) = max(0,bgcolor(3));
   else;
      bgcolor = get(0,'defaultuicontrolbackgroundcolor');
   end;
   %
   if strcmp(myimage,'information')==1;
      mylogo = mycons.information_image;
   elseif strcmp(myimage,'question')==1;
      mylogo = mycons.question_image;
   elseif strcmp(myimage,'warning')==1;
      mylogo = mycons.warning_image;
   elseif strcmp(myimage,'error')==1;
      mylogo = mycons.error_image;
   elseif strcmp(myimage,'borg')==1;
      mylogo = mycons.borg_image;
   elseif strcmp(myimage,'bootstrap')==1;
      mylogo = mycons.bootstrap_image;
   elseif strcmp(myimage,'figeditor')==1;
      mylogo = mycons.figeditor_image;
   elseif strcmp(myimage,'internet')==1;
      mylogo = mycons.internet_image;
   else;
      mylogo = mycons.logo_image;
   end;
   mylogo = maketrans(mylogo,[160 160 164],bgcolor);
   mylogo = mirrorimage(mylogo);
   thisexit = 0;
else;
   thisexit = 1;
   aboutdlg = get(0,'CurrentFigure');
   myabout = get(aboutdlg,'UserData');
end;

scrsz = get(0,'ScreenSize');

cu_ini = find_inisettings;

switch selector;
   case 'init';
      aboutdlg = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','about.m', ...
         'MenuBar','none', ...
         'Units','pixels', ...
         'Position',[(scrsz(3)-width)/2 (scrsz(4)-thisheight)/2 width thisheight], ...
         'Tag','FigAbout', ...
         'Resize','off', ...
         'Visible','off', ...
         'Name',mylabel, ...
         'NumberTitle','off', ...
         'WindowStyle','modal', ...
         'ToolBar','none');

      if matlabnumber>=7.0;
         set(aboutdlg,'DockControl','off');
      end;

      imageaxes = axes('Units','pixels', ...
         'Box','on', ...
         'TickLength',[0 0], ...
         'CameraUpVector',[0 1 0], ...
         'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[10 50+axesheight 39 39], ...
         'XTickLabelMode','manual', ...
         'YTickLabelMode','manual', ...
         'Tag','AxisLogo', ...
         'XColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'YColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'ZColor',get(0,'defaultuicontrolbackgroundcolor'));

      image('CData',mylogo,'Clipping','off','Parent',imageaxes);

      about_txt = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[50 50 width-52 textheight], ...
         'FontSize',cu_ini.gui_fontsize, ...
         'FontName',cu_ini.gui_fontname, ...
         'FontWeight',cu_ini.gui_fontweight, ...
         'FontAngle',cu_ini.gui_fontangle, ...
         'Style','text', ...
         'HorizontalAlignment','left', ...
         'String',' ', ...
         'Tag','Text');

      %
      % need to fix mytext string and turn it into a cell str
      %
      [out_str,pos] = textwrap(about_txt,cellstr(mytext));
      set(about_txt,'String',out_str,'Position',[50 50 width-52 pos(4)]);
      if max(size(out_str))==1;
         set(about_txt,'HorizontalAlignment','center');
      end;
      c_pos = 0;
      if (60+pos(4)>=90)&(thisheight>60+pos(4));
         %
         % fix the height of the dialog
         %
         set(aboutdlg,'Position',[(scrsz(3)-width)/2 (scrsz(4)-(60+pos(4)))/2 width 60+pos(4)]);
         c_pos = 60+pos(4);
      elseif (60+pos(4)<90)&(thisheight>60+pos(4));
         set(aboutdlg,'Position',[(scrsz(3)-width)/2 (scrsz(4)-90)/2 width 90]);
         c_pos = 90;
      end;
      if c_pos>0;
         axesheight = (c_pos-90)/2;
         set(imageaxes,'Position',[10 50+axesheight 39 39]);
      end;

      if strcmp(help_topic,'')==0;
         uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[10 10 20 20], ...
            'String','?', ...
            'TooltipString','Open the help file', ...
            'FontWeight','bold', ...
            'FontSize',cu_ini.gui_fontsize, ...
            'FontName',cu_ini.gui_fontname, ...
            'ForegroundColor',[0.5 0 0], ...
            'Enable','on', ...
            'UserData',help_topic, ...
            'Callback','about_help_fcn', ...
            'Tag','HelpButton');
      end;

      myabout.ok = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[(width-50)/2 12 50 25], ...
         'String','OK', ...
         'FontSize',cu_ini.gui_fontsize, ...
         'FontName',cu_ini.gui_fontname, ...
         'FontWeight',cu_ini.gui_fontweight, ...
         'FontAngle',cu_ini.gui_fontangle, ...
         'Enable','on', ...
         'Callback','about', ...
         'UserData','waiting', ...
         'Tag','Button');

      set(aboutdlg,'UserData',myabout,...
         'HandleVisibility','callback');

   case 'ok'
      set(myabout.ok,'UserData','done');
      delete(aboutdlg);
      drawnow;
end;

if thisexit==0;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.noicon==1);
      set(aboutdlg,'WindowStyle','normal');
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(aboutdlg,'Name') ' NULL'];
      dos(prog);
      wait_fcn(curr_ini.delay);
      pos = get(aboutdlg,'Position');
      set(aboutdlg,'Position',[0 0 1 1]);
   end;
   %
   set(aboutdlg,'Visible','on');
   drawnow;
   if (iswinnt==1)&(iscompiled==1)&(matlabnumber<7);
      if curr_ini.noicon==1;
         drawnow;
         set(aboutdlg,'WindowStyle','modal');
         prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(aboutdlg,'Name') ' NULL'];
         dos(prog);
         wait_fcn(curr_ini.delay);
         set(aboutdlg,'Position',pos);
      end;
      %
      drawnow;
      prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(aboutdlg,'Name') ' 1'];
      dos(prog);
      drawnow;
      if curr_ini.noicon==1;
         set(aboutdlg,'Position',pos);
      end;
   elseif matlabnumber>=7;
      %
      % set focus on OK button
      %
      uicontrol(myabout.ok);
   end;
   waitfor(myabout.ok,'UserData','done');
end;

%
% end of about.m
%