%
% Estimate alpha and beta under 1 additional beta restriction
%

function [theta,newbeta] = alpha_beta_2d_restrict(Z0,Z1,Z2,Z_3,newbeta,Theta,Rmat,rvec,dcoint,q1,modelsdir,modelfile,thisbij,row,col);

n = size(Theta,1);
r = size(newbeta,2);
T = size(Z0,2);

curr_ini = find_inisettings;

if curr_ini.convcrit<10;
   ch_convcrit = ['1.0e-00' num2str(curr_ini.convcrit)];
else;
   ch_convcrit = ['1.0e-0' num2str(curr_ini.convcrit)];
end;
ccrit = mystr2num(ch_convcrit);

%
% starting up the estimation by getting a restricted estimate of alpha and Psi
%

[theta,Sigma_theta,infomat,abort] = linrest(Z0,Z_3,Theta,Rmat,rvec,0,1);
g2 = size(theta,2);
alphar = theta(:,g2-r+1:g2);
if g2>r;
   Psir = theta(:,1:g2-r);
else;
   Psir = [];
end;
neweps = Z0-(theta*Z_3);
newlnl = loglike(neweps);
newOmega = (1/T)*neweps*neweps';
sivec = zeros(r,1);

file = strcat(modelsdir,'normalize-',num2str(n),'x',num2str(r),'x',num2str(dcoint+q1),'-',modelfile,'.norm');
normvec = loaddata(file);
%
% setting up the restrictions
%
for i=1:r;
   file = strcat(modelsdir,'H_',num2str(i),'-',num2str(n),'x',num2str(r),'x',num2str(dcoint+q1),'-',modelfile,'.rest');
   if fileexist(file)==1;
      h = loaddata(file);
      if i==col;
         %
         % Recreate h such that new restriction is properly taken into account
         %
         normelem = normvec(i,1);
         normmatrix = [h(normelem,:);h(row,:)];
         if size(h,2)>size(normmatrix,1);
            for k=1:(n+q1+dcoint);
               if (k~=normelem)&(k~=row);
                  checkHk = [normmatrix;h(k,:)];
                  if rank(checkHk*checkHk')==size(checkHk,1);
                     normmatrix = checkHk;
                     if size(normmatrix,1)==size(h,2);
                        break;
                     end;
                  end;
               end;
            end;
         end;
         %
         % ensuring that h has [1 0 ... 0]
         % for normalizing parameter and
         % [0 1 0 ... 0] for restricted parameter
         %
         h = h/normmatrix;
         %
         % imposing the restriction
         %
         hj = thisbij*h(:,2);
         if size(h,2)>2;
            h = [h(:,1)+hj h(:,3:size(h,2))];
         else;
            h = h(:,1)+hj;
         end;
      end;
      if i==1;
         H = h;
         bH = h;
      else;
         H = [H h];
         bH = [[bH zeros(size(bH,1),size(h,2))];[zeros(size(h,1),size(bH,2)) h]];
      end;
      sivec(i,1) = size(h,2);
   end;
end;
%
% Setting up the normalizing restrictions
%

if isempty(normvec)==0;
   nq1 = size(newbeta,1);
   addrestmat = zeros(nq1*r,r);
   for i=1:r;
      thisnorm = normvec(i,1);
      addrestmat(thisnorm+nq1*(i-1),i) = 1;
   end;
else;
   addrestmat = [];
end;

%
% constructing restriction matrices for beta
%

Knr = commutation(n+q1+dcoint,r);
bH_ort = null(bH','r');
bH_ort = [bH_ort addrestmat];
bRmat = bH_ort'*Knr';
if isempty(addrestmat)==1;
   brvec = zeros(size(bRmat,1),1);
else;
   brvec = [zeros(size(bRmat,1)-r,1);ones(r,1)];
end;
bH = null(bH_ort','r');

%
% Computing the gradient using the new theta matrix
%

M_01 = (1/T)*Z0*Z1';
M_11 = (1/T)*Z1*Z1';
if isempty(Z2)==0;
   M_21 = (1/T)*Z2*Z1';
   M_12 = M_21';
   M_22 = (1/T)*Z2*Z2';
else;
   M_21 = [];
   M_12 = [];
   M_22 = [];
end;
inv_newOmega = eye(size(newOmega,1))/newOmega;
if isempty(M_21)==0;
   grad = T*(vec(alphar))'*kron(eye(r),inv_newOmega*(M_01-(alphar*newbeta'*M_11)-(Psir*M_21)))*bH;
else;
   grad = T*(vec(alphar))'*kron(eye(r),inv_newOmega*(M_01-(alphar*newbeta'*M_11)))*bH;
end;
grad = max(abs(grad));
%
% setting up iterations if needed
%
if grad>ccrit;
   it = 1;
   while (it<=curr_ini.maxit)&(grad>ccrit);
      oldgrad = grad;
      oldlnl = newlnl;
      %
      % create new R0 and R1 series using Psir, alphar, and newbeta
      %
      if isempty(Z2)==0;
         newR0 = Z0-(Psir+(alphar*newbeta'*(M_12/M_22)))*Z2;
         newR1 = Z1-(M_12/M_22)*Z2;
      else;
         newR0 = Z0;
         newR1 = Z1;
      end;
      %
      % Constructing unrestricted beta estimate
      %
      S_00_new = (1/T)*newR0*newR0';
      S_10_new = (1/T)*newR1*newR0';
      S_11_new = (1/T)*newR1*newR1';
      S_01_new = (1/T)*newR0*newR1';
      alpharort = null(alphar');
      alpharbar = alphar/(alphar'*alphar);
      S_11_alpha = S_11_new-(S_10_new*alpharort*((alpharort'*S_00_new*alpharort)\(alpharort'*S_01_new)));
      S_10_alpha = S_10_new-(S_10_new*alpharort*((alpharort'*S_00_new*alpharort)\(alpharort'*S_00_new)));
      S_00_alpha = S_00_new-(S_00_new*alpharort*((alpharort'*S_00_new*alpharort)\(alpharort'*S_00_new)));
      newbeta = (S_11_alpha)\(S_10_alpha*alpharbar);
      %
      % Computing restricted newbeta estimate using R0tilde and R1tilde
      %
      R0tilde = alpharbar'*(eye(n)-(S_00_new*alpharort*((alpharort'*S_00_new*alpharort)\(alpharort'))))*newR0;
      R1tilde = newR1-(S_10_new*alpharort*((alpharort'*S_00_new*alpharort)\alpharort'))*newR0;
      [thisbeta,sig_beta,infmat,newabort] = linrest(R0tilde,R1tilde,newbeta',bRmat,brvec,0,1);
      newbeta = thisbeta';
      if isempty(Z2)==0;
         Z_3 = [Z2;newbeta'*Z1];
      else;
         Z_3 = newbeta'*Z1;
      end;
      [theta,Sigma_theta,infomat,newabort,inv_Omega] = linrest(Z0,Z_3,theta,Rmat,rvec,0,1);
      g2 = size(theta,2);
      alphar = theta(:,g2-r+1:g2);
      if g2>r;
         Psir = theta(:,1:g2-r);
      else;
         Psir = [];
      end;
      neweps = Z0-(theta*Z_3);
      newlnl = loglike(neweps);
      newOmega = (1/T)*neweps*neweps';
      if curr_ini.betagrad==0;
         grad = abs((newlnl-oldlnl)/oldlnl);
         oldgrad = 0;
      else;
         if isempty(M_21)==0;
            oldgrad = T*(vec(alphar))'*kron(eye(r),inv_Omega*(M_01-(alphar*newbeta'*M_11)-(Psir*M_21)))*bH;
         else;
            oldgrad = T*(vec(alphar))'*kron(eye(r),inv_Omega*(M_01-(alphar*newbeta'*M_11)))*bH;
         end;
         oldgrad = max(abs(oldgrad));
         if oldgrad>min([ccrit*10 1.0e-006]);
            oldgrad = 0;
         end;
         inv_newOmega = eye(size(newOmega,1))/newOmega;
         if isempty(M_21)==0;
            grad = T*(vec(alphar))'*kron(eye(r),inv_newOmega*(M_01-(alphar*newbeta'*M_11)-(Psir*M_21)))*bH;
         else;
            grad = T*(vec(alphar))'*kron(eye(r),inv_newOmega*(M_01-(alphar*newbeta'*M_11)))*bH;
         end;
      end;
      grad = abs(max(abs(grad))-oldgrad);
      infomat = [it grad];
      it = it+1;
   end;
end;

%
% end of alpha_beta_2d_restrict.m
%
