%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for bootstrapping the LR/F test     %
%          for restrictions on alpha and estimate confidence     %
%          intervals for the alpha and Psi parameters            %
%                                                                %
%          Function: alpha_bootstrap                             %
%                                                                %
%          Input:                                                %
%                       selector: case switch function           %
%                       cm: structure with model info            %
%                                                                %
%          Output:                                               %
%                                                                %
%          This version:        July 6, 2006                     %
%          Written by:          Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function alpha_bootstrap(varargin)

%
% GUI for bootstrapping the Alpha and Psi distributions
%

selector = varargin{1};
if (nargin==0)|(strcmp(selector,'init')==1);
   tm = varargin{2};
   if tm.restrict(1,1)==1;
      tm.resalpha = 'alpha-';
   else;
      tm.resalpha = '';
   end;
   if tm.restrict(1,2)==1;
      tm.resbeta = 'beta-';
   else;
      tm.resbeta = '';
   end;
   if (size(tm.restrict,2)>2)&(tm.restrict(1,3)==1);
      tm.resc = 'c-';
   else;
      tm.resc = '';
   end;
   if isfield(tm,'Sigma_theta')==0;
      %
      % we're in the Restrictions on alpha,beta dialog
      %
      betaguidlg = findobj('Type','figure','Tag','BetaGUI')';
      cointbeta = get(betaguidlg,'UserData');
      tm.Sigma_theta = get(cointbeta.genalpha,'UserData');
   end;
   %
   % toolbar images
   %
   button_images = read_images;
   %
   % more initialization
   %
   selector = 'init';
   my_exit = 1;
   tm.const_model = [0 0 0 0 0];
   if tm.deterselect(1)==1;
      tm.const_model(3) = 1;
   elseif tm.deterselect(2)==1
      tm.const_model(2) = 1;
   elseif tm.deterselect(3)==1;
      tm.const_model(5) = 1;
   else;
      tm.const_model(4) = 1;
   end;
   %
   % Set screen size directly instead of using
   % get(0,'ScreenSize')!
   %
   tm.realscrsz = get(0,'ScreenSize');
   tm.beta_run = 0;
   %
   % read var.in
   %
   curr_ini = find_inisettings;
   my_T = tm.T;
   rep = curr_ini.nRep;
   repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
   nRep_value = 1;
   for i=1:size(repvalues,2);
      if curr_ini.nRep==repvalues(1,i);
         nRep_value = i;
         break;
      end;
   end;
   if direxist(curr_ini.simulatedir)==0;
      mystatus = makedirs(curr_ini.simulatedir);
   else;
      mystatus = 2;
   end;
   if mystatus==0;
      curr_ini.simulatedir = pwd;
      if ispc==1;
         curr_ini.simulatedir = [curr_ini.simulatedir '\'];
      end;
   end;
   if isnumeric(curr_ini.external)==0;
      curr_ini.external = 0;
   end;
   if curr_ini.sscorrect==1;
      tm.testtype = '-f';
   else;
      tm.testtype = '-lr';
   end;
   if curr_ini.parametric==1;
      bootstyle = '';
   else;
      bootstyle = ['np' num2str(curr_ini.blocksize) '-'];
   end;
   full_mat = '';
   if tm.const_model(1)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
   elseif tm.const_model(2)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
   elseif tm.const_model(3)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
   elseif tm.const_model(4)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
   elseif tm.const_model(5)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
   end;
   if fileexist(full_mat)==1;
      full_enable = 'on';
      if tm.r<tm.n;
         view_enable = 'on';
      else;
         view_enable = 'off';
      end;
      if rep>=5000;
         this_text = strvcat(' ',['Collecting data from ' getfilename(full_mat) '...'],'Please hold!');
         mywait = waitdlg(this_text,'information');
         waitf = get(mywait,'UserData');
      end;
      alpha_mat = load(full_mat);
      alpha_sorted = alpha_mat.alpha_sorted;
      param_vec_sorted = alpha_mat.param_vec_sorted;
      param_t_dist = alpha_mat.param_t_dist;
      vec_Theta = alpha_mat.vec_Theta;
      se_Theta = alpha_mat.se_Theta;
      if rep>=5000;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
      end;
   else;
      view_enable = 'off';
      alpha_sorted = [];
      param_vec_sorted = [];
      param_t_dist = [];
      vec_Theta = [];
      se_Theta = [];
      full_mat = '';
      full_enable = 'off';
   end;
   summary_txt = '';
   if tm.const_model(1)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-summary-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.txt'];
      mod_type = 'noconst';
      model_type = 'No Constant';
   elseif tm.const_model(2)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-summary-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
      mod_type = 'resconst';
      model_type = 'Restricted Constant';
   elseif tm.const_model(3)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-summary-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
      mod_type = 'const';
      model_type = 'Constant';
   elseif tm.const_model(4)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-summary-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
      mod_type = 'restrend';
      model_type = 'Restricted Linear Trend';
   elseif tm.const_model(5)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-summary-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
      mod_type = 'trend';
      model_type = 'Linear Trend';
   end;
%   if curr_ini.texoutputformat>=2;
%      summary_txt = strrep(summary_txt,'.txt','.ltx');
%   end;
   if fileexist(summary_txt)==1;
      summary_enable = 'on';
   else;
      summary_txt = '';
      summary_enable = 'off';
   end;
   %
   % check if file with bootstrapped residuals exists
   %
   epsfile = [curr_ini.simulatedir tm.modelfile '-' 'alpha-epsilon-' num2str(tm.scale_endo,'%0.4f') '-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '-' num2str(rep) '-' mod_type '.mat'];
   testfile = strrep(epsfile,'.mat',['-' 'alpha-data.mat']);
   if fileexist(epsfile)==1;
      boot_enable = 'on';;
   else;
      epsfile = '';
      boot_enable = 'off';
   end;
   if fileexist(testfile)==0;
      testfile = '';
   end;
   %
   tm.interpolate = curr_ini.interpolate;
   if strcmp(tm.interpolate,'nearest')==1;
      tm.interpolate_value = 1;
   elseif strcmp(tm.interpolate,'linear')==1;
      tm.interpolate_value = 2;
   elseif strcmp(tm.interpolate,'spline')==1;
      tm.interpolate_value = 3;
   elseif strcmp(tm.interpolate,'cubic')==1;
      tm.interpolate_value = 4;
   elseif strcmp(tm.interpolate,'knorm')==1;
      tm.interpolate_value = 5;
   elseif strcmp(tm.interpolate,'kepan')==1;
      tm.interpolate_value = 6;
   elseif strcmp(tm.interpolate,'krect')==1;
      tm.interpolate_value = 7;
   elseif strcmp(tm.interpolate,'ktria')==1;
      tm.interpolate_value = 8;
   elseif strcmp(tm.interpolate,'kbiwe')==1;
      tm.interpolate_value = 9;
   elseif strcmp(tm.interpolate,'ktriw')==1;
      tm.interpolate_value = 10;
   elseif strcmp(tm.interpolate,'klapl')==1;
      tm.interpolate_value = 11;
   elseif strcmp(tm.interpolate,'klogi')==1;
      tm.interpolate_value = 12;
   end;
else;
   my_exit = 0;
   alpha_boot_gui = findobj('Type','figure','Tag','AlphaBoot')';
   boot_alpha = get(alpha_boot_gui,'UserData');
   curr_ini = get(boot_alpha.matfilebutton,'UserData');
   tm = curr_ini.models;
   button_images = curr_ini.images;
end;

switch selector
case 'init'
   alpha_boot_gui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','alpha_bootstrap.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(tm.realscrsz(3)-560)/2 (tm.realscrsz(4)-465)/2 560 465], ...
         'Tag','AlphaBoot', ...
         'Visible','off', ...
         'Resize','off', ...
         'Name','Bootstrap Distributions for Alpha, Delta, Gamma', ...
         'NumberTitle','off', ...
         'CloseRequestFcn','alpha_bootstrap done', ...
         'ToolBar','none');

   if matlabnumber>=7.0;
      set(alpha_boot_gui,'DockControl','off');
   end;

   if strcmp(curr_ini.helpexe,'')==1;
      helpenable = 'off';
   else;
      helpenable = 'on';
   end;

   %
   % File menu
   %

   filemenu = uimenu('Parent',alpha_boot_gui, ...
      'Label','&File', ...
      'Tag','FileMenu');

   boot_alpha.simulatemenu = uimenu('Parent',filemenu, ...
         'Label','&Run Bootstrap', ...
         'Callback','alpha_bootstrap simulate', ...
         'Enable','on', ...
         'Accelerator','R', ...
         'Tag','SimulateMenu');

   boot_alpha.matfilemenu = uimenu('Parent',filemenu, ...
         'Label','Save to m&at-file', ...
         'Separator','on', ...
         'Accelerator','A', ...
         'Enable',full_enable, ...
         'Callback','alpha_bootstrap matfile', ...
         'Tag','MatFileMenu');

   boot_alpha.summarymenu = uimenu('Parent',filemenu, ...
         'Label','&Simulation Summary', ...
         'Separator','on', ...
         'Callback','alpha_bootstrap summary', ...
         'UserData',summary_txt, ...
         'Accelerator','S', ...
         'Enable',summary_enable, ...
         'Tag','SummaryMenu');

   boot_alpha.fullmenu = uimenu('Parent',filemenu, ...
         'Label','&Full Simulation', ...
         'Callback','alpha_bootstrap full', ...
         'Accelerator','F', ...
         'UserData',full_mat, ...
         'Enable',full_enable, ...
         'Tag','FullMenu');

   if curr_ini.noprint==0;
      boot_alpha.output = uimenu('Parent',filemenu, ...
            'Label','Append to &Output', ...
            'Separator','on', ...
            'Callback','alpha_bootstrap output', ...
            'Accelerator','O', ...
            'Enable',summary_enable, ...
            'Tag','SummaryMenu');
   end;

   uimenu('Parent',filemenu, ...
         'Label','Center &Window', ...
         'Separator','on', ...
         'Accelerator','W', ...
         'Enable','on', ...
         'Callback','center_figure_fcn', ...
         'Tag','CenterMenu');

   boot_alpha.returnmenu = uimenu('Parent',filemenu, ...
         'Label','R&eturn', ...
         'Separator','on', ...
         'Callback','alpha_bootstrap done', ...
         'Enable','on', ...
         'Tag','MenuFileReturn');

   boot_alpha.filemenu = filemenu;

   %
   % Graph Menu
   %

   graphmenu = uimenu('Parent',alpha_boot_gui, ...
      'Label','&Graphics', ...
      'Tag','GraphMenu');

   boot_alpha.bootstrapgraphmenu = uimenu('Parent',graphmenu, ...
         'Label','Graph &Bootstrap Sample', ...
         'Callback','alpha_bootstrap display_bootstrap', ...
         'Accelerator','B', ...
         'UserData',testfile, ...
         'Enable',boot_enable, ...
         'Tag','BootstrapGraphMenu');

   boot_alpha.displaymenu = uimenu('Parent',graphmenu, ...
         'Label','&Graph Distribution', ...
         'Callback','alpha_bootstrap display', ...
         'Separator','on', ...
         'Accelerator','G', ...
         'UserData',tm.const_model, ...
         'Enable',view_enable, ...
         'Tag','DisplayMenu');

   boot_alpha.histogrammenu = uimenu('Parent',graphmenu, ...
         'Label','&Histogram of Distribution', ...
         'Callback','alpha_bootstrap display', ...
         'Accelerator','D', ...
         'Enable',view_enable, ...
         'Tag','HistogramMenu');

   %
   % Help Menu
   %

   helpmenu = uimenu('Parent',alpha_boot_gui, ...
      'Label','&Help', ...
      'Tag','HelpMenu');

   boot_alpha.helpmenu = uimenu('Parent',helpmenu, ...
         'Label','&Help Topics', ...
         'Callback','help_fcn(''bootstrapping'')', ...
         'Accelerator','H', ...
         'Enable',helpenable, ...
         'Tag','HelpMenu');

   %
   % The toolbar
   %

   boot_alpha.toolbar = uitoolbar('Parent',alpha_boot_gui, ...
                     'HandleVisibility','off', ...
                     'Interruptible','on', ...
                     'Clipping','on');

   if (iswinxp==0)|(matlabnumber<7);
      xline([1 464 560],[0.5 1]);
   end;

   boot_alpha.simulate = uipushtool('Parent',boot_alpha.toolbar, ...
                      'TooltipString','Run Bootstrap', ...
                      'CData',button_images.simulate, ...
                      'ClickedCallback','alpha_bootstrap simulate', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable','on', ...
                      'UserData',0, ...
                      'Tag','Simulate');


   boot_alpha.matfilebutton = uipushtool('Parent',boot_alpha.toolbar, ...
                      'TooltipString','Save to mat-file', ...
                      'CData',button_images.matfile, ...
                      'ClickedCallback','alpha_bootstrap matfile', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',full_enable, ...
                      'Tag','MatFileButton');

   boot_alpha.summary = uipushtool('Parent',boot_alpha.toolbar, ...
                      'TooltipString','View Simulation Summary', ...
                      'CData',button_images.sim_summary, ...
                      'ClickedCallback','alpha_bootstrap summary', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'UserData',se_Theta, ...
                      'Enable',summary_enable, ...
                      'Tag','SummaryButton');

   boot_alpha.full = uipushtool('Parent',boot_alpha.toolbar, ...
                      'TooltipString','View Full Simulation', ...
                      'CData',button_images.sim_full, ...
                      'ClickedCallback','alpha_bootstrap full', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'UserData',param_t_dist, ...
                      'Clipping','on', ...
                      'Enable',full_enable, ...
                      'Tag','FullButton');

   boot_alpha.bootstrapgraph = uipushtool('Parent',boot_alpha.toolbar, ...
                      'TooltipString','Graph Bootstrap Sample', ...
                      'CData',button_images.bootstrapsmall, ...
                      'ClickedCallback','alpha_bootstrap display_bootstrap', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'UserData',epsfile, ...
                      'Clipping','on', ...
                      'Enable',boot_enable, ...
                      'Tag','ViewBootstrapButton');

   boot_alpha.display = uipushtool('Parent',boot_alpha.toolbar, ...
                      'TooltipString','Graph Distribution', ...
                      'CData',button_images.viewdist, ...
                      'ClickedCallback','alpha_bootstrap display', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'UserData',alpha_sorted, ...
                      'Clipping','on', ...
                      'Enable',view_enable, ...
                      'Tag','ViewDistButton');

   boot_alpha.histogram = uipushtool('Parent',boot_alpha.toolbar, ...
                      'TooltipString','Histogram of Distribution', ...
                      'CData',button_images.bars, ...
                      'ClickedCallback','alpha_bootstrap display', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'UserData',param_vec_sorted, ...
                      'Clipping','on', ...
                      'Enable',view_enable, ...
                      'Tag','HistogramButton');

   boot_alpha.help = uipushtool('Parent',boot_alpha.toolbar, ...
                      'TooltipString','Help Topics', ...
                      'CData',button_images.help, ...
                      'ClickedCallback','help_fcn(''bootstrapping'')', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',helpenable, ...
                      'Tag','HelpButton');

   boot_alpha.done = uipushtool('Parent',boot_alpha.toolbar, ...
                      'TooltipString','Return', ...
                      'CData',button_images.continue, ...
                      'ClickedCallback','alpha_bootstrap done', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'UserData','waiting', ...
                      'Enable','on', ...
                      'Tag','Done');

   axesbox([2 2 558 450],'Alpha, Delta, Gamma',105,[0.5 1]);

   %
   % GUI Header
   %

   header_txt = ['Bootstrap Alpha, Delta and Gamma (' model_type ' Model)'];
   if (tm.restrict(1,1)==1)|((size(tm.restrict,2)==3)&(tm.restrict(1,3)==1));
      if curr_ini.sscorrect==1;
         header_txt = ['Bootstrap Alpha, Delta, Gamma and F Test (' model_type ' Model)'];
      else;
         header_txt = ['Bootstrap Alpha, Delta, Gamma and LR Test (' model_type ' Model)'];
      end;
   end;
   desc_txt = 'Select the type of bootstrap you wish to perform, the number of observations and replications. Press the "Run Bootstrap" button when you''re satisfied with your choices and wait for the computations to finish.';
   dialog_header_fcn([16 366 530 70],button_images.bootstrap,header_txt,desc_txt);

   %
   % Options
   %

   axesbox([16 190 155 160],'Options',35,[0.5 1]);

   boot_alpha.clock = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 315 130 20], ...
      'Value',1, ...
      'String','Show elapsed time', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'UserData',vec_Theta, ...
      'Enable','on', ...
      'Tag','TimeCheck');

   boot_alpha.progress = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 295 130 20], ...
      'Value',1, ...
      'String','Show progress dialog', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ProgressCheck');

   boot_alpha.save = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 275 130 20], ...
      'Value',1, ...
      'String','Save full simulation', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','SaveCheck');

   boot_alpha.parametric = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 255 130 20], ...
      'Value',curr_ini.parametric, ...
      'String','Parametric bootstrap', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'Callback','alpha_bootstrap fixobscontrol', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ParametricCheck');


   boot_alpha.blocktext = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[45 225 100 20], ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Style','text', ...
      'HorizontalAlignment','left', ...
      'String','Block size:', ...
      'Enable','off', ...
      'Tag','BlockText');

   boot_alpha.block = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[105 230 50 20], ...
      'Value',1, ...
      'String','1|2|3|4|5|6|7|8|9|10|11|12', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Value',curr_ini.blocksize, ...
      'Enable','off', ...
      'Callback','alpha_bootstrap check', ...
      'Tag','BlockPopup');
   
   if curr_ini.parametric==0;
      set(boot_alpha.blocktext,'Enable','on');
      set(boot_alpha.block,'Enable','on');
   end;

   boot_alpha.bootstrap = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 205 130 20], ...
      'Value',curr_ini.reuse_bootstrap, ...
      'String','Reuse/save residuals', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ReuseBootstrapCheck');

   axesbox([185 190 361 160],'Parameters',55,[0.5 1]);

   %
   % number of observations per replication
   %

   boot_alpha.obstext = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 309 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'HorizontalAlignment','left', ...
      'String','Number of observations:', ...
      'Tag','ObsText');

   boot_alpha.obs = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 314 168 20], ...
      'Value',1, ...
      'String',[num2str(my_T) '|100|200|300|400|500|600|700|800|900|1000|1100|1200|1300|1400|1500|1600|1700|1800|1900|2000|2500|3000|4000|5000|6000|7000|8000|9000|10000'], ...
      'Style','popupmenu', ...
      'UserData',my_T, ...
      'Callback','alpha_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'Tag','ObsPopup');

   if (tm.q1+tm.q0==0)&(isempty(tm.deterfile)==1);
      set(boot_alpha.obstext,'Enable','on');
      set(boot_alpha.obs,'Enable','on');
   end;

   %
   % number of replications
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 256.5 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Number of replications:', ...
      'Tag','SimulText');

   boot_alpha.rep = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 261.5 168 20], ...
      'Value',nRep_value, ...
      'String','99|999|1,999|2,999|3,999|4,999|9,999|19,999|29,999|39,999|49,999|99,999|199,999|299,999|399,999|499,999|999,999', ...
      'Style','popupmenu', ...
      'Callback','alpha_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'UserData',rep,...
      'Enable','on', ...
      'Tag','SimulPopup');

   %
   % Trim estimates
   %

   boot_alpha.trim_estimatestext = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 204 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Trim tails of distributions by:', ...
      'Tag','TrimText');

   boot_alpha.trim_estimates = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 209 168 20], ...
      'Value',1, ...
      'String','0%|0.05%|0.1%|0.2%|0.3%|0.4%|0.5%|0.6%|0.7%|0.8%|0.9%|1%|2%|3%|4%|5%', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','TrimmingPopup');

   %
   % Select interpolation function
   %

   axesbox([16 16 530 160],'Graphics',45,[0.5 1]);

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 134 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Interpolation function:', ...
      'Tag','InterpolateText');

   boot_alpha.interpolate = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 139 168 20], ...
      'Value',tm.interpolate_value, ...
      'String','Nearest neighborhood|Linear|Cubic spline|Cubic|Kernel density normal|Kernel density Epanechnikov|Kernel density rectangular|Kernel density triangular|Kernel density biweight|Kernel density triweight|Kernel density Laplace|Kernel density logistic', ...
      'Callback','alpha_bootstrap interpolate', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','InterpolatePopup');

   %
   % Select bootstrap distribution for parameter graphs
   %

   boot_alpha.bootdisttext = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 99 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Parameter distribution:', ...
      'Tag','BootDistText');

   boot_alpha.bootdist = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 104 168 20], ...
      'Value',1, ...
      'String','bootstrapped t-statistic|bootstrapped parameter', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','BootDistPopup');

   %
   % graph functions
   %
   
   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 64 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Graph distributions for:', ...
      'Tag','GraphTypeText');
   
   grt_val = 1;
   num = 0;
   if tm.dfalpha>0;
      grt_str = 'LR-test|';
      num = num+1;
   else;
      grt_str = '';
   end;
   if tm.d+tm.dcoint>0;
      grt_str = [grt_str 'delta (deterministic)|'];
      num = num+1;
   end;
   if tm.p>1;
      grt_str = [grt_str 'Gamma (lagged endogenous)|'];
      num = num+1;
   end;
   if (tm.q1>0)&(tm.pe>0);
      grt_str = [grt_str 'Psi (exogenous I(1))|'];
      num = num+1;
   end;
   if tm.q0>0;
      grt_str = [grt_str 'Phi (exogenous I(0))|'];
      num = num+1;
   end;
   if tm.r>0;
      grt_str = [grt_str 'alpha|'];
      if tm.dfalpha==0;
         grt_val = num+1;
      end;
   end;
   grt_str = [grt_str 'All'];
   
   boot_alpha.graphtype = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 69 168 20], ...
      'Value',grt_val, ...
      'String',grt_str, ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','GraphTypePopup');

   %
   % Number of cells for graphing density functions
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 29 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Number of cells for histograms:', ...
      'Tag','CellText');

   boot_alpha.cells = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 34 168 20], ...
      'Value',1, ...
      'String','20|25|30|35|40|45|50|55|60|65|70|75|80|85|90|95|100', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','CellPopup');

   %
   % Additional options
   %

   boot_alpha.cdf = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 140 140 20], ...
      'Value',0, ...
      'String','Cumulative distribution', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','cdfCheckbox');

   boot_alpha.adaptive = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 103+(1/3) 140 20], ...
      'Value',0, ...
      'String','Adaptive KDE method', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'Tag','adaptiveCheckbox');

   boot_alpha.bart = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 66+(1/3) 140 20], ...
      'Value',0, ...
      'String','Bartlett corr. bootstrap', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','BartlettCheckbox');

   boot_alpha.pq_plot = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 30 140 20], ...
      'Value',0, ...
      'String','P-value plots, etc.', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','PQplotCheckbox');

   if tm.interpolate_value>=5;
      set(boot_alpha.adaptive,'Enable','on');
   end;

   if tm.dfalpha==0;
      set(boot_alpha.bart,'Enable','off');
      set(boot_alpha.pq_plot,'Enable','off');
   end;

   set(alpha_boot_gui,'UserData',boot_alpha,...
         'HandleVisibility','callback');

case 'output'
   if curr_ini.texoutputformat>=2;
      file = strrep(lower(get(boot_alpha.summarymenu,'UserData')),'.txt','.ltx');
      txt_str = readtext(file);
      fout = fopen(tm.outputfile,'at');
      fprintf(fout,'\\subsection*{Bootstrap Simulation of $\\alpha$} \n\n');
      for i=1:size(txt_str,2);
         fprintf(fout,'%s\n',txt_str{i});
      end;
      fclose(fout);
   else;
      txt_str = readtext(lower(get(boot_alpha.summarymenu,'UserData')));
      fout = fopen(tm.outputfile,'at');
      fprintf(fout,'                      Bootstrap Simulation of Alpha\n                      ----------------------------\n');
      for i=5:size(txt_str,2)-4;
         fprintf(fout,'%s\n',txt_str{i});
      end;
      fprintf(fout,'\n===============================================================================\n\n');
      fclose(fout);
   end;
case 'display_bootstrap'
   epsfile = get(boot_alpha.bootstrapgraph,'UserData');
   testfile = get(boot_alpha.bootstrapgraphmenu,'UserData');
   param_vec_sorted = get(boot_alpha.histogram,'UserData');
   my_T = get(boot_alpha.obs,'UserData');
   rep = get(boot_alpha.rep,'UserData');
   if rep<4999;
      answer = 'Yes';
   else;
      check_txt = ['Your bootstrap setup includes ' num2str(rep) ' draws of the residuals. With ' num2str(tm.n) ' series and ' num2str(my_T) ' observations, this yields ' num2str(rep*tm.n*my_T) ' observations. Are you sure you want to load that much data into memory?'];
      answer = query(check_txt,'warning',120,'Exit',500,'no');
   end;
   if strcmp(answer,'Yes')==1;
      %
      if tm.dfalpha>0;
         if curr_ini.sscorrect==1;
            txt_str = ['F(' num2str(tm.dfalpha,'%0.0f') ',' num2str(my_T-tm.df,'%0.0f') ') ='];
         else;
            txt_str = ['LR(' num2str(tm.dfalpha,'%0.0f') ') ='];
         end;
      else;
         txt_str = '';
      end;
      %
      set(alpha_boot_gui,'Visible','off');
      drawnow;
      thisgraph = bootgraphdlg('init',tm,epsfile,testfile,txt_str,tm.beta,rep,my_T,tm.r);
      bootgraph = get(thisgraph,'UserData');
      set(bootgraph.show,'UserData','done');
      killguipid(thisgraph);
      set(alpha_boot_gui,'Visible','on');
      drawnow;
   end;
case 'fixobscontrol'
   if get(boot_alpha.parametric,'Value')==0;
      T_str = get(boot_alpha.obs,'String');
      my_T = mystr2num(strtrim(T_str(get(boot_alpha.obs,'Value'),:)));
      set(boot_alpha.obs,'Value',1,'UserData',my_T,'Enable','off');
      set(boot_alpha.obstext,'Enable','off');
   elseif (tm.q1+tm.q0==0)&(isempty(tm.deterfile)==1);
      set(boot_alpha.obs,'Enable','on');
      set(boot_alpha.obstext,'Enable','on');
   end;
   alpha_bootstrap('check');
case 'interpolate'
   tm.interpolate_value = get(boot_alpha.interpolate,'Value');
   interpol_vec = strvcat('nearest','linear','spline','cubic','knorm','kepan','krect','ktria','kbiwe','ktriw','klapl','klogi');
   tm.interpolate = strtrim(interpol_vec(tm.interpolate_value,:));
   if tm.interpolate_value>=5;
      set(boot_alpha.adaptive,'Enable','on');
   else;
      set(boot_alpha.adaptive,'Enable','off','Value',0);
   end;
case 'matfile'
   alpha_sorted = get(boot_alpha.display,'UserData');
   param_vec_sorted = get(boot_alpha.histogram,'UserData');
   param_t_dist = get(boot_alpha.full,'UserData');
   vec_Theta = get(boot_alpha.clock,'UserData');
   se_Theta = get(boot_alpha.summary,'UserData');
   rep = get(boot_alpha.rep,'UserData');
   my_T = get(boot_alpha.obs,'UserData');
   my_const_model = get(boot_alpha.displaymenu,'UserData');
   if get(boot_alpha.parametric,'Value')==1;
      bootstyle = '';
   else;
      bootstyle = ['np' num2str(get(boot_alpha.block,'Value')) '-'];
   end;
   if my_const_model(1)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
   elseif my_const_model(2)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
   elseif my_const_model(3)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
   elseif my_const_model(4)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
   elseif my_const_model(5)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
   end;
   if fileexist(full_mat)==1;
      my_text = ['The file "' getfilename(full_mat) '" already exists. Are you sure you want to overwrite it?'];
      answer = query(my_text,'question',120,'Save to mat-file',500,'no');
   else;
      answer = 'Yes';
   end;
   if strcmp(answer,'Yes')==1;
      setlogtext('Savings results to mat-files...');
      Number = (1:1:rep)';
      save(full_mat,'alpha_sorted','param_vec_sorted','param_t_dist','vec_Theta','se_Theta');
   end;
case 'check'
   T_str = get(boot_alpha.obs,'String');
   my_T = mystr2num(strtrim(T_str(get(boot_alpha.obs,'Value'),:)));
   repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
   rep_val = get(boot_alpha.rep,'Value');
   rep = repvalues(rep_val);
   set(boot_alpha.rep,'UserData',rep);
   set(boot_alpha.obs,'UserData',my_T);
   %
   % adjusting the view text buttons
   %
   if get(boot_alpha.parametric,'Value')==1;
      bootstyle = '';
      set(boot_alpha.blocktext,'Enable','off');
      set(boot_alpha.block,'Enable','off','Value',1);
   else;
      if strcmp(get(boot_alpha.block,'Enable'),'off')==1;
         set(boot_alpha.blocktext,'Enable','on');
         set(boot_alpha.block,'Enable','on','Value',curr_ini.blocksize);
      end;
      bootstyle = ['np' num2str(get(boot_alpha.block,'Value')) '-'];
   end;
   %
   full_mat = '';
   if tm.const_model(1)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
      mod_type = 'noconst';
   elseif tm.const_model(2)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
      mod_type = 'resconst';
   elseif tm.const_model(3)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
      mod_type = 'const';
   elseif tm.const_model(4)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
      mod_type = 'restrend';
   elseif tm.const_model(5)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
      mod_type = 'trend';
   end;
   if fileexist(full_mat)==1;
      full_enable = 'on';
      if rep>=5000;
         this_text = strvcat(' ',['Collecting data from ' getfilename(full_mat) '...'],'Please hold!');
         mywait = waitdlg(this_text,'information');
         waitf = get(mywait,'UserData');
      end;
      alpha_mat = load(full_mat);
      alpha_sorted = alpha_mat.alpha_sorted;
      param_vec_sorted = alpha_mat.param_vec_sorted;
      param_t_dist = alpha_mat.param_t_dist;
      vec_Theta = alpha_mat.vec_Theta;
      se_Theta = alpha_mat.se_Theta;
      if rep>=5000;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
      end;
      %
      % adjusting the Graph Distrbution button
      %
      set(boot_alpha.display,'Enable','on','UserData',alpha_sorted);
      set(boot_alpha.histogram,'Enable','on','UserData',param_vec_sorted);
      set(boot_alpha.displaymenu,'Enable','on','UserData',tm.const_model);
      set(boot_alpha.full,'UserData',param_t_dist);
      set(boot_alpha.clock,'UserData',vec_Theta);
      set(boot_alpha.summary,'UserData',se_Theta);
      set(boot_alpha.histogrammenu,'Enable','on');
      set(boot_alpha.matfilebutton,'Enable','on');
      set(boot_alpha.matfilemenu,'Enable','on');
   else;
      full_mat = '';
      full_enable = 'off';
      set(boot_alpha.display,'Enable','off','UserData',[]);
      set(boot_alpha.displaymenu,'Enable','off','UserData',tm.const_model);
      set(boot_alpha.histogram,'Enable','off','UserData',[]);
      set(boot_alpha.full,'UserData',[]);
      set(boot_alpha.clock,'UserData',[]);
      set(boot_alpha.summary,'UserData',[]);
      set(boot_alpha.histogrammenu,'Enable','off');
      set(boot_alpha.matfilebutton,'Enable','off');
      set(boot_alpha.matfilemenu,'Enable','off');
   end;
   %
   % Checking if residuals file exists
   %
   epsfile = [curr_ini.simulatedir tm.modelfile '-' 'alpha-epsilon-' num2str(tm.scale_endo,'%0.4f') '-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '-' num2str(rep) '-' mod_type '.mat'];
   testfile = strrep(epsfile,'.mat',['-' 'alpha-data.mat']);
   if (fileexist(epsfile)==1)&(fileexist(testfile)==1);
      set(boot_alpha.bootstrapgraph,'Enable','on','UserData',epsfile);
      set(boot_alpha.bootstrapgraphmenu,'Enable','on','UserData',testfile);
   elseif fileexist(testfile)==1;
      set(boot_alpha.bootstrapgraph,'Enable','off','UserData',[]);
      set(boot_alpha.bootstrapgraphmenu,'Enable','off','UserData',testfile);
   else;
      set(boot_alpha.bootstrapgraph,'Enable','off','UserData',[]);
      set(boot_alpha.bootstrapgraphmenu,'Enable','off','UserData','');
   end;
   %
   set(boot_alpha.fullmenu,'Enable',full_enable,'UserData',full_mat);
   set(boot_alpha.full,'Enable',full_enable);
   summary_txt = '';
   if tm.const_model(1)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-summary-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.txt'];
   elseif tm.const_model(2)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-summary-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
   elseif tm.const_model(3)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-summary-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
   elseif tm.const_model(4)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-summary-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
   elseif tm.const_model(5)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-summary-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
   end;
%   if curr_ini.texoutputformat>=2;
%      summary_txt = strrep(summary_txt,'.txt','.ltx');
%   end;
   if fileexist(summary_txt)==1;
      summary_enable = 'on';
   else;
      summary_txt = '';
      summary_enable = 'off';
   end;
   if curr_ini.noprint==0;
      set(boot_alpha.output,'Enable',summary_enable);
   end;
   set(boot_alpha.summarymenu,'Enable',summary_enable,'UserData',summary_txt);
   set(boot_alpha.summary,'Enable',summary_enable);
   set(alpha_boot_gui,'UserData',boot_alpha);
case 'summary'
   set(alpha_boot_gui,'Visible','off');
   drawnow;
   file = lower(get(boot_alpha.summarymenu,'UserData'));
   prtgui = printgui('init',file,'Structural VAR - Alpha, Delta, Gamma Bootstrap Simulation Summary',[(tm.realscrsz(3)-700)/2 (tm.realscrsz(4)-500)/2 700 500],'Results',40);
   myprint = get(prtgui,'UserData');
   set(myprint.print,'UserData','done');
   killguipid(prtgui);
   set(alpha_boot_gui,'Visible','on');
   drawnow;
   set(alpha_boot_gui,'UserData',boot_alpha);
case 'full'
   set(alpha_boot_gui,'Visible','off');
   drawnow;
   rep = get(boot_alpha.rep,'UserData');
   full_mat = lower(get(boot_alpha.fullmenu,'UserData'));
   param_vec_sorted = get(boot_alpha.histogram,'UserData');
   my_T = get(boot_alpha.obs,'UserData');
   %
   sp_str = spacestr(curr_ini.decimals-2);
   prt_val = ['%' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
   prt_str = '%7.0f';
   head_str = ' Number';
   if tm.dfalpha>0;
      if curr_ini.sscorrect==1;
         head_str = [head_str sp_str sprintf('  F(%2.0f,%3.0f)',tm.dfalpha,my_T-tm.df)];
      else;
         head_str = [head_str sp_str sprintf('     LR(%2.0f)',tm.dfalpha)];
      end;
      prt_str = [prt_str '   ' prt_val];
   end;
   se_Theta = get(boot_alpha.summary,'UserData');
   num = 1;
   if tm.d+tm.dcoint>0;
      for i=1:tm.d+tm.dcoint;
         for j=1:tm.n;
            if se_Theta(1,num)>1.0e-008;
               head_str = [head_str sp_str sprintf('   delta(%2.0f,%2.0f)',j,i)];
               prt_str = [prt_str '       ' prt_val];
            end;
            num = num+1;
         end;
      end;
   end;
   if tm.p>1;
      for i1=1:tm.p-1;
         for i=1:tm.n;
            for j=1:tm.n;
               if se_Theta(1,num)>1.0e-008;
                  head_str = [head_str sp_str sprintf(' Gamma(%2.0f,%2.0f;%2.0f)',j,i,i1)];
                  prt_str = [prt_str '        ' prt_val];
               end;
               num = num+1;
            end;
         end;
      end;
   end;
   if (tm.q1>0)&(tm.pe>0);
      for i1=0:tm.pe-1;
         for i=1:tm.q1;
            for j=1:tm.n;
               if se_Theta(1,num)>1.0e-008;
                  head_str = [head_str sp_str sprintf('   Psi(%2.0f,%2.0f;%2.0f)',j,i,i1)];
                  prt_str = [prt_str '        ' prt_val];
               end;
               num = num+1;
            end;
         end;
      end;
   end;
   if tm.q0>0;
      for i1=0:tm.pe;
         for i=1:tm.q0;
            for j=1:tm.n;
               if se_Theta(1,num)>1.0e-008;
                  head_str = [head_str sp_str sprintf('   Phi(%2.0f,%2.0f;%2.0f)',j,i,i1)];
                  prt_str = [prt_str '        ' prt_val];
               end;
               num = num+1;
            end;
         end;
      end;
   end;
   if tm.r>0;
      for i=1:tm.r;
         for j=1:tm.n;
            if se_Theta(1,num)>1.0e-008;
               head_str = [head_str sp_str sprintf('   alpha(%2.0f,%2.0f)',j,i)];
               prt_str = [prt_str '       ' prt_val];
            end;
            num = num+1;
         end;
      end;
   end;
   %
   my_text = strvcat(' ',head_str,' ');
   abort = '';
   if rep>=5000;
      input_var.title = ['Progress for ' int2str(rep) ' replications'];
      input_var.facecolor = curr_ini.progress_facecolor;
      input_var.startfacecolor = curr_ini.progress_startfacecolor;
      input_var.edgecolor = curr_ini.progress_edgecolor;
      input_var.bgcolor = curr_ini.progress_bgcolor;
      input_var.label = 'Replication number:';
      input_var.stop = 0;
      input_var.clock = 1;
      input_var.name = ['Data in ' getname(full_mat)];
      mywait = progressdlg(0,input_var);
%      set(mywait,'Name',['Data in ' getname(full_mat)]);
      set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
      drawnow;
   end;
   alpha_mat = load(full_mat);
   my_data = alpha_mat.Number;
   if isempty(alpha_mat.alpha_sorted)==0;
      my_data = [my_data alpha_mat.alpha_sorted];
   end;
   my_data = [my_data alpha_mat.param_vec_sorted];
   for i=1:size(my_data,1);
      if rep>=5000;
         abort = get(mywait,'UserData');
         if strcmp(abort,'cancel')==1;
            break;
         else;
            progressdlg([(i/rep) i]);
         end;
      end;
      my_text = strvcat(my_text,sprintf(prt_str,my_data(i,:)'));
   end;
   my_text = strvcat(my_text,' ');
   if rep>=5000;
      set(mywait,'UserData','done');
      close(mywait);
      drawnow;
   end;
   if strcmp(abort,'cancel')==0;
      textgui(my_text,'Structural VAR - Alpha, Delta, Gamma Bootstrap Simulation',[(tm.realscrsz(3)-700)/2 (tm.realscrsz(4)-500)/2 700 500],'Results',40);
   end;
   set(alpha_boot_gui,'Visible','on');
   drawnow;
   set(alpha_boot_gui,'UserData',boot_alpha);
case 'display'
   alpha_sorted = get(boot_alpha.display,'UserData');
   param_vec_sorted = get(boot_alpha.histogram,'UserData');
   param_t_dist = get(boot_alpha.full,'UserData');
   vec_Theta = get(boot_alpha.clock,'UserData');
   se_Theta = get(boot_alpha.summary,'UserData');
   pos = [(tm.realscrsz(3)-600)/2 (tm.realscrsz(4)-400)/2];
   rep = get(boot_alpha.rep,'UserData');
   my_T = get(boot_alpha.obs,'UserData');
   %
   % check graph type
   %
   gr_str = get(boot_alpha.graphtype,'String');
   gr_val = get(boot_alpha.graphtype,'Value');
   gr_type = strtrim(gr_str(gr_val,:));
   %
   % trim parameter distributions
   %
   trim_val = get(boot_alpha.trim_estimates,'Value');
   if trim_val>1;
      trim_str = get(boot_alpha.trim_estimates,'String');
      trim_p = strrep(trim_str(trim_val,:),'%','');
      trim_p = mystr2num(trim_p)/200;
      b_val = ceil(trim_p*rep)+1;
      t_val = rep+1-b_val;
   else;
      b_val = 1;
      t_val = rep;
   end;
   %
   % need to fix the rest
   %
   my_const_model = get(boot_alpha.displaymenu,'UserData');
   if my_const_model(1)==1;
      this_mod = '(no constant)';
   elseif my_const_model(2)==1;
      this_mod = '(restricted constant)';
   elseif my_const_model(3)==1;
      this_mod = '(constant)';
   elseif my_const_model(4)==1;
      this_mod = '(restricted trend)';
   elseif my_const_model(5)==1;
      this_mod = '(trend)';
   end;
   cell_value = get(boot_alpha.cells,'Value');
   cell_vec = [20 25 30 35 40 45 50 55 60 65 70 75 80 85 90 95 100];
   numcells = cell_vec(cell_value);
   my_80 = floor(0.8*rep);
   my_90 = floor(0.9*rep);
   my_95 = floor(0.95*rep);
   my_975 = floor(0.98*rep);
   my_99 = floor(0.99*rep);
   if curr_ini.colors==1;
      c_vec_1 = [0 0 1];
      c_vec_2 = [1 0 0];
      c_vec_3 = [0 0.75 0];
      c_vec_4 = [1 0.5 0];
      c_vec_5 = [0 0.75 0.75];
      c_vec_6 = [0 0 0];
      c_vec_7 = (1/255)*[255 28 28];
      c_vec_8 = [0 1 0];
   else;
      c_vec_1 = [0 0 0];
      c_vec_2 = [0.7 0.7 0.7];
      c_vec_3 = [0.6 0.6 0.6];
      c_vec_4 = [0.5 0.5 0.5];
      c_vec_5 = [0.4 0.4 0.4];
      c_vec_6 = [0.3 0.3 0.3];
      c_vec_7 = [0.8 0.8 0.8];
      c_vec_8 = [0.2 0.2 0.2];
   end;
   cdf_value = get(boot_alpha.cdf,'Value');
   %
   if curr_ini.colors==1;
      col.vec_1 = [0 0 1];
      col.vec_2 = [1 0 0];
      col.vec_3 = [0 0.75 0];
      col.vec_4 = [1 0.5 0];
      col.vec_5 = [0 0.75 0.75];
      col.vec_6 = [0 0 0];
      col.vec_7 = (1/255)*[255 28 28];
      col.vec_8 = [0 1 0];
      col.vec_9 = (1/255)*[255 255 177];
   else;
      col.vec_1 = [0 0 0];
      col.vec_2 = [0.7 0.7 0.7];
      col.vec_3 = [0.6 0.6 0.6];
      col.vec_4 = [0.5 0.5 0.5];
      col.vec_5 = [0.4 0.4 0.4];
      col.vec_6 = [0.3 0.3 0.3];
      col.vec_7 = [0.8 0.8 0.8];
      col.vec_8 = [0.2 0.2 0.2];
      col.vec_9 = col.vec_3;
   end;
   %
   if ((strcmp(gr_type,'LR-test')==1)|(strcmp(gr_type,'All')==1))&(isempty(alpha_sorted)==0);
      alpha_series = [];
      %
      if (gcbo==boot_alpha.display)|(gcbo==boot_alpha.displaymenu);
         if curr_ini.sscorrect==1;
            df = [tm.dfalpha (my_T-tm.df)];
         else;
            df = tm.dfalpha;
         end;
         [alpha_series,alpha_quant,alpha_table] = asymp_series(df,curr_ini.sscorrect);
         if get(boot_alpha.pq_plot,'Value')==1;
            [p_series,pp_series,qq_series] = pq_plot_series(alpha_sorted,alpha_quant,alpha_table,df,curr_ini.sscorrect);
         end;
      end;
      %
      if curr_ini.sscorrect==1;
         add_name = ['F(' num2str(tm.dfalpha,'%0.0f') ',' num2str(my_T-tm.df,'%0.0f') ')'];
      else;
         add_name = ['LR(' num2str(tm.dfalpha,'%0.0f') ')'];
      end;
      %
      if ((gcbo==boot_alpha.display)|(gcbo==boot_alpha.displaymenu))&(get(boot_alpha.pq_plot,'Value')==1);
         [pos,newplot] = pq_plot(pos,'alpha-test-pqplot-',['P-value and Quantile Plots for ' add_name ' Test'],['P-value plot of ' add_name],['P-value discrepancy plot of ' add_name],['PP plot of ' add_name],['QQ plot of ' add_name],tm,alpha_quant,alpha_table,p_series,pp_series,qq_series,col);
      end;
      [pos,thisplot] = dist_plot(pos,'alpha-test-plot-',['Density for ' add_name ' Test'],[add_name ' alpha test ' this_mod ' with ' num2str(tm.n) ' variables and ' num2str(tm.r) ' cointegration vectors'],tm,curr_ini,boot_alpha,alpha_sorted,alpha_series,1,0,0,col,my_80,my_90,my_95,my_975,my_99,numcells,df);
   end;
   param_plots = [];
   %
   % check if we should make any parameter plots at all. if we should, then
   % construct a series with asymptotic t-values
   %
   if (strcmp(gr_type,'LR-test')==0)&(isempty(param_t_dist)==0)&(get(boot_alpha.bootdist,'Value')==1)&(gcbo~=boot_alpha.histogram)&(gcbo~=boot_alpha.histogrammenu);
      t_series = gauss_dist_series;
   else;
      t_series = [];
   end;
   %
   % delta parameters
   %
   p_num = 1;
   e_num = 1;
   if tm.d+tm.dcoint>0;
      for i=1:tm.d+tm.dcoint;
         for j=1:tm.n;
            if se_Theta(1,e_num)>1.0e-008;
               if (strcmp(gr_type,'delta (deterministic)')==1)|(strcmp(gr_type,'All')==1);
                  if get(boot_alpha.bootdist,'Value')==2;
                     %
                     % using parameter distribution
                     %
                     [pos,param_plot] = parm_dist(pos,['delta-' num2str(j,'%0.0f') '.' num2str(i,'%0.0f') '-plot-'],['Density for delta(' num2str(j,'%0.0f') ',' num2str(i,'%0.0f') ') parameter (bootstrapped delta)'],['Bootstrapped \delta_{' num2str(j,'%0.0f') num2str(i,'%0.0f') '} with ' num2str(tm.cbs) '% confidence interval from bootstrapped \delta distribution'],vec_Theta(1,e_num),vec_Theta(1,e_num),se_Theta(1,e_num),tm,curr_ini,boot_alpha,my_T,[],param_vec_sorted(b_val:t_val,p_num),1,numcells,col,rep);
                  else;
                     %
                     % using t-distribution
                     %
                     [pos,param_plot] = parm_dist(pos,['delta-' num2str(j,'%0.0f') '.' num2str(i,'%0.0f') '-plot-'],['Density for delta(' num2str(j,'%0.0f') ',' num2str(i,'%0.0f') ') parameter (bootstrapped t-value)'],['Bootstrapped \delta_{' num2str(j,'%0.0f') num2str(i,'%0.0f') '} with ' num2str(tm.cbs) '% confidence interval from bootstrapped t-statistic distribution'],vec_Theta(1,e_num),vec_Theta(1,e_num),se_Theta(1,e_num),tm,curr_ini,boot_alpha,my_T,t_series,param_t_dist(:,p_num),1,numcells,col,rep);
                  end;
                  param_plots = [param_plots param_plot];
               end;
               p_num = p_num+1;
            end;
            e_num = e_num+1;
         end;
      end;
   end;
   %
   % Gamma parameters
   %
   if tm.p>1;
      for i1=1:tm.p-1;
         for i=1:tm.n;
            for j=1:tm.n;
               if se_Theta(1,e_num)>1.0e-008;
                  if (strcmp(gr_type,'Gamma (lagged endogenous)')==1)|(strcmp(gr_type,'All')==1);
                     if get(boot_alpha.bootdist,'Value')==2;
                        %
                        % using parameter distribution
                        %
                        [pos,param_plot] = parm_dist(pos,['gamma-' num2str(j,'%0.0f') '.' num2str(i,'%0.0f') '.' num2str(i1) '-plot-'],['Density for Gamma(' num2str(j,'%0.0f') ',' num2str(i,'%0.0f') ') parameter for lag ' num2str(i1) ' (bootstrapped Gamma)'],['Bootstrapped \Gamma_{' num2str(j,'%0.0f') num2str(i,'%0.0f') '} for lag ' num2str(i1) ' with ' num2str(tm.cbs) '% confidence interval from bootstrapped \Gamma distribution'],vec_Theta(1,e_num),vec_Theta(1,e_num),se_Theta(1,e_num),tm,curr_ini,boot_alpha,my_T,[],param_vec_sorted(b_val:t_val,p_num),1,numcells,col,rep);
                     else;
                        %
                        % using t-distribution
                        %
                        [pos,param_plot] = parm_dist(pos,['gamma-' num2str(j,'%0.0f') '.' num2str(i,'%0.0f') '.' num2str(i1) '-plot-'],['Density for Gamma(' num2str(j,'%0.0f') ',' num2str(i,'%0.0f') ') parameter for lag ' num2str(i1) ' (bootstrapped t-value)'],['Bootstrapped \Gamma_{' num2str(j,'%0.0f') num2str(i,'%0.0f') '} for lag ' num2str(i1) ' with ' num2str(tm.cbs) '% confidence interval from bootstrapped t-statistic distribution'],vec_Theta(1,e_num),vec_Theta(1,e_num),se_Theta(1,e_num),tm,curr_ini,boot_alpha,my_T,t_series,param_t_dist(:,p_num),1,numcells,col,rep);
                     end;
                     param_plots = [param_plots param_plot];
                  end;
                  p_num = p_num+1;
               end;
               e_num = e_num+1;
            end;
         end;
      end;
   end;
   %
   % Psi parameters
   %
   if (tm.q1>0)&(tm.pe>0);
      for i1=0:tm.pe-1;
         for i=1:tm.q1;
            for j=1:tm.n;
               if se_Theta(1,e_num)>1.0e-008;
                  if (strcmp(gr_type,'Psi (exogenous I(1))')==1)|(strcmp(gr_type,'All')==1);
                     if get(boot_alpha.bootdist,'Value')==2;
                        %
                        % using parameter distribution
                        %
                        [pos,param_plot] = parm_dist(pos,['psi-' num2str(j,'%0.0f') '.' num2str(i,'%0.0f') '.' num2str(i1) '-plot-'],['Density for Psi(' num2str(j,'%0.0f') ',' num2str(i,'%0.0f') ') parameter for lag ' num2str(i1) ' (bootstrapped Psi)'],['Bootstrapped \Psi_{' num2str(j,'%0.0f') num2str(i,'%0.0f') '} for lag ' num2str(i1) ' with ' num2str(tm.cbs) '% confidence interval from bootstrapped \Psi distribution'],vec_Theta(1,e_num),vec_Theta(1,e_num),se_Theta(1,e_num),tm,curr_ini,boot_alpha,my_T,[],param_vec_sorted(b_val:t_val,p_num),1,numcells,col,rep);
                     else;
                        %
                        % using t-distribution
                        %
                        [pos,param_plot] = parm_dist(pos,['psi-' num2str(j,'%0.0f') '.' num2str(i,'%0.0f') '.' num2str(i1) '-plot-'],['Density for Psi(' num2str(j,'%0.0f') ',' num2str(i,'%0.0f') ') parameter for lag ' num2str(i1) ' (bootstrapped t-value)'],['Bootstrapped \Psi_{' num2str(j,'%0.0f') num2str(i,'%0.0f') '} for lag ' num2str(i1) ' with ' num2str(tm.cbs) '% confidence interval from bootstrapped t-statistic distribution'],vec_Theta(1,e_num),vec_Theta(1,e_num),se_Theta(1,e_num),tm,curr_ini,boot_alpha,my_T,t_series,param_t_dist(:,p_num),1,numcells,col,rep);
                     end;
                     param_plots = [param_plots param_plot];
                  end;
                  p_num = p_num+1;
               end;
               e_num = e_num+1;
            end;
         end;
      end;
   end;
   %
   % Phi parameters
   %
   if tm.q0>0;
      for i1=0:tm.pe;
         for i=1:tm.q0;
            for j=1:tm.n;
               if se_Theta(1,e_num)>1.0e-008;
                  if (strcmp(gr_type,'Phi (exogenous I(0))')==1)|(strcmp(gr_type,'All')==1);
                     if get(boot_alpha.bootdist,'Value')==2;
                        %
                        % using parameter distribution
                        %
                        [pos,param_plot] = parm_dist(pos,['phi-' num2str(j,'%0.0f') '.' num2str(i,'%0.0f') '.' num2str(i1) '-plot-'],['Density for Phi(' num2str(j,'%0.0f') ',' num2str(i,'%0.0f') ') parameter for lag ' num2str(i1) ' (bootstrapped Phi)'],['Bootstrapped \Phi_{' num2str(j,'%0.0f') num2str(i,'%0.0f') '} for lag ' num2str(i1) ' with ' num2str(tm.cbs) '% confidence interval from bootstrapped \Phi distribution'],vec_Theta(1,e_num),vec_Theta(1,e_num),se_Theta(1,e_num),tm,curr_ini,boot_alpha,my_T,[],param_vec_sorted(b_val:t_val,p_num),1,numcells,col,rep);
                     else;
                        %
                        % using t-distribution
                        %
                        [pos,param_plot] = parm_dist(pos,['phi-' num2str(j,'%0.0f') '.' num2str(i,'%0.0f') '.' num2str(i1) '-plot-'],['Density for Phi(' num2str(j,'%0.0f') ',' num2str(i,'%0.0f') ') parameter for lag ' num2str(i1) ' (bootstrapped t-value)'],['Bootstrapped \Phi_{' num2str(j,'%0.0f') num2str(i,'%0.0f') '} for lag ' num2str(i1) ' with ' num2str(tm.cbs) '% confidence interval from bootstrapped t-statistic distribution'],vec_Theta(1,e_num),vec_Theta(1,e_num),se_Theta(1,e_num),tm,curr_ini,boot_alpha,my_T,t_series,param_t_dist(:,p_num),1,numcells,col,rep);
                     end;
                     param_plots = [param_plots param_plot];
                  end;
                  p_num = p_num+1;
               end;
               e_num = e_num+1;
            end;
         end;
      end;
   end;
   %
   % alpha parameters
   %
   if tm.r>0;
      for i=1:tm.r;
         for j=1:tm.n;
            if se_Theta(1,e_num)>1.0e-008;
               if (strcmp(gr_type,'alpha')==1)|(strcmp(gr_type,'All')==1);
                  if get(boot_alpha.bootdist,'Value')==2;
                     %
                     % using parameter distribution
                     %
                     [pos,param_plot] = parm_dist(pos,['alpha-' num2str(j,'%0.0f') '.' num2str(i,'%0.0f') '-plot-'],['Density for alpha(' num2str(j,'%0.0f') ',' num2str(i,'%0.0f') ') parameter (bootstrapped alpha)'],['Bootstrapped \alpha_{' num2str(j,'%0.0f') num2str(i,'%0.0f') '} with ' num2str(tm.cbs) '% confidence interval from bootstrapped \alpha distribution'],vec_Theta(1,e_num),vec_Theta(1,e_num),se_Theta(1,e_num),tm,curr_ini,boot_alpha,my_T,[],param_vec_sorted(b_val:t_val,p_num),1,numcells,col,rep);
                  else;
                     %
                     % using t-distribution
                     %
                     [pos,param_plot] = parm_dist(pos,['alpha-' num2str(j,'%0.0f') '.' num2str(i,'%0.0f') '-plot-'],['Density for alpha(' num2str(j,'%0.0f') ',' num2str(i,'%0.0f') ') parameter (bootstrapped t-value)'],['Bootstrapped \alpha_{' num2str(j,'%0.0f') num2str(i,'%0.0f') '} with ' num2str(tm.cbs) '% confidence interval from bootstrapped t-statistic distribution'],vec_Theta(1,e_num),vec_Theta(1,e_num),se_Theta(1,e_num),tm,curr_ini,boot_alpha,my_T,t_series,param_t_dist(:,p_num),1,numcells,col,rep);
                  end;
                  param_plots = [param_plots param_plot];
               end;
               p_num = p_num+1;
            end;
            e_num = e_num+1;
         end;
      end;
   end;
   %
   % Display plots
   %
   if curr_ini.external==0;
      if (strcmp(gr_type,'LR-test')==1)|(strcmp(gr_type,'All')==1);
         if ((gcbo==boot_alpha.display)|(gcbo==boot_alpha.displaymenu))&(get(boot_alpha.pq_plot,'Value')==1);
            set(newplot,'Visible','on');
         end;
         set(thisplot,'Visible','on');
      end;
      if isempty(param_plots)==0;
         set(param_plots,'Visible','on');
      end;
   else;
      stats = [];
      file_names = '';
      if (strcmp(gr_type,'LR-test')==1)|(strcmp(gr_type,'All')==1);
         this_mod = strrep(this_mod,'(','');
         this_mod = strrep(this_mod,')','');
         this_mod = strtrim(this_mod);
         this_mod = strrep(this_mod,' ','.');
         if (gcbo==boot_alpha.histogram)|(gcbo==boot_alpha.histogrammenu);
            file = [curr_ini.simulatedir tm.modelfile tm.testtype '-alpha-hist-boot-' num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-' this_mod];
            file2 = '';
         else;
            file = [curr_ini.simulatedir tm.modelfile tm.testtype '-alpha-boot-' num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-' this_mod];
            if get(boot_alpha.pq_plot,'Value')==1;
               file2 = [curr_ini.simulatedir tm.modelfile tm.testtype '-alpha-boot-pqplots-' num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-' this_mod];
            else;
               file2 = '';
            end;
         end;
         if strcmp(file2,'')==0;
            set(0,'CurrentFigure',newplot);
            stats = autosavefigure(newplot,file2);
            %
            set(0,'CurrentFigure',thisplot);
            stats = [stats autosavefigure(thisplot,file)];
            file_names = strvcat(file2,file);
         else;
            set(0,'CurrentFigure',thisplot);
            stats = autosavefigure(thisplot,file);
            file_names = file;
         end;
      end;
      if isempty(param_plots)==0;
         for i=1:size(param_plots,2);
            file = [curr_ini.simulatedir tm.modelfile '-' get(param_plots(1,i),'Tag') num2str(my_T) '.' num2str(rep) '.' num2str(tm.r)];
            set(0,'CurrentFigure',param_plots(1,i));
            mstat = autosavefigure(param_plots(1,i),file);
            stats = [stats mstat];
            file_names = strvcat(file_names,file);
         end;
      end;
      if isempty(stats)==0;
         for i=1:size(stats,2);
            if stats(i)==0;
               autoshowfigure(strtrim(file_names(i,:)));
               wait_fcn(100);
            end;
         end;
      end;
   end;
   clear('alpha_sorted','param_vec_sorted','param_t_dist','vec_Theta','se_Theta');
   set(alpha_boot_gui,'UserData',boot_alpha);
   %
   % case simulate
   %
case 'simulate'
   tm.beta_run = 1;
   set(alpha_boot_gui,'Visible','off');
   drawnow;
   %
   % check identification
   %
   if tm.restrict(1,2)==1;
      status = testident(tm.modelsdir,tm.modelfile,tm.r,tm.n,tm.dcoint,tm.q1);
   else;
      status = ones(1,tm.r);
   end;
   %
   if sum(status)==tm.r;
      %
      % collect values
      %
      T_str = get(boot_alpha.obs,'String');
      my_T = mystr2num(strtrim(T_str(get(boot_alpha.obs,'Value'),:)));
      repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
      rep_val = get(boot_alpha.rep,'Value');
      rep = repvalues(rep_val);
      set(boot_alpha.simulate,'UserData',rep);
      blocksize = get(boot_alpha.block,'Value');
      block_txt = '';
      if blocksize>1;
         block_txt = ['Applying block bootstrap with block length ' num2str(blocksize,'%0.0f') '...'];
      end;
      if get(boot_alpha.parametric,'Value')==1;
         bootstyle = '';
      else;
         bootstyle = ['np' num2str(get(boot_alpha.block,'Value')) '-'];
      end;
      %
      trim_val = get(boot_alpha.trim_estimates,'Value');
      if trim_val>1;
         trim_str = get(boot_alpha.trim_estimates,'String');
         trim_p = strrep(trim_str(trim_val,:),'%','');
         trim_p = mystr2num(trim_p)/200;
         low_bval = ceil(trim_p*rep)+1;
         high_bval = rep+1-low_bval;
      else;
         low_bval = 1;
         high_bval = rep;
      end;
      %
      % initialize
      %
      if tm.dfalpha>0;
         alpha_test = zeros(rep,1);
      else;
         alpha_test = [];
      end;
      %
      % Original parameters
      %
      Theta = [tm.Psi tm.alpha];
      if (tm.deterselect(1,2)==1)|(tm.deterselect(1,4)==1);
         [theta,sigma_theta] = fix_params(Theta,tm.Sigma_theta,tm.beta,tm.d);
      else;
         theta = Theta;
         sigma_theta = tm.Sigma_theta;
      end;
      %
      tm.se_param = sqrt(abs(diag(sigma_theta)))';
      tm.vecTheta = vec(theta)';
      ch = tm.se_param(tm.se_param>1.0e-008);
      if isempty(ch)==0;
         param_vec = zeros(rep,size(tm.se_param(tm.se_param>1.0e-008),2));
         param_t_dist = param_vec;
      else;
         param_vec = [];
         param_t_dist = [];
      end;
      if curr_ini.symmetric==0;
         Omega_sig = chol(tm.Omega)';
      else;
         Omega_sig = symm(tm.Omega);
      end;
      abort = '';
      draw = 1;
      showprog = get(boot_alpha.progress,'Value');
      if showprog==1;
         input_var.title = ['Progress for ' int2str(rep) ' replications'];
         input_var.facecolor = curr_ini.progress_facecolor;
         input_var.startfacecolor = curr_ini.progress_startfacecolor;
         input_var.edgecolor = curr_ini.progress_edgecolor;
         input_var.bgcolor = curr_ini.progress_bgcolor;
         input_var.clock = get(boot_alpha.clock,'Value');
         input_var.label = 'Replication number:';
         input_var.stop = 0;
         mywait = progressdlg(0,input_var);
         set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
      else;
         this_text = strvcat('Bootstrapping. The art of pulling oneself up by the bootstraps. Attempt started at...',' ',['Time: ' datestr(now,14)],' ','Please hold!');
         mywait = waitdlg(this_text,'bootstrap','Alpha, Delta, Gamma Bootstrap Simulation');
         waitf = get(mywait,'UserData');
         tic;
      end;
      if tm.const_model(2)==1;
         setlogtext(strvcat(' ','Bootstrapping distributions for alpha, delta, Gamma...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Restricted constant',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(tm.r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
         if showprog==1;
            set(mywait,'Name',['Restricted constant model with ' num2str(my_T,'%0.0f') ' obs']);
            drawnow;
         end;
         mod_type = 'resconst';
      elseif tm.const_model(3)==1;
         setlogtext(strvcat(' ','Bootstrapping distributions for alpha, delta, Gamma...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Unrestricted constant',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(tm.r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
         if showprog==1;
            set(mywait,'Name',['Constant model with ' num2str(my_T,'%0.0f') ' obs']);
            drawnow;
         end;
         mod_type = 'const';
      elseif tm.const_model(4)==1;
         setlogtext(strvcat(' ','Bootstrapping distributions for alpha, delta, Gamma...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Restricted linear trend',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(tm.r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
         if showprog==1;
            set(mywait,'Name',['Restricted trend model with ' num2str(my_T,'%0.0f') ' obs']);
            drawnow;
         end;
         mod_type = 'restrend';
      elseif tm.const_model(5)==1;
         setlogtext(strvcat(' ','Bootstrapping distributions for alpha, delta, Gamma...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Linear trend',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(tm.r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
         if showprog==1;
            set(mywait,'Name',['Linear trend model with ' num2str(my_T,'%0.0f') ' obs']);
            drawnow;
         end;
         mod_type = 'trend';
      end;
      epsfile = [curr_ini.simulatedir tm.modelfile '-' 'alpha-epsilon-' num2str(tm.scale_endo,'%0.4f') '-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '-' num2str(rep) '-' mod_type '.mat'];
      if get(boot_alpha.bootstrap,'Value')==1;
         %
         % epsilon-file
         %
         if fileexist(epsfile)==1;
            load_eps = 1;
            %
            % load old epsilons
            %
            eps_data = load(epsfile);
         else;
            load_eps = 0;
         end;
      else;
         load_eps = 0;
      end;
      %
      % replicating
      %
      while (draw<=rep);  % should be until rep
         if showprog==1;
            abort = get(mywait,'UserData');
            if strcmp(abort,'cancel')==1;
               break;
            else;
               progressdlg([(draw/rep) draw]);
            end;
         end;
         %
         % check for bootstrap style
         %
         if load_eps==0;
            if get(boot_alpha.parametric,'Value')==1;
               %
               % reset the random number generator
               %
               if curr_ini.random_state==2;
                  randn('state',draw);
               elseif curr_ini.random_state==3;
                  randn('state',sum(100*clock));
               elseif curr_ini.random_state==4;
                  randn('state',sum(100*clock)+draw);
               end;
               %
               Epr = randn(tm.n,my_T+50);
               Epr = Epr(:,51:my_T+50);
               %
               % make sure draws in Epr have identity covariance matrix
               %
               Sig = (1/my_T)*Epr*Epr';
               P_sig = chol(Sig)';
               Epr = P_sig\Epr;
               Epr = Omega_sig*Epr;
            else;
               %
               % reset the random number generator
               %
               if curr_ini.random_state==2;
                  rand('state',draw);
               elseif curr_ini.random_state==3;
                  rand('state',sum(100*clock));
               elseif curr_ini.random_state==4;
                  rand('state',sum(100*clock)+draw);
               end;
               %
               % resample from estimated epsilons
               %
               uni_draws = rand([1 my_T+50]);
               uni_draws = uni_draws(1,51:my_T+50);
               Epr = boot_draw(uni_draws,tm.epsilon,blocksize);
            end;
            if get(boot_alpha.bootstrap,'Value')==1;
               bootstrap(draw).epsilon = Epr;
            end;
         else;
            Epr = eps_data.bootstrap(draw).epsilon;
         end;
         %
         % create new sample
         %
         boot = bootstrap_sample(tm,tm.beta,Epr);
         %
         % Computing tests
         %
         [S_00,S_01,S_10,S_11,M_02,M_22,M_12,beta,lambda,trace_test] = mlcointbasic(boot.Z0,boot.Z1,boot.Z2,tm.r);
         if tm.restrict(1,2)==1;
            [beta,newlambda,newdfbeta,stdbeta,outputtxt,new_abort] = betarestrict(S_00,S_11,S_01,S_10,beta,my_T,tm.modelsdir,tm.modelfile,0,tm.dcoint);
         end;
         %
         % compute alpha, Psi, and epsilon
         %
         alpha = (S_01*beta)/(beta'*S_11*beta);
         if isempty(boot.Z2)==0;
            Psi = (M_02/M_22)-(alpha*beta'*(M_12/M_22));
            Z3 = [boot.Z2;beta'*boot.Z1];
         else;
            Psi = [];
            Z3 = beta'*boot.Z1;
         end;
         Theta = [Psi alpha];
         epsilon = boot.Z0-(Theta*Z3);
         Omega = (1/my_T)*epsilon*epsilon';
         Sigma_theta = kron(inverse(Z3*Z3'),Omega);
         %
         % compute alpha, Psi, under restrictions
         %
         if tm.restrict(1,1)==1;
            if draw==1;
               file = strcat(tm.modelsdir,'G-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
               G = loaddata(file);
               [Rmat,rvec] = rmatrix(G,tm.n,tm.r);
               if isempty(boot.Z2)==0;
                  Rmat = [zeros(tm.dfalpha,size(boot.Z2,1)*tm.n) Rmat];
               end;
            end;
            %
            % now we estimate under alpha restrictions
            %
            if curr_ini.reestbeta==0;
               [Theta,Sigma_theta,infomat,new_abort] = linrest(boot.Z0,Z3,Theta,Rmat,rvec,0);
            else;
               [Theta,Sigma_theta,beta,newstdbeta,Z3,infomat,new_abort] = alpha_beta_restrict(boot.Z0,boot.Z1,boot.Z2,Z3,beta,Theta,Rmat,rvec,tm.dcoint,tm.q1,tm.modelsdir,tm.modelfile,0);
            end;
            epsilon = boot.Z0-(Theta*Z3);
            resOmega = (1/my_T)*epsilon*epsilon';
            %
            % compute the LR-test
            %
            LR = my_T*log(det(resOmega)/det(Omega));
            Omega = resOmega;
            if curr_ini.sscorrect==1;
               LR = ((my_T-tm.df)/(my_T*tm.dfalpha))*LR;
            end;
            alpha_test(draw,1) = LR;
         end;
         %
         % Estimate under C restrictions
         %
         if (size(tm.restrict,2)>2)&(tm.restrict(1,3)==1);
            if draw==1;
               file = strcat(tm.modelsdir,'C-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
               G = loaddata(file);
               [Rmat_C,rvec_C] = rmatrix(G,tm.n,tm.n);
            end;
            %
            [Theta,Sigma_theta,beta,stdbeta,C,Sigma_C,num_c_rest,num_a_rest,infomat,new_abort] = c_restrict(boot.Z0,boot.Z1,boot.Z2,tm.restrict,beta,Theta,Rmat_C,rvec_C,tm.p,tm.pe,tm.d,tm.dcoint,tm.q0,tm.q1,tm.modelsdir,tm.modelfile,0);
         end;
         %
         % Deal with potential restricted constants and trends - this affects Theta and Sigma_theta
         %
         if (tm.deterselect(1,2)==1)|(tm.deterselect(1,4)==1);
            [theta,sigma_theta] = fix_params(Theta,Sigma_theta,beta,tm.d);
         else;
            theta = Theta;
            sigma_theta = Sigma_theta;
         end;
         %
         % collect the results
         %
         if isempty(param_vec)==0;
            se_theta = sqrt(abs(diag(sigma_theta)))';
            vTheta = vec(theta)';
            vTheta = vTheta(tm.se_param>1.0e-008);
            param_vec(draw,:) = vTheta;
            param_t_dist(draw,:) = (vTheta-tm.vecTheta(tm.se_param>1.0e-008)) ./ se_theta(tm.se_param>1.0e-008);
         end;
         %
         % include param_t_dist values
         %
         draw = draw+1;
      end;
      %
      % bootstrap has finished
      %
      if showprog==1;
         set(mywait,'UserData','done');
         close(mywait);
         drawnow;
      else;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
         new_time = toc;
         my_hrs = '00';
         my_min = '00';
         my_sec = num2str(new_time,'%0.2f');
         if new_time>=60;
            ch_min = floor(new_time/60);
            my_sec = num2str(new_time-(ch_min*60),'%0.2f');
            my_min = num2str(ch_min,'%0.0f');
            if ch_min>=60;
               ch_hrs = floor(ch_min/60);
               my_min = num2str(ch_min-(ch_hrs*60),'%0.0f');
               my_hrs = num2str(ch_hrs,'%0.0f');
            end;
         end;
         if size(my_sec,2)==4;
            my_sec = ['0' my_sec];
         end;
         if size(my_min,2)==1;
            my_min = ['0' my_min];
         end;
         if size(my_hrs,2)==1;
            my_hrs = ['0' my_hrs];
         end;
         clock_str = [my_hrs ':' my_min ':' my_sec];
         this_text = strvcat('The bootstrapping process took:',' ',['    ' clock_str ' (hrs:min:sec)']);
         about(this_text,'bootstrap','Simulation Time',120,350);
      end;
      %
      % if we don't cancel
      %
      if (strcmp(abort,'cancel')==0)&(isempty(param_vec)==0);
         this_text = strvcat(' ','Saving bootstrap results to disk...','Please hold!');
         mywait = waitdlg(this_text,'bootstrap','Alpha, Delta, Gamma Bootstrap Simulation');
         waitf = get(mywait,'UserData');
         if get(boot_alpha.bootstrap,'Value')==1;
            if load_eps==0;
               this_text = strvcat(' ','Saving bootstrapped residuals to disk...','Please hold!');
               set(waitf.text,'String',this_text);
               save(epsfile,'bootstrap');
            end;
            clear('bootstrap');
            set(boot_alpha.bootstrapgraph,'Enable','on','UserData',epsfile);
            set(boot_alpha.bootstrapgraphmenu,'Enable','on');
         end;
         testfile = strrep(epsfile,'.mat',['-' 'alpha-data.mat']);
         test_data = alpha_test;
         %
         save(testfile,'test_data','param_vec','param_t_dist');
         %
         clear('test_data');
         set(boot_alpha.bootstrapgraphmenu,'UserData',testfile);
         %
         setlogtext(['Bootstrap simulation completed at: ' datestr(now,14) '!']);
         %
         % sort the test
         %
         if tm.dfalpha>0;
            alpha_sorted = sort(alpha_test);
         else;
            alpha_sorted = [];
         end;
         clear('alpha_test');
         %
         % sort the t-ratios
         %
         if isempty(param_vec)==0;
            for i=1:size(param_t_dist,2);
               param_t_dist(:,i) = sort(param_t_dist(:,i));
            end;
            param_vec_sorted = zeros(size(param_vec));
            for i=1:size(param_vec,2);
               param_vec_sorted(:,i) = sort(param_vec(:,i));
            end;
            clear('param_vec');
         else;
            param_vec_sorted = [];
         end;
         set(boot_alpha.rep,'UserData',rep);
         set(boot_alpha.obs,'UserData',my_T);
         set(boot_alpha.displaymenu,'Enable','on','UserData',tm.const_model);
         if tm.const_model(2)==1;
            my_mod = 'Restricted constant';
         elseif tm.const_model(3)==1;
            my_mod = 'Constant';
         elseif tm.const_model(4)==1;
            my_mod = 'Restricted linear trend';
         elseif tm.const_model(5)==1;
            my_mod = 'Linear trend';
         end;
         if curr_ini.sscorrect==1;
            add_test = 'F';
            add_str = [',' num2str(my_T-tm.df,'%0.0f')];
            test_str = ['F(' num2str(tm.dfalpha,'%0.0f') add_str ')'];
         else;
            add_test = 'LR';
            add_str = '';
            test_str = ['chi-square(' num2str(tm.dfalpha,'%0.0f') ')'];
         end;
         %
         % save full simulations
         %
         if get(boot_alpha.save,'Value')==1;
            this_text = strvcat(' ',['Saving bootstrapped beta estimates and ' add_test ' tests to disk...'],'Please hold!');
            set(waitf.text,'String',this_text);
            setlogtext('Saving results to mat-files...');
            if tm.const_model(1)==1;
               full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
            elseif tm.const_model(2)==1;
               full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
            elseif tm.const_model(3)==1;
               full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
            elseif tm.const_model(4)==1;
               full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
            elseif tm.const_model(5)==1;
               full_mat = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-full-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
            end;
            Number = (1:1:rep)';
            vec_Theta = tm.vecTheta;
            se_Theta = tm.se_param;
            save(full_mat,'Number','alpha_sorted','param_vec_sorted','param_t_dist','vec_Theta','se_Theta');
            set(boot_alpha.fullmenu,'Enable','on','UserData',full_mat);
            set(boot_alpha.full,'Enable','on');
         end;
         setlogtext('Saving simulation summary to text file...');
         %
         % dealing with the size of the test
         %
         boot_size = [];
         boot_pval = [];
         if tm.dfalpha>0;
            this_text = strvcat(' ',['Determining the empirical size of the ' add_test ' test...'],'Please hold!');
            set(waitf.text,'String',this_text);
            if curr_ini.sscorrect==1;
               my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],tm.dfalpha*ones(5,1),(my_T-tm.df)*ones(5,1));
            else;
               my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],tm.dfalpha*ones(5,1));
            end;
            for i=1:5;
               for j=1:rep;
                  if my_cv(i,1)>=alpha_sorted(rep+1-j,1);
                     break;
                  end;
               end;
               if (j<rep)|(my_cv(i,1)>=alpha_sorted(1,1));
                  boot_size = [boot_size (rep+1-j)/rep];
               else;
                  boot_size = [boot_size 0];
               end;
            end;
            if tm.T==my_T;
               this_text = strvcat(' ',['Determining the empirical p-value of the ' add_test ' test...'],'Please hold!');
               set(waitf.text,'String',this_text);
               for j=1:rep;
                  if tm.LRalpha>=alpha_sorted(rep+1-j);
                     break;
                  end;
               end;
               if j<rep;
                  boot_pval = (j-1)/rep;
               else;
                  boot_pval = 1;
               end;
            end;
         end;
         this_text = strvcat(' ','Writing bootstrap summary information to disk...','Please hold!');
         set(waitf.text,'String',this_text);
         %
         % write summary to file
         %
         sp_str = spacestr(curr_ini.decimals-2);
         prt_val = ['%' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
         prt_tex = ['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'];
         my_80 = floor(0.8*rep);
         my_90 = floor(0.9*rep);
         my_95 = floor(0.95*rep);
         my_975 = floor(0.98*rep);
         my_99 = floor(0.99*rep);
         res_str = strvcat(' ','**************************************************************','*                          Results                           *');
         res_str = strvcat(res_str,'**************************************************************',' ',['  Model:                   ' my_mod],['  Endogenous variables:    ' num2str(tm.n,'%0.0f')],['  Cointegration relations: ' num2str(tm.r,'%0.0f')],['  Replications:            ' num2str(rep,'%0.0f')],['  Draws per replication:   ' num2str(my_T,'%0.0f')],' ');
         if blocksize>1;
            res_str = strvcat(res_str,strrep(block_txt,'.',''),' ');
         end;
         if tm.dfalpha>0;
            res_str = strvcat(res_str,['                      ' add_test ' test for ' num2str(tm.dfalpha,'%0.0f') ' restrictions on alpha'],'                      -----------------------------------',' ',['    80%   ' sp_str '     90%   ' sp_str '     95%   ' sp_str '     98%   ' sp_str '     99%   ' sp_str '     Mean  ' sp_str '  Std. Dev.']);
            max_std = sqrt( (1/rep)*sum( ( alpha_sorted - ( (1/rep)*sum(alpha_sorted) ) ).*( alpha_sorted - ( (1/rep)*sum(alpha_sorted) ) ) ) );
            res_str = strvcat(res_str,sprintf([prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],alpha_sorted(my_80,1),alpha_sorted(my_90,1),alpha_sorted(my_95,1),alpha_sorted(my_975,1),alpha_sorted(my_99,1),(1/rep)*sum(alpha_sorted),max_std));
            if curr_ini.sscorrect==1;
               res_str = strvcat(res_str,['From the ' test_str ' distribution we have the following:'],sprintf([prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1)),' ');
            else;
               res_str = strvcat(res_str,['From the ' test_str ' distribution we have the following:'],sprintf([prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),tm.dfalpha,sqrt(2*tm.dfalpha)),' ');
            end;
            res_str = strvcat(res_str,'                      Empirical size','                      --------------',' ','Test level    20%      10%       5%       2%       1%',sprintf('            %6.2f   %6.2f   %6.2f   %6.2f   %6.2f',100*(1-boot_size(1,5)),100*(1-boot_size(1,4)),100*(1-boot_size(1,3)),100*(1-boot_size(1,2)),100*(1-boot_size(1,1))),' ');
            if isempty(boot_pval)==0;
               res_str = strvcat(res_str,'                      Empirical p-value','                      -----------------',' ',sprintf([add_test '(' num2str(tm.dfalpha,'%0.0f') add_str ') = ' prt_val ',   p-value = ' prt_tex],tm.LRalpha,boot_pval),' ');
            end;
         end;
         %
         % dealing with alpha, delta, Gamma
         %
         my_cv_min(1,1) = ceil(0.1*rep);
         my_cv_min(2,1) = ceil(0.05*rep);
         my_cv_min(3,1) = ceil(0.025*rep);
         my_cv_min(4,1) = ceil(0.01*rep);
         my_cv_min(5,1) = ceil(0.005*rep);
         my_cv_max(1,1) = floor(0.9*rep);
         my_cv_max(2,1) = floor(0.95*rep);
         my_cv_max(3,1) = floor(0.975*rep);
         my_cv_max(4,1) = floor(0.99*rep);
         my_cv_max(5,1) = floor(0.995*rep);
         %
         % deterministic variables
         %
         parm_num = 1;
         elem = 1;
         if (isempty(param_vec_sorted)==0)&(tm.d+tm.dcoint>0);
            res_str = strvcat(res_str,'   Bootstrap statistics for delta parameters','   -----------------------------------------',' ',['Using simulated values from sorted value ' num2str(low_bval,'%0.0f') ' to ' num2str(high_bval,'%0.0f')],' ',['Variables: ' tm.deter],' ',['parameter       ML Estimate   ' sp_str '    Mean    ' sp_str '    Median  ' sp_str '   Std. Dev.  ' sp_str '   Skewness  ' sp_str '   Kurtosis']);
            %
            for i=1:tm.d+tm.dcoint;
               for j=1:tm.n;
                  %
                  % check if parameter is restricted
                  %
                  if se_Theta(1,elem)>1.0e-008;
                     mean_val = (1/(high_bval+1-low_bval))*sum(param_vec_sorted(low_bval:high_bval,parm_num));
                     median_val = param_vec_sorted(ceil(0.5*rep),parm_num);
                     std_val = sqrt( (1/(high_bval+1-low_bval))*sum( (param_vec_sorted(low_bval:high_bval,parm_num)-mean_val).*(param_vec_sorted(low_bval:high_bval,parm_num)-mean_val) ) );
                     norm_beta = (1/std_val)*(param_vec_sorted(low_bval:high_bval,parm_num)-mean_val);
                     skew_val = (1/(high_bval+1-low_bval))*sum(norm_beta.*norm_beta.*norm_beta);
                     kurt_val = (1/(high_bval+1-low_bval))*sum(norm_beta.*norm_beta.*norm_beta.*norm_beta);
                     %
                     delta_str = sprintf(['delta(%2.0f,%2.0f)     ' prt_val '     ' prt_val '     ' prt_val '     ' prt_val '     ' prt_val '     ' prt_val],j,i,vec_Theta(1,elem),mean_val,median_val,std_val,skew_val,kurt_val);
                     %
                     parm_num = parm_num+1;
                  else;
                     delta_str = sprintf(['delta(%2.0f,%2.0f)     ' prt_val],j,i,vec_Theta(1,elem));
                  end;
                  res_str = strvcat(res_str,delta_str);
                  elem = elem+1;
               end;
            end;
            %
            % Dealing with confidence bands
            %
            res_str = strvcat(res_str,' ','   Bootstrap confidence intervals for delta parameters using bootstrapped delta','   ----------------------------------------------------------------------------',' ',['parameter      ' sp_str '        80%        ' sp_str sp_str '           90%        ' sp_str sp_str '           95%        ' sp_str sp_str '           98%        ' sp_str sp_str '           99%']);
            parm_num = 1;
            elem = 1;
            for i=1:tm.d+tm.dcoint;
               for j=1:tm.n;
                  if se_Theta(1,elem)>1.0e-008;
                     c_vals = zeros(10,1);
                     for j1=1:5;
                        lower_val = param_vec_sorted(my_cv_min(j1,1),parm_num);
                        upper_val = param_vec_sorted(my_cv_max(j1,1),parm_num);
                        c_vals(1+(2*(j1-1)),1) = lower_val;
                        c_vals(2+(2*(j1-1)),1) = upper_val;
                     end;
                     delta_str = sprintf(['delta(%2.0f,%2.0f)   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],j,i,c_vals);
                     parm_num = parm_num+1;
                  else;
                     delta_str = sprintf('delta(%2.0f,%2.0f)   No values',j,i);
                  end;
                  %
                  res_str = strvcat(res_str,delta_str);
                  elem = elem+1;
               end;
            end;
            %
            res_str = strvcat(res_str,' ','   Bootstrap confidence intervals for delta parameters using bootstrapped t-values','   -------------------------------------------------------------------------------',' ',['parameter      ' sp_str '        80%        ' sp_str sp_str '           90%        ' sp_str sp_str '           95%        ' sp_str sp_str '           98%        ' sp_str sp_str '           99%']);
            parm_num = 1;
            elem = 1;
            for i=1:tm.d+tm.dcoint;
               for j=1:tm.n;
                  if se_Theta(1,elem)>1.0e-008;
                     c_vals = zeros(10,1);
                     for j1=1:5;
                        %
                        % notice that upper t-dist is used for lower value and lower t-dist for upper
                        %
                        lower_val = vec_Theta(1,elem)-(param_t_dist(my_cv_max(j1,1),parm_num)*sqrt(tm.T/my_T)*se_Theta(1,elem));
                        upper_val = vec_Theta(1,elem)-(param_t_dist(my_cv_min(j1,1),parm_num)*sqrt(tm.T/my_T)*se_Theta(1,elem));
                        c_vals(1+(2*(j1-1)),1) = lower_val;
                        c_vals(2+(2*(j1-1)),1) = upper_val;
                     end;
                     delta_str = sprintf(['delta(%2.0f,%2.0f)   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],j,i,c_vals);
                     parm_num = parm_num+1;
                  else;
                     delta_str = sprintf('delta(%2.0f,%2.0f)   No values',j,i);
                  end;
                  %
                  res_str = strvcat(res_str,delta_str);
                  elem = elem+1;
               end;
            end;
            res_str = strvcat(res_str,' ');
         end;
         %
         old_parm_num = parm_num;
         old_elem = elem;
         %
         if (isempty(param_vec_sorted)==0)&(tm.p>1);
            res_str = strvcat(res_str,'   Bootstrap statistics for Gamma parameters','   -----------------------------------------',' ',['Using simulated values from sorted value ' num2str(low_bval,'%0.0f') ' to ' num2str(high_bval,'%0.0f')],' ',['Variables: ' tm.evars],' ',['parameter     Lag    ML Estimate   ' sp_str '    Mean   ' sp_str '     Median  ' sp_str '   Std. Dev.  ' sp_str '   Skewness   ' sp_str '  Kurtosis']);
            %
            for i1=1:tm.p-1;
               for i=1:tm.n;
                  for j=1:tm.n;
                     %
                     % check if parameter is restricted
                     %
                     if se_Theta(1,elem)>1.0e-008;
                        mean_val = (1/(high_bval+1-low_bval))*sum(param_vec_sorted(low_bval:high_bval,parm_num));
                        median_val = param_vec_sorted(ceil(0.5*rep),parm_num);
                        std_val = sqrt( (1/(high_bval+1-low_bval))*sum( (param_vec_sorted(low_bval:high_bval,parm_num)-mean_val).*(param_vec_sorted(low_bval:high_bval,parm_num)-mean_val) ) );
                        norm_beta = (1/std_val)*(param_vec_sorted(low_bval:high_bval,parm_num)-mean_val);
                        skew_val = (1/(high_bval+1-low_bval))*sum(norm_beta.*norm_beta.*norm_beta);
                        kurt_val = (1/(high_bval+1-low_bval))*sum(norm_beta.*norm_beta.*norm_beta.*norm_beta);
                        %
                        delta_str = sprintf(['Gamma(%2.0f,%2.0f)   %2.0f     ' prt_val '     ' prt_val '     ' prt_val '     ' prt_val '     ' prt_val '     ' prt_val],j,i,i1,vec_Theta(1,elem),mean_val,median_val,std_val,skew_val,kurt_val);
                        parm_num = parm_num+1;
                     else;
                        delta_str = sprintf(['Gamma(%2.0f,%2.0f)   %2.0f     ' prt_val],j,i,i1,vec_Theta(1,elem));
                     end;
                     res_str = strvcat(res_str,delta_str);
                     elem = elem+1;
                  end;
               end;
            end;
            %
            res_str = strvcat(res_str,' ','   Bootstrap confidence intervals for Gamma parameters using bootstrapped Gamma','   ----------------------------------------------------------------------------',' ',['parameter     Lag     ' sp_str '      80%        ' sp_str sp_str '           90%        ' sp_str sp_str '           95%        ' sp_str sp_str '           98%        ' sp_str sp_str '           99%']);
            parm_num = old_parm_num;
            elem = old_elem;
            %
            % Dealing with confidence bands
            %
            for i1=1:tm.p-1;
               for i=1:tm.n;
                  for j=1:tm.n;
                     if se_Theta(1,elem)>1.0e-008;
                        c_vals = zeros(10,1);
                        for j1=1:5;
                           lower_val = param_vec_sorted(my_cv_min(j1,1),parm_num);
                           upper_val = param_vec_sorted(my_cv_max(j1,1),parm_num);
                           c_vals(1+(2*(j1-1)),1) = lower_val;
                           c_vals(2+(2*(j1-1)),1) = upper_val;
                        end;
                        delta_str = sprintf(['Gamma(%2.0f,%2.0f)   %2.0f   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],j,i,i1,c_vals);
                        parm_num = parm_num+1;
                     else;
                        delta_str = sprintf('Gamma(%2.0f,%2.0f)   %2.0f   No values',j,i,i1);
                     end;
                     %
                     res_str = strvcat(res_str,delta_str);
                     elem = elem+1;
                  end;
               end;
            end;
            %
            res_str = strvcat(res_str,' ','   Bootstrap confidence intervals for Gamma parameters using bootstrapped t-values','   -------------------------------------------------------------------------------',' ',['parameter     Lag     ' sp_str '      80%        ' sp_str sp_str '           90%        ' sp_str sp_str '           95%        ' sp_str sp_str '           98%        ' sp_str sp_str '           99%']);
            parm_num = old_parm_num;
            elem = old_elem;
            %
            for i1=1:tm.p-1;
               for i=1:tm.n;
                  for j=1:tm.n;
                     if se_Theta(1,elem)>1.0e-008;
                        c_vals = zeros(10,1);
                        for j1=1:5;
                           %
                           % notice that upper t-dist is used for lower value and lower t-dist for upper
                           %
                           lower_val = vec_Theta(1,elem)-(param_t_dist(my_cv_max(j1,1),parm_num)*sqrt(tm.T/my_T)*se_Theta(1,elem));
                           upper_val = vec_Theta(1,elem)-(param_t_dist(my_cv_min(j1,1),parm_num)*sqrt(tm.T/my_T)*se_Theta(1,elem));
                           c_vals(1+(2*(j1-1)),1) = lower_val;
                           c_vals(2+(2*(j1-1)),1) = upper_val;
                        end;
                        delta_str = sprintf(['Gamma(%2.0f,%2.0f)   %2.0f   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],j,i,i1,c_vals);
                        parm_num = parm_num+1;
                     else;
                        delta_str = sprintf('Gamma(%2.0f,%2.0f)   %2.0f   No values',j,i,i1);
                     end;
                     %
                     res_str = strvcat(res_str,delta_str);
                     elem = elem+1;
                  end;
               end;
            end;
            res_str = strvcat(res_str,' ');
         end;
         %
         old_parm_num = parm_num;
         old_elem = elem;
         %
         % exogenous I(1) variables - if any
         %
         if (isempty(param_vec_sorted)==0)&(tm.q1>0)&(tm.pe>0);
            res_str = strvcat(res_str,'   Bootstrap statistics for Psi parameters','   ---------------------------------------',' ',['Using simulated values from sorted value ' num2str(low_bval,'%0.0f') ' to ' num2str(high_bval,'%0.0f')],' ',['Variables: ' tm.xvars1],' ',['parameter     Lag    ML Estimate  ' sp_str '     Mean    ' sp_str '    Median  ' sp_str '   Std. Dev.  ' sp_str '   Skewness  ' sp_str '   Kurtosis']);
            %
            for i1=1:tm.pe;
               for i=1:tm.q1;
                  for j=1:tm.n;
                     %
                     % check if parameter is restricted
                     %
                     if se_Theta(1,elem)>1.0e-008;
                        mean_val = (1/(high_bval+1-low_bval))*sum(param_vec_sorted(low_bval:high_bval,parm_num));
                        median_val = param_vec_sorted(ceil(0.5*rep),parm_num);
                        std_val = sqrt( (1/(high_bval+1-low_bval))*sum( (param_vec_sorted(low_bval:high_bval,parm_num)-mean_val).*(param_vec_sorted(low_bval:high_bval,parm_num)-mean_val) ) );
                        norm_beta = (1/std_val)*(param_vec_sorted(low_bval:high_bval,parm_num)-mean_val);
                        skew_val = (1/(high_bval+1-low_bval))*sum(norm_beta.*norm_beta.*norm_beta);
                        kurt_val = (1/(high_bval+1-low_bval))*sum(norm_beta.*norm_beta.*norm_beta.*norm_beta);
                        %
                        delta_str = sprintf(['Psi(%2.0f,%2.0f)     %2.0f     ' prt_val '     ' prt_val '     ' prt_val '     ' prt_val '     ' prt_val '     ' prt_val],j,i,i1-1,vec_Theta(1,elem),mean_val,median_val,std_val,skew_val,kurt_val);
                        parm_num = parm_num+1;
                     else;
                        delta_str = sprintf(['Psi(%2.0f,%2.0f)     %2.0f     ' prt_val],j,i,i1-1,vec_Theta(1,elem));
                     end;
                     res_str = strvcat(res_str,delta_str);
                     elem = elem+1;
                  end;
               end;
            end;
            %
            res_str = strvcat(res_str,' ','   Bootstrap confidence intervals for Psi parameters using bootstrapped Psi','   ------------------------------------------------------------------------',' ',['parameter     Lag     ' sp_str '      80%        ' sp_str sp_str '           90%        ' sp_str sp_str '           95%        ' sp_str sp_str '           98%        ' sp_str sp_str '           99%']);
            parm_num = old_parm_num;
            elem = old_elem;
            %
            % Dealing with confidence bands
            %
            for i1=1:tm.pe;
               for i=1:tm.q1;
                  for j=1:tm.n;
                     c_vals = zeros(10,1);
                     if se_Theta(1,elem)>1.0e-008;
                        for j1=1:5;
                           lower_val = param_vec_sorted(my_cv_min(j1,1),parm_num);
                           upper_val = param_vec_sorted(my_cv_max(j1,1),parm_num);
                           c_vals(1+(2*(j1-1)),1) = lower_val;
                           c_vals(2+(2*(j1-1)),1) = upper_val;
                        end;
                        delta_str = sprintf(['Psi(%2.0f,%2.0f)     %2.0f   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],j,i,i1-1,c_vals);
                        parm_num = parm_num+1;
                     else;
                        delta_str = sprintf('Psi(%2.0f,%2.0f)     %2.0f   No values',j,i,i1-1);
                     end;
                     %
                     res_str = strvcat(res_str,delta_str);
                     elem = elem+1;
                  end;
               end;
            end;
            %
            res_str = strvcat(res_str,' ','   Bootstrap confidence intervals for Psi parameters using bootstrapped t-values','   -----------------------------------------------------------------------------',' ',['parameter     Lag     ' sp_str '      80%        ' sp_str sp_str '           90%        ' sp_str sp_str '           95%        ' sp_str sp_str '           98%        ' sp_str sp_str '           99%']);
            parm_num = old_parm_num;
            elem = old_elem;
            %
            for i1=1:tm.pe;
               for i=1:tm.q1;
                  for j=1:tm.n;
                     c_vals = zeros(10,1);
                     if se_Theta(1,elem)>1.0e-008;
                        for j1=1:5;
                           %
                           % notice that upper t-dist is used for lower value and lower t-dist for upper
                           %
                           lower_val = vec_Theta(1,elem)-(param_t_dist(my_cv_max(j1,1),parm_num)*sqrt(tm.T/my_T)*se_Theta(1,elem));
                           upper_val = vec_Theta(1,elem)-(param_t_dist(my_cv_min(j1,1),parm_num)*sqrt(tm.T/my_T)*se_Theta(1,elem));
                           c_vals(1+(2*(j1-1)),1) = lower_val;
                           c_vals(2+(2*(j1-1)),1) = upper_val;
                        end;
                        delta_str = sprintf(['Psi(%2.0f,%2.0f)     %2.0f   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],j,i,i1-1,c_vals);
                        parm_num = parm_num+1;
                     else;
                        delta_str = sprintf('Psi(%2.0f,%2.0f)     %2.0f   No values',j,i,i1-1);
                     end;
                     %
                     res_str = strvcat(res_str,delta_str);
                     elem = elem+1;
                  end;
               end;
            end;
            res_str = strvcat(res_str,' ');
         end;
         %
         old_parm_num = parm_num;
         old_elem = elem;
         %
         % exogenous I(0) variables - if any
         %
         if (isempty(param_vec_sorted)==0)&(tm.q0>0);
            res_str = strvcat(res_str,'   Bootstrap statistics for Phi parameters','   ---------------------------------------',' ',['Using simulated values from sorted value ' num2str(low_bval,'%0.0f') ' to ' num2str(high_bval,'%0.0f')],' ',['Variables: ' tm.xvars0],' ',['parameter     Lag    ML Estimate  ' sp_str '     Mean    ' sp_str '    Median  ' sp_str '   Std. Dev.  ' sp_str '   Skewness  ' sp_str '   Kurtosis']);
            %
            for i1=0:tm.pe;
               for i=1:tm.q0;
                  for j=1:tm.n;
                     %
                     % check if parameter is restricted
                     %
                     if se_Theta(1,elem)>1.0e-008;
                        mean_val = (1/(high_bval+1-low_bval))*sum(param_vec_sorted(low_bval:high_bval,parm_num));
                        median_val = param_vec_sorted(ceil(0.5*rep),parm_num);
                        std_val = sqrt( (1/(high_bval+1-low_bval))*sum( (param_vec_sorted(low_bval:high_bval,parm_num)-mean_val).*(param_vec_sorted(low_bval:high_bval,parm_num)-mean_val) ) );
                        norm_beta = (1/std_val)*(param_vec_sorted(low_bval:high_bval,parm_num)-mean_val);
                        skew_val = (1/(high_bval+1-low_bval))*sum(norm_beta.*norm_beta.*norm_beta);
                        kurt_val = (1/(high_bval+1-low_bval))*sum(norm_beta.*norm_beta.*norm_beta.*norm_beta);
                        %
                        delta_str = sprintf(['Phi(%2.0f,%2.0f)     %2.0f     ' prt_val '     ' prt_val '     ' prt_val '     ' prt_val '     ' prt_val '     ' prt_val],j,i,i1,vec_Theta(1,elem),mean_val,median_val,std_val,skew_val,kurt_val);
                        parm_num = parm_num+1;
                     else;
                        delta_str = sprintf(['Phi(%2.0f,%2.0f)     %2.0f     ' prt_val],j,i,i1,vec_Theta(1,elem));
                     end;
                     res_str = strvcat(res_str,delta_str);
                     elem = elem+1;
                  end;
               end;
            end;
            %
            res_str = strvcat(res_str,' ','   Bootstrap confidence intervals for Phi parameters using bootstrapped Phi','   ------------------------------------------------------------------------',' ',['parameter     Lag     ' sp_str '      80%        ' sp_str sp_str '           90%        ' sp_str sp_str '           95%        ' sp_str sp_str '           98%        ' sp_str sp_str '           99%']);
            parm_num = old_parm_num;
            elem = old_elem;
            %
            % Dealing with confidence bands
            %
            for i1=0:tm.pe;
               for i=1:tm.q0;
                  for j=1:tm.n;
                     c_vals = zeros(10,1);
                     if se_Theta(1,elem)>1.0e-008;
                        for j1=1:5;
                           lower_val = param_vec_sorted(my_cv_min(j1,1),parm_num);
                           upper_val = param_vec_sorted(my_cv_max(j1,1),parm_num);
                           c_vals(1+(2*(j1-1)),1) = lower_val;
                           c_vals(2+(2*(j1-1)),1) = upper_val;
                        end;
                        delta_str = sprintf(['Phi(%2.0f,%2.0f)     %2.0f   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],j,i,i1,c_vals);
                        parm_num = parm_num+1;
                     else;
                        delta_str = sprintf('Phi(%2.0f,%2.0f)     %2.0f   No values',j,i,i1);
                     end;
                     %
                     res_str = strvcat(res_str,delta_str);
                     elem = elem+1;
                  end;
               end;
            end;
            %
            res_str = strvcat(res_str,' ','   Bootstrap confidence intervals for Phi parameters using bootstrapped t-values','   -----------------------------------------------------------------------------',' ',['parameter     Lag     ' sp_str '      80%        ' sp_str sp_str '           90%        ' sp_str sp_str '           95%        ' sp_str sp_str '           98%        ' sp_str sp_str '           99%']);
            parm_num = old_parm_num;
            elem = old_elem;
            %
            for i1=0:tm.pe;
               for i=1:tm.q0;
                  for j=1:tm.n;
                     c_vals = zeros(10,1);
                     if se_Theta(1,elem)>1.0e-008;
                        for j1=1:5;
                           %
                           % notice that upper t-dist is used for lower value and lower t-dist for upper
                           %
                           lower_val = vec_Theta(1,elem)-(param_t_dist(my_cv_max(j1,1),parm_num)*sqrt(tm.T/my_T)*se_Theta(1,elem));
                           upper_val = vec_Theta(1,elem)-(param_t_dist(my_cv_min(j1,1),parm_num)*sqrt(tm.T/my_T)*se_Theta(1,elem));
                           c_vals(1+(2*(j1-1)),1) = lower_val;
                           c_vals(2+(2*(j1-1)),1) = upper_val;
                        end;
                        delta_str = sprintf(['Phi(%2.0f,%2.0f)     %2.0f   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],j,i,i1,c_vals);
                        parm_num = parm_num+1;
                     else;
                        delta_str = sprintf('Phi(%2.0f,%2.0f)     %2.0f   No values',j,i,i1);
                     end;
                     %
                     res_str = strvcat(res_str,delta_str);
                     elem = elem+1;
                  end;
               end;
            end;
            res_str = strvcat(res_str,' ');
         end;
         %
         old_parm_num = parm_num;
         old_elem = elem;
         %
         % alpha parameters
         %
         if (isempty(param_vec_sorted)==0)&(tm.r>0);
            res_str = strvcat(res_str,'   Bootstrap statistics for alpha parameters','   -----------------------------------------',' ',['Using simulated values from sorted value ' num2str(low_bval,'%0.0f') ' to ' num2str(high_bval,'%0.0f')],' ',['parameter       ML Estimate   ' sp_str '    Mean   ' sp_str '     Median  ' sp_str '   Std. Dev.  ' sp_str '   Skewness  ' sp_str '   Kurtosis']);
            %
            for i=1:tm.r;
               for j=1:tm.n;
                  %
                  % check if parameter is restricted
                  %
                  if se_Theta(1,elem)>1.0e-008;
                     mean_val = (1/(high_bval+1-low_bval))*sum(param_vec_sorted(low_bval:high_bval,parm_num));
                     median_val = param_vec_sorted(ceil(0.5*rep),parm_num);
                     std_val = sqrt( (1/(high_bval+1-low_bval))*sum( (param_vec_sorted(low_bval:high_bval,parm_num)-mean_val).*(param_vec_sorted(low_bval:high_bval,parm_num)-mean_val) ) );
                     norm_beta = (1/std_val)*(param_vec_sorted(low_bval:high_bval,parm_num)-mean_val);
                     skew_val = (1/(high_bval+1-low_bval))*sum(norm_beta.*norm_beta.*norm_beta);
                     kurt_val = (1/(high_bval+1-low_bval))*sum(norm_beta.*norm_beta.*norm_beta.*norm_beta);
                     %
                     delta_str = sprintf(['alpha(%2.0f,%2.0f)     ' prt_val '     ' prt_val '     ' prt_val '     ' prt_val '     ' prt_val '     ' prt_val],j,i,vec_Theta(1,elem),mean_val,median_val,std_val,skew_val,kurt_val);
                     parm_num = parm_num+1;
                  else;
                     delta_str = sprintf(['alpha(%2.0f,%2.0f)     ' prt_val],j,i,vec_Theta(1,elem));
                  end;
                  res_str = strvcat(res_str,delta_str);
                  elem = elem+1;
               end;
            end;
            %
            % Dealing with confidence bands
            %
            res_str = strvcat(res_str,' ','   Bootstrap confidence intervals for alpha parameters using bootstrapped alpha','   ----------------------------------------------------------------------------',' ',['parameter      ' sp_str '        80%        ' sp_str sp_str '           90%        ' sp_str sp_str '           95%        ' sp_str sp_str '           98%        ' sp_str sp_str '           99%']);
            parm_num = old_parm_num;
            elem = old_elem;
            for i=1:tm.r;
               for j=1:tm.n;
                  c_vals = zeros(10,1);
                  if se_Theta(1,elem)>1.0e-008;
                     for j1=1:5;
                        lower_val = param_vec_sorted(my_cv_min(j1,1),parm_num);
                        upper_val = param_vec_sorted(my_cv_max(j1,1),parm_num);
                        c_vals(1+(2*(j1-1)),1) = lower_val;
                        c_vals(2+(2*(j1-1)),1) = upper_val;
                     end;
                     delta_str = sprintf(['alpha(%2.0f,%2.0f)   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],j,i,c_vals);
                     parm_num = parm_num+1;
                  else;
                     delta_str = sprintf('alpha(%2.0f,%2.0f)   No values',j,i);
                  end;
                  %
                  res_str = strvcat(res_str,delta_str);
                  elem = elem+1;
               end;
            end;
            %
            res_str = strvcat(res_str,' ','   Bootstrap confidence intervals for alpha parameters using bootstrapped t-values','   -------------------------------------------------------------------------------',' ',['parameter      ' sp_str '        80%        ' sp_str sp_str '           90%        ' sp_str sp_str '           95%        ' sp_str sp_str '           98%        ' sp_str sp_str '           99%']);
            parm_num = old_parm_num;
            elem = old_elem;
            for i=1:tm.r;
               for j=1:tm.n;
                  c_vals = zeros(10,1);
                  if se_Theta(1,elem)>1.0e-008;
                     for j1=1:5;
                        %
                        % notice that upper t-dist is used for lower value and lower t-dist for upper
                        %
                        lower_val = vec_Theta(1,elem)-(param_t_dist(my_cv_max(j1,1),parm_num)*sqrt(tm.T/my_T)*se_Theta(1,elem));
                        upper_val = vec_Theta(1,elem)-(param_t_dist(my_cv_min(j1,1),parm_num)*sqrt(tm.T/my_T)*se_Theta(1,elem));
                        c_vals(1+(2*(j1-1)),1) = lower_val;
                        c_vals(2+(2*(j1-1)),1) = upper_val;
                     end;
                     delta_str = sprintf(['alpha(%2.0f,%2.0f)   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],j,i,c_vals);
                     parm_num = parm_num+1;
                  else;
                     delta_str = sprintf('alpha(%2.0f,%2.0f)   No values',j,i);
                  end;
                  %
                  res_str = strvcat(res_str,delta_str);
                  elem = elem+1;
               end;
            end;
            res_str = strvcat(res_str,' ');
         end;
         %
         res_str = strvcat(res_str,'**************************************************************',' ');
         %
         if tm.const_model(1)==1;
            file_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-summary-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.txt'];
         elseif tm.const_model(2)==1;
            file_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-summary-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
         elseif tm.const_model(3)==1;
            file_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-summary-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
         elseif tm.const_model(4)==1;
            file_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-summary-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
         elseif tm.const_model(5)==1;
            file_txt = [curr_ini.simulatedir  tm.modelfile tm.testtype '-alpha-boot-summary-' bootstyle tm.resalpha tm.resbeta tm.resc num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
         end;
         fid_txt = fopen(file_txt,'wt');
         for i=1:size(res_str,1);
            fprintf(fid_txt,[strrep(res_str(i,:),'%','%%') '\n']);
         end;
         fprintf(fid_txt,['Output created on: ' datestr(now,0) '\n']);
         fclose(fid_txt);
         %
         % write to tex-file
         %
         file_tex = strrep(file_txt,'.txt','.ltx');
         f_id = fopen(file_tex,'wt');
         fprintf(f_id,'\\begin{tabular}{ll}\n');
         fprintf(f_id,['Model: & ' my_mod ' \\\\\n']);
         fprintf(f_id,['\\#Endogenous variables: & ' num2str(tm.n,'%0.0f') ' \\\\\n']);
         fprintf(f_id,['\\#Cointegration relations: & ' num2str(tm.r,'%0.0f') ' \\\\\n']);
         fprintf(f_id,['\\#Replications: & ' num2str(rep,'%0.0f') ' \\\\\n']);
         fprintf(f_id,['\\#Draws per replication: & ' num2str(my_T,'%0.0f') ' \\\\\n']);
         if blocksize>1;
            fprintf(f_id,['Block size length: & ' num2str(blocksize,'%0.0f') ' \\\\\n']);
         end;
         fprintf(f_id,'\\end{tabular}\n\n');
         if tm.dfalpha>0;
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrr}\n');
            fprintf(f_id,['\\multicolumn{7}{c}{' add_test ' test for ' num2str(tm.dfalpha,'%0.0f') ' restrictions on $\\alpha$} \\\\\n']);
            fprintf(f_id,'80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% & Mean & Std. Dev. \\\\\n');
            max_std = sqrt( (1/rep)*sum( ( alpha_sorted - ( (1/rep)*sum(alpha_sorted) ) ).*( alpha_sorted - ( (1/rep)*sum(alpha_sorted) ) ) ) );
            fprintf(f_id,[prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],alpha_sorted(my_80,1),alpha_sorted(my_90,1),alpha_sorted(my_95,1),alpha_sorted(my_975,1),alpha_sorted(my_99,1),(1/rep)*sum(alpha_sorted),max_std);
            fprintf(f_id,'\\multicolumn{7}{c}{ } \\\\\n');
            fprintf(f_id,['\\multicolumn{7}{c}{From the ' test_str ' distribution we have the following:} \\\\\n']);
            if curr_ini.sscorrect==1;
               fprintf(f_id,[prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & & \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1));
            else;
               fprintf(f_id,[prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),tm.dfalpha,sqrt(2*tm.dfalpha));
            end;
            fprintf(f_id,'\\end{tabular}\n\n');
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrr}\n');
            fprintf(f_id,'\\multicolumn{6}{c}{Empirical size} \\\\\n');
            fprintf(f_id,'Nominal size & 20\\%% & 10\\%% & 5\\%% & 2\\%% & 1\\%% \\\\\n');
            fprintf(f_id,' & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% \\\\\n',100*(1-boot_size(1,5)),100*(1-boot_size(1,4)),100*(1-boot_size(1,3)),100*(1-boot_size(1,2)),100*(1-boot_size(1,1)));
            fprintf(f_id,'\\end{tabular}\n\n');
            if isempty(boot_pval)==0;
               fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{ll}\n');
               fprintf(f_id,'\\multicolumn{2}{c}{Empirical $p$-value} \\\\\n');
               fprintf(f_id,[' & ' add_test '(%0.0f' add_str ') = ' prt_tex ' \\\\ \n'],tm.dfalpha,tm.LRalpha);
               fprintf(f_id,[' & $p$-value = ' prt_tex ' \\\\ \n'],boot_pval);
               fprintf(f_id,'\\end{tabular}\n\n');
            end;
         end;
         %
         % deterministic variables
         %
         parm_num = 1;
         elem = 1;
         if (isempty(param_vec_sorted)==0)&(tm.d+tm.dcoint>0);
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrr}\n');
            fprintf(f_id,'\\multicolumn{7}{c}{Bootstrap statistics for $\\delta$ parameters using simulated} \\\\\n');
            fprintf(f_id,['\\multicolumn{7}{c}{values from sorted value ' num2str(low_bval,'%0.0f') ' to ' num2str(high_bval,'%0.0f') '} \\\\\n']);
            fprintf(f_id,['\\multicolumn{7}{c}{Variables: ' txt2ltxmath(strtrim(tm.deter)) '} \\\\\n']);
            fprintf(f_id,'parameter & ML Estimate & Mean & Median & Std. Dev. & Skewness & Kurtosis \\\\\n');
            %
            for i=1:tm.d+tm.dcoint;
               for j=1:tm.n;
                  %
                  % check if parameter is restricted
                  %
                  if se_Theta(1,elem)>1.0e-008;
                     est_val = vec_Theta(1,elem);
                     mean_val = (1/(high_bval+1-low_bval))*sum(param_vec_sorted(low_bval:high_bval,parm_num));
                     median_val = param_vec_sorted(ceil(0.5*rep),parm_num);
                     std_val = sqrt( (1/(high_bval+1-low_bval))*sum( (param_vec_sorted(low_bval:high_bval,parm_num)-mean_val).*(param_vec_sorted(low_bval:high_bval,parm_num)-mean_val) ) );
                     norm_beta = (1/std_val)*(param_vec_sorted(low_bval:high_bval,parm_num)-mean_val);
                     skew_val = (1/(high_bval+1-low_bval))*sum(norm_beta.*norm_beta.*norm_beta);
                     kurt_val = (1/(high_bval+1-low_bval))*sum(norm_beta.*norm_beta.*norm_beta.*norm_beta);
                     fprintf(f_id,['$\\delta_{%0.0f%0.0f}$ & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],j,i,est_val,mean_val,median_val,std_val,skew_val,kurt_val);
                     %
                     parm_num = parm_num+1;
                  else;
                     est_val = vec_Theta(1,elem);
                     fprintf(f_id,['$\\delta_{%0.0f%0.0f}$ & ' prt_tex ' & & & & & \\\\ \n'],j,i,est_val);
                  end;
                  elem = elem+1;
               end;
            end;
            fprintf(f_id,'\\end{tabular}\n\n');
            %
            % Dealing with confidence bands
            %
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrr}\n');
            fprintf(f_id,'\\multicolumn{6}{c}{Bootstrap confidence intervals for $\\delta$ parameters using empirical $\\delta$ distribution} \\\\\n');
            fprintf(f_id,'parameter & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% \\\\\n');
            %
            parm_num = 1;
            elem = 1;
            for i=1:tm.d+tm.dcoint;
               for j=1:tm.n;
                  delta_str = ['$\\delta_{' num2str(j,'%0.0f') num2str(i,'%0.0f') '}$'];
                  if se_Theta(1,elem)>1.0e-008;
                     for j1=1:5;
                        lower_val = param_vec_sorted(my_cv_min(j1,1),parm_num);
                        upper_val = param_vec_sorted(my_cv_max(j1,1),parm_num);
                        delta_str = [delta_str ' & [' num2str(lower_val,prt_tex) ',' num2str(upper_val,prt_tex) ']'];
                     end;
                     fprintf(f_id,[delta_str ' \\\\\n']);
                     parm_num = parm_num+1;
                  else;
                     fprintf(f_id,[delta_str ' & \\multicolumn{5}{c}{No values} \\\\\n']);
                  end;
                  %
                  elem = elem+1;
               end;
            end;
            fprintf(f_id,'\\end{tabular}\n\n');
            parm_num = 1;
            elem = 1;
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrr}\n');
            fprintf(f_id,'\\multicolumn{6}{c}{Bootstrap confidence intervals for $\\delta$ parameters using empirical $t$-value distribution} \\\\\n');
            fprintf(f_id,'parameter & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% \\\\\n');
            for i=1:tm.d+tm.dcoint;
               for j=1:tm.n;
                  delta_str = ['$\\delta_{' num2str(j,'%0.0f') num2str(i,'%0.0f') '}$'];
                  if se_Theta(1,elem)>1.0e-008;
                     for j1=1:5;
                        %
                        % notice that upper t-dist is used for lower value and lower t-dist for upper
                        %
                        lower_val = vec_Theta(1,elem)-(param_t_dist(my_cv_max(j1,1),parm_num)*sqrt(tm.T/my_T)*se_Theta(1,elem));
                        upper_val = vec_Theta(1,elem)-(param_t_dist(my_cv_min(j1,1),parm_num)*sqrt(tm.T/my_T)*se_Theta(1,elem));
                        delta_str = [delta_str ' & [' num2str(lower_val,prt_tex) ',' num2str(upper_val,prt_tex) ']'];
                     end;
                     fprintf(f_id,[delta_str ' \\\\\n']);
                     parm_num = parm_num+1;
                  else;
                     fprintf(f_id,[delta_str ' & \\multicolumn{5}{c}{No values} \\\\\n']);
                  end;
                  %
                  elem = elem+1;
               end;
            end;
            fprintf(f_id,'\\end{tabular}\n\n\\halfruler\n\n');
         end;
         %
         old_parm_num = parm_num;
         old_elem = elem;
         %
         % Lagged first differences
         %
         if (isempty(param_vec_sorted)==0)&(tm.p>1);
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrrr}\n');
            fprintf(f_id,'\\multicolumn{8}{c}{Bootstrap statistics for $\\Gamma$ parameters using simulated} \\\\\n');
            fprintf(f_id,['\\multicolumn{8}{c}{values from sorted value ' num2str(low_bval,'%0.0f') ' to ' num2str(high_bval,'%0.0f') '} \\\\\n']);
            fprintf(f_id,['\\multicolumn{8}{c}{Variables: ' txt2ltxmath(strtrim(tm.evars)) '} \\\\\n']);
            fprintf(f_id,'parameter & Lag & ML Estimate & Mean & Median & Std. Dev. & Skewness & Kurtosis \\\\\n');
            %
            for i1=1:tm.p-1;
               for i=1:tm.n;
                  for j=1:tm.n;
                     %
                     % check if parameter is restricted
                     %
                     if se_Theta(1,elem)>1.0e-008;
                        est_val = vec_Theta(1,elem);
                        mean_val = (1/(high_bval+1-low_bval))*sum(param_vec_sorted(low_bval:high_bval,parm_num));
                        median_val = param_vec_sorted(ceil(0.5*rep),parm_num);
                        std_val = sqrt( (1/(high_bval+1-low_bval))*sum( (param_vec_sorted(low_bval:high_bval,parm_num)-mean_val).*(param_vec_sorted(low_bval:high_bval,parm_num)-mean_val) ) );
                        norm_beta = (1/std_val)*(param_vec_sorted(low_bval:high_bval,parm_num)-mean_val);
                        skew_val = (1/(high_bval+1-low_bval))*sum(norm_beta.*norm_beta.*norm_beta);
                        kurt_val = (1/(high_bval+1-low_bval))*sum(norm_beta.*norm_beta.*norm_beta.*norm_beta);
                        fprintf(f_id,['$\\Gamma_{%0.0f%0.0f}$ & %0.0f & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],j,i,i1,est_val,mean_val,median_val,std_val,skew_val,kurt_val);
                        %
                        parm_num = parm_num+1;
                     else;
                        est_val = vec_Theta(1,elem);
                        fprintf(f_id,['$\\Gamma_{%0.0f%0.0f}$ & %0.0f & ' prt_tex ' & & & & & \\\\ \n'],j,i,i1,est_val);
                     end;
                     elem = elem+1;
                  end;
               end;
            end;
            fprintf(f_id,'\\end{tabular}\n\n');
            %
            % Dealing with confidence bands
            %
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrr}\n');
            fprintf(f_id,'\\multicolumn{7}{c}{Bootstrap confidence intervals for $\\Gamma$ parameters using empirical $\\Gamma$ distribution} \\\\\n');
            fprintf(f_id,'parameter & Lag & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% \\\\\n');
            %
            parm_num = old_parm_num;
            elem = old_elem;
            %
            % Dealing with confidence bands
            %
            for i1=1:tm.p-1;
               for i=1:tm.n;
                  for j=1:tm.n;
                     delta_str = ['$\\Gamma_{' num2str(j,'%0.0f') num2str(i,'%0.0f') '}$ & ' num2str(i1,'%0.0f')];
                     if se_Theta(1,elem)>1.0e-008;
                        for j1=1:5;
                           lower_val = param_vec_sorted(my_cv_min(j1,1),parm_num);
                           upper_val = param_vec_sorted(my_cv_max(j1,1),parm_num);
                           delta_str = [delta_str ' & [' num2str(lower_val,prt_tex) ',' num2str(upper_val,prt_tex) ']'];
                        end;
                        fprintf(f_id,[delta_str ' \\\\\n']);
                        parm_num = parm_num+1;
                     else;
                        fprintf(f_id,[delta_str ' & \\multicolumn{5}{c}{No values} \\\\\n']);
                     end;
                     %
                     elem = elem+1;
                  end;
               end;
            end;
            fprintf(f_id,'\\end{tabular}\n\n');
            parm_num = 1;
            elem = 1;
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrr}\n');
            fprintf(f_id,'\\multicolumn{7}{c}{Bootstrap confidence intervals for $\\Gamma$ parameters using empirical $t$-value distribution} \\\\\n');
            fprintf(f_id,'parameter & Lag & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% \\\\\n');
            %
            parm_num = old_parm_num;
            elem = old_elem;
            %
            for i1=1:tm.p-1;
               for i=1:tm.n;
                  for j=1:tm.n;
                     delta_str = ['$\\Gamma_{' num2str(j,'%0.0f') num2str(i,'%0.0f') '}$ & ' num2str(i1,'%0.0f')];
                     if se_Theta(1,elem)>1.0e-008;
                        for j1=1:5;
                           %
                           % notice that upper t-dist is used for lower value and lower t-dist for upper
                           %
                           lower_val = vec_Theta(1,elem)-(param_t_dist(my_cv_max(j1,1),parm_num)*sqrt(tm.T/my_T)*se_Theta(1,elem));
                           upper_val = vec_Theta(1,elem)-(param_t_dist(my_cv_min(j1,1),parm_num)*sqrt(tm.T/my_T)*se_Theta(1,elem));
                           delta_str = [delta_str ' & [' num2str(lower_val,prt_tex) ',' num2str(upper_val,prt_tex) ']'];
                        end;
                        fprintf(f_id,[delta_str ' \\\\\n']);
                        parm_num = parm_num+1;
                     else;
                        fprintf(f_id,[delta_str ' & \\multicolumn{5}{c}{No values} \\\\\n']);
                     end;
                     %
                     elem = elem+1;
                  end;
               end;
            end;
            fprintf(f_id,'\\end{tabular}\n\n\\halfruler\n\n');
         end;
         %
         old_parm_num = parm_num;
         old_elem = elem;
         %
         % Exogenous I(1) variables
         %
         if (isempty(param_vec_sorted)==0)&(tm.q1>0)&(tm.pe>0);
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrrr}\n');
            fprintf(f_id,'\\multicolumn{8}{c}{Bootstrap statistics for $\\Psi$ parameters using simulated} \\\\\n');
            fprintf(f_id,['\\multicolumn{8}{c}{values from sorted value ' num2str(low_bval,'%0.0f') ' to ' num2str(high_bval,'%0.0f') '} \\\\\n']);
            fprintf(f_id,['\\multicolumn{8}{c}{Variables: ' txt2ltxmath(strtrim(tm.xvars1)) '} \\\\\n']);
            fprintf(f_id,'parameter & Lag & ML Estimate & Mean & Median & Std. Dev. & Skewness & Kurtosis \\\\\n');
            %
            for i1=0:tm.pe-1;
               for i=1:tm.q1;
                  for j=1:tm.n;
                     %
                     % check if parameter is restricted
                     %
                     if se_Theta(1,elem)>1.0e-008;
                        est_val = vec_Theta(1,elem);
                        mean_val = (1/(high_bval+1-low_bval))*sum(param_vec_sorted(low_bval:high_bval,parm_num));
                        median_val = param_vec_sorted(ceil(0.5*rep),parm_num);
                        std_val = sqrt( (1/(high_bval+1-low_bval))*sum( (param_vec_sorted(low_bval:high_bval,parm_num)-mean_val).*(param_vec_sorted(low_bval:high_bval,parm_num)-mean_val) ) );
                        norm_beta = (1/std_val)*(param_vec_sorted(low_bval:high_bval,parm_num)-mean_val);
                        skew_val = (1/(high_bval+1-low_bval))*sum(norm_beta.*norm_beta.*norm_beta);
                        kurt_val = (1/(high_bval+1-low_bval))*sum(norm_beta.*norm_beta.*norm_beta.*norm_beta);
                        fprintf(f_id,['$\\Psi_{%0.0f%0.0f}$ & %0.0f & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],j,i,i1,est_val,mean_val,median_val,std_val,skew_val,kurt_val);
                        %
                        parm_num = parm_num+1;
                     else;
                        est_val = vec_Theta(1,elem);
                        fprintf(f_id,['$\\Psi_{%0.0f%0.0f}$ & %0.0f & ' prt_tex ' & & & & & \\\\ \n'],j,i,i1,est_val);
                     end;
                     elem = elem+1;
                  end;
               end;
            end;
            fprintf(f_id,'\\end{tabular}\n\n');
            %
            % Dealing with confidence bands
            %
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrr}\n');
            fprintf(f_id,'\\multicolumn{7}{c}{Bootstrap confidence intervals for $\\Psi$ parameters using empirical $\\Psi$ distribution} \\\\\n');
            fprintf(f_id,'parameter & Lag & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% \\\\\n');
            %
            parm_num = old_parm_num;
            elem = old_elem;
            %
            % Dealing with confidence bands
            %
            for i1=0:tm.pe-1;
               for i=1:tm.q1;
                  for j=1:tm.n;
                     delta_str = ['$\\Psi_{' num2str(j,'%0.0f') num2str(i,'%0.0f') '}$ & ' num2str(i1,'%0.0f')];
                     if se_Theta(1,elem)>1.0e-008;
                        for j1=1:5;
                           lower_val = param_vec_sorted(my_cv_min(j1,1),parm_num);
                           upper_val = param_vec_sorted(my_cv_max(j1,1),parm_num);
                           delta_str = [delta_str ' & [' num2str(lower_val,prt_tex) ',' num2str(upper_val,prt_tex) ']'];
                        end;
                        fprintf(f_id,[delta_str ' \\\\\n']);
                        parm_num = parm_num+1;
                     else;
                        fprintf(f_id,[delta_str ' & \\multicolumn{5}{c}{No values} \\\\\n']);
                     end;
                     %
                     elem = elem+1;
                  end;
               end;
            end;
            fprintf(f_id,'\\end{tabular}\n\n');
            parm_num = 1;
            elem = 1;
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrr}\n');
            fprintf(f_id,'\\multicolumn{7}{c}{Bootstrap confidence intervals for $\\Psi$ parameters using empirical $t$-value distribution} \\\\\n');
            fprintf(f_id,'parameter & Lag & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% \\\\\n');
            %
            parm_num = old_parm_num;
            elem = old_elem;
            %
            for i1=0:tm.pe-1;
               for i=1:tm.q1;
                  for j=1:tm.n;
                     delta_str = ['$\\Psi_{' num2str(j,'%0.0f') num2str(i,'%0.0f') '}$ & ' num2str(i1,'%0.0f')];
                     if se_Theta(1,elem)>1.0e-008;
                        for j1=1:5;
                           %
                           % notice that upper t-dist is used for lower value and lower t-dist for upper
                           %
                           lower_val = vec_Theta(1,elem)-(param_t_dist(my_cv_max(j1,1),parm_num)*sqrt(tm.T/my_T)*se_Theta(1,elem));
                           upper_val = vec_Theta(1,elem)-(param_t_dist(my_cv_min(j1,1),parm_num)*sqrt(tm.T/my_T)*se_Theta(1,elem));
                           delta_str = [delta_str ' & [' num2str(lower_val,prt_tex) ',' num2str(upper_val,prt_tex) ']'];
                        end;
                        fprintf(f_id,[delta_str ' \\\\\n']);
                        parm_num = parm_num+1;
                     else;
                        fprintf(f_id,[delta_str ' & \\multicolumn{5}{c}{No values} \\\\\n']);
                     end;
                     %
                     elem = elem+1;
                  end;
               end;
            end;
            fprintf(f_id,'\\end{tabular}\n\n\\halfruler\n\n');
         end;
         %
         old_parm_num = parm_num;
         old_elem = elem;
         %
         % Exogenous I(1) variables
         %
         if (isempty(param_vec_sorted)==0)&(tm.q0>0);
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrrr}\n');
            fprintf(f_id,'\\multicolumn{8}{c}{Bootstrap statistics for $\\Phi$ parameters using simulated} \\\\\n');
            fprintf(f_id,['\\multicolumn{8}{c}{values from sorted value ' num2str(low_bval,'%0.0f') ' to ' num2str(high_bval,'%0.0f') '} \\\\\n']);
            fprintf(f_id,['\\multicolumn{8}{c}{Variables: ' txt2ltxmath(strtrim(tm.xvars0)) '} \\\\\n']);
            fprintf(f_id,'parameter & Lag & ML Estimate & Mean & Median & Std. Dev. & Skewness & Kurtosis \\\\\n');
            %
            for i1=0:tm.pe;
               for i=1:tm.q0;
                  for j=1:tm.n;
                     %
                     % check if parameter is restricted
                     %
                     if se_Theta(1,elem)>1.0e-008;
                        est_val = vec_Theta(1,elem);
                        mean_val = (1/(high_bval+1-low_bval))*sum(param_vec_sorted(low_bval:high_bval,parm_num));
                        median_val = param_vec_sorted(ceil(0.5*rep),parm_num);
                        std_val = sqrt( (1/(high_bval+1-low_bval))*sum( (param_vec_sorted(low_bval:high_bval,parm_num)-mean_val).*(param_vec_sorted(low_bval:high_bval,parm_num)-mean_val) ) );
                        norm_beta = (1/std_val)*(param_vec_sorted(low_bval:high_bval,parm_num)-mean_val);
                        skew_val = (1/(high_bval+1-low_bval))*sum(norm_beta.*norm_beta.*norm_beta);
                        kurt_val = (1/(high_bval+1-low_bval))*sum(norm_beta.*norm_beta.*norm_beta.*norm_beta);
                        fprintf(f_id,['$\\Phi_{%0.0f%0.0f}$ & %0.0f & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],j,i,i1,est_val,mean_val,median_val,std_val,skew_val,kurt_val);
                        %
                        parm_num = parm_num+1;
                     else;
                        est_val = vec_Theta(1,elem);
                        fprintf(f_id,['$\\Phi_{%0.0f%0.0f}$ & %0.0f & ' prt_tex ' & & & & & \\\\ \n'],j,i,i1,est_val);
                     end;
                     elem = elem+1;
                  end;
               end;
            end;
            fprintf(f_id,'\\end{tabular}\n\n');
            %
            % Dealing with confidence bands
            %
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrr}\n');
            fprintf(f_id,'\\multicolumn{7}{c}{Bootstrap confidence intervals for $\\Phi$ parameters using empirical $\\Phi$ distribution} \\\\\n');
            fprintf(f_id,'parameter & Lag & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% \\\\\n');
            %
            parm_num = old_parm_num;
            elem = old_elem;
            %
            % Dealing with confidence bands
            %
            for i1=0:tm.pe;
               for i=1:tm.q0;
                  for j=1:tm.n;
                     delta_str = ['$\\Phi_{' num2str(j,'%0.0f') num2str(i,'%0.0f') '}$ & ' num2str(i1,'%0.0f')];
                     if se_Theta(1,elem)>1.0e-008;
                        for j1=1:5;
                           lower_val = param_vec_sorted(my_cv_min(j1,1),parm_num);
                           upper_val = param_vec_sorted(my_cv_max(j1,1),parm_num);
                           delta_str = [delta_str ' & [' num2str(lower_val,prt_tex) ',' num2str(upper_val,prt_tex) ']'];
                        end;
                        fprintf(f_id,[delta_str ' \\\\\n']);
                        parm_num = parm_num+1;
                     else;
                        fprintf(f_id,[delta_str ' & \\multicolumn{5}{c}{No values} \\\\\n']);
                     end;
                     %
                     elem = elem+1;
                  end;
               end;
            end;
            fprintf(f_id,'\\end{tabular}\n\n');
            parm_num = 1;
            elem = 1;
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrr}\n');
            fprintf(f_id,'\\multicolumn{7}{c}{Bootstrap confidence intervals for $\\Phi$ parameters using empirical $t$-value distribution} \\\\\n');
            fprintf(f_id,'parameter & Lag & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% \\\\\n');
            %
            parm_num = old_parm_num;
            elem = old_elem;
            %
            for i1=0:tm.pe;
               for i=1:tm.q0;
                  for j=1:tm.n;
                     delta_str = ['$\\Phi_{' num2str(j,'%0.0f') num2str(i,'%0.0f') '}$ & ' num2str(i1,'%0.0f')];
                     if se_Theta(1,elem)>1.0e-008;
                        for j1=1:5;
                           %
                           % notice that upper t-dist is used for lower value and lower t-dist for upper
                           %
                           lower_val = vec_Theta(1,elem)-(param_t_dist(my_cv_max(j1,1),parm_num)*sqrt(tm.T/my_T)*se_Theta(1,elem));
                           upper_val = vec_Theta(1,elem)-(param_t_dist(my_cv_min(j1,1),parm_num)*sqrt(tm.T/my_T)*se_Theta(1,elem));
                           delta_str = [delta_str ' & [' num2str(lower_val,prt_tex) ',' num2str(upper_val,prt_tex) ']'];
                        end;
                        fprintf(f_id,[delta_str ' \\\\\n']);
                        parm_num = parm_num+1;
                     else;
                        fprintf(f_id,[delta_str ' & \\multicolumn{5}{c}{No values} \\\\\n']);
                     end;
                     %
                     elem = elem+1;
                  end;
               end;
            end;
            fprintf(f_id,'\\end{tabular}\n\n\\halfruler\n\n');
         end;
         %
         old_parm_num = parm_num;
         old_elem = elem;
         %
         % and the alpha parameters on the cointegration relations
         %
         if (isempty(param_vec_sorted)==0)&(tm.r>0);
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrr}\n');
            fprintf(f_id,'\\multicolumn{7}{c}{Bootstrap statistics for $\\alpha$ parameters using simulated} \\\\\n');
            fprintf(f_id,['\\multicolumn{7}{c}{values from sorted value ' num2str(low_bval,'%0.0f') ' to ' num2str(high_bval,'%0.0f') '} \\\\\n']);
            fprintf(f_id,'parameter & ML Estimate & Mean & Median & Std. Dev. & Skewness & Kurtosis \\\\\n');
            %
            for i=1:tm.r;
               for j=1:tm.n;
                  %
                  % check if parameter is restricted
                  %
                  if se_Theta(1,elem)>1.0e-008;
                     est_val = vec_Theta(1,elem);
                     mean_val = (1/(high_bval+1-low_bval))*sum(param_vec_sorted(low_bval:high_bval,parm_num));
                     median_val = param_vec_sorted(ceil(0.5*rep),parm_num);
                     std_val = sqrt( (1/(high_bval+1-low_bval))*sum( (param_vec_sorted(low_bval:high_bval,parm_num)-mean_val).*(param_vec_sorted(low_bval:high_bval,parm_num)-mean_val) ) );
                     norm_beta = (1/std_val)*(param_vec_sorted(low_bval:high_bval,parm_num)-mean_val);
                     skew_val = (1/(high_bval+1-low_bval))*sum(norm_beta.*norm_beta.*norm_beta);
                     kurt_val = (1/(high_bval+1-low_bval))*sum(norm_beta.*norm_beta.*norm_beta.*norm_beta);
                     fprintf(f_id,['$\\alpha_{%0.0f%0.0f}$ & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'],j,i,est_val,mean_val,median_val,std_val,skew_val,kurt_val);
                     %
                     parm_num = parm_num+1;
                  else;
                     est_val = vec_Theta(1,elem);
                     fprintf(f_id,['$\\alpha_{%0.0f%0.0f}$ & ' prt_tex ' & & & & & \\\\ \n'],j,i,est_val);
                  end;
                  elem = elem+1;
               end;
            end;
            fprintf(f_id,'\\end{tabular}\n\n');
            %
            % Dealing with confidence bands
            %
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrr}\n');
            fprintf(f_id,'\\multicolumn{6}{c}{Bootstrap confidence intervals for $\\alpha$ parameters using empirical $\\alpha$ distribution} \\\\\n');
            fprintf(f_id,'parameter & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% \\\\\n');
            %
            parm_num = old_parm_num;
            elem = old_elem;
            for i=1:tm.r;
               for j=1:tm.n;
                  delta_str = ['$\\alpha_{' num2str(j,'%0.0f') num2str(i,'%0.0f') '}$'];
                  if se_Theta(1,elem)>1.0e-008;
                     for j1=1:5;
                        lower_val = param_vec_sorted(my_cv_min(j1,1),parm_num);
                        upper_val = param_vec_sorted(my_cv_max(j1,1),parm_num);
                        delta_str = [delta_str ' & [' num2str(lower_val,prt_tex) ',' num2str(upper_val,prt_tex) ']'];
                     end;
                     fprintf(f_id,[delta_str ' \\\\\n']);
                     parm_num = parm_num+1;
                  else;
                     fprintf(f_id,[delta_str ' & \\multicolumn{5}{c}{No values} \\\\\n']);
                  end;
                  %
                  elem = elem+1;
               end;
            end;
            fprintf(f_id,'\\end{tabular}\n\n');
            parm_num = old_parm_num;
            elem = old_elem;
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrr}\n');
            fprintf(f_id,'\\multicolumn{6}{c}{Bootstrap confidence intervals for $\\alpha$ parameters using empirical $t$-value distribution} \\\\\n');
            fprintf(f_id,'parameter & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% \\\\\n');
            for i=1:tm.r;
               for j=1:tm.n;
                  delta_str = ['$\\alpha_{' num2str(j,'%0.0f') num2str(i,'%0.0f') '}$'];
                  if se_Theta(1,elem)>1.0e-008;
                     for j1=1:5;
                        %
                        % notice that upper t-dist is used for lower value and lower t-dist for upper
                        %
                        lower_val = vec_Theta(1,elem)-(param_t_dist(my_cv_max(j1,1),parm_num)*sqrt(tm.T/my_T)*se_Theta(1,elem));
                        upper_val = vec_Theta(1,elem)-(param_t_dist(my_cv_min(j1,1),parm_num)*sqrt(tm.T/my_T)*se_Theta(1,elem));
                        delta_str = [delta_str ' & [' num2str(lower_val,prt_tex) ',' num2str(upper_val,prt_tex) ']'];
                     end;
                     fprintf(f_id,[delta_str ' \\\\\n']);
                     parm_num = parm_num+1;
                  else;
                     fprintf(f_id,[delta_str ' & \\multicolumn{5}{c}{No values} \\\\\n']);
                  end;
                  %
                  elem = elem+1;
               end;
            end;
            fprintf(f_id,'\\end{tabular}\n\n');
         end;
         %
         fprintf(f_id,'\\ruler\n\n%%*************************************************************\n');
         fclose(f_id);
         %
         set(boot_alpha.display,'UserData',alpha_sorted);
         set(boot_alpha.histogram,'UserData',param_vec_sorted);
         clear('alpha_sorted','param_vec_sorted');
         set(boot_alpha.clock,'UserData',vec_Theta);
         set(boot_alpha.summary,'UserData',se_Theta);
         set(boot_alpha.full,'UserData',param_t_dist);
         clear('param_t_dist');
         %
         if curr_ini.noprint==0;
            set(boot_alpha.output,'Enable','on');
         end;
         set(boot_alpha.summarymenu,'Enable','on','UserData',file_txt);
         set(boot_alpha.summary,'Enable','on');
         set(boot_alpha.display,'Enable','on');
         set(boot_alpha.displaymenu,'Enable','on');
         set(boot_alpha.histogram,'Enable','on');
         set(boot_alpha.histogrammenu,'Enable','on');
         set(boot_alpha.matfilebutton,'Enable','on');
         set(boot_alpha.matfilemenu,'Enable','on');
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
      else;
         setlogtext('Cancelled...');
      end;
   else;
      unident = '';
      for i=1:tm.r;
         if status(i,1)==0;
            if strcmp(unident,'')==1;
               unident = ['beta(' num2str(i) ')'];
               thisres = 'restriction';
               thisfail = 'fails';
            else;
               unident = [unident ', beta(' num2str(i) ')'];
               thisres = 'restrictions';
               thisfail = 'fail';
            end;
         end;
      end;
      setlogtext(strvcat(' ','ERROR: The restrictions on beta are not identifying...'));
      txt = ['The restrictions you have selected for beta are not identifying. In particular, the ' thisres ' on ' unident ' ' thisfail ' the identification test.'];
      about(txt,'warning','Identification Test Failure',120,500);
   end;
   tm.beta_run = 0;
   set(alpha_boot_gui,'Visible','on');
case 'done'
   if tm.beta_run==0;
      set(boot_alpha.done,'UserData','done');
      pid = get(boot_alpha.filemenu,'UserData');
      if isempty(pid)==1;
         delete(alpha_boot_gui);
      else;
         close(alpha_boot_gui);
      end;
   end;
end;

if strcmp(selector,'init')==1;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(alpha_boot_gui,'Name') ' ' fix_filepath([pwd '\icons\bootstrap.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(boot_alpha.filemenu,'UserData',pid);
         set(alpha_boot_gui,'CloseRequestFcn','killwinpid');
      end;
   end;
   set(alpha_boot_gui,'Visible','on');
   drawnow;
end;

if strcmp(selector,'done')==0;
   curr_ini.models = tm;
   curr_ini.images = button_images;
   set(boot_alpha.matfilebutton,'UserData',curr_ini);
end;

if my_exit==1;
   waitfor(boot_alpha.done,'UserData','done');
end;

%
% end of alpha_bootstrap.m
%
