%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for selecting files from list       %
%                                                                %
%          Function: alt_model_dlg                               %
%                                                                %
%          Input:                                                %
%                       selector: case switch function           %
%                       tm: structure with model information     %
%                                                                %
%          Output:                                               %
%                       h = handle                               %
%                                                                %
%          This version:        May 18, 2006                     %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function h = alt_model_dlg(selector,tm)

if strcmp(selector,'init')==1;
   thisexit = 0;
   %
   % setting up the actual sample period
   %
   [tm.dataindex,tm.samplebeg,tm.sampleend] = make_dataindex(tm.freq,tm.samplebeg,tm.sampleend);
   checkyear = floor(tm.samplebeg);
   checkperiod = tm.samplebeg-checkyear;
   tm.subbeginyear = num2str(checkyear);
   if strcmp(tm.freq,'q')==1;
      checkperiod = 4*(checkperiod+(1/8));
      tm.subbeginperiod = num2str(round(checkperiod));
   elseif strcmp(tm.freq,'m')==1;
      checkperiod = 12*(checkperiod+(1/24));
      tm.subbeginperiod = num2str(round(checkperiod));
   end;
   if (isfield(tm,'altmodel')==0)|(isempty(tm.altmodel)==1);
      tm.altmodel.tempbegin = 1;
      tm.altmodel.tempend = 1;
      tm.altmodel.permbegin = tm.T;
      tm.altmodel.tempdummy = 0;
      tm.altmodel.permdummy = 0;
      %
      tm.altmodel.tempcoint = 0;
      tm.altmodel.tempacc = 0;
      tm.altmodel.tempcorel = 0;
      if (tm.deterselect(1,2)==1)|(tm.deterselect(1,4)==1);
         tm.altmodel.tempcoint = 1;
      end;
      tm.altmodel.tempcoidet = 0;
      tm.altmodel.tempshortrun = 0;
      tm.altmodel.permcoint = 0;
      tm.altmodel.permacc = 0;
      tm.altmodel.permcorel = 0;
      if (tm.deterselect(1,2)==1)|(tm.deterselect(1,4)==1);
         tm.altmodel.permcoint = 1;
      end;
      tm.altmodel.permcoidet = 0;
      tm.altmodel.permshortrun = 0;
      tm.altmodel.changed = 0;
      tm.altmodel.saved = 0;
      tm.altmodel.relsample = 1;
      tm.altmodel.temprank = 1;
      tm.altmodel.permrank = 1;
      tm.altmodel.bootlr = 0;
   else;
      if isfield(tm.altmodel,'temprank')==0;
         tm.altmodel.temprank = 1;
         tm.altmodel.permrank = 1;
      end;
      if isfield(tm.altmodel,'tempshortrun')==0;
         tm.altmodel.tempshortrun = 0;
         tm.altmodel.permshortrun = 0;
      end;
      if isfield(tm.altmodel,'bootlr')==0;
         tm.altmodel.bootlr = 0;
      end;
      if isfield(tm.altmodel,'tempcoidet')==0;
         tm.altmodel.tempcoidet = 0;
         tm.altmodel.permcoidet = 0;
      end;
   end;
   tm.oldaltmodel = tm.altmodel;
   %
   % create sample strings
   %
   tm.sample_string = '';
   for i=1:tm.T;
      tm.sample_string = strvcat(tm.sample_string,getdate(tm.samplebeg,tm.sampleend,tm.freq,i/tm.T));
   end;
   %
   % curr_ini
   %
   curr_ini = find_inisettings;
   %
   mycons = getstoredimages;
   if curr_ini.use_toolbar_bgcolor==1;
      bgcolor = (1/255)*(round(255*get(0,'defaultuicontrolbackgroundcolor'))-[8 4 8]);
      bgcolor(1) = max(0,bgcolor(1));
      bgcolor(2) = max(0,bgcolor(2));
      bgcolor(3) = max(0,bgcolor(3));
   else;
      bgcolor = get(0,'defaultuicontrolbackgroundcolor');
   end;
   %
   % Set screen size directly instead of using
   % get(0,'ScreenSize')!
   %
   realscrsz = get(0,'ScreenSize');
else;
   thisexit = 1;
   alt_gui = findobj('Type','figure','Tag','AltModelGUI');
   altmod_controls = get(alt_gui,'UserData');
   tm = get(altmod_controls.tempdummy,'UserData');
end;

switch selector;
   case 'init';

      if (tm.deterselect(1,2)==1)|(tm.deterselect(1,4)==1);
         add_height = 40;
      else;
         add_height = 0;
      end;

      alt_gui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','alt_model_dlg.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(realscrsz(3)-550)/2 (realscrsz(4)-370-add_height)/2 550 370+add_height], ...
         'Tag','AltModelGUI', ...
         'Resize','off', ...
         'Name','Alternative Model', ...
         'NumberTitle','off', ...
         'Visible','off', ...
         'WindowStyle','modal', ...
         'CloseRequestFcn','alt_model_dlg done', ...
         'ToolBar','none');

      if matlabnumber>=7.0;
         set(alt_gui,'DockControl','off');
      end;

      %
      % Outer axis
      %

      axesbox([2 2 548 360+add_height],'Model Properties',80,[0.5 1]);

      imageaxes = axes('Units','pixels', ...
         'Box','on', ...
         'TickLength',[0 0], ...
         'CameraUpVector',[0 1 0], ...
         'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[491 301+add_height 39 39], ...
         'XTickLabelMode','manual', ...
         'YTickLabelMode','manual', ...
         'Tag','AxisLogo', ...
         'XColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'YColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'ZColor',get(0,'defaultuicontrolbackgroundcolor'));

      %
      image('CData',mirrorimage(maketrans(mycons.powerbig_image,[160 160 164],bgcolor)),'Clipping','off','Parent',imageaxes);
      %
      % Displaying the controls for dummy variable creation
      %

      altmod_controls.tempdummy = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[20 320+add_height 200 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',tm.altmodel.tempdummy, ...
         'Enable','on', ...
         'Callback','alt_model_dlg checkdummy', ...
         'String','Temporary 0-1 dummy for period:', ...
         'HorizontalAlignment','left', ...
         'Tag','TempDummy');

      altmod_controls.tempbegin = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[240 320+add_height 100 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'String',tm.sample_string, ...
         'Callback','alt_model_dlg checkperiod', ...
         'HorizontalAlignment','center', ...
         'Tag','TempBeginPopup',...
         'Value',tm.altmodel.tempbegin);

      altmod_controls.icon = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[340 322+add_height 10 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'String','_', ...
         'HorizontalAlignment','center', ...
         'Tag','DashText');

      altmod_controls.tempend = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[350 320+add_height 100 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'String',tm.sample_string, ...
         'Callback','alt_model_dlg checkperiod', ...
         'HorizontalAlignment','center', ...
         'Tag','TempEndPopup',...
         'Value',tm.altmodel.tempend);

      altmod_controls.tempacc = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 290+add_height 200 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',tm.altmodel.tempacc, ...
         'Enable','on', ...
         'Callback','alt_model_dlg checkacc_coint', ...
         'String','Accumulate dummy', ...
         'HorizontalAlignment','left', ...
         'Tag','AccTempDummy');

      altmod_controls.tempcoint = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 270+add_height 200 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',tm.altmodel.tempcoint, ...
         'Enable','on', ...
         'Callback','alt_model_dlg checkacc_coint', ...
         'String','Restrict to cointegration space', ...
         'HorizontalAlignment','left', ...
         'Tag','CointTempDummy');

      altmod_controls.tempcorel = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 250+add_height 200 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',tm.altmodel.tempcorel, ...
         'Enable','on', ...
         'Callback','alt_model_dlg checkacc_coint', ...
         'String','Apply to cointegration relations for', ...
         'HorizontalAlignment','left', ...
         'Tag','CointRelTempDummy');

      altmod_controls.temprank = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[240 250+add_height 100 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Enable','off', ...
         'String','fixed rank|higher rank by 1|lower rank by 1', ...
         'Callback','alt_model_dlg checkacc_coint', ...
         'HorizontalAlignment','center', ...
         'Tag','TempRankPopup',...
         'Value',1);

      if (sum(tm.restrict)==0)&(get(altmod_controls.tempcorel,'Value')==1);
         set(altmod_controls.temprank,'Enable','on','Value',tm.altmodel.temprank);
      end;
      
      if (tm.deterselect(1,2)==1)|(tm.deterselect(1,4)==1);
         if tm.deterselect(1,2)==1;
            coi_str = 'Skip restricted constant';
         elseif tm.deterselect(1,4)==1;
            coi_str = 'Skip restricted linear trend';
         end;
         
         altmod_controls.tempcoidet = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[240 265 200 20], ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'Style','checkbox', ...
            'Value',0, ...
            'Enable','off', ...
            'Callback','alt_model_dlg checkacc_coint', ...
            'String',coi_str, ...
            'HorizontalAlignment','left', ...
            'Tag','CointRelTempDummy2');
         if (get(altmod_controls.tempcorel,'Value')==1)&(get(altmod_controls.temprank,'Value')==1);
            set(altmod_controls.tempcoidet,'Value',tm.altmodel.tempcoidet,'Enable','on');
         end;
      else;
         altmod_controls.tempcoidet = [];
      end;

      altmod_controls.tempshortrun = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 230+(add_height/2) 200 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',0, ...
         'Enable','off', ...
         'Callback','alt_model_dlg checkacc_coint', ...
         'String','Apply to short-run dynamics', ...
         'HorizontalAlignment','left', ...
         'Tag','ShortRunTempDummy');
      
      if ((size(tm.restrict,2)==2)|(tm.restrict(1,3)==0))&((tm.p>1)|(tm.q1+tm.q0>0))&(get(altmod_controls.tempdummy,'Value')==1);
         set(altmod_controls.tempshortrun,'Enable','on','Value',tm.altmodel.tempshortrun);
      end;

      %
      % permanent dummy controls
      %

      altmod_controls.permdummy = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[20 190+(add_height/2) 200 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',tm.altmodel.permdummy, ...
         'Enable','on', ...
         'UserData',curr_ini, ...
         'Callback','alt_model_dlg checkdummy', ...
         'String','Permanent 0-1 dummy from period:', ...
         'HorizontalAlignment','left', ...
         'Tag','PermDummy');

      altmod_controls.permbegin = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[240 190+(add_height/2) 100 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'String',tm.sample_string, ...
         'Callback','alt_model_dlg checkpermperiod', ...
         'HorizontalAlignment','center', ...
         'Tag','TempEndPopup',...
         'Value',tm.altmodel.permbegin);

      altmod_controls.permacc = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 160+(add_height/2) 200 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',tm.altmodel.permacc, ...
         'Enable','on', ...
         'Callback','alt_model_dlg checkacc_coint', ...
         'String','Accumulate dummy', ...
         'HorizontalAlignment','left', ...
         'Tag','AccPermDummy');

      altmod_controls.permcoint = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 140+(add_height/2) 200 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',tm.altmodel.permcoint, ...
         'Enable','on', ...
         'Callback','alt_model_dlg checkacc_coint', ...
         'String','Restrict to cointegration space', ...
         'HorizontalAlignment','left', ...
         'Tag','CointPermDummy');

      altmod_controls.permcorel = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 120+(add_height/2) 200 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',tm.altmodel.permcorel, ...
         'Enable','on', ...
         'Callback','alt_model_dlg checkacc_coint', ...
         'String','Apply to cointegration relations', ...
         'HorizontalAlignment','left', ...
         'Tag','CointRelPermDummy');

      altmod_controls.permrank = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[240 120+(add_height/2) 100 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Enable','off', ...
         'String','fixed rank|higher rank by 1|lower rank by 1', ...
         'Callback','alt_model_dlg checkacc_coint', ...
         'HorizontalAlignment','center', ...
         'Tag','PermRankPopup',...
         'Value',1);

      if (sum(tm.restrict)==0)&(get(altmod_controls.permcorel,'Value')==1);
         set(altmod_controls.permrank,'Enable','on','Value',tm.altmodel.permrank);
      end;

      if (tm.deterselect(1,2)==1)|(tm.deterselect(1,4)==1);
         altmod_controls.permcoidet = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[240 115 200 20], ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'Style','checkbox', ...
            'Value',0, ...
            'Enable','off', ...
            'Callback','alt_model_dlg checkacc_coint', ...
            'String',coi_str, ...
            'HorizontalAlignment','left', ...
            'Tag','CointRelTempDummy2');
         if (get(altmod_controls.permcorel,'Value')==1)&(get(altmod_controls.permrank,'Value')==1);
            set(altmod_controls.permcoidet,'Value',tm.altmodel.permcoidet,'Enable','on');
         end;
      else;
         altmod_controls.permcoidet = [];
      end;


      altmod_controls.permshortrun = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 100 200 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',0, ...
         'Enable','off', ...
         'Callback','alt_model_dlg checkacc_coint', ...
         'String','Apply to short-run dynamics', ...
         'HorizontalAlignment','left', ...
         'Tag','ShortRunPermDummy');
      
%      if (sum(tm.restrict)==0)&((tm.p>1)|(tm.q1+tm.q0>0))&(get(altmod_controls.permdummy,'Value')==1);
      if ((size(tm.restrict,2)==2)|(tm.restrict(1,3)==0))&((tm.p>1)|(tm.q1+tm.q0>0))&(get(altmod_controls.permdummy,'Value')==1);
         set(altmod_controls.permshortrun,'Enable','on','Value',tm.altmodel.permshortrun);
      end;

      %
      % Check box for using relative sample
      %
      
      altmod_controls.relsample = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[20 70 200 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',tm.altmodel.relsample, ...
         'Enable','on', ...
         'Callback','alt_model_dlg checkacc_coint', ...
         'String','Define dummy relative to sample size', ...
         'HorizontalAlignment','left', ...
         'Tag','RelSampleDummy');

      altmod_controls.lr_test = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[20 50 200 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',tm.altmodel.bootlr, ...
         'Enable','on', ...
         'Callback','alt_model_dlg checkacc_coint', ...
         'String','Bootstrap LR-test vs. alternative model', ...
         'HorizontalAlignment','left', ...
         'Tag','BootLRTest');

      if (get(altmod_controls.temprank,'Value')>1)|(get(altmod_controls.permrank,'Value')>1);
         set(altmod_controls.lr_test,'Enable','off','Value',0);
      else;
         set(altmod_controls.lr_test,'Enable','on','Value',tm.altmodel.bootlr);
      end;


      %
      % Estimate, Graph and Save buttons
      %

      altmod_controls.estimate = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[440 125 90 25], ...
         'String','Estimate', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','alt_model_dlg estimate', ...
         'Enable','off', ...
         'Tag','EstimateButton');

      altmod_controls.graphdummy = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[440 90 90 25], ...
         'String','Display', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','alt_model_dlg graphdummy', ...
         'Enable','off', ...
         'Tag','GraphDummyButton');

      altmod_controls.savemodel = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[440 55 90 25], ...
         'String','Save', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','alt_model_dlg savemodel', ...
         'Enable','off', ...
         'Tag','SaveModelButton');

      %
      % OK and Cancel and Apply buttons
      %

      altmod_controls.done = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[240 20 90 25], ...
         'String','OK', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','alt_model_dlg done', ...
         'Enable','on', ...
         'UserData','waiting', ...
         'Tag','DoneButton');

      altmod_controls.cancel = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[340 20 90 25], ...
         'String','Cancel', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','alt_model_dlg cancel', ...
         'Enable','on', ...
         'UserData','waiting', ...
         'Tag','CancelButton');

      altmod_controls.apply = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[440 20 90 25], ...
         'String','Apply', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','alt_model_dlg apply', ...
         'Enable','off', ...
         'Tag','ApplyButton');

      %
      % Fix enable state for controls based on tm.altmodel structure info
      %

      if tm.altmodel.tempdummy==0;
         set(altmod_controls.tempbegin,'Enable','off');
         set(altmod_controls.tempend,'Enable','off');
         set(altmod_controls.icon,'Enable','off');
         set(altmod_controls.tempacc,'Enable','off');
         set(altmod_controls.tempcoint,'Enable','off');
         set(altmod_controls.tempcorel,'Enable','off');
      else;
         set(altmod_controls.permdummy,'Enable','off');
      end;
      %
      if tm.altmodel.permdummy==0;
         set(altmod_controls.permbegin,'Enable','off');
         set(altmod_controls.permacc,'Enable','off');
         set(altmod_controls.permcoint,'Enable','off');
         set(altmod_controls.permcorel,'Enable','off');
      else;
         set(altmod_controls.tempdummy,'Enable','off');
      end;

      if (tm.altmodel.tempdummy==1)|(tm.altmodel.permdummy==1);
         set(altmod_controls.graphdummy,'Enable','on');
         set(altmod_controls.estimate,'Enable','on');
      else;
         set(altmod_controls.graphdummy,'Enable','off');
         set(altmod_controls.estimate,'Enable','off');
      end;
      if (tm.altmodel.changed==1)&(tm.altmodel.saved==0);
         set(altmod_controls.savemodel,'Enable','on');
      else;
         set(altmod_controls.savemodel,'Enable','off');
      end;

      set(alt_gui,'UserData',altmod_controls,...
         'HandleVisibility','callback');

   case 'graphdummy'
      curr_ini = get(altmod_controls.permdummy,'UserData');
      if curr_ini.colors==1;
         colorstr = 'b';
      else;
         colorstr = 'k';
      end;
      tempdummy = get(altmod_controls.tempdummy,'Value');
      permdummy = get(altmod_controls.permdummy,'Value');
      %
      % just in case we made a logical mistake about when graphing is allowed
      %
      if tempdummy+permdummy>0;
         if tempdummy==1;
            d_begin = get(altmod_controls.tempbegin,'Value');
            d_end = get(altmod_controls.tempend,'Value');
            d_acc = get(altmod_controls.tempacc,'Value');
         else;
            d_begin = get(altmod_controls.permbegin,'Value');
            d_end = tm.T;
            d_acc = get(altmod_controls.permacc,'Value');
         end;
         if (d_begin>1)&(d_end<tm.T);
            data_dummy = [zeros(d_begin-1,1);ones(d_end-d_begin+1,1);zeros(tm.T-d_end,1)];
         elseif d_begin==1;
            data_dummy = [ones(d_end,1);zeros(tm.T-d_end,1)];
         else;
            data_dummy = [zeros(d_begin-1,1);ones(tm.T-d_begin+1,1)];
         end;
         if d_acc==1;
            data_dummy = cumsum(data_dummy);
         end;
         %
         realscrsz = get(0,'ScreenSize');
         thisplot = figure('Units','pixels', ...
            'Position',[(realscrsz(3)-512)/2 (realscrsz(4)-384)/2 512 384], ...
            'Menubar','none', ...
            'Toolbar','none', ...
            'NumberTitle','off', ...
            'Visible','off', ...
            'Name','Time Series Plot of Dummy');
         %
         % default figure properties
         %
         setfigureproperties(thisplot);
         %
         [y1,y2] = stairs(tm.dataindex,data_dummy);
         hp = plot(y1,y2,'-','LineWidth',1,'Color',colorstr);
         set(hp,'Tag','dummy');
         set(gca,'YLim',[min(data_dummy)-0.1 max(data_dummy)+0.1]);
         set(gca,'XLim',[tm.dataindex(1,1) tm.dataindex(tm.T,1)]);
         setaxesfonts('Title','Dummy variable for alternative model');
         toolbar_fcn(gca);
         set(thisplot,'Visible','on');
      end;
   case 'estimate'
      curr_ini = get(altmod_controls.permdummy,'UserData');
      tempdummy = get(altmod_controls.tempdummy,'Value');
      permdummy = get(altmod_controls.permdummy,'Value');
      if tempdummy+permdummy>0;
         if tempdummy==1;
            d_begin = get(altmod_controls.tempbegin,'Value');
            d_end = get(altmod_controls.tempend,'Value');
            d_acc = get(altmod_controls.tempacc,'Value');
            d_coint = get(altmod_controls.tempcoint,'Value');
            d_corel = get(altmod_controls.tempcorel,'Value');
            d_rank = get(altmod_controls.temprank,'Value');
            d_shortrun = get(altmod_controls.tempshortrun,'Value');
            if isempty(altmod_controls.tempcoidet)==0;
               d_coidet = get(altmod_controls.tempcoidet,'Value');
            else;
               d_coidet = 0;
            end;
         else;
            d_begin = get(altmod_controls.permbegin,'Value');
            d_end = tm.T;
            d_acc = get(altmod_controls.permacc,'Value');
            d_coint = get(altmod_controls.permcoint,'Value');
            d_corel = get(altmod_controls.permcorel,'Value');
            d_rank = get(altmod_controls.permrank,'Value');
            d_shortrun = get(altmod_controls.permshortrun,'Value');
            if isempty(altmod_controls.permcoidet)==0;
               d_coidet = get(altmod_controls.permcoidet,'Value');
            else;
               d_coidet = 0;
            end;
         end;
         if (d_begin>1)&(d_end<tm.T);
            data_dummy = [zeros(d_begin-1,1);ones(d_end-d_begin+1,1);zeros(tm.T-d_end,1)];
         elseif d_begin==1;
            data_dummy = [ones(d_end,1);zeros(tm.T-d_end,1)];
         else;
            data_dummy = [zeros(d_begin-1,1);ones(tm.T-d_begin+1,1)];
         end;
         if d_acc==1;
            data_dummy = cumsum(data_dummy);
         end;
         if (d_corel==1)&(d_rank==3);
            data_dummy = 1-data_dummy;
         end;
         %
         % check to make sure it can be estimated
         %
         %
         % check rank of [tm.Z1;data_dummy';tm.Z2]
         %
         bad_dummy = 0;
         if d_corel==0;
            if d_shortrun==0;
               test_mat = [tm.Z1;data_dummy';tm.Z2];
               if size(test_mat,1)>rank(test_mat);
                  bad_dummy = 1;
               end;
            else;
               test_mat = tm.Z2(tm.d+1:size(tm.Z2,1),:);
               num_ones = sum((data_dummy>0));
               num_zeros = sum((data_dummy==0));
               if min(num_ones,num_zeros)<=size(test_mat,1);
                  bad_dummy = 3;
               end;
            end;
         else;
            num_ones = sum((data_dummy>0));
            num_zeros = sum((data_dummy==0));
            if min(num_ones,num_zeros)<=size(tm.Z1,1);
               bad_dummy = 2;
            end;
         end;
         %
         if bad_dummy==0;
            if d_rank==1;
               %
               % we can start estimating
               %
               am.Z0 = tm.Z0;
               if d_coint==0;
                  if d_corel==0;
                     am.Z1 = tm.Z1;
                     if d_shortrun==0;
                        am.Z2 = [data_dummy';tm.Z2];
                     else;
                        test_mat = tm.Z2(tm.d+1:size(tm.Z2,1),:);
                        am.Z2 = [];
                        if tm.d>0;
                           am.Z2 = tm.Z2(1:tm.d,:);
                        end;
                        am.Z2 = [am.Z2;test_mat .* (ones(size(test_mat,1),1)*(1-data_dummy'));test_mat .* (ones(size(test_mat,1),1)*data_dummy')];
                     end;
                  else;
                     %
                     % we have a break in the cointegration space
                     %
                     if d_coidet==0;
                        am.Z1 = [tm.Z1 .* (ones(size(tm.Z1,1),1)*(1-data_dummy'));tm.Z1 .* (ones(size(tm.Z1,1),1)*data_dummy')];
                     else;
                        am.Z1 = [tm.Z1(1:size(tm.Z1,1)-1,:) .* (ones(size(tm.Z1,1)-1,1)*(1-data_dummy'));tm.Z1(size(tm.Z1,1),:);tm.Z1(1:size(tm.Z1,1)-1,:) .* (ones(size(tm.Z1,1)-1,1)*data_dummy')];
                     end;
                     am.Z2 = tm.Z2;
                  end;
               else;
                  am.Z1 = [tm.Z1;data_dummy'];
                  am.Z2 = tm.Z2;
               end;
               %
               % check that the dummy doesn't make am.Z1 or am.Z2 being singular
               %
               if rank(am.Z1)<size(am.Z1,1);
                  bad_dummy = 4;
               else;
                  if isempty(am.Z2)==0;
                     if rank(am.Z2)<size(am.Z2,1);
                        bad_dummy = 5;
                     end;
                  end;
               end;
               if bad_dummy==0;
                  [am.S_00,am.S_01,am.S_10,am.S_11,am.M_02,am.M_22,am.M_12,am.beta,am.lambda,am.trace] = mlcointbasic(am.Z0,am.Z1,am.Z2,tm.my_r);
                  %
                  % need to run a routine which can have dcoint 1 and have a dummy in the cointegration space
                  %
                  if tm.restrict(1,2)==1;
                     [am.beta,am.dfbeta,const_rest] = beta_alt_estimate(am.S_00,am.S_11,am.S_01,am.S_10,am.beta,tm.T,tm.modelsdir,tm.modelfile,tm.dcoint,tm.q1,d_coint,d_corel,d_coidet);
                  end;
                  %
                  am.alpha = (am.S_01*am.beta)/(am.beta'*am.S_11*am.beta);
                  if isempty(am.Z2)==0;
                     am.Psi = (am.M_02/am.M_22)-(am.alpha*am.beta'*(am.M_12/am.M_22));
                     am.Z = [am.Z2;am.beta'*am.Z1];
                  else;
                     am.Psi = [];
                     am.Z = am.beta'*am.Z1;
                  end;
                  Theta = [am.Psi am.alpha];
                  am.epsilon = am.Z0-(Theta*am.Z);
                  am.Omega = (1/tm.T)*am.epsilon*am.epsilon';
                  if tm.restrict(1,1)==1;
                     %
                     % estimate alpha under restrictions
                     %
                     file = strcat(tm.modelsdir,'G-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
                     G = loaddata(file);
                     [Rmat,rvec] = rmatrix(G,tm.n,tm.r);
                     am.dfalpha = size(G,1);
                     if isempty(am.Z2)==0;
                        Rmat = [zeros(am.dfalpha,size(am.Z2,1)*tm.n) Rmat];
                     end;
                     if curr_ini.reestbeta==0;
                        [theta,Sigma_theta,infomat,abort] = linrest(am.Z0,am.Z,Theta,Rmat,rvec,0);
                     else;
                        %
                        % re-estimate beta under alpha restrictions
                        %
                        [theta,am.beta,am.Z] = alpha_beta_alt_estimate(am.Z0,am.Z1,am.Z2,am.Z,am.beta,Theta,Rmat,rvec,tm.dcoint,tm.q1,tm.modelsdir,tm.modelfile,d_coint,d_corel,d_coidet);
                     end;
                     g2 = size(theta,2);
                     am.alpha = theta(:,g2-tm.r+1:g2);
                     if g2>tm.r;
                        am.Psi = theta(:,1:g2-tm.r);
                     else;
                        am.Psi = [];
                     end;
                     am.epsilon = am.Z0-(theta*am.Z);
                     am.Omega = (1/tm.T)*am.epsilon*am.epsilon';
                     Theta = theta;
                  end;
                  %
                  % consider restrictions on C
                  %
                  if (size(tm.restrict,2)==3)&(tm.restrict(1,3)==1);
                     %
                     % collect restrictions on C
                     %
                     file = strcat(tm.modelsdir,'C-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
                     Cres = loaddata(file);
                     [Rmat_C,rvec_C] = rmatrix(Cres,tm.n,tm.n);
                     %
                     % Estimate under C restrictions
                     %
                     d_parm = tm.d;
                     if d_corel==0;
                        d_parm = tm.d+(1-d_coint);
                     end;
                     [theta,am.beta] = c_alt_restrict(am.Z0,am.Z1,am.Z2,tm.restrict,am.beta,Theta,Rmat_C,rvec_C,tm.p,tm.pe,d_parm,tm.dcoint,tm.q0,tm.q1,tm.modelsdir,tm.modelfile,curr_ini.reestbeta,d_coint,d_corel,d_coidet);
                     am.Z = [];
                     if tm.r>0;
                        am.Z = am.beta'*am.Z1;
                     end;
                     am.Z = [am.Z2;am.Z];
                     %
                     % fix all the other parameters
                     %
                     am.epsilon = am.Z0-(theta*am.Z);
                     am.Omega = (1/tm.T)*am.epsilon*am.epsilon';
                     g2 = size(theta,2);
                     if tm.r>0;
                        am.alpha = theta(:,g2-tm.r+1:g2);
                     else;
                        am.alpha = [];
                     end;
                     if g2>tm.r;
                        am.Psi = theta(:,1:g2-tm.r);
                     else;
                        am.Psi = [];
                     end;               
                     Theta = theta;
                  end;
                  %
                  lnl_null = loglike(tm.epsilon);
                  lnl_alt = loglike(am.epsilon);
                  lr_test = 2*(lnl_alt-lnl_null);
                  lr_warn = 0;
                  if d_corel==1;
                     if d_coidet==0;
                        lr_df = (size(am.beta,1)/2)*size(am.beta,2);
                     else;
                        lr_df = (tm.n+tm.q1)*size(am.beta,2);
                     end;
                     if tm.restrict(1,2)==1;
                        lr_df = round((((size(am.beta,1)-size(am.beta,2))*size(am.beta,2))-am.dfbeta-const_rest)/2);
                        if lr_df==0;
                           lr_warn = 1;
                        end;
                     end;
                  else;
                     if d_coint==1;
                        lr_df = tm.r;
                     else;
                        if d_shortrun==0;
                           lr_df = tm.n;
                        else;
                           lr_df = size(test_mat,1)*tm.n;
                        end;
                     end;
                  end;
                  if lr_warn==0;
                     lr_pval = 1-chis_cdf(lr_test,lr_df);
                  end;
                  %
                  tm.old_d = tm.d;
                  if (d_corel==0)&(d_shortrun==0);
                     tm.d = tm.d+(1-d_coint);
                  end;
                  %
                  % the parameters of interest are: am.beta, am.Psi, am.alpha, and am.Omega
                  %
                  if lr_warn==0;
                     txt = strvcat(' ','   LR test of the original model against the alternative model','   -----------------------------------------------------------',' ');
                     txt = strvcat(txt,['LR(' num2str(lr_df,'%0.0f') ') = ' num2str(lr_test,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])],['p-value = ' num2str(lr_pval,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])]);
                     txt = strvcat(txt,' ',['   Original model:    lnL = ' num2str(lnl_null,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])],['   Alternative model: lnL = ' num2str(lnl_alt,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])],' ');
                  else;
                     txt = strvcat(' ','WARNING: The original and the alternative models are equivalent!');
                  end;
                  sp_str = spacestr(curr_ini.decimals-2);
                  txt = strvcat(txt,' ','   Estimated Parameters for the Alternative Model','   ----------------------------------------------',' ');
                  txt = strvcat(txt,'Cointegration Relations',' ');
                  n_txt = 'Number';
                  new_txt = '';
                  for i=1:tm.n;
                     new_txt = [new_txt '      ' sp_str tm.myvars(i,:)];
                  end;
                  if strcmp(tm.restvec,'')==0;
                     new_txt = [new_txt '   ' sp_str tm.restvec];
                  end;
                  if d_coint>0;
                     new_txt = [new_txt '     dummy'];
                  elseif d_corel==1;
                     new_txt = [new_txt new_txt];
                  end;
                  txt = strvcat(txt,[n_txt new_txt]);
                  prt_str = ['%' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
                  if d_coidet==1;
                     am.beta = [am.beta;am.beta(tm.n+tm.q1+tm.dcoint,:)];
                  end;
                  bpr_str = ' %2.0f   ';
                  for i=1:size(am.beta,1);
                     bpr_str = [bpr_str prt_str];
                  end;
                  for i=1:size(am.beta,2);
                     txt = strvcat(txt,sprintf(bpr_str,i,am.beta(:,i)));
                  end;
                  if tm.d>0;
                     deltamat = am.Psi(:,1:tm.d);
                  else;
                     deltamat = [];
                  end;
                  if d_corel==0;
                     if tm.dcoint+d_coint>0;
                        deltamat = [deltamat am.alpha*am.beta(tm.n+tm.q1+1:size(am.beta,1),:)'];
                     end;
                  else;
                     if tm.dcoint>0;
                        deltamat = [deltamat am.alpha*am.beta(tm.n+tm.q1+1,:)' am.alpha*am.beta(size(am.beta,1),:)'];
                     end;
                  end;
                  %
                  % create strings to display deltamat
                  %
                  if isempty(deltamat)==0;
                     new_txt = '';
                     if tm.old_d>1;
                        dt_str = vecstr(tm.deter);
                        for i=1:tm.old_d;
                           new_txt = [new_txt '   ' sp_str dt_str(i,:)];
                        end;
                     else;
                        new_txt = tm.deter;
                     end;
                     if (d_coint==0)&(d_corel==0)&(d_shortrun==0);
                        new_txt = ['     dummy' new_txt];
                     end;
                     new_txt = ['equation ' sp_str new_txt];
                     add_txt = '';
                     if d_shortrun==0;
                        if (d_coint>0)&(tm.dcoint==1);
                           add_txt = [tm.restvec sp_str '   dummy'];
                        elseif (d_coint==0)&(tm.dcoint==1)&(d_corel==0);
                           add_txt = tm.restvec;
                        elseif (d_corel==1)&(tm.dcoint==1);
                           add_txt = [tm.restvec '   ' sp_str tm.restvec];
                        end;
                     else;
                        if tm.dcoint==1;
                           add_txt = tm.restvec;
                        end;
                     end;
                     new_txt = strtrim([new_txt '     ' add_txt]);
                     txt = strvcat(txt,' ','Deterministic Terms',' ',new_txt);
                     dp_str = '';
                     for i=1:size(deltamat,2);
                        dp_str = [dp_str prt_str];
                     end;
                     for i=1:size(deltamat,1);
                        txt = strvcat(txt,sprintf(['   %s      ' dp_str],tm.myvars(i,:),deltamat(i,:)));
                     end;
                  end;
                  txt = strvcat(txt,' ','Alpha Parameters',' ');
                  ap_str = '   %s    ';
                  for i=1:size(am.alpha,2);
                     ap_str = [ap_str prt_str];
                  end;
                  for i=1:tm.n;
                     txt = strvcat(txt,sprintf(ap_str,tm.myvars(i,:),am.alpha(i,:)));
                  end;
                  %
                  % if dummy has been applied to short-run dynamics
                  %
                  if d_shortrun==1;
                     shortstr = '';
                     s_d = size(test_mat,1);
                     shortstr = strvcat(shortstr,['Endogenous variables: ' tm.evars]);
                     gp_str = '   %s    ';
                     for i=1:tm.n;
                        gp_str = [gp_str prt_str];
                     end;
                     for j=1:tm.p-1;
                        shortstr = strvcat(shortstr,' ',['               First difference lag ' num2str(j)],'               (when dummy is 0)',' ');
                        for i=1:tm.n;
                           shortstr = strvcat(shortstr,sprintf(gp_str,tm.myvars(i,:),am.Psi(i,tm.d+1+tm.n*(j-1):tm.d+tm.n*j)));
                        end;
                        shortstr = strvcat(shortstr,' ',['               First difference lag ' num2str(j)],'               (when dummy is 1)',' ');
                        for i=1:tm.n;
                           shortstr = strvcat(shortstr,sprintf(gp_str,tm.myvars(i,:),am.Psi(i,tm.d+s_d+1+tm.n*(j-1):tm.d+s_d+tm.n*j)));
                        end;
                     end;
                     txt = strvcat(txt,' ',shortstr);
                  end;
                  %
                  realscrsz = get(0,'ScreenSize');
                  %
                  textgui(txt,'Alternative Model',[(realscrsz(3)-700)/2 (realscrsz(4)-500)/2 700 500],'Results',38);
                  %
                  tm.d = tm.old_d;
               else;
                  if bad_dummy==4;
                     txt = 'The dummy variable you have created makes some of the levels variables linearly dependent. It''s therefore impossible to extend that model with the new dummy variable. Please select another dummy!';
                     about(txt,'information','Bad Dummy...',120,500);
                  elseif bad_dummy==5;
                     txt = 'The dummy variable you have created makes some of the first difference, exogenous, and/or deterministic variables linearly dependent. It''s therefore impossible to extend that model with the new dummy variable. Please select another dummy!';
                     about(txt,'information','Bad Dummy...',120,500);
                  end;
               end;
            else;
               sp_str = spacestr(curr_ini.decimals-2);
               if d_rank==2;
                  my_r = tm.my_r;
                  r_0 = my_r;
                  r_1 = my_r+1;
               elseif d_rank==3;
                  my_r = tm.my_r-1;
                  r_0 = my_r+1;
                  r_1 = my_r;
               end;
               [beta_1,beta_2,alpha_1,alpha_2,Psi,Omega,epsilon] = varyrank(tm.Z0,tm.Z1,tm.Z2,data_dummy,my_r,1);
               lnL_orig = loglike(tm.epsilon);
               lnL_new = loglike(epsilon);
               if d_rank==2;
                  beta0 = beta_1;
                  beta1 = [beta_1 beta_2];
                  alpha0 = alpha_1;
                  alpha1 = [alpha_1 alpha_2];
               elseif d_rank==3;
                  beta0 = [beta_1 beta_2];
                  beta1 = beta_1;
                  alpha0 = [alpha_1 alpha_2];
                  alpha1 = alpha_1;
               end;
               %
               % collecting summary information into txt string variable
               %
               txt = strvcat(' ','Alternative model:',['    ' num2str(r_0) ' cointegration relations when dummy is 0'],['    ' num2str(r_1) ' cointegration relations when dummy is 1']);
               txt = strvcat(txt,' ',['   Original model:    lnL = ' num2str(lnL_orig,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])],['   Alternative model: lnL = ' num2str(lnL_new,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])],' ');
               txt = strvcat(txt,' ','   Estimated Parameters for the Alternative Model','   ----------------------------------------------',' ');
               txt = strvcat(txt,'Cointegration Relations when dummy is 0:',' ');
               %
               n_txt = 'Number ';
               new_txt = '';
               for i=1:tm.n;
                  new_txt = [new_txt '        ' strtrim(tm.myvars(i,:))];
               end;
               if strcmp(tm.restvec,'')==0;
                  new_txt = [new_txt '       ' tm.restvec];
               end;
               txt = strvcat(txt,[n_txt new_txt]);
               prt_str = ['%' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
               for i=1:size(beta0,2);
                  txt = strvcat(txt,['    ' num2str(i,'%0.0f') '         ' num2str(beta0(:,i)',prt_str)]);
               end;
               txt = strvcat(txt,' ','Cointegration Relations when dummy is 1:',' ');
               %
               if isempty(beta1)==0;
                  txt = strvcat(txt,[n_txt new_txt]);
                  for i=1:size(beta1,2);
                     txt = strvcat(txt,['    ' num2str(i,'%0.0f') '         ' num2str(beta1(:,i)',prt_str)]);
                  end;
               else;
                  txt = strvcat(txt,'    None');
               end;
               %
               if tm.d>0;
                  deltamat = Psi(:,1:tm.d);
               else;
                  deltamat = [];
               end;
               if tm.dcoint==1;
                  if r_1>0;
                     deltamat = [deltamat alpha0*beta0(tm.n+tm.q1+1:size(beta0,1),:)' alpha1*beta1(tm.n+tm.q1+1:size(beta1,1),:)'];
                  else;
                     deltamat = [deltamat alpha0*beta0(tm.n+tm.q1+1:size(beta0,1),:)' zeros(tm.n,1)];
                  end;
               end;
               %
               if isempty(deltamat)==0;
                  new_txt = ['equation      ' strtrim(tm.deter)];
                  if tm.dcoint==1;
                     new_txt = [new_txt '  ' sp_str tm.restvec '  ' sp_str tm.restvec];
                  end;
                  txt = strvcat(txt,' ','Deterministic Terms',' ',new_txt);
                  dp_str = '';
                  for i=1:size(deltamat,2);
                     dp_str = [dp_str ' %' num2str(4+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
                  end;
                  for i=1:size(deltamat,1);
                     txt = strvcat(txt,sprintf(['    %s        ' dp_str],tm.myvars(i,:),deltamat(i,:)));
                  end;
               end;
               if isempty(alpha0)==0;
                  txt = strvcat(txt,' ','Alpha Parameters when dummy is 0:',' ');
                  for i=1:tm.n;
                     txt = strvcat(txt,['    ' strtrim(tm.myvars(i,:)) '        ' num2str(alpha0(i,:),['%' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'])]);
                  end;
                  txt = strvcat(txt,' ',['   rank(alpha*beta'') = ' num2str(rank(alpha0*beta0'),'%0.0f')],' ');
               else;
                  txt = strvcat(txt,'Rank of alpha, beta when dummy is 0:',' ','   rank(alpha*beta'') = 0',' ');
               end;
               if isempty(alpha1)==0;
                  txt = strvcat(txt,'Alpha Parameters when dummy is 1:',' ');
                  for i=1:tm.n;
                     txt = strvcat(txt,['    ' strtrim(tm.myvars(i,:)) '        ' num2str(alpha1(i,:),['%' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'])]);
                  end;
                  txt = strvcat(txt,' ',['   rank(alpha*beta'') = ' num2str(rank(alpha1*beta1'),'%0.0f')]);
               else;
                  txt = strvcat(txt,'Rank of alpha, beta when dummy is 1:',' ','   rank(alpha*beta'') = 0');
               end;
               %
               realscrsz = get(0,'ScreenSize');
               %
               textgui(txt,'Alternative Model',[(realscrsz(3)-700)/2 (realscrsz(4)-500)/2 700 500],'Results',38);
            end;
         elseif bad_dummy==1;
            txt = 'The dummy variable you have created is linearly dependent of some of the variables in your original model. It''s therefore impossible to extend that model with the new dummy variable. Please select another dummy!';
            about(txt,'information','Bad Dummy...',120,500);
         elseif bad_dummy==2;
            txt = ['You have too few observations of the long-run relations in one of the regimes, i.e. ' num2str(min(num_ones,num_zeros),'%0.0f') '. You need at least ' num2str(size(tm.Z1,1)+1,'%0.0f') ' observations from each regime. Please select another regime dummy!'];
            about(txt,'information','Bad Dummy...',120,500);
         elseif bad_dummy==3;
            txt = 'You have too few observations in one of the regimes to estimate all the short-run parameters for that regime. Please select another dummy!';
            about(txt,'information','Bad Dummy...',120,500);
         end;
      end;
   case 'savemodel'
      curr_ini = get(altmod_controls.permdummy,'UserData');
      if tm.const_model(1)==1;
         alt_mat = [tm.outputdir  tm.modelfile '-nyblom-boot-alt-' num2str(tm.n) '-noconst.mat'];
      elseif tm.const_model(2)==1;
         alt_mat = [tm.outputdir  tm.modelfile '-nyblom-boot-alt-' num2str(tm.n) '-resconst.mat'];
      elseif tm.const_model(3)==1;
         alt_mat = [tm.outputdir  tm.modelfile '-nyblom-boot-alt-' num2str(tm.n) '-const.mat'];
      elseif tm.const_model(4)==1;
         alt_mat = [tm.outputdir  tm.modelfile '-nyblom-boot-alt-' num2str(tm.n) '-restrend.mat'];
      elseif tm.const_model(5)==1;
         alt_mat = [tm.outputdir  tm.modelfile '-nyblom-boot-alt-' num2str(tm.n) '-trend.mat'];
      end;
      tm.altmodel.saved = 1;
      altmodel = tm.altmodel;
      save(alt_mat,'altmodel');
      %
      set(altmod_controls.savemodel,'Enable','off');
   case 'checkacc_coint'
      %
      % check if we have check marked permcorel or tempcorel
      %
      if gco==altmod_controls.tempcorel;
         if get(altmod_controls.tempcorel,'Value')==1;
            set(altmod_controls.tempcoint,'Value',0);
            set(altmod_controls.tempacc,'Value',0);
            if sum(tm.restrict)==0;
               set(altmod_controls.temprank,'Enable','on','Value',tm.altmodel.temprank);
            end;
            set(altmod_controls.tempshortrun,'Value',0);
            if isempty(altmod_controls.tempcoidet)==0;
               set(altmod_controls.tempcoidet,'Enable','on','Value',tm.altmodel.tempcoidet);
            end;
         else;
            set(altmod_controls.temprank,'Enable','off','Value',1);
            if isempty(altmod_controls.tempcoidet)==0;
               set(altmod_controls.tempcoidet,'Enable','off','Value',0);
            end;
         end;
      elseif gco==altmod_controls.tempcoint;
         if get(altmod_controls.tempcoint,'Value')==1;
            set(altmod_controls.tempcorel,'Value',0);
            set(altmod_controls.temprank,'Enable','off','Value',1);
            set(altmod_controls.tempshortrun,'Value',0);
         end;
         if isempty(altmod_controls.tempcoidet)==0;
            set(altmod_controls.tempcoidet,'Enable','off','Value',0);
         end;
      elseif gco==altmod_controls.tempacc;
         if get(altmod_controls.tempacc,'Value')==1;
            set(altmod_controls.tempcorel,'Value',0);
            set(altmod_controls.temprank,'Enable','off','Value',1);
            set(altmod_controls.tempshortrun,'Value',0);
         end;
         if isempty(altmod_controls.tempcoidet)==0;
            set(altmod_controls.tempcoidet,'Enable','off','Value',0);
         end;
      elseif gco==altmod_controls.tempshortrun;
         if get(altmod_controls.tempshortrun,'Value')==1;
            set(altmod_controls.tempacc,'Value',0);
            set(altmod_controls.tempcoint,'Value',0);
            set(altmod_controls.tempcorel,'Value',0);
            set(altmod_controls.temprank,'Enable','off','Value',1);
         end;
         if isempty(altmod_controls.tempcoidet)==0;
            set(altmod_controls.tempcoidet,'Enable','off','Value',0);
         end;
      elseif gco==altmod_controls.temprank;
         if get(altmod_controls.temprank,'Value')>1;
            set(altmod_controls.lr_test,'Value',0,'Enable','off');
            set(altmod_controls.tempcoidet,'Enable','off','Value',0);
         else;
            set(altmod_controls.lr_test,'Enable','on');
            set(altmod_controls.tempcoidet,'Enable','on','Value',tm.altmodel.tempcoidet);
         end;
      elseif gco==altmod_controls.permcorel;
         if get(altmod_controls.permcorel,'Value')==1;
            set(altmod_controls.permcoint,'Value',0);
            set(altmod_controls.permacc,'Value',0);
            if sum(tm.restrict)==0;
               set(altmod_controls.permrank,'Enable','on','Value',tm.altmodel.permrank);
            end;
            set(altmod_controls.permshortrun,'Value',0);
            if isempty(altmod_controls.permcoidet)==0;
               set(altmod_controls.permcoidet,'Enable','on','Value',tm.altmodel.permcoidet);
            end;
         else;
            set(altmod_controls.permrank,'Enable','off','Value',1);
            if isempty(altmod_controls.permcoidet)==0;
               set(altmod_controls.permcoidet,'Enable','off','Value',0);
            end;
         end;
      elseif gco==altmod_controls.permcoint;
         if get(altmod_controls.permcoint,'Value')==1;
            set(altmod_controls.permcorel,'Value',0);
            set(altmod_controls.permrank,'Enable','off','Value',1);
            set(altmod_controls.permshortrun,'Value',0);
         end;
         if isempty(altmod_controls.permcoidet)==0;
            set(altmod_controls.permcoidet,'Enable','off','Value',0);
         end;
      elseif gco==altmod_controls.permacc;
         if get(altmod_controls.permacc,'Value')==1;
            set(altmod_controls.permcorel,'Value',0);
            set(altmod_controls.permrank,'Enable','off','Value',1);
            set(altmod_controls.permshortrun,'Value',0);
         end;
         if isempty(altmod_controls.permcoidet)==0;
            set(altmod_controls.permcoidet,'Enable','off','Value',0);
         end;
      elseif gco==altmod_controls.permshortrun;
         if get(altmod_controls.permshortrun,'Value')==1;
            set(altmod_controls.permacc,'Value',0);
            set(altmod_controls.permcoint,'Value',0);
            set(altmod_controls.permcorel,'Value',0);
            set(altmod_controls.permrank,'Enable','off','Value',1);
         end;
         if isempty(altmod_controls.permcoidet)==0;
            set(altmod_controls.permcoidet,'Enable','off','Value',0);
         end;
      elseif gco==altmod_controls.permrank;
         if get(altmod_controls.permrank,'Value')>1;
            set(altmod_controls.lr_test,'Value',0,'Enable','off');
            set(altmod_controls.permcoidet,'Enable','off','Value',0);
         else;
            set(altmod_controls.lr_test,'Enable','on');
            set(altmod_controls.permcoidet,'Enable','on','Value',tm.altmodel.permcoidet);
         end;
      end;
      set(altmod_controls.apply,'Enable','on')
   case 'checkpermperiod'
      beginp = get(altmod_controls.permbegin,'Value');
      if beginp~=tm.altmodel.permbegin;
         if beginp>1;
            set(altmod_controls.apply,'Enable','on');
         else;
            set(altmod_controls.permbegin,'Value',tm.altmodel.permbegin);
         end;
      end;
   case 'checkperiod'
      endp = get(altmod_controls.tempend,'Value');
      beginp = get(altmod_controls.tempbegin,'Value');
      if beginp>endp;
         endp = beginp;
         set(altmod_controls.tempend,'Value',endp);
      end;
      if (beginp~=tm.altmodel.tempbegin)|(endp~=tm.altmodel.tempend);
         if (beginp>1)|(endp<tm.T);
            set(altmod_controls.apply,'Enable','on');
         else;
            set(altmod_controls.tempbegin,'Value',tm.altmodel.tempbegin);
            set(altmod_controls.tempend,'Value',tm.altmodel.tempend);
         end;
      end;
   case 'checkdummy'
      if gco==altmod_controls.tempdummy;
         if get(gco,'Value')==1;
            set(altmod_controls.permdummy,'Enable','off');
            set(altmod_controls.tempbegin,'Enable','on');
            set(altmod_controls.tempend,'Enable','on');
            set(altmod_controls.icon,'Enable','on');
            set(altmod_controls.tempacc,'Enable','on');
            set(altmod_controls.tempcoint,'Enable','on');
            set(altmod_controls.tempcorel,'Enable','on');
            if (get(altmod_controls.tempcorel,'Value')==1)&(sum(tm.restrict)==0);
               set(altmod_controls.temprank,'Enable','on','Value',tm.altmodel.temprank);
            end;
            if isempty(altmod_controls.tempcoidet)==0;
               if (get(altmod_controls.tempcorel,'Value')==1)&(get(altmod_controls.temprank,'Value')==1);
                  set(altmod_controls.tempcoidet,'Enable','on','Value',tm.altmodel.tempcoidet);
               else;
                  set(altmod_controls.tempcoidet,'Enable','off','Value',0);
               end;
            end;
            if ((size(tm.restrict,2)==2)|(tm.restrict(1,3)==0))&((tm.p>1)|(tm.q1+tm.q0>0))&(get(altmod_controls.tempdummy,'Value')==1);
               set(altmod_controls.tempshortrun,'Enable','on','Value',tm.altmodel.tempshortrun);
            else;
               set(altmod_controls.tempshortrun,'Enable','off','Value',0);
            end;
         else;
            set(altmod_controls.permdummy,'Enable','on');
            set(altmod_controls.tempbegin,'Enable','off');
            set(altmod_controls.tempend,'Enable','off');
            set(altmod_controls.icon,'Enable','off');
            set(altmod_controls.tempacc,'Enable','off');
            set(altmod_controls.tempcoint,'Enable','off');
            set(altmod_controls.tempcorel,'Enable','off');
            set(altmod_controls.temprank,'Enable','off','Value',1);
            set(altmod_controls.tempshortrun,'Enable','off','Value',0);
            if isempty(altmod_controls.tempcoidet)==0;
               set(altmod_controls.tempcoidet,'Enable','off','Value',0);
            end;
         end;
      elseif gco==altmod_controls.permdummy;
         if get(gco,'Value')==1;
            set(altmod_controls.tempdummy,'Enable','off');
            set(altmod_controls.permbegin,'Enable','on');
            set(altmod_controls.permacc,'Enable','on');
            set(altmod_controls.permcoint,'Enable','on');
            set(altmod_controls.permcorel,'Enable','on');
            if (get(altmod_controls.permcorel,'Value')==1)&(sum(tm.restrict)==0);
               set(altmod_controls.permrank,'Enable','on','Value',tm.altmodel.permrank);
            end;
            if isempty(altmod_controls.permcoidet)==0;
               if (get(altmod_controls.permcorel,'Value')==1)&(get(altmod_controls.permrank,'Value')==1);
                  set(altmod_controls.permcoidet,'Enable','on','Value',tm.altmodel.permcoidet);
               else;
                  set(altmod_controls.permcoidet,'Enable','off','Value',0);
               end;
            end;
            if ((size(tm.restrict,2)==2)|(tm.restrict(1,3)==0))&((tm.p>1)|(tm.q1+tm.q0>0))&(get(altmod_controls.permdummy,'Value')==1);
               set(altmod_controls.permshortrun,'Enable','on','Value',tm.altmodel.permshortrun);
            else;
               set(altmod_controls.permshortrun,'Enable','off','Value',0);
            end;
         else;
            set(altmod_controls.tempdummy,'Enable','on');
            set(altmod_controls.permbegin,'Enable','off');
            set(altmod_controls.permacc,'Enable','off');
            set(altmod_controls.permcoint,'Enable','off');
            set(altmod_controls.permcorel,'Enable','off');
            set(altmod_controls.permrank,'Enable','off','Value',1);
            set(altmod_controls.permshortrun,'Enable','off','Value',0);
            if isempty(altmod_controls.permcoidet)==0;
               set(altmod_controls.permcoidet,'Enable','off','Value',0);
            end;
         end;
      end;
      if (get(altmod_controls.tempdummy,'Value')==1)|(get(altmod_controls.permdummy,'Value')==1);
         set(altmod_controls.graphdummy,'Enable','on');
         set(altmod_controls.estimate,'Enable','on');
      else;
         set(altmod_controls.graphdummy,'Enable','off');
         set(altmod_controls.estimate,'Enable','off');
      end;
      set(altmod_controls.apply,'Enable','on');
   case 'apply'
      %
      % need to check first if the created dummy is a "new variable"
      % instead of an "old variable"
      %
      bad_dummy = 0;
      tempdummy = get(altmod_controls.tempdummy,'Value');
      permdummy = get(altmod_controls.permdummy,'Value');
      %
      if tempdummy+permdummy>0;
         if tempdummy==1;
            d_begin = get(altmod_controls.tempbegin,'Value');
            d_end = get(altmod_controls.tempend,'Value');
            d_acc = get(altmod_controls.tempacc,'Value');
            d_corel = get(altmod_controls.tempcorel,'Value');
            d_rank = get(altmod_controls.temprank,'Value');
            d_shortrun = get(altmod_controls.tempshortrun,'Value');
         else;
            d_begin = get(altmod_controls.permbegin,'Value');
            d_end = tm.T;
            d_acc = get(altmod_controls.permacc,'Value');
            d_corel = get(altmod_controls.permcorel,'Value');
            d_rank = get(altmod_controls.permrank,'Value');
            d_shortrun = get(altmod_controls.permshortrun,'Value');
         end;
         if (d_begin>1)&(d_end<tm.T);
            data_dummy = [zeros(d_begin-1,1);ones(d_end-d_begin+1,1);zeros(tm.T-d_end,1)];
         elseif d_begin==1;
            data_dummy = [ones(d_end,1);zeros(tm.T-d_end,1)];
         else;
            data_dummy = [zeros(d_begin-1,1);ones(tm.T-d_begin+1,1)];
         end;
         if d_acc==1;
            data_dummy = cumsum(data_dummy);
         end;
         if (d_corel==1)&(d_rank==3);
            data_dummy = 1-data_dummy;
         end;
         %
         if strcmp(tm.deterfile,'')==0;
            %
            % check rank of [tm.Z1;data_dummy';tm.Z2]
            %
            if d_corel==0;
               if d_shortrun==0;
                  test_mat = [tm.Z1;data_dummy';tm.Z2];
                  if size(test_mat,1)>rank(test_mat);
                     bad_dummy = 1;
                  end;
               else;
                  test_mat = tm.Z2(tm.d+1:size(tm.Z2,1),:);
                  num_ones = sum((data_dummy>0));
                  num_zeros = sum((data_dummy==0));
                  if min(num_ones,num_zeros)<=size(test_mat,1);
                     bad_dummy = 3;
                  end;
               end;
            else;
               num_ones = sum((data_dummy>0));
               num_zeros = sum((data_dummy==0));
               if min(num_ones,num_zeros)<=size(tm.Z1,1);
                  bad_dummy = 2;
               end;
            end;
         else;
            if d_corel==1;
               num_ones = sum((data_dummy>0));
               num_zeros = sum((data_dummy==0));
               if min(num_ones,num_zeros)<=size(tm.Z1,1);
                  bad_dummy = 2;
               end;
            elseif d_shortrun==1;
               test_mat = tm.Z2(tm.d+1:size(tm.Z2,1),:);
               num_ones = sum((data_dummy>0));
               num_zeros = sum((data_dummy==0));
               if min(num_ones,num_zeros)<=size(test_mat,1);
                  bad_dummy = 3;
               end;
            end;
         end;
         if bad_dummy==0;
            tm.altmodel.tempdummy = get(altmod_controls.tempdummy,'Value');
            tm.altmodel.tempbegin = get(altmod_controls.tempbegin,'Value');
            tm.altmodel.tempend = get(altmod_controls.tempend,'Value');
            tm.altmodel.tempacc = get(altmod_controls.tempacc,'Value');
            tm.altmodel.tempcoint = get(altmod_controls.tempcoint,'Value');
            tm.altmodel.tempcorel = get(altmod_controls.tempcorel,'Value');
            tm.altmodel.temprank = get(altmod_controls.temprank,'Value');
            tm.altmodel.tempshortrun = get(altmod_controls.tempshortrun,'Value');
            %
            if isempty(altmod_controls.tempcoidet)==0;
               tm.altmodel.tempcoidet = get(altmod_controls.tempcoidet,'Value');
            end;
            %
            tm.altmodel.permdummy = get(altmod_controls.permdummy,'Value');
            tm.altmodel.permbegin = get(altmod_controls.permbegin,'Value');
            tm.altmodel.permacc = get(altmod_controls.permacc,'Value');
            tm.altmodel.permcoint = get(altmod_controls.permcoint,'Value');
            tm.altmodel.permcorel = get(altmod_controls.permcorel,'Value');
            tm.altmodel.permrank = get(altmod_controls.permrank,'Value');
            tm.altmodel.permshortrun = get(altmod_controls.permshortrun,'Value');
            %
            if isempty(altmod_controls.permcoidet)==0;
               tm.altmodel.permcoidet = get(altmod_controls.permcoidet,'Value');
            end;
            %
            tm.altmodel.relsample = get(altmod_controls.relsample,'Value');
            tm.altmodel.bootlr = get(altmod_controls.lr_test,'Value');
            %
            set(altmod_controls.graphdummy,'Enable','on');
            set(altmod_controls.estimate,'Enable','on');
            set(altmod_controls.savemodel,'Enable','on');
            tm.altmodel.changed = 1;
            tm.altmodel.saved = 0;
            set(altmod_controls.apply,'Enable','off');
         elseif bad_dummy==1;
            %
            % the created dummy variable is a linear combination of the variables
            % in tm.Z1 and tm.Z2. It can therefore not be used as an addition to
            % an alternative model
            %
            txt = ['The dummy variable you have created is linearly dependent of some of the variables in your original model. It''s therefore not possible to extend that model with the new dummy variable. Please select another dummy!'];
            about(txt,'information','Bad Dummy...',120,500);
         elseif bad_dummy==2;
            txt = ['You have too few observations of the long-run relations in one of the regimes, i.e., ' num2str(min(num_ones,num_zeros),'%0.0f') '. You need at least ' num2str(size(tm.Z1,1)+1,'%0.0f') ' observations from each regime. Please select another regime dummy!'];
            about(txt,'information','Bad Dummy...',120,500);
         elseif bad_dummy==3;
            txt = 'You have too few observations in one of the regimes to estimate all the short-run parameters for that regime. Please select another dummy!';
            about(txt,'information','Bad Dummy...',120,500);
         end;
      else;
         tm.altmodel.tempdummy = get(altmod_controls.tempdummy,'Value');
         tm.altmodel.tempbegin = get(altmod_controls.tempbegin,'Value');
         tm.altmodel.tempend = get(altmod_controls.tempend,'Value');
         tm.altmodel.tempacc = get(altmod_controls.tempacc,'Value');
         tm.altmodel.tempcoint = get(altmod_controls.tempcoint,'Value');
         tm.altmodel.tempcorel = get(altmod_controls.tempcorel,'Value');
         tm.altmodel.temprank = get(altmod_controls.temprank,'Value');
         tm.altmodel.tempshortrun = get(altmod_controls.tempshortrun,'Value');
         %
         if isempty(altmod_controls.tempcoidet)==0;
            tm.altmodel.tempcoidet = get(altmod_controls.tempcoidet,'Value');
         end;
         %
         tm.altmodel.permdummy = get(altmod_controls.permdummy,'Value');
         tm.altmodel.permbegin = get(altmod_controls.permbegin,'Value');
         tm.altmodel.permacc = get(altmod_controls.permacc,'Value');
         tm.altmodel.permcoint = get(altmod_controls.permcoint,'Value');
         tm.altmodel.permcorel = get(altmod_controls.permcorel,'Value');
         tm.altmodel.permrank = get(altmod_controls.permrank,'Value');
         tm.altmodel.permshortrun = get(altmod_controls.permshortrun,'Value');
         %
         if isempty(altmod_controls.permcoidet)==0;
            tm.altmodel.permcoidet = get(altmod_controls.permcoidet,'Value');
         end;
         %
         tm.altmodel.relsample = get(altmod_controls.relsample,'Value');
         tm.altmodel.bootlr = get(altmod_controls.lr_test,'Value');
         %
         set(altmod_controls.graphdummy,'Enable','off');
         set(altmod_controls.estimate,'Enable','off');
         set(altmod_controls.savemodel,'Enable','on');
         tm.altmodel.changed = 1;
         tm.altmodel.saved = 0;
         set(altmod_controls.apply,'Enable','off');
      end;
   case 'cancel';
      fix_save = 0;
      if tm.altmodel.saved==1;
         fix_save = 1;
      end;
      tm.altmodel = tm.oldaltmodel;
      set(altmod_controls.tempdummy,'Value',tm.altmodel.tempdummy);
      set(altmod_controls.tempbegin,'Value',tm.altmodel.tempbegin);
      set(altmod_controls.tempend,'Value',tm.altmodel.tempend);
      set(altmod_controls.tempacc,'Value',tm.altmodel.tempacc);
      set(altmod_controls.tempcoint,'Value',tm.altmodel.tempcoint);
      set(altmod_controls.tempcorel,'Value',tm.altmodel.tempcorel);
      set(altmod_controls.relsample,'Value',tm.altmodel.relsample);
      if tm.altmodel.tempdummy==0;
         set(altmod_controls.permdummy,'Enable','on');
         set(altmod_controls.tempbegin,'Enable','off');
         set(altmod_controls.tempend,'Enable','off');
         set(altmod_controls.icon,'Enable','off');
         set(altmod_controls.tempacc,'Enable','off');
         set(altmod_controls.tempcoint,'Enable','off');
         set(altmod_controls.tempcorel,'Enable','off');
         set(altmod_controls.temprank,'Enable','off','Value',1);
         set(altmod_controls.tempshortrun,'Enable','off','Value',0);
         if isempty(altmod_controls.tempcoidet)==0;
            set(altmod_controls.tempcoidet,'Enable','off','Value',0);
         end;
      else;
         set(altmod_controls.permdummy,'Enable','off');
         set(altmod_controls.tempbegin,'Enable','on');
         set(altmod_controls.tempend,'Enable','on');
         set(altmod_controls.icon,'Enable','on');
         set(altmod_controls.tempacc,'Enable','on');
         set(altmod_controls.tempcoint,'Enable','on');
         set(altmod_controls.tempcorel,'Enable','on');
         if (get(altmod_controls.tempcorel,'Value')==1)&(sum(tm.restrict)==0);
            set(altmod_controls.temprank,'Enable','on','Value',tm.altmodel.temprank);
         else;
            set(altmod_controls.temprank,'Enable','off','Value',1);
         end;
         if isempty(altmod_controls.tempcoidet)==0;
            if (get(altmod_controls.tempcorel,'Value')==1)&(get(altmod_controls.temprank,'Value')==1);
               set(altmod_controls.tempcoidet,'Enable','on','Value',tm.altmodel.tempcoidet);
            else;
               set(altmod_controls.tempcoidet,'Enable','off','Value',0);
            end;
         end;
         if ((size(tm.restrict,2)==2)|(tm.restrict(1,3)==0))&((tm.p>1)|(tm.q1+tm.q0>0))&(get(altmod_controls.tempdummy,'Value')==1);
            set(altmod_controls.tempshortrun,'Enable','on','Value',tm.altmodel.tempshortrun);
         else;
            set(altmod_controls.tempshortrun,'Enable','off','Value',0);
         end;
      end;
      %
      set(altmod_controls.permdummy,'Value',tm.altmodel.permdummy);
      set(altmod_controls.permbegin,'Value',tm.altmodel.permbegin);
      set(altmod_controls.permacc,'Value',tm.altmodel.permacc);
      set(altmod_controls.permcoint,'Value',tm.altmodel.permcoint);
      set(altmod_controls.permcorel,'Value',tm.altmodel.permcorel);
      if tm.altmodel.permdummy==0;
         set(altmod_controls.tempdummy,'Enable','on');
         set(altmod_controls.permbegin,'Enable','off');
         set(altmod_controls.permacc,'Enable','off');
         set(altmod_controls.permcoint,'Enable','off');
         set(altmod_controls.permcorel,'Enable','off');
         set(altmod_controls.permrank,'Enable','off','Value',1);
         set(altmod_controls.permshortrun,'Enable','off','Value',0);
         if isempty(altmod_controls.permcoidet)==0;
            set(altmod_controls.permcoidet,'Enable','off','Value',0);
         end;
      else;
         set(altmod_controls.tempdummy,'Enable','off');
         set(altmod_controls.permbegin,'Enable','on');
         set(altmod_controls.permacc,'Enable','on');
         set(altmod_controls.permcoint,'Enable','on');
         set(altmod_controls.permcorel,'Enable','on');
         if (get(altmod_controls.permcorel,'Value')==1)&(sum(tm.restrict)==0);
            set(altmod_controls.permrank,'Enable','on','Value',tm.altmodel.permrank);
         else;
            set(altmod_controls.permrank,'Enable','off','Value',1);
         end;
         if isempty(altmod_controls.permcoidet)==0;
            if (get(altmod_controls.permcorel,'Value')==1)&(get(altmod_controls.permrank,'Value')==1);
               set(altmod_controls.permcoidet,'Enable','on','Value',tm.altmodel.permcoidet);
            else;
               set(altmod_controls.permcoidet,'Enable','off','Value',0);
            end;
         end;
         if ((size(tm.restrict,2)==2)|(tm.restrict(1,3)==0))&((tm.p>1)|(tm.q1+tm.q0>0))&(get(altmod_controls.permdummy,'Value')==1);
            set(altmod_controls.permshortrun,'Enable','on','Value',tm.altmodel.permshortrun);
         else;
            set(altmod_controls.permshortrun,'Enable','off','Value',0);
         end;
      end;
      %
      if (get(altmod_controls.temprank,'Value')>1)|(get(altmod_controls.permrank,'Value')>1);
         set(altmod_controls.lr_test,'Enable','off','Value',0);
      else;
         set(altmod_controls.lr_test,'Enable','on','Value',tm.altmodel.bootlr);
      end;
      %
      if (tm.altmodel.tempdummy==1)|(tm.altmodel.permdummy==1);
         set(altmod_controls.graphdummy,'Enable','on');
         set(altmod_controls.estimate,'Enable','on');
      else;
         set(altmod_controls.graphdummy,'Enable','off');
         set(altmod_controls.estimate,'Enable','off');
      end;
      if (tm.altmodel.changed==1)&(fix_save==0);
         set(altmod_controls.savemodel,'Enable','on');
      else;
         set(altmod_controls.savemodel,'Enable','off');
      end;
      %
      tm.altmodel.changed = 0;
      set(altmod_controls.apply,'Enable','off');
      if fix_save==1;
         %
         % undo any changes to saved mat-file by replacing it with new data
         %
         curr_ini = get(altmod_controls.permdummy,'UserData');
         if tm.const_model(1)==1;
            alt_mat = [tm.outputdir  tm.modelfile '-nyblom-boot-alt-' num2str(tm.n) '-noconst.mat'];
         elseif tm.const_model(2)==1;
            alt_mat = [tm.outputdir  tm.modelfile '-nyblom-boot-alt-' num2str(tm.n) '-resconst.mat'];
         elseif tm.const_model(3)==1;
            alt_mat = [tm.outputdir  tm.modelfile '-nyblom-boot-alt-' num2str(tm.n) '-const.mat'];
         elseif tm.const_model(4)==1;
            alt_mat = [tm.outputdir  tm.modelfile '-nyblom-boot-alt-' num2str(tm.n) '-restrend.mat'];
         elseif tm.const_model(5)==1;
            alt_mat = [tm.outputdir  tm.modelfile '-nyblom-boot-alt-' num2str(tm.n) '-trend.mat'];
         end;
         tm.altmodel.saved = 1;
         altmodel = tm.altmodel;
         save(alt_mat,'altmodel');
      end;
      set(altmod_controls.savemodel,'Enable','off');
   case 'done';
      set(altmod_controls.done,'UserData','done');
      set(alt_gui,'UserData',altmod_controls);
end;

if strcmp(selector,'init')==1;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(alt_gui,'Name') ' ' fix_filepath([pwd '\icons\power.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(altmod_controls.icon,'UserData',pid);
      end;
   end;
   set(alt_gui,'Visible','on');
   drawnow;
   if (iswinnt==1)&(iscompiled==1)&(matlabnumber<7);
      drawnow;
      prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(alt_gui,'Name') ' 2'];
      dos(prog);
      drawnow;
   elseif matlabnumber>=7;
      uicontrol(altmod_controls.cancel);
   end;
end;

if nargout==1;
   h = alt_gui;
end;

if strcmp(selector,'done')==0;
   if (strcmp(get(altmod_controls.apply,'Enable'),'on'))&(strcmp(get(altmod_controls.savemodel,'Enable'),'on'));
      set(altmod_controls.savemodel,'Enable','off');
   end;
   set(altmod_controls.tempdummy,'UserData',tm);
end;

if thisexit==0;
   waitfor(altmod_controls.done,'UserData','done');
end;

%
% end of alt_model_dlg.m
%
