%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          Computes multivariate LR tests for serial             %
%             correlation                                        %
%                                                                %
%          Function: autocorr                                    %
%                                                                %
%          Input:                                                %
%                       epsilon: nxT matrix with residuals       %
%                       freq: data frequency                     %
%                       t: degrees of freedom from original      %
%                           estimates                            %
%                                                                %
%          Output:                                               %
%          	            autocorrvec: vector with results         %
%                       df: string with degrees of freedom       %
%                                                                %
%          This version:        June 1, 2004                     %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2004          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [autocorrvec,df] = autocorr(epsilon,freq,t);

[n T] = size(epsilon);
y = epsilon(:,2:T);
y1 = epsilon(:,1:T-1);

curr_ini = find_inisettings;

%
% create matrices for 1 year lag
%

if strcmp(freq,'')==0;
   if strcmp(freq,'q')==1;
      k = 4;
   else;
      k = 12;
   end;
   yk = epsilon(:,k+1:T);
   yk1 = epsilon(:,1:T-k);
end;

b = (y*y1')/(y1*y1');
eps1 = y-b*y1;

LR1 = (T-1)*log(det((1/(T-1))*y*y')/det((1/(T-1))*eps1*eps1'));
if curr_ini.bartserial==1;
   bc = 1+(1/(2*T*n*n))*((n*n)+(2*n*n*n)-(4*n));
   LR1 = LR1/bc;
end;
if curr_ini.sscorrect==0;
   autocorrvec = LR1;
   df = num2str(n*n);
   pval = chis_cdf(LR1,n*n);
   autocorrvec = [LR1 1-pval];
else;
   LR1 = ((t-n-1)/((T-1)*n*n))*LR1;
   autocorrvec = LR1;
   df = ['(' num2str(n*n) ',' num2str(t-1-n) ')'];
   pval = fdis_cdf(LR1,n*n,t-n-1);
   autocorrvec = [LR1 1-pval];
end;

if strcmp(freq,'')==0;
   bk = (yk*yk1')/(yk1*yk1');
   epsk = yk-bk*yk1;
   LRk = (T-k)*log(det((1/(T-k))*yk*yk')/det((1/(T-k))*epsk*epsk'));
   if curr_ini.bartserial==1;
      LRk = LRk/bc;
   end;
   if curr_ini.sscorrect==0;
      autocorrvec = [autocorrvec LRk];
      df = strvcat(df,num2str(n*n));
      pval = chis_cdf(LRk,n*n);
      autocorrvec = [autocorrvec 1-pval];
   else;
      LRk = ((t-n-k)/((T-k)*n*n))*LRk;
      autocorrvec = [autocorrvec LRk];
      df2 = ['(' num2str(n*n) ',' num2str(t-k-n) ')'];
      df = strvcat(df,df2);
      pval = fdis_cdf(LRk,n*n,t-n-k);
      autocorrvec = [autocorrvec 1-pval];
   end;
end;

%
% end of autocorr.m
%
