%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for displaying graphs of            %
%          cointegration relations                               %
%                                                                %
%          Function: bayes_graph_median                          %
%                                                                %
%          Input:                                                %
%                       selector: case switch function           %
%                       c_mod: structure with model info         %
%                       curr_ini: structure with options         %
%                          selections                            %
%                       median_mat: matrix with median estimates %
%                       param_str: string matrix with parameter  %
%                          names                                 %
%                       param_name: string with parameter type   %
%                       dist_type: string with distribution type %
%                                                                %
%          Output:                                               %
%                       h: handle                                %
%                                                                %
%          This version:        May 3, 2006                      %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function h = bayes_graph_median(selector,c_mod,curr_ini,median_mat,param_str,param_name,dist_type)

if strcmp(selector,'init')==1;
   tm = c_mod;
   thisexit = 0;
   tm.median_mat = median_mat;
   tm.param_name = param_name;
   tm.dist_type = dist_type;
   curr_ini.models = tm;
else;
   thisexit = 1;
   bayes_median_gui = get(0,'CurrentFigure');
   graph = get(bayes_median_gui,'UserData');
   curr_ini = get(graph.popup,'UserData');
   tm = curr_ini.models;
end;

%
% Set screen size directly instead of using
% get(0,'ScreenSize')!
%

realscrsz = get(0,'ScreenSize');

switch selector;
   case 'init';
      bayes_median_gui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','bayes_graph_median.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(realscrsz(3)-341)/2 (realscrsz(4)-140)/2 341 165], ...
         'Tag','FigParent', ...
         'Resize','off', ...
         'Visible','off', ...
         'Name',[param_name ' Convergence - ' dist_type ], ...
         'NumberTitle','off', ...
         'CloseRequestFcn','bayes_graph_median done', ...
         'ToolBar','none');

      if matlabnumber>=7.0;
         set(bayes_median_gui,'DockControl','off');
      end;

      %
      % Outer axis
      %

      axesbox([2 2 339 155],'Graphics',45,[0.5 1]);

      imageaxes = axes('Units','pixels', ...
         'Box','on', ...
         'TickLength',[0 0], ...
         'CameraUpVector',[0 1 0], ...
         'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[24 105 39 39], ...
         'XTickLabelMode','manual', ...
         'YTickLabelMode','manual', ...
         'Tag','AxisLogo', ...
         'XColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'YColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'ZColor',get(0,'defaultuicontrolbackgroundcolor'));

      mycons = getstoredimages;
      if curr_ini.use_toolbar_bgcolor==1;
         bgcolor = (1/255)*(round(255*get(0,'defaultuicontrolbackgroundcolor'))-[8 4 8]);
         bgcolor(1) = max(0,bgcolor(1));
         bgcolor(2) = max(0,bgcolor(2));
         bgcolor(3) = max(0,bgcolor(3));
      else;
         bgcolor = get(0,'defaultuicontrolbackgroundcolor');
      end;
      %
      image('CData',mirrorimage(maketrans(mycons.param_filebig_image,[160 160 164],bgcolor)),'Clipping','off','Parent',imageaxes);

      graph.icon = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[24 65 220 30], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'String',['Recursive median estimates for ' num2str(size(median_mat,2),'%0.0f') ' draws from the posterior.'], ...
         'HorizontalAlignment','left', ...
         'Tag','SampleText');

      %
      % Select variable
      %

      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[24 15 120 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'String','Select Parameter:', ...
         'HorizontalAlignment','left', ...
         'Tag','VariableText');

      graph.popup = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[124 20 100 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'String',param_str, ...
         'Tag','GraphListbox',...
         'Value',1);

      %
      % Create graph button
      %

      graph.show = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[236 55 90 20], ...
         'String','Display', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','bayes_graph_median showgraph', ...
         'UserData','working', ...
         'Enable','on', ...
         'Tag','Done');

      %
      %  Done button
      %

      graph.done = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[236 20 90 20], ...
         'String','Done', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','bayes_graph_median done', ...
         'Enable','on', ...
         'UserData','waiting', ...
         'Tag','Done');

      set(bayes_median_gui,'UserData',graph,...
         'HandleVisibility','callback');
   case 'showgraph'
      series = get(graph.popup,'Value');
      param_str = get(graph.popup,'String');
      param_name = strtrim(param_str(series,:));
      newvalue = series+1;
      if newvalue>size(tm.median_mat,1);
         set(graph.popup,'Value',1);
      else;
         set(graph.popup,'Value',newvalue);
      end;
      if curr_ini.colors==1;
         colorstr1 = [1 0 0];
      else;
         colorstr1 = [0 0 0];
      end;
      %
      realscrsz = get(0,'ScreenSize');
      pos = [(realscrsz(3)-612)/2 (realscrsz(4)-484)/2];
      %
      %
      % Display results
      %
      fig_handle = figure('Units','pixels', ...
         'Position',[pos 612 484], ...
         'Menubar','none', ...
         'Toolbar','none', ...
         'NumberTitle','off', ...
         'Tag',[lower(tm.param_name) '-series-' num2str(series,'%0.0f') '-'], ...
         'Visible','off', ...
         'Name',['Recursive Median Estimates - ' param_name]);
      %
      % default figure properties
      %
      setfigureproperties(fig_handle);
      %
      % median values
      %
      line_median = plot((1:1:size(tm.median_mat,2)),tm.median_mat(series,:),'-','LineWidth',1,'Color',colorstr1,'Tag',['median-' lower(tm.param_name) '-series-' num2str(series,'%0.0f')]);
      hold('on');
      set(gca,'XLim',[1 size(tm.median_mat,2)]);
      %
      % plot a zero line if needed
      %
      y_lim = get(gca,'YLim');
      if (y_lim(1)<0)&(y_lim(2)>0);
         plot([1 size(tm.median_mat,2)],[0 0],'-','LineWidth',1,'Color',[0 0 0]);
         hold('on');
      end;
      param_name = strrep(param_name,'(','_{');
      param_name = ['\' strrep(param_name,')','}')];
      param_name = strrep(param_name,',','');
      title_str = ['Median estimates of ' param_name ' from the ' lower(tm.dist_type) ' posterior distribution'];
      setaxesfonts('Title',title_str,'XLabel','Number of Draws','YLabel',param_name);
      hold('off');
      toolbar_fcn(gca);
      if curr_ini.external==0;
         set(fig_handle,'Visible','on');
         drawnow;
      else;
         file = [tm.outputdir tm.modelfile '-' get(fig_handle,'Tag') '-' num2str(tm.burn_in,'%0.0f') '.' num2str(tm.save_draws,'%0.0f') '.' num2str(tm.save_freq,'%0.0f')];
         set(0,'CurrentFigure',fig_handle);
         stat = autosavefigure(fig_handle,file);
         %
         if isempty(stat)==0;
            if stat==0;
               autoshowfigure(file);
            end;
         end;
      end;
   case 'done'
      set(graph.done,'UserData','done');
end;

if nargout==1;
   h = bayes_median_gui;
end;

if strcmp(selector,'done')==0;
   curr_ini.models = tm;
   set(graph.popup,'UserData',curr_ini);
   set(bayes_median_gui,'UserData',graph);
end;

if thisexit==0;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(bayes_median_gui,'Name') ' ' fix_filepath([pwd '\icons\var_restfile.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(graph.icon,'UserData',pid);
      end;
   end;
   %
   set(bayes_median_gui,'Visible','on');
   drawnow;
   if (iswinnt==1)&(iscompiled==1)&(matlabnumber<7);
      drawnow;
      prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(bayes_median_gui,'Name') ' 1'];
      dos(prog);
      drawnow;
   elseif matlabnumber>=7;
      uicontrol(graph.done);
   end;
   waitfor(graph.done,'UserData','done');
end;

%
% end of bayes_graph_median.m
%
