%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for showing estimated B matrix      %
%          for a structural model                                %
%                                                                %
%          Function: bdlg                                        %
%                                                                %
%          Input:                                                %
%                       selector: case switch function           %
%                       cm: structure with model info            %
%                       infomat: summary information about       %
%                           about the estimation                 %
%                       pval: pvalues of test (if any)           %
%                       LR_B0: LR tests of restrictions          %
%                       epsilon: nxT matrix with residuals       %
%                       Psi: nxnq matrix                         %
%                       alpha: nxr matrix                        %
%                       Sigma_theta: covariance matrix for Psi   %
%                           and alpha                            %
%                                                                %
%          Output:                                               %
%                       h = handle                               %
%                                                                %
%          This version:        July 4, 2006                     %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function h = bdlg(selector,cm,infomat,pval,LR_B0,epsilon,Psi,alpha,beta,stdbeta,Sigma_theta,df,B_0,Sigma_B0,Sigma_B0_adj,A,Sigma_A,evalue,S,gamma,R_l,R_mat,type_var,C,dC_theta,dB_theta)

if strcmp(selector,'init')==1;
   if isempty(pval)==0;
      pval = 1-pval;
   end;
   tm = cm;
   tm.beta = beta;
   tm.stdbeta = stdbeta;
   if isempty(beta)==0;
      if tm.restrict(1,2)==1;
         tm.bZ1t = tm.beta'*tm.Z1t;
         tm.bR1t = tm.beta'*tm.R1t;
      else;
         tm.bZ1t = normbeta(tm.beta)'*tm.Z1t;
         tm.bR1t = normbeta(tm.beta)'*tm.R1t;
      end;
   end;
   tm.epsilon = epsilon;
   tm.Psi = Psi;
   tm.alpha = alpha;
   tm.Sigma_theta = Sigma_theta;
   tm.dfb = df;
   tm.B_0 = B_0;
   tm.Sigma_B0 = Sigma_B0;
   tm.Sigma_B0_adj = Sigma_B0_adj;
   tm.A = A;
   tm.Sigma_A = Sigma_A;
   tm.evalue = evalue;
   tm.S = S;
   tm.gamma = gamma;
   tm.R_l = R_l;
   tm.R_mat = R_mat;
   tm.type = type_var;
   tm.C = C;
   tm.dC_theta = dC_theta;
   tm.dB_theta = dB_theta;
   tm.ir = [];
   if isfield(tm,'ir')==1;
      rmfield(tm,'ir');
   end;
   %
   curr_ini = find_inisettings;
   if curr_ini.lagtest>0;
      lagenable = 'on';
   else;
      lagenable = 'off';
   end;
   if isnumeric(curr_ini.external)==0;
      curr_ini.external = 0;
   end;
   std_B_0 = vecinv(sqrt(abs(diag(tm.Sigma_B0_adj))),tm.n);
   std_A = vecinv(sqrt(abs(diag(tm.Sigma_A))),tm.n);
   curr_A = vecstr(tm.evars,':      ');
   curr_B0 = strvcat('B matrix:',' ',curr_A);
   curr_A = strvcat('A matrix:',' ',curr_A);
   for j=1:tm.n;
      addto_A = '';
      for i=1:tm.n;
         if tm.A(i,j)<0;
            if abs(tm.A(i,j))>1.0e-008;
               addto_A = strvcat(addto_A,[num2str(tm.A(i,j),'%1.4f') '  (' num2str(std_A(i,j),'%1.4f') ')     ']);
            else;
               addto_A = strvcat(addto_A,' 0       (-)      ');
            end;
         else;
            if abs(tm.A(i,j))>1.0e-008;
               addto_A = strvcat(addto_A,[' ' num2str(tm.A(i,j),'%1.4f') '  (' num2str(std_A(i,j),'%1.4f') ')     ']);
            else;
               addto_A = strvcat(addto_A,' 0       (-)      ');
            end;
         end;
      end;
      sizeadd = size(addto_A,2)-16;
      if j>9;
         sizeadd = sizeadd-1;
      end;
      padd_A = '';
      for i=1:sizeadd;
         padd_A = [padd_A ' '];
      end;
      curr_A = [curr_A strvcat(' ',[padd_A tm.myshocks(j,:)],addto_A)];
   end;
   curr_A = strvcat(curr_A,' ');
   for j=1:tm.n;
      addto_B0 = '';
      for i=1:tm.n;
         if tm.B_0(i,j)<0;
            if abs(tm.B_0(i,j))>1.0e-008;
               addto_B0 = strvcat(addto_B0,[num2str(tm.B_0(i,j),'%1.4f') '  (' num2str(std_B_0(i,j),'%1.4f') ')     ']);
            else;
               addto_B0 = strvcat(addto_B0,' 0       (-)      ');
            end;
         else;
            if abs(tm.B_0(i,j))>1.0e-008;
               addto_B0 = strvcat(addto_B0,[' ' num2str(tm.B_0(i,j),'%1.4f') '  (' num2str(std_B_0(i,j),'%1.4f') ')     ']);
            else;
               addto_B0 = strvcat(addto_B0,' 0       (-)      ');
            end;
         end;
      end;
      sizeadd = size(addto_B0,2)-16;
      if j>9;
         sizeadd = sizeadd-1;
      end;
      padd_B0 = '';
      for i=1:sizeadd;
         padd_B0 = [padd_B0 ' '];
      end;
      curr_B0 = [curr_B0 strvcat(' ',[padd_B0 tm.myshocks(j,:)],addto_B0)];
   end;
   curr_B0 = strvcat(curr_B0,' ');
   %
   % import images
   %
   button_images = read_images;
   %
   tm.myrun = 0;
   thisexit = 0;
   addheight = 0;
   %
   if curr_ini.method(1,1)==1;
      tm.model_info.header = strvcat('Number of iterations for algorithm:','Value of convergence criterion (max|dlnL/dgamma|):','Largest non-unit eigenvalue of the companion matrix:');
   elseif curr_ini.method(1,2)==1;
      tm.model_info.header = strvcat('Number of iterations for algorithm:','Value of convergence criterion (lnL(i)-lnL(i-1)):','Largest non-unit eigenvalue of the companion matrix:');
   end;
   tm.model_info.info = strvcat(num2str(infomat(1,1),'%0.0f'),num2str(infomat(1,2)),num2str(tm.evalue,'%0.4f'));
   if isempty(LR_B0)==0;
      addheight = 15;
      tm.model_info.info = strvcat(tm.model_info.info,num2str(LR_B0(1,1),'%0.4f'));
      add_s = '';
      if tm.dfb>1;
         add_s = 's';
      end;
      if curr_ini.sscorrect==0;
         tm.model_info.header = strvcat(tm.model_info.header,['LR-test of ' num2str(tm.dfb) ' B restriction' add_s ':']);
      else;
         tm.model_info.header = strvcat(tm.model_info.header,['F-test of (' num2str(tm.dfb) ',' num2str(tm.T-tm.df) ') B restriction' add_s ':']);
      end;
      if isempty(pval)==0;
         tm.model_info.header = strvcat(tm.model_info.header,'p-value:');
         tm.model_info.info = strvcat(tm.model_info.info,num2str(pval,'%0.4f'));
      end;
   end;
   %
   if tm.r<tm.n+tm.q1;
      if tm.evalue>=1;
         mypermcompenable = 'off';
      else;
         mypermcompenable = 'on';
      end;
   else;
      mypermcompenable = 'off';
   end;
   %
   cmatenable = mypermcompenable;
   weakexoenable = 'on';
   if (tm.r==tm.n)|(tm.r==0);
      weakexoenable = 'off';
   end;
   if (tm.n==1)&(tm.q1+tm.q0==0);
      gcenable = 'off';
   else;
      gcenable = 'on';
   end;
   if (tm.r==0)&(tm.p==1);
      cmatenable = 'off';
      mypermcompenable = 'off';
      gcenable = 'off';
   end;
else;
   thisexit = 1;
   bdlggui = findobj('Type','figure','Tag','BmatDLG')';
   brest = get(bdlggui,'UserData');
   curr_ini = get(brest.viewdata,'UserData');
   button_images = curr_ini.images;
   tm = curr_ini.models;
end;

%
% Set screen size directly instead of using
% get(0,'ScreenSize')!
%

scrsz = [1 1 1024 768];
realscrsz = get(0,'ScreenSize');

switch selector;
   case 'init';
      addb = 'B';
      if strcmp(tm.type,'long_run')==1;
         addb = 'A = C*B';
      elseif strcmp(tm.type,'joint')==1;
         addb = 'B and A = C*B';
      end;
      bdlggui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','bdlg.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(realscrsz(3)-scrsz(3)/2)/2-50 (realscrsz(4)-420-addheight)/2-9.5 scrsz(3)/2+100 420+addheight], ...
         'Tag','BmatDLG', ...
         'Resize','off', ...
         'Name',['Restrictions on ' addb ' - Results'], ...
         'NumberTitle','off', ...
         'Visible','off', ...
         'CloseRequestFcn','bdlg wayout', ...
         'ToolBar','none');

      if matlabnumber>=7.0;
         set(bdlggui,'DockControl','off');
      end;

      %
      % File menu
      %

      filemenu = uimenu('Parent',bdlggui, ...
         'Label','&File', ...
         'Tag','FileMenu');

      %
      % Objects on File menu
      %

      brest.viewdata = uimenu('Parent',filemenu, ...
         'Label','View &Data...', ...
         'Callback','bdlg viewdata', ...
         'Enable','on', ...
         'Tag','ViewData');

      add_sep = 'on';

      if (tm.cointvalue==1)&(tm.r>0)&(tm.r~=tm.n+tm.q1+tm.dcoint);

         brest.savecoint = uimenu('Parent',filemenu, ...
            'Label','Save &Cointegration Relations...', ...
            'Callback','bdlg savecoint', ...
            'Separator','on', ...
            'Enable','on', ...
            'Tag','SaveResid');

         add_sep = 'off';

      end;

      brest.savetc = uimenu('Parent',filemenu, ...
         'Label','Save &Transitory Components...', ...
         'Callback','bdlg savetc', ...
         'Accelerator','T', ...
         'Separator',add_sep, ...
         'Enable',mypermcompenable, ...
         'Tag','SaveTC');

      brest.saveresid = uimenu('Parent',filemenu, ...
         'Label','Save &Residuals...', ...
         'Callback','bdlg saveresid', ...
         'Accelerator','D', ...
         'Enable','on', ...
         'Tag','SaveCoint');

      uimenu('Parent',filemenu, ...
         'Label','Center &Window', ...
         'Separator','on', ...
         'Accelerator','W', ...
         'Enable','on', ...
         'Callback','center_figure_fcn', ...
         'Tag','CenterMenu');

      brest.menuuse = uimenu('Parent',filemenu, ...
         'Label','&Use New B', ...
         'Callback','bdlg use', ...
         'Separator','on', ...
         'Enable','on', ...
         'Tag','MenuFileUse');

      brest.menuskip = uimenu('Parent',filemenu, ...
         'Label','R&ecycle New B', ...
         'Callback','bdlg skip', ...
         'Enable','off', ...
         'Tag','MenuFileSkip');

      brest.menucontinue = uimenu('Parent',filemenu, ...
         'Label','C&ontinue', ...
         'Separator','on', ...
         'Callback','bdlg done', ...
         'Accelerator','C', ...
         'Enable','on', ...
         'Tag','MenuFileContinue');


      %
      % Tools menu
      %

      testmenu = uimenu('Parent',bdlggui, ...
         'Label','&Tools', ...
         'Tag','TestMenu');

      %
      % Objects on Tools menu
      %

      brest.corrtest = uimenu('Parent',testmenu, ...
         'Label','&Serial Correlation...', ...
         'Callback','bdlg corrtest', ...
         'Enable','on', ...
         'Accelerator','S', ...
         'Tag','CorrTest');

      brest.archtest = uimenu('Parent',testmenu, ...
         'Label','&ARCH...', ...
         'Callback','bdlg archtest', ...
         'Accelerator','A', ...
         'Enable','on', ...
         'Tag','ArchTest');

      brest.normalitytest = uimenu('Parent',testmenu, ...
         'Label','&Normality...', ...
         'Callback','bdlg normalitytest', ...
         'Accelerator','N', ...
         'Enable','on', ...
         'Tag','NormalityTest');

      brest.constancytest = uimenu('Parent',testmenu, ...
         'Label','&Parameter Constancy...', ...
         'Callback','bdlg constancytest', ...
         'Accelerator','P', ...
         'Enable','on', ...
         'Tag','ConstancyTest');

      brest.lagorder = uimenu('Parent',testmenu, ...
         'Label','&Lag Order...', ...
         'Callback','bdlg lagorder', ...
         'Separator','on', ...
         'Accelerator','L', ...
         'Enable',lagenable, ...
         'Tag','LagOrder');

      if (tm.cointvalue==1)&(tm.r>0)&(tm.r~=tm.n+tm.q1+tm.dcoint);

         brest.weakexo = uimenu('Parent',testmenu, ...
            'Label','&Weak Exogeneity...', ...
            'Callback','bdlg weakexo', ...
            'Enable',weakexoenable, ...
            'Tag','WeakExogeneity');

      end;

      brest.gctest = uimenu('Parent',testmenu, ...
         'Label','&Granger Causality...', ...
         'Callback','bdlg gctest', ...
         'Accelerator','G', ...
         'Enable',gcenable, ...
         'Tag','GrangerCausality');

      if (tm.n>2)&((tm.p>1)|(tm.r>0));
         brest.multigctest = uimenu('Parent',testmenu, ...
            'Label','M&ulti-Step Granger Causality...', ...
            'Callback','bdlg multigctest', ...
            'Enable','on', ...
            'Tag','MultiGrangerCausality');
      end;

      if ((tm.p>1)&(tm.n>2))|(tm.q0>0)|((tm.q1>0)&(tm.pe>0));
         brest.exclude = uimenu('Parent',testmenu, ...
            'Label','&Exclusion', ...
            'Separator','on', ...
            'Enable','on', ...
            'Tag','ExclusionMenu');
         
         brest.firstdiffs = uimenu('Parent',brest.exclude, ...
            'Label','&First Differences', ...
            'Callback','bdlg firstdiffs', ...
            'Enable','on', ...
            'Tag','FirstDiffMenu');
      end;

      if (tm.r>0)&(tm.r<tm.n+tm.q1)&(tm.cointvalue==1);
         brest.showbeta = uimenu('Parent',testmenu, ...
            'Label','Cointegration &Vectors...', ...
            'Callback','bdlg showbeta', ...
            'Separator','on', ...
            'Enable','on', ...
            'Tag','ShowBeta');
      end;

      if tm.dfb==0;
         if (tm.p>1)&(tm.r<tm.n);
            brest.common_cycles = uimenu('Parent',testmenu, ...
               'Label','Co&mmon Cycles...', ...
               'Callback','bdlg common_cycles', ...
               'Separator','on', ...
               'Enable','on', ...
               'Tag','ShowCommonCycles');
         end;

         if tm.datad>0;
            brest.dummy = uimenu('Parent',testmenu, ...
               'Label','&Deterministic Variables', ...
               'Separator','on', ...
               'Enable','on', ...
               'Tag','DummyVarMenu');
   
            brest.dummyexclusion = uimenu('Parent',brest.dummy, ...
               'Label','&Exclusion...', ...
               'Callback','bdlg dummyexclusion', ...
               'Enable','on', ...
               'Tag','DummyExclusionMenu');
   
            brest.dummylongrun = uimenu('Parent',brest.dummy, ...
               'Label','&Long Run...', ...
               'Callback','bdlg dummylongrun', ...
               'Enable',weakexoenable, ...
               'Tag','DummyLongRunMenu');
   
            if tm.datad>1;
               brest.propdummy = uimenu('Parent',brest.dummy, ...
               'Label','&Proportionality...', ...
               'Callback','bdlg dummyprop', ...
               'Enable','on', ...
               'Tag','DummyPropMenu');
            end;
   
         end;

      end;

      brest.cmat = uimenu('Parent',testmenu, ...
         'Label','&C-Matrix...', ...
         'Callback','bdlg cmat', ...
         'Separator','on', ...
         'Accelerator','M', ...
         'Enable',cmatenable, ...
         'Tag','CMatrix');

      brest.longrun_gir = uimenu('Parent',testmenu, ...
         'Label','L&ong Run GIRs...', ...
         'Callback','bdlg longrun_gir', ...
         'Separator','off', ...
         'Enable',cmatenable, ...
         'Tag','LongRunGIRsMenu');

      brest.residanalysis = uimenu('Parent',testmenu, ...
         'Label','&Residual Analysis...', ...
         'Callback','bdlg residanalysis', ...
         'Enable','on', ...
         'Accelerator','R', ...
         'Tag','ResidAnalysis');

      brest.shortdyn = uimenu('Parent',testmenu, ...
         'Label','S&hort Run Dynamics...', ...
         'Callback','bdlg shortdyn', ...
         'Accelerator','Y', ...
         'Enable','on', ...
         'Tag','ShortDyn');

      brest.vardecomp = uimenu('Parent',testmenu, ...
         'Label','Var&iance Decompositions...', ...
         'Callback','bdlg vardecomp', ...
         'Separator','on', ...
         'Enable','on', ...
         'Tag','VarianceDecompMenu');

      brest.distribution = uimenu('Parent',testmenu, ...
         'Label','Distri&bution...', ...
         'Callback','bdlg distribution', ...
         'Separator','on', ...
         'Enable','on', ...
         'Tag','DistributionMenu');

      %
      % Graphics menu
      %

      graphmenu = uimenu('Parent',bdlggui, ...
         'Label','&Graphics', ...
         'Tag','GraphicsMenu');

      if (tm.cointvalue==1)&(tm.r>0)&(tm.r~=tm.n+tm.q1+tm.dcoint);

         brest.menugraph = uimenu('Parent',graphmenu, ...
            'Label','&Cointegration Relations...', ...
            'Callback','bdlg graphs', ...
            'Enable','on', ...
            'Tag','MenuGraph');

      end;

      brest.menupermcomp = uimenu('Parent',graphmenu, ...
         'Label','&Permanent and Transitory Components...', ...
         'Callback','bdlg permcomp', ...
         'Enable',mypermcompenable, ...
         'Accelerator','E', ...
         'Tag','MenuPermComp');

      brest.menu_permcomp = uimenu('Parent',graphmenu, ...
         'Label','P&ermanent and Transitory Shock Components...', ...
         'Callback','bdlg perm_comp', ...
         'Enable',mypermcompenable, ...
         'Tag','Menu_PermComp');

      brest.menuresiduals = uimenu('Parent',graphmenu, ...
         'Label','&Residuals...', ...
         'Callback','bdlg residuals', ...
         'Enable','on', ...
         'Accelerator','I', ...
         'Tag','MenuResiduals');

      brest.menufitted = uimenu('Parent',graphmenu, ...
         'Label','Fitted &Terms...', ...
         'Callback','bdlg fitted', ...
         'Enable','on', ...
         'Tag','MenuFitted');

      brest.forecast = uimenu('Parent',graphmenu, ...
         'Label','Forec&asting...', ...
         'Callback','bdlg forecast', ...
         'Separator','on', ...
         'Enable','on', ...
         'Tag','MenuForecast');

      brest.varforecast = uimenu('Parent',graphmenu, ...
         'Label','Forecast &Variable Transformations...', ...
         'Callback','bdlg varforecast', ...
         'Enable','on', ...
         'Tag','MenuVARForecast');

      if tm.q1+tm.q0>0;
         set(brest.forecast,'Enable','off');
         set(brest.varforecast,'Enable','off');
      end;

      brest.menuchow = uimenu('Parent',graphmenu, ...
         'Label','Recursive Ch&ow Tests', ...
         'Callback','bdlg chow', ...
         'Separator','on', ...
         'Accelerator','O', ...
         'Enable','on', ...
         'Tag','MenuChow');

      brest.menuploberger = uimenu('Parent',graphmenu, ...
         'Label','Recursive &Fluctuation Test', ...
         'Callback','bdlg ploberger', ...
         'Accelerator','F', ...
         'Enable','on', ...
         'Tag','MenuPloberger');

      brest.menuirfunction = uimenu('Parent',graphmenu, ...
         'Label','&Impulse Responses...', ...
         'Separator','on', ...
         'Accelerator','U', ...
         'Callback','bdlg irfunction', ...
         'Enable','on', ...
         'Tag','MenuImpulse');

      brest.histdecomp = uimenu('Parent',graphmenu, ...
         'Label','&Historical Decompositions...', ...
         'Callback','bdlg histdecomp', ...
         'Enable','on', ...
         'Tag','MenuHistDecomp');

      brest.genimpulse = uimenu('Parent',graphmenu, ...
         'Label','&Generalized Impulse Responses...', ...
         'Callback','bdlg genimpulse', ...
         'Separator','on', ...
         'Enable','on', ...
         'Tag','MenuGeneralizedImpulse');

%      if (isempty(tm.isdummy)==0)&(max(tm.isdummy)==1);
      if tm.datad>0;
         brest.dummyimpulse = uimenu('Parent',graphmenu, ...
            'Label','&Dummy Impulse Responses...', ...
            'Callback','bdlg dummyimpulse', ...
            'Enable','on', ...
            'Tag','MenuDummyImpulse');
      end;

      brest.companion = uimenu('Parent',graphmenu, ...
         'Label','Eigenvalues of Companion &Matrix', ...
         'Callback','bdlg companion', ...
         'Separator','on', ...
         'Enable','on', ...
         'Tag','MenuCompanion');

      %
      % Help menu
      %

      helpmenu = uimenu('Parent',bdlggui, ...
         'Label','&Help', ...
         'Tag','HelpMenu');

      brest.b_help = uimenu('Parent',helpmenu, ...
            'Label','&Restrictions on B and A=CB', ...
            'Callback','help_fcn(''RestrictionsonBandACB'');', ...
            'Accelerator','H', ...
            'Separator','off', ...
            'Enable','on', ...
            'Tag','MenuCHelp');

      %
      % Horizontal lines for toolbar
      %

      xline([1 419+addheight scrsz(3)/2+100],[0.5 1]);

      brest.toolbar = uitoolbar('Parent',bdlggui, ...
                        'HandleVisibility','off', ...
                        'Interruptible','on', ...
                        'Clipping','on');

      %
      %  Use button
      %

      brest.use = uipushtool('Parent',brest.toolbar, ...
                         'TooltipString','Use New B', ...
                         'CData',button_images.pickb, ...
                         'ClickedCallback','bdlg use', ...
                         'Separator','off', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable','on', ...
                         'Tag','UseButton');

      brest.skip = uipushtool('Parent',brest.toolbar, ...
                         'TooltipString','Recycle New B', ...
                         'CData',button_images.skipb, ...
                         'ClickedCallback','bdlg skip', ...
                         'Separator','off', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable','off', ...
                         'Tag','SkipButton');

      %
      %  Done button
      %

      brest.done = uipushtool('Parent',brest.toolbar, ...
                         'TooltipString','Continue', ...
                         'CData',button_images.continue, ...
                         'ClickedCallback','bdlg done', ...
                         'Separator','on', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'UserData','waiting', ...
                         'Enable','on', ...
                         'Tag','DoneButton');

      %
      % Graphics button
      %
      separator_str = 'on';

      if (tm.cointvalue==1)&(tm.r>0)&(tm.r~=tm.n+tm.q1+tm.dcoint);
         brest.graphs = uipushtool('Parent',brest.toolbar, ...
                            'TooltipString','Cointegration Relations', ...
                            'CData',button_images.graph, ...
                            'ClickedCallback','bdlg graphs', ...
                            'Separator','on', ...
                            'Interruptible','on', ...
                            'Clipping','on', ...
                            'UserData','working', ...
                            'Enable','on', ...
                            'Tag','Graphics');
         separator_str = 'off';
      end;

      brest.permcomp = uipushtool('Parent',brest.toolbar, ...
                         'TooltipString','Permanent and Transitory Components', ...
                         'CData',button_images.permcomp, ...
                         'ClickedCallback','bdlg permcomp', ...
                         'Separator',separator_str, ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable',mypermcompenable, ...
                         'Tag','PermCompGraphics');

      brest.residgraph = uipushtool('Parent',brest.toolbar, ...
                         'TooltipString','Residuals', ...
                         'CData',button_images.histogram, ...
                         'ClickedCallback','bdlg residuals', ...
                         'Separator','off', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable','on', ...
                         'Tag','ResidGraphics');

      %
      % Forecasting
      %

      brest.forecast_button = uipushtool('Parent',brest.toolbar, ...
                         'TooltipString','Forecasting', ...
                         'CData',button_images.forecast, ...
                         'ClickedCallback','bdlg forecast', ...
                         'Separator','on', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable','on', ...
                         'Tag','ForecastGraph');

      if tm.q1+tm.q0>0;
         set(brest.forecast_button,'Enable','off');
      end;

      %
      % Chow test button
      %

      brest.chow = uipushtool('Parent',brest.toolbar, ...
                         'TooltipString','Recursive Chow Tests', ...
                         'CData',button_images.chow, ...
                         'ClickedCallback','bdlg chow', ...
                         'Separator','on', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable','on', ...
                         'Tag','RecChowGraph');

      brest.ploberger = uipushtool('Parent',brest.toolbar, ...
                         'TooltipString','Recursive Fluctuation Test', ...
                         'CData',button_images.fluctest, ...
                         'ClickedCallback','bdlg ploberger', ...
                         'Separator','off', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable','on', ...
                         'Tag','RecPlobGraph');

      %
      % Impulse responses
      %

      brest.irfunction = uipushtool('Parent',brest.toolbar, ...
                         'TooltipString','Impulse Responses', ...
                         'CData',button_images.irfunction, ...
                         'ClickedCallback','bdlg irfunction', ...
                         'Separator','on', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable','on', ...
                         'Tag','ImpulseGraphics');

      if tm.dfb>0;
         set(brest.constancytest,'Enable','off');
         set(brest.menuchow,'Enable','off');
         set(brest.menuploberger,'Enable','off');
         set(brest.chow,'Enable','off');
         set(brest.ploberger,'Enable','off');

      end;

      %
      % Outer axis
      %

      axesbox([2 2 (scrsz(3)/2)+98 405+addheight],'Maximum Likelihood Results',135,[0.5 1]);

      %
      % Outer axis for showing beta
      %

      axesbox([14 128+addheight scrsz(3)/2+72 262],'Current B and A Matrix',107,[0.5 1]);

      %
      % Outer axis for additional info
      %

      axesbox([14 14 scrsz(3)/2+72 100+addheight],'Estimation Information',105,[0.5 1]);

      %
      % Listbox for showing estimated beta
      %

      brest.betamat = uicontrol('Units','pixels', ...
         'BackgroundColor','white', ...
         'Position',[30 265+addheight scrsz(3)/2+40 110], ...
         'Style','listbox', ...
         'FontSize',10, ...
         'FontName','FixedWidth', ...
         'TooltipString','B estimates with standard errors within parentheses', ...
         'Max',2, ...
         'Value',[], ...
         'String',curr_B0, ...
         'Enable','inactive', ...
         'UserData',0, ...
         'HorizontalAlignment','center', ...
         'Tag','AlphaListbox');

      %
      % Listbox for showing estimated conditional standard
      % errors for beta
      %

      brest.alphamat = uicontrol('Units','pixels', ...
         'BackgroundColor','white', ...
         'Position',[30 144+addheight scrsz(3)/2+40 110], ...
         'Style','listbox', ...
         'FontSize',10, ...
         'FontName','FixedWidth', ...
         'TooltipString','A estimates with standard errors within parentheses', ...
         'Max',2, ...
         'Value',[], ...
         'String',curr_A, ...
         'Enable','inactive', ...
         'UserData','working', ...
         'HorizontalAlignment','center', ...
         'Tag','AlphaStdListbox');

      %
      % Show output text
      %

      brest.model_header = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[30 30 scrsz(3)/2+40 68+addheight], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','on', ...
         'HorizontalAlignment','left', ...
         'ForegroundColor',curr_ini.gui_foreground_color, ...
         'String',tm.model_info.header, ...
         'Tag','OutputText');

      head_ext = get(brest.model_header,'Extent');
      if head_ext(1,4)<=68+addheight;
         new_pos = [30 30+(68+addheight-head_ext(1,4))/2 head_ext(1,3:4)];
      else;
         new_pos = [30 30 head_ext(1,3) 68+addheight];
      end;
      set(brest.model_header,'Position',new_pos);

      brest.model_info = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[35+new_pos(1,3) new_pos(1,2) scrsz(3)/2+35-new_pos(1,3) new_pos(1,4)], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'String',tm.model_info.info, ...
         'ForegroundColor',curr_ini.gui_foreground_color, ...
         'HorizontalAlignment','left', ...
         'Tag','ModelInfoText');

      set(bdlggui,'UserData',brest,...
         'HandleVisibility','callback');

   case 'vardecomp'
      if tm.myrun==0;
         tm.myrun = 1;
         set(bdlggui,'Visible','off');
         drawnow;
         abort = '';
         do_print = 0;
         if isempty(tm.ir)==1;
            do_print = 1;
            setlogtext(strvcat(['Computing variance decompositions up to period ' num2str(tm.h)],['with asymptotic ' num2str(tm.c) ' % confidence bands...']));
            if curr_ini.method(1,1)==1;
               [ir,stdvec,betair,betair_std,abort,vd] = impulses_vlaar_fcn(tm,tm.type,tm.B_0,tm.Sigma_B0,tm.gamma,tm.C,tm.dC_theta,tm.h,tm.S,tm.R_mat,tm.R_l,tm.Psi,tm.alpha,tm.beta,tm.Sigma_theta,1,1);
               if strcmp(abort,'cancel')==0;
                  %
                  % get the value from the normal distribution corresponding to the
                  % chosen levels of significance c
                  %
                  c_val = norm_inv((100+tm.c)/200);
                  %
                  % Now we compute the upper and lower c percent confidence band size
                  %
                  tm.ir = ir;
                  tm.stdvec = stdvec;
                  tm.vd = vd;
                  tm.betair = betair;
                  tm.betair_std = betair_std;
               end;
            elseif curr_ini.method(1,2)==1;
               [ir,stdvec,betair,betair_std,abort,vd] = impulses_warne_fcn(tm,tm.type,tm.B_0,tm.Sigma_B0,tm.C,tm.dB_theta,tm.h,tm.S,tm.Psi,tm.alpha,tm.beta,tm.Sigma_theta,1,1);
               if strcmp(abort,'cancel')==0;
                  %
                  % get the value from the normal distribution corresponding to the
                  % chosen levels of significance c
                  %
                  c_val = norm_inv((100+tm.c)/200);
                  %
                  % Now we compute the upper and lower c percent confidence band size
                  %
                  tm.ir = ir;
                  tm.stdvec = stdvec;
                  tm.vd = vd;
                  tm.betair = betair;
                  tm.betair_std = betair_std;
               end;
            end;
            %
            if strcmp(abort,'cancel')==0;
               for i=1:size(tm.ir,2);
                  for j=1:tm.n*tm.n;
                     if abs(tm.stdvec(j,i))<1.0e-008;
                        tm.stdvec(j,i) = 0;
                     end;
                  end;
               end;
               tm.upper = ir+(c_val*tm.stdvec);
               tm.lower = ir-(c_val*tm.stdvec);
               %
               if isempty(tm.betair)==0;
                  for i=1:size(tm.betair,2);
                     for j=1:tm.r*tm.n;
                        if abs(tm.betair_std(j,i))<1.0e-008;
                           tm.betair_std(j,i) = 0;
                        end;
                     end;
                  end;
                  tm.betair_upper = tm.betair+(c_val*tm.betair_std);
                  tm.betair_lower = tm.betair-(c_val*tm.betair_std);
               else;
                  tm.betair_upper = [];
                  tm.betair_lower = [];
               end;
            end;
         end;
         if strcmp(abort,'cancel')==0;
            %
            % perform the variance decompositions
            %
            [vardec,std_vardec] = var_decomp(tm.n,tm.ir,tm.vd.Sigma_theta,tm.vd.Sigma_B0,tm.vd.partial);
            %
            % print to output-file if requested and not already done
            %
            if (curr_ini.noprint==0)&(do_print==1);
               print_vardecomp(vardec,std_vardec,tm.n,tm.myvars,tm.myshocks,tm.outputfile,curr_ini.texoutputformat);
            end;
            %
            show_vardecomp(tm,vardec,std_vardec);
         end;
         set(bdlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'irfunction'
      if tm.myrun==0;
         tm.myrun = 1;
         set(bdlggui,'Visible','off');
         drawnow;
         abort = '';
         do_print = 0;
         if isempty(tm.ir)==1;
            do_print = 1;
            setlogtext(strvcat(['Computing impulse responses up to period ' num2str(tm.h)],['with asymptotic ' num2str(tm.c) ' % confidence bands...']));
            if curr_ini.method(1,1)==1;
               [ir,stdvec,betair,betair_std,abort,vd] = impulses_vlaar_fcn(tm,tm.type,tm.B_0,tm.Sigma_B0,tm.gamma,tm.C,tm.dC_theta,tm.h,tm.S,tm.R_mat,tm.R_l,tm.Psi,tm.alpha,tm.beta,tm.Sigma_theta,1);
               if strcmp(abort,'cancel')==0;
                  %
                  % get the value from the normal distribution corresponding to the
                  % chosen levels of significance c
                  %
                  c_val = norm_inv((100+tm.c)/200);
                  %
                  % Now we compute the upper and lower c percent confidence band size
                  %
                  tm.ir = ir;
                  tm.stdvec = stdvec;
                  tm.vd = vd;
                  tm.betair = betair;
                  tm.betair_std = betair_std;
               end;
            elseif curr_ini.method(1,2)==1;
               [ir,stdvec,betair,betair_std,abort,vd] = impulses_warne_fcn(tm,tm.type,tm.B_0,tm.Sigma_B0,tm.C,tm.dB_theta,tm.h,tm.S,tm.Psi,tm.alpha,tm.beta,tm.Sigma_theta,1);
               if strcmp(abort,'cancel')==0;
                  %
                  % get the value from the normal distribution corresponding to the
                  % chosen levels of significance c
                  %
                  c_val = norm_inv((100+tm.c)/200);
                  %
                  % Now we compute the upper and lower c percent confidence band size
                  %
                  tm.ir = ir;
                  tm.stdvec = stdvec;
                  tm.vd = vd;
                  tm.betair = betair;
                  tm.betair_std = betair_std;
               end;
            end;
            if strcmp(abort,'cancel')==0;
               for i=1:size(tm.ir,2);
                  for j=1:tm.n*tm.n;
                     if abs(tm.stdvec(j,i))<1.0e-008;
                        tm.stdvec(j,i) = 0;
                     end;
                  end;
               end;
               tm.upper = ir+(c_val*tm.stdvec);
               tm.lower = ir-(c_val*tm.stdvec);
               %
               if isempty(tm.betair)==0;
                  for i=1:size(tm.betair,2);
                     for j=1:tm.r*tm.n;
                        if abs(tm.betair_std(j,i))<1.0e-008;
                           tm.betair_std(j,i) = 0;
                        end;
                     end;
                  end;
                  tm.betair_upper = tm.betair+(c_val*tm.betair_std);
                  tm.betair_lower = tm.betair-(c_val*tm.betair_std);
               else;
                  tm.betair_upper = [];
                  tm.betair_lower = [];
               end;
            end;
         end;
         if strcmp(abort,'cancel')==0;
            %
            % perform the variance decompositions
            %
            [vardec,std_vardec] = var_decomp(tm.n,tm.ir,tm.vd.Sigma_theta,tm.vd.Sigma_B0,tm.vd.partial);
            %
            % print to output-file if requested and not already done
            %
            if (curr_ini.noprint==0)&(do_print==1);
               print_vardecomp(vardec,std_vardec,tm.n,tm.myvars,tm.myshocks,tm.outputfile,curr_ini.texoutputformat);
            end;
            %
            thisgraph = ir_graphdlg('init',tm);
            ir_graph = get(thisgraph,'UserData');
            set(ir_graph.show,'UserData','done');
            killguipid(thisgraph);
         end;
         set(bdlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'histdecomp'
      if tm.myrun==0;
         tm.myrun = 1;
         set(bdlggui,'Visible','off');
         drawnow;
         %
         fh = forecast_horizon('Historical Decompositions',tm.freq,tm.T,'ok');
         %
         if fh>0;
            [f_err,f_err_decomp,abort] = hist_decomp(tm,fh,tm.alpha,tm.beta,tm.Psi,tm.B_0,tm.epsilon,1);
            %
            if strcmp(abort,'cancel')==0;
               thisgraph = histdecompdlg('init',fh,f_err,f_err_decomp,tm);
               histdecomp = get(thisgraph,'UserData');
               set(histdecomp.show,'UserData','done');
               killguipid(thisgraph);
            end;
         end;
         %
         set(bdlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'fitted'
      if tm.myrun==0;
         tm.myrun = 1;
         set(bdlggui,'Visible','off');
         drawnow;
         mytheta = tm.Theta;
         thisgraph = fittedterms('init',tm,mytheta,tm.beta);
         fitted = get(thisgraph,'UserData');
         set(fitted.show,'UserData','done');
         killguipid(thisgraph);
         set(bdlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'companion'
      if tm.myrun==0;
         tm.myrun = 1;
         rind = 0;
         if tm.r>0;
            ind = 1;
         else;
            ind = 0;
            rind = 1;
         end;
         if tm.dfbeta==0;
            ind = 0;
         end;
         show_companion(tm.beta,tm.alpha,tm.Psi,tm,curr_ini,ind,rind);
         tm.myrun = 0;
      end;
   case 'distribution'
      if tm.myrun==0;
         tm.myrun = 1;
         set(bdlggui,'Visible','off');
         drawnow;
         %
         thisgraph = distdlg('init',tm.cbs);
         killguipid(thisgraph);
         %
         set(bdlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'common_cycles'
      if tm.myrun==0;
         tm.myrun = 1;
         set(bdlggui,'Visible','off');
         drawnow;
         show_common_cycles(tm,curr_ini,tm.alpha,tm.Psi,tm.beta);
         set(bdlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'dummyprop'
      if tm.myrun==0;
         tm.myrun = 1;
         set(bdlggui,'Visible','off');
         drawnow;
         proportionality_dummies_dlg('init',tm,curr_ini);
         set(bdlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'dummylongrun'
      if tm.myrun==0;
         tm.myrun = 1;
         show_longrun_dummies(bdlggui,tm,curr_ini);
         tm.myrun = 0;
      end;
   case 'dummyexclusion'
      if tm.myrun==0;
         tm.myrun = 1;
         show_exclude_dummies(bdlggui,tm,curr_ini);
         tm.myrun = 0;
      end;
   case 'dummyimpulse'
      if tm.myrun==0;
         tm.myrun = 1;
         set(bdlggui,'Visible','off');
         drawnow;
         Omega = (1/tm.T)*tm.epsilon*tm.epsilon';
         alpha = tm.alpha;
         beta = tm.beta;
         Psi = tm.Psi;
         Sigma_theta = tm.Sigma_theta;
         if tm.dfb==0;
            txt = 'Would you like to impose restrictions on the dummy variables?';
            if (tm.datad>1)|((tm.r<tm.n)&(tm.r>0));
               answer = query(txt,'question',120,'Structural VAR - Dummy Restrictions',300,'no');
            else;
               answer = 'No';
            end;
            if strcmp(answer,'Yes')==1;
               %
               % open a select restrictions dialog
               %
               cm = restrict_dummies_dlg('init',tm,curr_ini);
               if strcmp(cm.action,'cancel')==0;
                  %
                  % check if we should use new estimated
                  %
                  if (isfield(cm,'applied')==1)&(isempty(cm.applied)==0)&(ischar(cm.applied)==1)&(strcmp(cm.applied,'applied')==1);
                     if isfield(cm,'dm')==1;
                        txt = 'Are you sure you want to use the restricted estimates for the dummy impulse responses?';
                        answer = query(txt,'question',120,'Structural VAR - Dummy Restrictions',300,'yes');
                        if strcmp(answer,'Yes')==1;
                           alpha = cm.dm.alpha;
                           beta = cm.dm.beta;
                           Psi = cm.dm.Psi;
                           Omega = cm.dm.Omega;
                           Sigma_theta = cm.dm.Sigma_theta;
                        end;
                     end;
                  end;
               else;
                  %
                  % no dummy impulses
                  %
                  set(bdlggui,'Visible','on');
                  drawnow;
                  return;
               end;
            end;
         end;
         %
         setlogtext(strvcat(['Computing impulse responses for dummies up to period ' num2str(tm.h)],['with asymptotic ' num2str(tm.c) ' % confidence bands...']));
         abort = '';
         %
         [tm.duir,tm.duir_std,tm.buir,tm.buir_std,abort] = dummy_impulses_fcn(tm,alpha,beta,Psi,Omega,Sigma_theta,1);
         %
         if strcmp(abort,'cancel')==0;
            %
            % get the value from the normal distribution corresponding to the
            % chosen levels of significance c
            %
            c_val = norm_inv((100+tm.c)/200);
            for i=1:size(tm.duir,2);
               for j=1:tm.n*tm.datad;
                  if abs(tm.duir_std(j,i))<1.0e-008;
                     tm.duir_std(j,i) = 0;
                  end;
               end;
            end;
            tm.duir_upper = tm.duir+(c_val*tm.duir_std);
            tm.duir_lower = tm.duir-(c_val*tm.duir_std);
            %
            if isempty(tm.buir)==0;
               for i=1:size(tm.buir,2);
                  for j=1:tm.r*tm.datad;
                     if abs(tm.buir_std(j,i))<1.0e-008;
                        tm.buir_std(j,i) = 0;
                     end;
                  end;
               end;
               tm.buir_upper = tm.buir+(c_val*tm.buir_std);
               tm.buir_lower = tm.buir-(c_val*tm.buir_std);
            else;
               tm.buir_upper = [];
               tm.buir_lower = [];
            end;
            %
            thisgraph = duir_graphdlg('init',tm);
            ir_graph = get(thisgraph,'UserData');
            set(ir_graph.show,'UserData','done');
            killguipid(thisgraph);
         end;
         %
         set(bdlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'genimpulse'
      if tm.myrun==0;
         tm.myrun = 1;
         set(bdlggui,'Visible','off');
         drawnow;
         setlogtext(strvcat(['Computing generalized impulse responses up to period ' num2str(tm.h)],['with asymptotic ' num2str(tm.c) ' % confidence bands...']));
         abort = '';
         %
         Omega = (1/tm.T)*tm.epsilon*tm.epsilon';
         [tm.gir,tm.gir_std,tm.bir,tm.bir_std,abort] = generalized_impulses_fcn(tm,tm.alpha,tm.beta,tm.Psi,Omega,tm.Sigma_theta,1,tm.B_0,tm.Sigma_B0);
         if strcmp(abort,'cancel')==0;
            %
            % get the value from the normal distribution corresponding to the
            % chosen levels of significance c
            %
            c_val = norm_inv((100+tm.c)/200);
            for i=1:size(tm.gir,2);
               for j=1:tm.n*tm.n;
                  if abs(tm.gir_std(j,i))<1.0e-008;
                     tm.gir_std(j,i) = 0;
                  end;
               end;
            end;
            tm.gir_upper = tm.gir+(c_val*tm.gir_std);
            tm.gir_lower = tm.gir-(c_val*tm.gir_std);
            if isempty(tm.bir)==0;
               for i=1:size(tm.bir,2);
                  for j=1:tm.r*tm.n;
                     if abs(tm.bir_std(j,i))<1.0e-008;
                        tm.bir_std(j,i) = 0;
                     end;
                  end;
               end;
               tm.bir_upper = tm.bir+(c_val*tm.bir_std);
               tm.bir_lower = tm.bir-(c_val*tm.bir_std);
            else;
               tm.bir_upper = [];
               tm.bir_lower = [];
            end;
            thisgraph = gir_graphdlg('init',tm);
            ir_graph = get(thisgraph,'UserData');
            set(ir_graph.show,'UserData','done');
            killguipid(thisgraph);
         end;
         %
         set(bdlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'showbeta'
      if tm.myrun==0;
         tm.myrun = 1;
         set(bdlggui,'Visible','off');
         drawnow;
         if tm.restrict(1,2)==1;
            txt = showbeta(tm.beta,tm.evars,strtrim([tm.xvars1 ' ' tm.restvec]),['%' num2str(8+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f']);
         else;
            txt = showbeta(normbeta(tm.beta),tm.evars,strtrim([tm.xvars1 ' ' tm.restvec]),['%' num2str(8+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f']);
         end;
         if isempty(tm.stdbeta)==0;
            txt = strvcat(txt,'with estimated asymptotic conditional standard errors:',showbeta(tm.stdbeta,tm.evars,strtrim([tm.xvars1 ' ' tm.restvec]),['%' num2str(8+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f']));
         end;
         textgui(txt,'Cointegration Vectors',[(realscrsz(3)-700)/2 (realscrsz(4)-500)/2 700 500],'Results',38);
         %
         set(bdlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'residanalysis'
      if tm.myrun==0;
         tm.myrun = 1;
         if tm.r>0;
            ind = 1;
         else;
            ind = 0;
         end;
         if tm.dfbeta==0;
            ind = 0;
         end;
         show_residual_analysis(bdlggui,tm,ind);
         tm.myrun = 0;
      end;
   case 'corrtest'
      if tm.myrun==0;
         tm.myrun = 1;
         if tm.r>0;
            ind = 1;
         else;
            ind = 0;
         end;
         if tm.dfbeta==0;
            ind = 0;
         end;
         show_corrtest(bdlggui,tm,curr_ini,ind);
         tm.myrun = 0;
      end;
   case 'archtest'
      if tm.myrun==0;
         tm.myrun = 1;
         if tm.r>0;
            ind = 1;
         else;
            ind = 0;
         end;
         if tm.dfbeta==0;
            ind = 0;
         end;
         show_archtest(bdlggui,tm,curr_ini,ind);
         tm.myrun = 0;
      end;
   case 'normalitytest'
      if tm.myrun==0;
         tm.myrun = 1;
         if tm.r>0;
            ind = 1;
         else;
            ind = 0;
         end;
         if tm.dfbeta==0;
            ind = 0;
         end;
         show_normalitytest(bdlggui,tm,curr_ini,ind);
         tm.myrun = 0;
      end;
   case 'constancytest'
      if tm.myrun==0;
         tm.myrun = 1;
         if rank(tm.beta'*tm.beta,1.0e-004)==tm.r;
            ind = 1;
            rind = 0;
            if (tm.r==0)|(tm.dfbeta==0);
               ind = 0;
               rind = 1;
            end;
            aind = 0;
            if tm.restrict(1,1)==1;
               aind = 1;
            end;
            show_constancytest(bdlggui,tm.beta,tm,curr_ini,ind,aind,rind);
         else;
            myrank = rank(tm.beta'*tm.beta,1.0e-004);
            txt = ['The estimated beta matrix is badly scaled. The rank of beta''*beta is ' num2str(myrank(1,1)) ', i.e. less than ' num2str(tm.r) ', when a tolerance level of 1.0e-004 is used. Parameter constancy tests will not be calculated. Please consider some other restrictions.'];
            about(txt,'warning','Badly identified beta matrix',120,500);
         end;
         tm.myrun = 0;
      end;
   case 'weakexo'
      if tm.myrun==0;
         tm.myrun = 1;
         if tm.restrict(1,1)==0;
            aind = 0;
         else;
            aind = 1;
         end;
         ind = 1;
         if tm.dfbeta==0;
            ind = 0;
         end;
         show_weakexo(bdlggui,tm.beta,tm.alpha,tm.Sigma_theta,tm,curr_ini,ind,aind);
         tm.myrun = 0;
      end;
   case 'longrun_gir'
      if tm.myrun==0;
         tm.myrun = 1;
         set(bdlggui,'Visible','off');
         drawnow;
         %
         Omega = (1/tm.T)*tm.epsilon*tm.epsilon';
         [lr_gir,lr_gir_std] = longrun_gir_fcn(tm.alpha,tm.beta,tm.Psi,Omega,tm.Sigma_theta,tm.epsilon,tm.Z1,tm.Z2,tm.p,tm.d,tm.B_0,tm.Sigma_B0);
         %
         for i=1:tm.n;
            for j=1:tm.n;
               if abs(lr_gir_std(i,j))<1.0e-005;
                  lr_gir_std(i,j) = 0;
                  lr_gir(i,j) = mystr2num(strtrim(num2str(lr_gir(i,j),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])));
               end;
            end;
         end;
         %
         addrest = ' restricted';
         if tm.dfbeta==0;
            addrest = '';
         end;
         ctext = strvcat(' ',['LONG RUN GENERALIZED IMPULSE RESPONSES (for' addrest ' rank=' num2str(tm.r,'%1.0f') ')']);
         numchar = size(ctext,2);
         addcorr = '';
         for i=1:numchar;
            addcorr = strcat(addcorr,'=');
         end;
         ctext = strvcat(ctext,addcorr,' ');
         ctext = strvcat(ctext,showc(lr_gir,tm.myvars),' ');
         ctext = strvcat(ctext,'Estimated asymptotic standard errors:',' ',showc(lr_gir_std,tm.myvars),' ','t-ratios:',' ',showc(inf2nan(lr_gir./lr_gir_std),tm.myvars),' ');
         drawnow;
         textgui(ctext,'Long Run GIRs',[(realscrsz(3)-700)/2 (realscrsz(4)-500)/2 700 500],'Results',38);
         %
         set(bdlggui,'Visible','on');
         tm.myrun = 0;
      end;
   case 'cmat'
      if tm.myrun==0;
         tm.myrun = 1;
         addrest = ' restricted';
         if tm.dfbeta==0;
            addrest = '';
         end;
         if tm.r<tm.n;
            C = cmat(tm.Psi,tm.alpha,tm.beta,tm.epsilon,tm.Z1,tm.Z2,tm.p,tm.d,1,tm.Sigma_theta);
         else;
            C = cmat_stat(tm.Psi,tm.alpha,tm.beta,tm.epsilon,tm.Z1,tm.Z2,tm.p,tm.d,1,tm.Sigma_theta);
         end;
         ctext = strvcat(' ',['THE C-MATRIX (for' addrest ' rank=' num2str(tm.r,'%1.0f') ')']);
         numchar = size(ctext,2);
         addcorr = '';
         for i=1:numchar;
            addcorr = strcat(addcorr,'=');
         end;
         ctext = strvcat(ctext,addcorr,' ');
         %
         C_t = C(:,1:tm.n);
         C_std = C(:,tm.n+1:2*tm.n);
         for i=1:tm.n;
            for j=1:tm.n;
               if abs(C_std(i,j))<1.0e-005;
                  C_std(i,j) = 0;
                  C_t(i,j) = mystr2num(strtrim(num2str(C_t(i,j),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])));
               end;
            end;
         end;
         %
         ctext = strvcat(ctext,showc(C_t,tm.myvars),' ');
         ctext = strvcat(ctext,'Estimated asymptotic standard errors:',' ',showc(C_std,tm.myvars),' ','t-ratios:',' ',showc(inf2nan(C_t./C_std),tm.myvars),' ');
         set(bdlggui,'Visible','off');
         drawnow;
         textgui(ctext,'C-Matrix',[(realscrsz(3)-700)/2 (realscrsz(4)-500)/2 700 500],'Results',38);
         set(bdlggui,'Visible','on');
         tm.myrun = 0;
      end;
   case 'lagorder'
      if tm.myrun==0;
         tm.myrun = 1;
         if tm.r>0;
            ind = 1;
         else;
            ind = 0;
         end;
         if tm.dfbeta==0;
            ind = 0;
         end;
         aind = 0;
         if tm.restrict(1,1)==1;
            aind = 1;
         end;
         show_lagordertest(bdlggui,tm.beta,tm.alpha,tm.Psi,tm.Sigma_theta,tm,curr_ini,ind,aind);
         tm.myrun = 0;
      end;
   case 'firstdiffs'
      if tm.myrun==0;
         tm.myrun = 1;
         if tm.r>0;
            ind = 1;
         else;
            ind = 0;
         end;
         if tm.dfbeta==0;
            ind = 0;
         end;
         show_firstdiffstests(bdlggui,tm.beta,tm.alpha,tm.Psi,tm.Sigma_theta,tm,curr_ini,ind,tm.restrict(1,3));
         tm.myrun = 0;
      end;
   case 'gctest'
      if tm.myrun==0;
         tm.myrun = 1;
         if tm.r>0;
            ind = 1;
         else;
            ind = 0;
         end;
         if tm.dfbeta==0;
            ind = 0;
         end;
         aind = 0;
         if tm.restrict(1,1)==1;
            aind = 1;
         end;
         show_gctest(bdlggui,tm.beta,tm.alpha,tm.Psi,tm.Sigma_theta,tm,curr_ini,ind,aind);
         tm.myrun = 0;
      end;
   case 'multigctest'
      if tm.myrun==0;
         tm.myrun = 1;
         set(bdlggui,'Visible','off');
         drawnow;
         if tm.r>0;
            ind = 1;
         else;
            ind = 0;
         end;
         if tm.dfbeta==0;
            ind = 0;
         end;
         this_graph = select_mgc('init',tm,tm.beta,tm.Sigma_theta,tm.restrict(1,1),ind,tm.restrict(1,3));
         mgc = get(this_graph,'UserData');
         set(mgc.show,'UserData','done');
         killguipid(this_graph);
         set(bdlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'shortdyn'
      if tm.myrun==0;
         tm.myrun = 1;
         Omega = (1/tm.T)*tm.epsilon*tm.epsilon';
         shortstr = shortrun(tm.alpha,tm.Psi,Omega,tm.beta,tm.Z1,tm.Z2,tm.p,tm.pe,tm.d,tm.deterselect,tm.q0,tm.q1,tm.evars,tm.xvars0,tm.xvars1,tm.deter,tm.restvec,1,tm.outputfile,1,tm.Sigma_theta);
         if tm.dfbeta>0;
            myshortstr = shortstr(2,:);
            oldsize = size(myshortstr,2);
            myshortstr = strrep(myshortstr,'for rank=','for restricted rank=');
            newsize = size(myshortstr,2);
            myshortstr = myshortstr(1,1:newsize-11);
            kind = findstr(myshortstr,')');
            if isempty(kind)==0;
               shortstr(2,:) = myshortstr;
               shortstr(3,:) = strrep(shortstr(3,:),'=           ','============');
            end;
         end;
         set(bdlggui,'Visible','off');
         drawnow;
         textgui(shortstr,'Short Run Dynamics',[(realscrsz(3)-800)/2 (realscrsz(4)-500)/2 800 500],'Results',38);
         set(bdlggui,'Visible','on');
         tm.myrun = 0;
      end;
   case 'graphs'
      if tm.myrun==0;
         tm.myrun = 1;
         set(bdlggui,'Visible','off');
         drawnow;
         tm.running = 1;
         thisgraph = cointgraphdlg('init',tm,tm.bZ1t,tm.bR1t,tm.restrict(1,2));
         graph = get(thisgraph,'UserData');
         set(graph.show,'UserData','done');
         killguipid(thisgraph);
         set(bdlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'ploberger'
      if tm.myrun==0;
         tm.myrun = 1;
         if tm.r>0;
            ind = 1;
         else;
            ind = 0;
         end;
         if tm.dfbeta==0;
            ind = 0;
         end;
         aind = 0;
         if tm.restrict(1,1)==1;
            aind = 1;
         end;
         show_ploberger(bdlggui,tm.beta,tm,curr_ini,ind,aind);
         tm.myrun = 0;
      end;
   case 'chow'
      if tm.myrun==0;
         tm.myrun = 1;
         if tm.r>0;
            ind = 1;
         else;
            ind = 0;
         end;
         if tm.dfbeta==0;
            ind = 0;
         end;
         aind = 0;
         if tm.restrict(1,1)==1;
            aind = 1;
         end;
         show_chow(bdlggui,tm.beta,tm,curr_ini,ind,aind);
         tm.myrun = 0;
      end;
   case 'perm_comp'
      if tm.myrun==0;
         tm.myrun = 1;
         [y_t,perm_y,trans_y] = permcomp(tm.Psi,tm.alpha,tm.beta,tm.epsilon,tm.x0,tm.x1,tm.x1_r,tm.x2,tm.d,tm.dcoint,tm.p,tm.pe,tm.q1,tm.q0);
         if tm.r>0;
            ind = 1;
         else;
            ind = 0;
         end;
         if tm.restrict(1,2)==0;
            ind = 0;
         end;
         set(bdlggui,'Visible','off');
         drawnow;
         %
         % now we look into the shock components
         %
         [perm_shock,trans_shock,abort] = shockcomp(tm,tm.Psi,tm.alpha,tm.beta,tm.B_0,tm.epsilon,perm_y(:,1),trans_y,1);
         if strcmp(abort,'cancel')==0;
            thisgraph = scdlg('init',tm,y_t,perm_y,trans_y,perm_shock,trans_shock,ind);
            sc = get(thisgraph,'UserData');
            set(sc.show,'UserData','done');
            killguipid(thisgraph);
         end;
         set(bdlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'permcomp'
      if tm.myrun==0;
         tm.myrun = 1;
         [y_t,perm_y,trans_y] = permcomp(tm.Psi,tm.alpha,tm.beta,tm.epsilon,tm.x0,tm.x1,tm.x1_r,tm.x2,tm.d,tm.dcoint,tm.p,tm.pe,tm.q1,tm.q0);
         if tm.r>0;
            ind = 1;
         else;
            ind = 0;
         end;
         if tm.restrict(1,2)==0;
            ind = 0;
         end;
         set(bdlggui,'Visible','off');
         drawnow;
         thisgraph = pctcdlg('init',tm,y_t,perm_y,trans_y,ind);
         pctc = get(thisgraph,'UserData');
         set(pctc.show,'UserData','done');
         killguipid(thisgraph);
         set(bdlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'varforecast'
      if tm.myrun==0;
         tm.myrun = 1;
         set(bdlggui,'Visible','off');
         drawnow;
         thisgraph = var_forecastdlg('init',tm,tm.restrict);
         f_cast = get(thisgraph,'UserData');
         set(f_cast.show,'UserData','done');
         killguipid(thisgraph);
         set(bdlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'forecast'
      if tm.myrun==0;
         tm.myrun = 1;
         set(bdlggui,'Visible','off');
         drawnow;
         thisgraph = forecastdlg('init',tm,tm.restrict);
         f_cast = get(thisgraph,'UserData');
         set(f_cast.show,'UserData','done');
         killguipid(thisgraph);
         set(bdlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'residuals'
      if tm.myrun==0;
         tm.myrun = 1;
         if tm.r>0;
            ind = 1;
         else;
            ind = 0;
         end;
         if tm.dfbeta==0;
            ind = 0;
         end;
         set(bdlggui,'Visible','off');
         drawnow;
         thisgraph = epsilondlg('init',tm,ind);
         epsi = get(thisgraph,'UserData');
         set(epsi.show,'UserData','done');
         killguipid(thisgraph);
         set(bdlggui,'Visible','on');
         tm.myrun = 0;
      end;
   case 'viewdata'
      if tm.myrun==0;
         tm.myrun = 1;
         if matlabnumber>=6.0;
            myfile = {'*.txt;*.data;*.wk1;*.xls;*.mat;*.csv', 'Data Files (*.txt, *.data, *.wk1, *.xls, *.mat, *.csv)'; ...
                    '*.txt;*.data', 'Text Files (*.txt, *.data)'; ...
                    '*.mat', 'MatLab MAT Files (*.mat)'; ...
                    '*.wk1', 'Lotus 1-2-3 Spreadsheets (*.wk1)'; ...
                    '*.xls', 'Excel Spreadsheets (*.xls)'; ...
                    '*.csv', 'Comma Separated Value Files (*.csv)'; ...
                    '*.*', 'All Files (*.*)'};
         else;
            if (iscompiled==1)&(iswinnt==1)&(curr_ini.opendialog==1);
               fix_fig = findobj('Tag','StructuralVAR');
               model = get(fix_fig,'UserData');
               afile = get(model.endogenous,'String');
               basedir = getpath(strtrim(afile));
               file_fltr = 'Data Files (*.txt, *.data, *.wk1, *.mat, *.csv)|*.txt;*.data;*.wk1;*.mat;*.csv|Text Files (*.txt, *.data)|*.txt;*.data|MatLab MAT Files (*.mat)|*.mat|Lotus 1-2-3 Spreadsheets (*.wk1)|*.wk1|Comma Separated Value Files (*.csv)|*.csv|All Files (*.*)|*.*|';
               best_pos = 1;
               title_txt = 'Open';
            else;
               fix_fig = findobj('Tag','StructuralVAR');
               model = get(fix_fig,'UserData');
               afile = get(model.endogenous,'String');
               afile = strtrim(afile);
               if fileexist(afile)==1;
                  adir = getpath(afile);
                  if ispc==1;
                     if strcmp(adir(1,size(adir,2)),'\')==0;
                        adir = [adir '\'];
                     end;
                  else;
                     if strcmp(adir(1,size(adir,2)),'/')==0;
                        adir = [adir '/'];
                     end;
                  end;
               else;
                  adir = tm.outputdir;
               end;
               myfile = [adir '*.txt;*.data;*.wk1;*.mat;*.csv'];
            end;
         end;
         if (iscompiled==1)&(iswinnt==1)&(curr_ini.opendialog==1)&(matlabnumber<6.0);
            [openfile,openpath] = fileopen(basedir,file_fltr,1,title_txt);
         else;
            if matlabnumber>=6;
               [openfile,openpath] = uigetfile(myfile,'Open',getpath(tm.endofile));
            else;
               [openfile,openpath] = uigetfile(myfile,'Open');
            end;
         end;
         drawnow;
         if isnumeric(openfile)==0;
            openfile = strcat(openpath,openfile);
            set(bdlggui,'Visible','off');
            drawnow;
            textgui(openfile,['View Data - ' openfile],[(realscrsz(3)-(realscrsz(4)-80))/2 1 realscrsz(4)-80 realscrsz(4)-54],'Data',25);
            set(bdlggui,'Visible','on');
            drawnow;
         end;
         tm.myrun = 0;
      end;
   case 'savecoint'
      if tm.myrun==0;
         tm.myrun = 1;
         if tm.restrict(1,2)==1;
            CR = tm.beta'*tm.Z1t;
         else;
            CR = normbeta(tm.beta)'*tm.Z1t;
         end;
         addrest = 'rest-';
         if tm.dfbeta==0;
            addrest = '';
         end;
         myfile = [tm.outputdir 'coint-' addrest num2str(tm.r,'%1.0f') '.data'];
         [savefile,savepath] = uiputfile(myfile,'Save As');
         drawnow;
         if isnumeric(savefile)==0;
            [myR myT] = size(CR);
            myt = '';
            for i=1:myT;
               myt = strvcat(myt,getdate(tm.samplebeg,tm.sampleend,tm.freq,i/myT));
            end;
            setlogtext(['Saving cointegration relations to ' savefile '...']);
            savefile = strcat(savepath,savefile);
            fid = fopen(savefile,'wt');
            myprintstr = '';
            firststr = ' DATE  ';
            prt_str = ['%' num2str(2*(curr_ini.exportdata+3),'%0.0f') '.' num2str(curr_ini.exportdata+3,'%0.0f') 'f'];
            for i=1:myR;
               myprintstr = [myprintstr '   ' prt_str];
               firststr = [firststr '               ci_' num2str(i,'%1.0f')];
            end;
            fprintf(fid,[firststr '\n']);
            for i=1:myT;
               fprintf(fid,['%s ' myprintstr '\n'],myt(i,:),CR(:,i)');
            end;
            fclose(fid);
         end;
         tm.myrun = 0;
      end;
   case 'savetc'
      if tm.myrun==0;
         tm.myrun = 1;
         addrest = 'rest-';
         if tm.dfbeta==0;
            addrest = '';
         end;
         [y_t,perm_y,trans_y] = permcomp(tm.Psi,tm.alpha,tm.beta,tm.epsilon,tm.x0,tm.x1,tm.x1_r,tm.x2,tm.d,tm.dcoint,tm.p,tm.pe,tm.q1,tm.q0);
         myfile = [tm.outputdir 'trans.comp-' addrest num2str(tm.r,'%1.0f') '.data'];
         [savefile,savepath] = uiputfile(myfile,'Save As');
         drawnow;
         if isnumeric(savefile)==0;
            [myN myT] = size(trans_y);
            myt = '';
            for i=1:myT;
               myt = strvcat(myt,getdate(tm.samplebeg,tm.sampleend,tm.freq,i/myT));
            end;
            setlogtext(['Saving transitory components to ' savefile '...']);
            savefile = strcat(savepath,savefile);
            fid = fopen(savefile,'wt');
            myprintstr = '';
            firststr = ' DATE  ';
            prt_str = ['%' num2str(2*(curr_ini.exportdata+3),'%0.0f') '.' num2str(curr_ini.exportdata+3,'%0.0f') 'f'];
            for i=1:myN;
               myprintstr = [myprintstr '   ' prt_str];
               firststr = [firststr '              tc_' tm.myvars(i,:)];
            end;
            fprintf(fid,[firststr '\n']);
            for i=1:myT;
               fprintf(fid,['%s ' myprintstr '\n'],myt(i,:),trans_y(:,i)');
            end;
            fclose(fid);
         end;
         tm.myrun = 0;
      end;
   case 'saveresid'
      if tm.myrun==0;
         tm.myrun = 1;
         addrest = 'rest-';
         if tm.dfbeta==0;
            addrest = '';
         end;
         myfile = [tm.outputdir 'epsilon-' addrest num2str(tm.r,'%1.0f') '.data'];
         [savefile,savepath] = uiputfile(myfile,'Save As');
         drawnow;
         if isnumeric(savefile)==0;
            [myN myT] = size(tm.epsilon);
            myt = '';
            for i=1:myT;
               myt = strvcat(myt,getdate(tm.samplebeg,tm.sampleend,tm.freq,i/myT));
            end;
            setlogtext(['Saving residuals to ' savefile '...']);
            savefile = strcat(savepath,savefile);
            fid = fopen(savefile,'wt');
            myprintstr = '';
            firststr = ' DATE  ';
            prt_str = ['%' num2str(2*(curr_ini.exportdata+3),'%0.0f') '.' num2str(curr_ini.exportdata+3,'%0.0f') 'f'];
            for i=1:myN;
               myprintstr = [myprintstr '   ' prt_str];
               firststr = [firststr '             eps_' tm.myvars(i,:)];
            end;
            fprintf(fid,[firststr '\n']);
            for i=1:myT;
               fprintf(fid,['%s ' myprintstr '\n'],myt(i,:),tm.epsilon(:,i)');
            end;
            fclose(fid);
         end;
         tm.myrun = 0;
      end;
   case 'use'
      if tm.myrun==0;
         tm.myrun = 1;
         set(brest.use,'Enable','off');
         set(brest.menuuse,'Enable','off');
         set(brest.skip,'Enable','on');
         set(brest.menuskip,'Enable','on');
         set(brest.betamat,'UserData',1);
         set(bdlggui,'UserData',brest);
         tm.myrun = 0;
      end;
   case 'skip'
      if tm.myrun==0;
         tm.myrun = 1;
         set(brest.use,'Enable','on');
         set(brest.menuuse,'Enable','on');
         set(brest.skip,'Enable','off');
         set(brest.menuskip,'Enable','off');
         set(brest.betamat,'UserData',0);
         set(bdlggui,'UserData',brest);
         tm.myrun = 0;
      end;
   case 'done'
      if tm.myrun==0;
         tm.myrun = 1;
         set(brest.done,'UserData','done');
         set(bdlggui,'UserData',brest);
         tm.myrun = 0;
      end;
   case 'wayout'
      set(brest.done,'UserData','done');
      if strcmp(get(brest.alphamat,'UserData'),'done')==1;
         delete(bdlggui);
      end;
end;

if strcmp(selector,'init')==1;
   set(bdlggui,'Visible','on');
end;

if strcmp(selector,'wayout')==0;
   curr_ini.images = button_images;
   curr_ini.models = tm;
   set(brest.viewdata,'UserData',curr_ini);
end;

if nargout==1;
   h = bdlggui;
end;

if thisexit==0;
   waitfor(brest.done,'UserData','done');
end;

%
% end of bdlg.m
%
