function [nyblomT,nyblomcorr,e_parm] = boot_nyblom_full(Z0,Z1,Z2,r,p,q1,d,T0,np,deterselect,real_T)

curr_ini = find_inisettings;

[n T] = size(Z0);

%
% Ensuring that all input variables are set
%

if nargin<7;
   T1 = round(2*real_T/3);
else;
   if T0<0;
      T1 = round(2*real_T/3);
   elseif T0>0.95;
      T1 = round(2*real_T/3);
   else;
      T1 = round(real_T*T0);
   end;
end;

if T1<=size(Z1,1)+size(Z2,1);
   T1 = size(Z1,1)+size(Z2,1)+1;
end;

if nargin<8;
   np = r+round(r*(n-r)/n)+n*(p-1)+d;
end;

dcoint = 0;
if ((deterselect(1,2)==1)|(deterselect(1,4)==1));
   dcoint = 1;
end;

if T1>T;
   nyblomT = [];
   nyblomcorr = [];
   return;
end;

%
% compute full sample estimates
%

[S_00,S_01,S_10,S_11,M_02,M_22,M_12,beta,lambda,trace_test] = mlcointbasic(Z0,Z1,Z2,r);

alpha = S_01*beta/(beta'*S_11*beta);
if isempty(Z2)==0;
   Psi = (M_02/M_22)-(alpha*beta'*(M_12/M_22));
   epsilon = Z0-(alpha*beta'*Z1)-(Psi*Z2);
else;
   Psi = [];
   epsilon = Z0-(alpha*beta'*Z1);
end;
Omega = (1/T)*epsilon*epsilon';

%
% if full sample estimates of the parameters are requested
%

if nargout>2;
   e_parm.alpha = alpha;
   e_parm.beta = beta;
   e_parm.Psi = Psi;
   e_parm.Omega = Omega;
   e_parm.epsilon = epsilon;
end;

%
% material for Nyblom test
%

if r<n;
   beta_orth = null(beta(1:n+q1,1:r)');
   qp = size(beta,1)-n-q1;
   if size(beta,1)==n+q1;
      c = beta;
      c_orth = beta_orth;
   else;
      c = beta(1:n+q1,:);
      c_orth = beta_orth(1:n+q1,:);
      c = [c;zeros(qp,r)];
      c_orth = [[c_orth zeros(n,qp)];[zeros(qp,n-r) eye(qp)]];
   end;
   if curr_ini.taylor_nyblom==1;
      c_bar = c/(c'*c);
      c_bar_orth = c_orth*inverse(c_orth'*c_orth);
      betaT = beta;
      alpha_cT = alpha*betaT'*c_bar;
      M_T = (1/T)*c_orth'*S_11*c_orth;
      V_T = (alpha_cT'/Omega)*alpha_cT;
   else;
      J_T = kron(alpha'*inverse(Omega)*alpha,c_orth'*S_11*c_orth);
      alpha_T = alpha;
      Omega_T = Omega;
      beta_T = beta(:,1:r);
   end;
end;

beta = beta(1:n+q1,1:r);

%
% computing the max non-unit full-sample eigenvalue of the companion matrix
%

nyblomT = zeros(1,T-T1+1);
nyblomcorr = zeros(1,T-T1+1);

t = T-1;
while t>=T1;
   %
   % Checking for affinely dependent deterministic variables
   %
   if d>0;
      [Z2t,dfix] = fixdet(Z1(:,1:t),Z2(:,1:t),d,dcoint);
   else;
      dfix = 0;
      if isempty(Z2)==0;
         Z2t = Z2(:,1:t);
      else;
         Z2t = [];
      end;
   end;
   %
   % Reestimating the unrestricted beta for period t
   %
   if curr_ini.taylor_nyblom==1;
      [S_00,S_01,S_10,S_11,M_02,M_22,M_12,beta,lambda,trace_test] = mlcointbasic(Z0(:,1:t),Z1(:,1:t),Z2t,r);
   else;
      [S_00,S_01,S_10,S_11,M_02,M_22,M_12] = rrr_mat(Z0(:,1:t),Z1(:,1:t),Z2t);
   end;
   %
   %
   if r<n;
      if curr_ini.taylor_nyblom==1;
         betat = beta;
         M_t = c_orth'*S_11*c_orth;
         beta_ct = betat/(c_bar'*betat);
         q_t = c_bar_orth'*(beta_ct-betaT);
         nyblomt = V_T*q_t'*M_t*(M_T\M_t)*q_t;
         nyblomt = sum(diag(nyblomt));
         nyblomT(1,t-T1+1) = (t/T)*(t/T)*nyblomt(1,1);
         nyblomcorr(1,t-T1+1) = ((T-np)/T)*(t/T)*(t/T)*nyblomt(1,1);
      else;
         inv_Omega_T = eye(size(Omega_T,1))/Omega_T;
         S_t = (vec(alpha_T))'*kron(eye(r),inv_Omega_T*(S_01-alpha_T*beta_T'*S_11)*c_orth);
         inv_J_T = eye(size(J_T,1))/J_T;
         Q_t = (t/T)*(t/T)*T*S_t*inv_J_T*S_t';
         nyblomT(1,t-T1+1) = Q_t;
         nyblomcorr(1,t-T1+1) = ((T-np)/T)*Q_t;
      end;
   end;
   %
   t = t-1;
end;

%
% end of boot_nyblom_full.m
%
