%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for displaying graphs of            %
%          bootstrapped data                                     %
%                                                                %
%          Function: bootgraphdlg                                %
%                                                                %
%          Input:                                                %
%                       selector: case switch function           %
%                       c_mod: structure with model info         %
%          	            datafile: string                         %
%                       testfile: string                         %
%                       txt_str: string                          %
%                       beta: cointegration vectors              %
%                       T: number of observations                %
%                       r: number of cointegration vectors       %
%                                                                %
%          Output:                                               %
%                       h: handle                                %
%                                                                %
%          This version:        July 10, 2006                    %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function h = bootgraphdlg(selector,c_mod,datafile,testfile,txt_str,beta,rep,T,r)

if strcmp(selector,'init')==1;
   t_m = c_mod;
   t_m.beta = beta;
   thisexit = 0;
   curr_ini = find_inisettings;
   if isnumeric(curr_ini.external)==0;
      curr_ini.external = 0;
   end;
   %
   % setting up the actual sample period if T==t_m.T
   %
   if T==t_m.T;
      [t_m.dataindex,t_m.samplebeg,t_m.sampleend,add] = make_dataindex(t_m.freq,t_m.samplebeg,t_m.sampleend);
      t_m.dataindexfix = [t_m.samplebeg-3*add;t_m.samplebeg-2*add;t_m.samplebeg-add;t_m.dataindex];
      checkyear = floor(t_m.samplebeg);
      checkperiod = t_m.samplebeg-checkyear;
      t_m.subbeginyear = num2str(checkyear);
      if strcmp(t_m.freq,'q')==1;
         checkperiod = 4*(checkperiod+(1/8));
         t_m.subbeginperiod = num2str(round(checkperiod));
      elseif strcmp(t_m.freq,'m')==1;
         checkperiod = 12*(checkperiod+(1/24));
         t_m.subbeginperiod = num2str(round(checkperiod));
      end;
      showsample = 1;
   else;
      showsample = 0;
   end;
   t_m.r = r;
   if rep>=5000;
      this_text = strvcat(' ','Loading bootstrap residuals from disk...','Please hold!');
      mywait = waitdlg(this_text,'bootstrap','Bootstrap Simulation Data');
      waitf = get(mywait,'UserData');
   end;
   t_m.eps_file = load(datafile);
   if rep>=5000;
      this_text = strvcat(' ','Loading bootstrapped tests from disk...','Please hold!');
      set(waitf.text,'String',this_text);
   end;
   t_m.test_file = load(testfile);
   t_m.txt_str = txt_str;
   if showsample==0;
      t_m.dataindex = (1:1:size(t_m.eps_file.bootstrap(1).epsilon,2))';
   end;
   %
   if rep>=5000;
      set(mywait,'UserData','done');
      delete(mywait);
      drawnow;
   end;
   listvars = '';
   if t_m.r<t_m.n;
      for i=1:t_m.r;
         listvars = [listvars '|beta(' num2str(i) ')''*Y'];
      end;
      t_m.use_r = t_m.r;
   else;
      t_m.use_r = 0;
   end;
   if isfield(t_m,'usealtmodel')==0;
      t_m.usealtmodel = 0;
   end;
   if t_m.usealtmodel==1;
      %
      % need to estimate the parameters of the alternative model
      %
      tempdummy = t_m.altmodel.tempdummy;
      permdummy = t_m.altmodel.permdummy;
      if tempdummy==1;
         d_begin = t_m.altmodel.tempbegin;
         d_end = t_m.altmodel.tempend;
         d_acc = t_m.altmodel.tempacc;
         d_coint = t_m.altmodel.tempcoint;
         d_corel = t_m.altmodel.tempcorel;
         d_rank = t_m.altmodel.temprank;
         d_shortrun = t_m.altmodel.tempshortrun;
         d_coidet = t_m.altmodel.tempcoidet;
      else;
         d_begin = t_m.altmodel.permbegin;
         d_end = t_m.T;
         d_acc = t_m.altmodel.permacc;
         d_coint = t_m.altmodel.permcoint;
         d_corel = t_m.altmodel.permcorel;
         d_rank = t_m.altmodel.permrank;
         d_shortrun = t_m.altmodel.permshortrun;
         d_coidet = t_m.altmodel.permcoidet;
      end;
      if (d_begin>1)&(d_end<t_m.T);
         data_dummy = [zeros(d_begin-1,1);ones(d_end-d_begin+1,1);zeros(t_m.T-d_end,1)];
      elseif d_begin==1;
         data_dummy = [ones(d_end,1);zeros(t_m.T-d_end,1)];
      else;
         data_dummy = [zeros(d_begin-1,1);ones(t_m.T-d_begin+1,1)];
      end;
      if d_acc==1;
         data_dummy = cumsum(data_dummy);
      end;
      if (d_corel==1)&(d_rank==3);
         data_dummy = 1-data_dummy;
      end;
      %
      % we're now ready to estimate
      %
      if d_rank==1;
         am.Z0 = t_m.Z0;
         am.d = t_m.d;
         am.n = t_m.n;
         am.T = t_m.T;
         am.freq = t_m.freq;
         am.p = t_m.p;
         am.q1 = t_m.q1;
         am.q0 = t_m.q0;
         am.altmodel = t_m.altmodel;
         am.usealtmodel = 1;
         am.delete_d = 0;
         if d_coint==0;
            if d_corel==0;
               am.Z1 = t_m.Z1;
               if d_shortrun==0;
                  am.Z2 = [data_dummy';t_m.Z2];
                  am.d = am.d+1;
                  am.delete_d = 1;
               else;
                  am.Z2 = [];
                  if t_m.d>0;
                     am.Z2 = t_m.Z2(1:t_m.d,:);
                  end;
                  test_mat = t_m.Z2(t_m.d+1:size(t_m.Z2,1),:);
                  am.Z2 = [am.Z2;test_mat .* (ones(size(test_mat,1),1)*(1-data_dummy'));test_mat .* (ones(size(test_mat,1),1)*data_dummy')];
               end;
            else;
               am.Z2 = t_m.Z2;
               if d_coidet==0;
                  am.Z1 = [t_m.Z1 .* (ones(size(t_m.Z1,1),1)*(1-data_dummy'));t_m.Z1 .* (ones(size(t_m.Z1,1),1)*data_dummy')];
               else;
                  am.Z1 = [t_m.Z1(1:size(t_m.Z1,1)-1,:) .* (ones(size(t_m.Z1,1)-1,1)*(1-data_dummy'));t_m.Z1(size(t_m.Z1,1),:);t_m.Z1(1:size(t_m.Z1,1)-1,:) .* (ones(size(t_m.Z1,1)-1,1)*data_dummy')];
               end;
            end;
         else;
            am.Z1 = [t_m.Z1;data_dummy'];
            am.Z2 = t_m.Z2;
         end;
         [am.S_00,am.S_01,am.S_10,am.S_11,am.M_02,am.M_22,am.M_12,am.beta,am.lambda,am.trace] = mlcointbasic(am.Z0,am.Z1,am.Z2,t_m.my_r);
         %
         % need to run a routine which can have dcoint 1 and have a dummy in the cointegration space
         %
         if t_m.restrict(1,2)==1;
            [am.beta,am.dfbeta,const_rest] = beta_alt_estimate(am.S_00,am.S_11,am.S_01,am.S_10,am.beta,t_m.T,t_m.modelsdir,t_m.modelfile,t_m.dcoint,t_m.q1,d_coint,d_corel,d_coidet);
         end;
         %
         am.alpha = (am.S_01*am.beta)/(am.beta'*am.S_11*am.beta);
         if isempty(am.Z2)==0;
            am.Psi = (am.M_02/am.M_22)-(am.alpha*am.beta'*(am.M_12/am.M_22));
            am.Z = [am.Z2;am.beta'*am.Z1];
         else;
            am.Psi = [];
            am.Z = am.beta'*am.Z1;
         end;
         Theta = [am.Psi am.alpha];
         am.epsilon = am.Z0-(Theta*am.Z);
         am.Omega = (1/t_m.T)*am.epsilon*am.epsilon';
         if t_m.restrict(1,1)==1;
            %
            % estimate alpha under restrictions
            %
            file = strcat(t_m.modelsdir,'G-',int2str(t_m.n),'x',int2str(t_m.r),'-',t_m.modelfile,'.rest');
            G = loaddata(file);
            [Rmat,rvec] = rmatrix(G,t_m.n,t_m.r);
            am.dfalpha = size(G,1);
            if isempty(am.Z2)==0;
               Rmat = [zeros(am.dfalpha,size(am.Z2,1)*t_m.n) Rmat];
            end;
            if curr_ini.reestbeta==0;
               [theta,Sigma_theta,infomat,nabort] = linrest(am.Z0,am.Z,Theta,Rmat,rvec,0);
            else;
               %
               % re-estimate beta under alpha restrictions
               %
               [theta,am.beta,am.Z] = alpha_beta_alt_estimate(am.Z0,am.Z1,am.Z2,am.Z,am.beta,Theta,Rmat,rvec,t_m.dcoint,t_m.q1,t_m.modelsdir,t_m.modelfile,d_coint,d_corel,d_coidet);
            end;
            g2 = size(theta,2);
            am.alpha = theta(:,g2-t_m.r+1:g2);
            if g2>t_m.r;
               am.Psi = theta(:,1:g2-t_m.r);
            else;
               am.Psi = [];
            end;
            am.epsilon = am.Z0-(theta*am.Z);
            am.Omega = (1/t_m.T)*am.epsilon*am.epsilon';
            Theta = theta;
         end;
         %
         % consider restrictions on C
         %
         if (size(t_m.restrict,2)==3)&(t_m.restrict(1,3)==1);
            %
            % collect restrictions on C
            %
            file = strcat(t_m.modelsdir,'C-',int2str(t_m.n),'x',int2str(t_m.r),'-',t_m.modelfile,'.rest');
            Cres = loaddata(file);
            [Rmat_C,rvec_C] = rmatrix(Cres,t_m.n,t_m.n);
            %
            % Estimate under C restrictions
            %
            d_parm = t_m.d;
            if d_corel==0;
               d_parm = t_m.d+(1-d_coint);
            end;
            [theta,am.beta] = c_alt_restrict(am.Z0,am.Z1,am.Z2,t_m.restrict,am.beta,Theta,Rmat_C,rvec_C,t_m.p,t_m.pe,d_parm,t_m.dcoint,t_m.q0,t_m.q1,t_m.modelsdir,t_m.modelfile,curr_ini.reestbeta,d_coint,d_corel,d_coidet);
            am.Z = [];
            if t_m.r>0;
               am.Z = am.beta'*am.Z1;
            end;
            am.Z = [am.Z2;am.Z];
            %
            % fix all the other parameters
            %
            am.epsilon = am.Z0-(theta*am.Z);
            am.Omega = (1/t_m.T)*am.epsilon*am.epsilon';
            g2 = size(theta,2);
            if t_m.r>0;
               am.alpha = theta(:,g2-t_m.r+1:g2);
            else;
               am.alpha = [];
            end;
            if g2>t_m.r;
               am.Psi = theta(:,1:g2-t_m.r);
            else;
               am.Psi = [];
            end;               
            Theta = theta;
         end;
      else;
         %
         % estimate alternative model under changes in rank
         %
         if d_rank==2;
            r_0 = t_m.my_r;
            r_1 = t_m.my_r+1;
            alt_r = r_0;
         elseif d_rank==3;
            r_0 = t_m.my_r;
            r_1 = t_m.my_r-1;
            alt_r = r_1;
         end;
         am.Z0 = t_m.Z0;
         am.Z1 = t_m.Z1;
         am.Z2 = t_m.Z2;
         am.d = t_m.d;
         am.n = t_m.n;
         am.T = t_m.T;
         am.freq = t_m.freq;
         am.p = t_m.p;
         am.q1 = t_m.q1;
         am.q0 = t_m.q0;
         am.altmodel = t_m.altmodel;
         %
         [am.beta_1,am.beta_2,am.alpha_1,am.alpha_2,am.Psi,am.Omega,am.epsilon] = varyrank(t_m.Z0,t_m.Z1,t_m.Z2,data_dummy,alt_r,1);
      end;
      t_m.am = am;
      t_m.d_rank = d_rank;
   end;
else;
   thisexit = 1;
   bootgraphgui = get(0,'CurrentFigure');
   bootgraph = get(bootgraphgui,'UserData');
   curr_ini = get(bootgraph.listvars,'UserData');
   t_m = curr_ini.models;
end;

%
% Set screen size directly instead of using
% get(0,'ScreenSize')!
%

realscrsz = get(0,'ScreenSize');

switch selector;
   case 'init';

      bootgraphgui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','bootgraphdlg.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(realscrsz(3)-341)/2 (realscrsz(4)-140)/2 341 140], ...
         'Tag','FigParent', ...
         'Resize','off', ...
         'Visible','off', ...
         'Name','Graph Bootstrap Sample', ...
         'NumberTitle','off', ...
         'CloseRequestFcn','bootgraphdlg wayout', ...
         'ToolBar','none');

      if matlabnumber>=7.0;
         set(bootgraphgui,'DockControl','off');
      end;

      %
      % Outer axis
      %

      axesbox([2 2 339 130],'Graphics',45,[0.5 1]);

      imageaxes = axes('Units','pixels', ...
         'Box','on', ...
         'TickLength',[0 0], ...
         'CameraUpVector',[0 1 0], ...
         'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[24 80 39 39], ...
         'XTickLabelMode','manual', ...
         'YTickLabelMode','manual', ...
         'Tag','AxisLogo', ...
         'XColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'YColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'ZColor',get(0,'defaultuicontrolbackgroundcolor'));

      mycons = getstoredimages;
      if curr_ini.use_toolbar_bgcolor==1;
         bgcolor = (1/255)*(round(255*get(0,'defaultuicontrolbackgroundcolor'))-[8 4 8]);
         bgcolor(1) = max(0,bgcolor(1));
         bgcolor(2) = max(0,bgcolor(2));
         bgcolor(3) = max(0,bgcolor(3));
      else;
         bgcolor = get(0,'defaultuicontrolbackgroundcolor');
      end;
      %
      image('CData',mirrorimage(maketrans(mycons.bootstrap_image,[160 160 164],bgcolor)),'Clipping','off','Parent',imageaxes);

      if showsample==1;
         uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[126 85 200 20], ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'Style','text', ...
            'String',['Estimation Sample:    ' t_m.subbeginyear ':' t_m.subbeginperiod ' - ' t_m.subendyear ':' t_m.subendperiod], ...
            'HorizontalAlignment','right', ...
            'Tag','SampleText');
      end;

      %
      % Select variable
      %

      bootgraph.icon = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[24 50 120 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'String','Endogenous variable:', ...
         'HorizontalAlignment','left', ...
         'Tag','VariableText');

      bootgraph.listvars = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[144 55 80 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'String',[strrep(t_m.evars,' ','|') listvars], ...
         'Tag','EndoVarsList',...
         'Value',1);


      %
      % Select draw
      %

      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[24 16 120 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'String','Bootstrap draw number:', ...
         'HorizontalAlignment','left', ...
         'Tag','VariableText');

      bootgraph.draw = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[144 20 80 20], ...
         'Style','edit', ...
         'Callback','bootgraphdlg check', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'HorizontalAlignment','left', ...
         'String','1', ...
         'UserData',1, ...
         'Tag','Graphedit');

      %
      % Create graph button
      %

      bootgraph.show = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[236 55 90 20], ...
         'String','Display', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','bootgraphdlg showgraph', ...
         'UserData','working', ...
         'Enable','on', ...
         'Tag','Done');

      %
      %  Done button
      %

      bootgraph.done = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[236 20 90 20], ...
         'String','Done', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','bootgraphdlg done', ...
         'Enable','on', ...
         'UserData','waiting', ...
         'Tag','Done');

      set(bootgraphgui,'UserData',bootgraph,...
         'HandleVisibility','callback');
   case 'check'
      draw_val = get(bootgraph.draw,'String');
      draw_val = mystr2num(strtrim(draw_val(1,:)));
      if isempty(draw_val)==0;
         draw_val = ceil(draw_val);
         if (draw_val>=1)&(draw_val<=size(t_m.eps_file.bootstrap,2));
            set(bootgraph.draw,'String',num2str(draw_val,'%0.0f'),'UserData',draw_val);
         else;
            set(bootgraph.draw,'String',num2str(get(bootgraph.draw,'UserData'),'%0.0f'));
         end;
      else;
         set(bootgraph.draw,'String',num2str(get(bootgraph.draw,'UserData'),'%0.0f'));
      end;
   case 'showgraph'
      series = get(bootgraph.listvars,'Value');
      newseries = series+1;
      if newseries>t_m.n+t_m.use_r;
         set(bootgraph.listvars,'Value',1);
      else;
         set(bootgraph.listvars,'Value',newseries);
      end;
      var_name = get(bootgraph.listvars,'String');
      var_name = strtrim(var_name(series,:));
      draw = get(bootgraph.draw,'UserData');
      if newseries>t_m.n+t_m.use_r;
         newvalue = draw+1;
         if newvalue>size(t_m.eps_file.bootstrap,2);
            set(bootgraph.draw,'UserData',1,'String','1');
         else;
            set(bootgraph.draw,'UserData',newvalue,'String',num2str(newvalue,'%0.0f'));
         end;
      end;
      %
      if isempty(t_m.txt_str)==0;
         txt_str = '';
         for i=1:size(t_m.test_file.test_data,2);
            txt_str = strvcat(txt_str,['  ' num2str(t_m.test_file.test_data(draw,i),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])]);
         end;
         txt_str = align_right(txt_str);
         if size(t_m.txt_str,1)<=size(txt_str,1);
            txt_str = [t_m.txt_str txt_str(1:size(t_m.txt_str,1),:)];
         else;
            t_m.txt_str = '';
         end;
      end;
      %
      if curr_ini.colors==1;
         colorstr = 'b';
      else;
         colorstr = 'k';
      end;
      %
      % create the bootstrap sample
      %
      Epr = t_m.eps_file.bootstrap(draw).epsilon;
      %
      % need to take alternative models into account
      %
      if t_m.usealtmodel==0;
         boot = bootstrap_sample(t_m,t_m.beta,Epr);
      else;
         if t_m.d_rank==1;
            boot = bootstrap_sample(t_m.am,t_m.am.beta,Epr);
         else;
            boot = bootstrap_varyrank(t_m.am,Epr);
         end;
      end;
      %
      thisplot = figure('Units','pixels', ...
         'Position',[(realscrsz(3)-512)/2 (realscrsz(4)-384)/2 512 384], ...
         'Menubar','none', ...
         'Toolbar','none', ...
         'NumberTitle','off', ...
         'Visible','off', ...
         'Name',['Boostrap draw ' num2str(draw) ' - ' var_name '(t)']);
      %
      % default figure properties
      %
      setfigureproperties(thisplot);
      %
      if series<=t_m.n;
         plot(t_m.dataindex,cumsum(boot.Z0(series,:))+boot.Z1(series,1),'-','LineWidth',1,'Color',colorstr,'Tag',var_name);
      else;
         plot(t_m.dataindex,t_m.beta(:,series-t_m.n)'*boot.Z1,'-','LineWidth',1,'Color',colorstr,'Tag',['coint(' num2str(series-t_m.n,'%0.0f') ')']);
         set(thisplot,'Name',['Boostrap draw ' num2str(draw) ' - ' var_name '(t-1)']);
      end;
      if (min(get(gca,'YLim'))<=0)&(max(get(gca,'YLim'))>=0);
         hold('on');
         plot([t_m.dataindex(1,1) t_m.dataindex(size(t_m.dataindex,1),1)],zeros(2,1),'-','LineWidth',1,'Color','k');
      end;
      set(gca,'XLim',[t_m.dataindex(1,1) t_m.dataindex(size(t_m.dataindex,1),1)]);
      setaxesfonts('Title',['Bootstrap draw ' num2str(draw) ' of ' var_name]);
      curr_axes = gca;
      toolbar_fcn(gca);
      if isempty(t_m.txt_str)==0;
         ax_obj = disptext(txt_str,curr_axes);
      end;
      %
      if series<=t_m.n;
         nextplot = figure('Units','pixels', ...
            'Position',[(realscrsz(3)-512)/2+22 (realscrsz(4)-384)/2-22 512 384], ...
            'Menubar','none', ...
            'Toolbar','none', ...
            'NumberTitle','off', ...
            'Visible','off', ...
            'Name',['Boostrap draw ' num2str(draw) ' - ' var_name '(t)-' var_name '(t-1)']);
         %
         % default figure properties
         %
         setfigureproperties(nextplot);
         %
         plot(t_m.dataindex,boot.Z0(series,:),'-','LineWidth',1,'Color',colorstr,'Tag',['d' var_name]);
         hold('on');
         plot([t_m.dataindex(1,1) t_m.dataindex(size(t_m.dataindex,1),1)],zeros(2,1),'-','LineWidth',1,'Color','k');
         set(gca,'XLim',[t_m.dataindex(1,1) t_m.dataindex(size(t_m.dataindex,1),1)]);
         setaxesfonts('Title',['Bootstrap draw ' num2str(draw) ' of \Delta' var_name]);
         toolbar_fcn(gca);
      end;
      set(thisplot,'Visible','on');
      if series<=t_m.n;
         set(nextplot,'Visible','on');
      end;
      set(bootgraphgui,'UserData',bootgraph);
   case 'done'
      set(bootgraph.done,'UserData','done');
      set(bootgraphgui,'UserData',bootgraph);
   case 'wayout'
      set(bootgraph.done,'UserData','done');
      clear('t_m');
      if strcmp(get(bootgraph.show,'UserData'),'done')==1;
%         delete(bootgraphgui);
         killguipid(bootgraphgui);
      end;
end;

if nargout==1;
   h = bootgraphgui;
end;

if strcmp(selector,'wayout')==0;
   curr_ini.models = t_m;
   set(bootgraph.listvars,'UserData',curr_ini);
end;

if thisexit==0;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(bootgraphgui,'Name') ' ' fix_filepath([pwd '\icons\bootstrap.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(bootgraph.icon,'UserData',pid);
      end;
   end;
   set(bootgraphgui,'Visible','on');
   drawnow;
   if (iswinnt==1)&(iscompiled==1)&(matlabnumber<7);
      drawnow;
      prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(bootgraphgui,'Name') ' 1'];
      dos(prog);
      drawnow;
   elseif matlabnumber>=7;
      uicontrol(bootgraph.done);
   end;
   waitfor(bootgraph.done,'UserData','done');
end;

%
% end of bootgraphdlg.m
%
