function boot = bootstrap_varyrank(mm,epsilon)

boot = [];

%
% create a bootstrap sample of desired length
%

T = size(epsilon,2);
Z0 = zeros(size(mm.Z0,1),T);
Z0_new = [];

Z1 = zeros(size(mm.Z1,1),T);

if isempty(mm.Z2)==0;
   Z2 = zeros(size(mm.Z2,1),T);
else;
   Z2 = [];
end;

tempdummy = mm.altmodel.tempdummy;
permdummy = mm.altmodel.permdummy;
if tempdummy==1;
   d_begin = mm.altmodel.tempbegin;
   d_end = mm.altmodel.tempend;
   d_rank = mm.altmodel.temprank;
else;
   d_begin = mm.altmodel.permbegin;
   d_end = mm.T;
   d_rank = mm.altmodel.permrank;
end;
if mm.altmodel.relsample==1;
   d_begin = round(d_begin*(T/mm.T));
   d_end = round(d_end*(T/mm.T));
else;
   if (d_end==mm.T)&(permdummy==1);
      d_end = T;
   end;
end;

%
% create the dummy
%
if (d_begin>1)&(d_end<T);
   data_dummy = [zeros(d_begin-1,1);ones(d_end-d_begin+1,1);zeros(T-d_end,1)];
elseif d_begin==1;
   data_dummy = [ones(d_end,1);zeros(T-d_end,1)];
else;
   data_dummy = [zeros(d_begin-1,1);ones(T-d_begin+1,1)];
end;
if d_rank==3;
   data_dummy = 1-data_dummy;
end;

data_dummy = data_dummy';

if T>mm.T;
   last_trend = 0;
   if mm.deterselect(1,4)==1;
      last_trend = mm.Z1(mm.n+1,mm.T);
   elseif (mm.deterselect(1,3)==1);
      last_trend = mm.Z2(2,mm.T);
   end;
end;

for i=1:T;
   %
   % create new Z1 and Z2
   %
   if i==1;
      Z0_old = mm.Z1(1:mm.n,1);
      Z1(:,1) = mm.Z1(:,1);
      if isempty(mm.Z2)==0;
         Z2(:,1) = mm.Z2(:,1);
      end;
   else;
      Z0_old = Z0_new;
      %
      % create new Z1
      %
      Z1_new = Z0_old;
      if size(mm.Z1,1)>mm.n;
         if i<=mm.T;
            Z1_new = [Z1_new;mm.Z1(mm.n+1:size(mm.Z1,1),i)];
         else;
            %
            % Add a constant or a trend
            %
            if isalmostequal(Z1(mm.n+1,i-1),1)==1;
               Z1_new = [Z1_new;1];
            else;
               Z1_new = [Z1_new;i-mm.T+last_trend];
            end;
         end;
      end;
      Z1(:,i) =Z1_new;
      if isempty(Z2)==0;
         %
         % Create new Z2
         %
         % Step 1: deterministic variables
         %
         Z2_new = [];
         if i<=mm.T
            if mm.d>0;
               Z2_new = mm.Z2(1:mm.d,i);
            end;
         else;
            %
            % add a constant and/or a trend
            %
            pos = 0;
            if isalmostequal(Z2(1,i-1),1)==1;
               Z2_new = 1;
               pos = pos+1;
            end;
            if isalmostequal(Z2(2,i-1),i-1-mm.T+last_trend)==1;
               Z2_new = [Z2_new;i-mm.T+last_trend];
               pos = pos+1;
            end;
            %
            % deal with seasonals
            %
            if mm.d>2;
               if strcmp(mm.freq,'q')==1;
                  Z2_new = [Z2_new;Z2(pos+1:pos+3,i-4)];
               elseif strcmp(mm.freq,'m')==1;
                  Z2_new = [Z2_new;Z2(pos+1:pos+11,i-12)];
               end;
            end;
         end;
         %
         % Step 2: lagged endogenous variables
         %
         if mm.p>1;
            %
            % lag 1
            %
            Z2_new = [Z2_new;Z0(:,i-1)];
            %
            % the remaining
            %
            if mm.p>2;
               Z2_new = [Z2_new;Z2(mm.d+1:mm.d+(mm.n*(mm.p-2)),i-1)];
            end;
         end;
         %
         % Step 3: exogenous stochastic variables
         %
         if mm.q1+mm.q0>0;
            Z2_new = [Z2_new;mm.Z2(mm.d+(mm.n*(mm.p-1))+1:size(Z2,1),i)];
         end;
         if size(Z2,1)==size(Z2_new,1);
            Z2(:,i) = Z2_new;
         else;
            Z2(:,i) = Z2(:,i-1);
         end;
      end;
   end;
   %
   % Create the levels of the endogenous variables
   %
   Z0_add = data_dummy(1,i)*(mm.alpha_2*mm.beta_2'*Z1(:,i));
   if isempty(mm.beta_1)==0;
      Z0_new = mm.alpha_1*mm.beta_1'*Z1(:,i)+Z0_old+epsilon(:,i)+Z0_add;
   else;
      Z0_new = Z0_old+epsilon(:,i)+Z0_add;
   end;
   if isempty(Z2)==0;
      Z0_new = Z0_new+mm.Psi*Z2(:,i);
   end;
   %
   % Collecting endogenous variables in first differences
   %
   Z0(:,i) = (Z0_new-Z0_old);
end;

boot.Z0 = Z0;
boot.Z1 = Z1;
boot.Z2 = Z2;

%
% end of bootstrap_varyrank.m
%
