%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for bootstrapping the cointegration %
%          tests for exclusion, stationarity, and for the        %
%          deterministic part                                    %
%                                                                %
%          Function: cointtest_bootstrap                         %
%                                                                %
%          Input:                                                %
%                       selector: case switch function           %
%                       cm: structure with model info            %
%                                                                %
%          Output:                                               %
%                                                                %
%          This version:        July 5, 2006                     %
%          Written by:          Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function cointtest_bootstrap(varargin)

%
% GUI for bootstrapping the cointegration space tests
%

selector = varargin{1};
if (nargin==0)|(strcmp(selector,'init')==1);
   tm = varargin{2};
   %
   % toolbar images
   %
   button_images = read_images;
   %
   % more initialization
   %
   selector = 'init';
   my_exit = 1;
   tm.const_model = [0 0 0 0 0];
   if tm.deterselect(1)==1;
      tm.const_model(3) = 1;
   elseif tm.deterselect(2)==1
      tm.const_model(2) = 1;
   elseif tm.deterselect(3)==1;
      tm.const_model(5) = 1;
   else;
      tm.const_model(4) = 1;
   end;
   %
   % Set screen size directly instead of using
   % get(0,'ScreenSize')!
   %
   tm.realscrsz = get(0,'ScreenSize');
   tm.eigen_run = 0;
   %
   % read var.in
   %
   curr_ini = find_inisettings;
   my_T = tm.T;
   rep = curr_ini.nRep;
   repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
   nRep_value = 1;
   for i=1:size(repvalues,2);
      if curr_ini.nRep==repvalues(1,i);
         nRep_value = i;
         break;
      end;
   end;
   if direxist(curr_ini.simulatedir)==0;
      mystatus = makedirs(curr_ini.simulatedir);
   else;
      mystatus = 2;
   end;
   if mystatus==0;
      curr_ini.simulatedir = pwd;
      if ispc==1;
         curr_ini.simulatedir = [curr_ini.simulatedir '\'];
      end;
   end;
   if isnumeric(curr_ini.external)==0;
      curr_ini.external = 0;
   end;
   %
   if curr_ini.parametric==1;
      bootstyle = '';
   else;
      bootstyle = ['np' num2str(curr_ini.blocksize) '-'];
   end;
   full_mat = '';
   if tm.const_model(1)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-full-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
   elseif tm.const_model(2)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-full-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
   elseif tm.const_model(3)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-full-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
   elseif tm.const_model(4)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-full-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
   elseif tm.const_model(5)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-full-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
   end;
   if fileexist(full_mat)==1;
      full_enable = 'on';
      view_enable = 'on';
      if rep>=5000;
         this_text = strvcat(' ',['Collecting data from ' getfilename(full_mat) '...'],'Please hold!');
         mywait = waitdlg(this_text,'information');
         waitf = get(mywait,'UserData');
      end;
      cointtest_mat = load(full_mat);
      coint_test_sorted = cointtest_mat.coint_test_sorted;
      if rep>=5000;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
      end;
   else;
      view_enable = 'off';
      coint_test_sorted = [];
      full_mat = '';
      full_enable = 'off';
   end;
   summary_txt = '';
   if tm.const_model(1)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-summary-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.txt'];
      mod_type = 'noconst';
      model_type = 'No Constant';
   elseif tm.const_model(2)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-summary-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
      mod_type = 'resconst';
      model_type = 'Restricted Constant';
   elseif tm.const_model(3)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-summary-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
      mod_type = 'const';
      model_type = 'Constant';
   elseif tm.const_model(4)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-summary-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
      mod_type = 'restrend';
      model_type = 'Restricted Linear Trend';
   elseif tm.const_model(5)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-summary-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
      mod_type = 'trend';
      model_type = 'Linear Trend';
   end;
%   if curr_ini.texoutputformat>=2;
%      summary_txt = strrep(summary_txt,'.txt','.ltx');
%   end;
   if fileexist(summary_txt)==1;
      summary_enable = 'on';
   else;
      summary_txt = '';
      summary_enable = 'off';
   end;
   %
   % check if file with bootstrapped residuals exists
   %
   epsfile = [curr_ini.simulatedir tm.modelfile '-' 'cointtest-epsilon-' num2str(tm.scale_endo,'%0.4f') '-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '-' num2str(rep) '-' mod_type '.mat'];
   testfile = strrep(epsfile,'.mat',['-' 'cointtest-data.mat']);
   if fileexist(epsfile)==1;
      boot_enable = 'on';;
   else;
      epsfile = '';
      testfile = '';
      boot_enable = 'off';
   end;
   %
   tm.interpolate = curr_ini.interpolate;
   if strcmp(tm.interpolate,'nearest')==1;
      tm.interpolate_value = 1;
   elseif strcmp(tm.interpolate,'linear')==1;
      tm.interpolate_value = 2;
   elseif strcmp(tm.interpolate,'spline')==1;
      tm.interpolate_value = 3;
   elseif strcmp(tm.interpolate,'cubic')==1;
      tm.interpolate_value = 4;
   elseif strcmp(tm.interpolate,'knorm')==1;
      tm.interpolate_value = 5;
   elseif strcmp(tm.interpolate,'kepan')==1;
      tm.interpolate_value = 6;
   elseif strcmp(tm.interpolate,'krect')==1;
      tm.interpolate_value = 7;
   elseif strcmp(tm.interpolate,'ktria')==1;
      tm.interpolate_value = 8;
   elseif strcmp(tm.interpolate,'kbiwe')==1;
      tm.interpolate_value = 9;
   elseif strcmp(tm.interpolate,'ktriw')==1;
      tm.interpolate_value = 10;
   elseif strcmp(tm.interpolate,'klapl')==1;
      tm.interpolate_value = 11;
   elseif strcmp(tm.interpolate,'klogi')==1;
      tm.interpolate_value = 12;
   end;
else;
   my_exit = 0;
   cointtest_boot_gui = findobj('Type','figure','Tag','CointTestBoot')';
   boot_cointtest = get(cointtest_boot_gui,'UserData');
   curr_ini = get(boot_cointtest.matfilebutton,'UserData');
   tm = curr_ini.models;
   button_images = curr_ini.images;
end;

switch selector
case 'init'
   cointtest_boot_gui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','cointtest_bootstrap.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(tm.realscrsz(3)-560)/2 (tm.realscrsz(4)-405)/2 560 405], ...
         'Tag','CointTestBoot', ...
         'Visible','off', ...
         'Resize','off', ...
         'Name','Bootstrap Distributions for Cointegration Space Tests', ...
         'NumberTitle','off', ...
         'CloseRequestFcn','cointtest_bootstrap done', ...
         'ToolBar','none');

   if matlabnumber>=7.0;
      set(cointtest_boot_gui,'DockControl','off');
   end;

   if strcmp(curr_ini.helpexe,'')==1;
      helpenable = 'off';
   else;
      helpenable = 'on';
   end;

   %
   % File menu
   %

   filemenu = uimenu('Parent',cointtest_boot_gui, ...
      'Label','&File', ...
      'Tag','FileMenu');

   boot_cointtest.simulatemenu = uimenu('Parent',filemenu, ...
         'Label','&Run Bootstrap', ...
         'Callback','cointtest_bootstrap simulate', ...
         'Enable','on', ...
         'Accelerator','R', ...
         'Tag','SimulateMenu');

   boot_cointtest.matfilemenu = uimenu('Parent',filemenu, ...
         'Label','Save to m&at-file', ...
         'Separator','on', ...
         'Accelerator','A', ...
         'Enable',full_enable, ...
         'Callback','cointtest_bootstrap matfile', ...
         'Tag','MatFileMenu');

   boot_cointtest.summarymenu = uimenu('Parent',filemenu, ...
         'Label','&Simulation Summary', ...
         'Separator','on', ...
         'Callback','cointtest_bootstrap summary', ...
         'UserData',summary_txt, ...
         'Accelerator','S', ...
         'Enable',summary_enable, ...
         'Tag','SummaryMenu');

   boot_cointtest.fullmenu = uimenu('Parent',filemenu, ...
         'Label','&Full Simulation', ...
         'Callback','cointtest_bootstrap full', ...
         'Accelerator','F', ...
         'UserData',full_mat, ...
         'Enable',full_enable, ...
         'Tag','FullMenu');

   if curr_ini.noprint==0;
      boot_cointtest.output = uimenu('Parent',filemenu, ...
            'Label','Append to &Output', ...
            'Separator','on', ...
            'Callback','cointtest_bootstrap output', ...
            'Accelerator','O', ...
            'Enable',summary_enable, ...
            'Tag','SummaryMenu');
   end;

   uimenu('Parent',filemenu, ...
         'Label','Center &Window', ...
         'Separator','on', ...
         'Accelerator','W', ...
         'Enable','on', ...
         'Callback','center_figure_fcn', ...
         'Tag','CenterMenu');

   boot_cointtest.returnmenu = uimenu('Parent',filemenu, ...
         'Label','R&eturn', ...
         'Separator','on', ...
         'Callback','cointtest_bootstrap done', ...
         'Enable','on', ...
         'Tag','MenuFileReturn');

   boot_cointtest.filemenu = filemenu;

   %
   % Graph Menu
   %

   graphmenu = uimenu('Parent',cointtest_boot_gui, ...
      'Label','&Graphics', ...
      'Tag','GraphMenu');

   boot_cointtest.bootstrapgraphmenu = uimenu('Parent',graphmenu, ...
         'Label','Graph &Bootstrap Sample', ...
         'Callback','cointtest_bootstrap display_bootstrap', ...
         'Accelerator','B', ...
         'UserData',testfile, ...
         'Enable',boot_enable, ...
         'Tag','BootstrapGraphMenu');

   boot_cointtest.displaymenu = uimenu('Parent',graphmenu, ...
         'Label','&Graph Distribution', ...
         'Callback','cointtest_bootstrap display', ...
         'Separator','on', ...
         'Accelerator','G', ...
         'UserData',tm.const_model, ...
         'Enable',view_enable, ...
         'Tag','DisplayMenu');

   boot_cointtest.histogrammenu = uimenu('Parent',graphmenu, ...
         'Label','&Histogram of Distribution', ...
         'Callback','cointtest_bootstrap display', ...
         'Accelerator','D', ...
         'Enable',view_enable, ...
         'Tag','HistogramMenu');

   %
   % Help Menu
   %

   helpmenu = uimenu('Parent',cointtest_boot_gui, ...
      'Label','&Help', ...
      'Tag','HelpMenu');

   boot_cointtest.helpmenu = uimenu('Parent',helpmenu, ...
         'Label','&Help Topics', ...
         'Callback','help_fcn(''bootstrapping'')', ...
         'Accelerator','H', ...
         'Enable',helpenable, ...
         'Tag','HelpMenu');

   %
   % The toolbar
   %

   boot_cointtest.toolbar = uitoolbar('Parent',cointtest_boot_gui, ...
                     'HandleVisibility','off', ...
                     'Interruptible','on', ...
                     'Clipping','on');

   if (iswinxp==0)|(matlabnumber<7);
      xline([1 404 560],[0.5 1]);
   end;

   boot_cointtest.simulate = uipushtool('Parent',boot_cointtest.toolbar, ...
                      'TooltipString','Run Bootstrap', ...
                      'CData',button_images.simulate, ...
                      'ClickedCallback','cointtest_bootstrap simulate', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable','on', ...
                      'UserData',0, ...
                      'Tag','Simulate');


   boot_cointtest.matfilebutton = uipushtool('Parent',boot_cointtest.toolbar, ...
                      'TooltipString','Save to mat-file', ...
                      'CData',button_images.matfile, ...
                      'ClickedCallback','cointtest_bootstrap matfile', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',full_enable, ...
                      'Tag','MatFileButton');

   boot_cointtest.summary = uipushtool('Parent',boot_cointtest.toolbar, ...
                      'TooltipString','View Simulation Summary', ...
                      'CData',button_images.sim_summary, ...
                      'ClickedCallback','cointtest_bootstrap summary', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',summary_enable, ...
                      'Tag','SummaryButton');

   boot_cointtest.full = uipushtool('Parent',boot_cointtest.toolbar, ...
                      'TooltipString','View Full Simulation', ...
                      'CData',button_images.sim_full, ...
                      'ClickedCallback','cointtest_bootstrap full', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',full_enable, ...
                      'Tag','FullButton');

   boot_cointtest.bootstrapgraph = uipushtool('Parent',boot_cointtest.toolbar, ...
                      'TooltipString','Graph Bootstrap Sample', ...
                      'CData',button_images.bootstrapsmall, ...
                      'ClickedCallback','cointtest_bootstrap display_bootstrap', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'UserData',epsfile, ...
                      'Clipping','on', ...
                      'Enable',boot_enable, ...
                      'Tag','ViewBootstrapButton');

   boot_cointtest.display = uipushtool('Parent',boot_cointtest.toolbar, ...
                      'TooltipString','Graph Distribution', ...
                      'CData',button_images.viewdist, ...
                      'ClickedCallback','cointtest_bootstrap display', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'UserData',coint_test_sorted, ...
                      'Clipping','on', ...
                      'Enable',view_enable, ...
                      'Tag','ViewDistButton');

   boot_cointtest.histogram = uipushtool('Parent',boot_cointtest.toolbar, ...
                      'TooltipString','Histogram of Distribution', ...
                      'CData',button_images.bars, ...
                      'ClickedCallback','cointtest_bootstrap display', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',view_enable, ...
                      'Tag','HistogramButton');

   boot_cointtest.help = uipushtool('Parent',boot_cointtest.toolbar, ...
                      'TooltipString','Help Topics', ...
                      'CData',button_images.help, ...
                      'ClickedCallback','help_fcn(''bootstrapping'')', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',helpenable, ...
                      'Tag','HelpButton');

   boot_cointtest.done = uipushtool('Parent',boot_cointtest.toolbar, ...
                      'TooltipString','Return', ...
                      'CData',button_images.continue, ...
                      'ClickedCallback','cointtest_bootstrap done', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'UserData','waiting', ...
                      'Enable','on', ...
                      'Tag','Done');

   axesbox([2 2 558 390],'Cointegration Space Tests',135,[0.5 1]);

   %
   % GUI Header
   %

   header_txt = ['Cointegration Space Tests (' model_type ' Model)'];
   desc_txt = 'Select the type of bootstrap you wish to perform, the number of observations and replications. Press the "Run Bootstrap" button when you''re satisfied with your choices and wait for the computations to finish.';
   dialog_header_fcn([16 306 530 70],button_images.bootstrap,header_txt,desc_txt);

   %
   % Options
   %

   axesbox([16 130 155 160],'Options',35,[0.5 1]);

   boot_cointtest.clock = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 255 130 20], ...
      'Value',1, ...
      'String','Show elapsed time', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','TimeCheck');

   boot_cointtest.progress = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 235 130 20], ...
      'Value',1, ...
      'String','Show progress dialog', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ProgressCheck');

   boot_cointtest.save = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 215 130 20], ...
      'Value',1, ...
      'String','Save full simulation', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','SaveCheck');

   boot_cointtest.parametric = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 195 130 20], ...
      'Value',curr_ini.parametric, ...
      'String','Parametric bootstrap', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'Callback','cointtest_bootstrap fixobscontrol', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ParametricCheck');


   boot_cointtest.blocktext = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[45 165 100 20], ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Style','text', ...
      'HorizontalAlignment','left', ...
      'String','Block size:', ...
      'Enable','off', ...
      'Tag','BlockText');

   boot_cointtest.block = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[105 170 50 20], ...
      'Value',1, ...
      'String','1|2|3|4|5|6|7|8|9|10|11|12', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Value',curr_ini.blocksize, ...
      'Enable','off', ...
      'Callback','cointtest_bootstrap check', ...
      'Tag','BlockPopup');
   
   if curr_ini.parametric==0;
      set(boot_cointtest.blocktext,'Enable','on');
      set(boot_cointtest.block,'Enable','on');
   end;

   boot_cointtest.bootstrap = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 145 130 20], ...
      'Value',curr_ini.reuse_bootstrap, ...
      'String','Reuse/save residuals', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ReuseBootstrapCheck');

   axesbox([185 130 361 160],'Parameters',55,[0.5 1]);

   %
   % number of observations per replication
   %

   boot_cointtest.obstext = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 249 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'HorizontalAlignment','left', ...
      'String','Number of observations:', ...
      'Tag','ObsText');

   boot_cointtest.obs = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 254 168 20], ...
      'Value',1, ...
      'String',[num2str(my_T) '|100|200|300|400|500|600|700|800|900|1000|1100|1200|1300|1400|1500|1600|1700|1800|1900|2000|2500|3000|4000|5000|6000|7000|8000|9000|10000'], ...
      'Style','popupmenu', ...
      'UserData',my_T, ...
      'Callback','cointtest_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'Tag','ObsPopup');

   if (tm.q1+tm.q0==0)&(isempty(tm.deterfile)==1);
      set(boot_cointtest.obstext,'Enable','on');
      set(boot_cointtest.obs,'Enable','on');
   end;

   %
   % number of replications
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 196.5 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Number of replications:', ...
      'Tag','SimulText');

   boot_cointtest.rep = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 201.5 168 20], ...
      'Value',nRep_value, ...
      'String','99|999|1,999|2,999|3,999|4,999|9,999|19,999|29,999|39,999|49,999|99,999|199,999|299,999|399,999|499,999|999,999', ...
      'Style','popupmenu', ...
      'Callback','cointtest_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'UserData',rep,...
      'Enable','on', ...
      'Tag','SimulPopup');

   %
   % number of cointegration relations
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 144 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'HorizontalAlignment','left', ...
      'String','Number of cointegration relations:', ...
      'Tag','CointText');

   r_str = '1';
   for i=2:tm.n-1;
      r_str = [r_str '|' num2str(i)];
   end;

   boot_cointtest.my_r = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 149 168 20], ...
      'Value',tm.r, ...
      'String',r_str, ...
      'UserData',tm.r, ...
      'Style','popupmenu', ...
      'Callback','cointtest_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','CointPopup');

   %
   % Select interpolation function
   %

   axesbox([16 16 530 100],'Graphics',45,[0.5 1]);

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 74 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Interpolation function:', ...
      'Tag','InterpolateText');

   boot_cointtest.interpolate = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 79 168 20], ...
      'Value',tm.interpolate_value, ...
      'String','Nearest neighborhood|Linear|Cubic spline|Cubic|Kernel density normal|Kernel density Epanechnikov|Kernel density rectangular|Kernel density triangular|Kernel density biweight|Kernel density triweight|Kernel density Laplace|Kernel density logistic', ...
      'Callback','cointtest_bootstrap interpolate', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','InterpolatePopup');

   %
   % Number of cells for graphing density functions
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 29 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Number of cells for histograms:', ...
      'Tag','CellText');

   boot_cointtest.cells = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 34 168 20], ...
      'Value',1, ...
      'String','20|25|30|35|40|45|50|55|60|65|70|75|80|85|90|95|100', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','CellPopup');

   boot_cointtest.cdf = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 84.5 140 20], ...
      'Value',0, ...
      'String','Cumulative distribution', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','cdfCheckbox');

   boot_cointtest.adaptive = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 64.5 140 20], ...
      'Value',0, ...
      'String','Adaptive KDE method', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'Tag','adaptiveCheckbox');

   boot_cointtest.bart = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 44.5 140 20], ...
      'Value',0, ...
      'String','Bartlett corr. bootstrap', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','BartlettCheckbox');

   boot_cointtest.pqplot = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 24.5 140 20], ...
      'Value',0, ...
      'String','P-value plots, etc.', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','PQPlotCheckbox');

   if tm.interpolate_value>=5;
      set(boot_cointtest.adaptive,'Enable','on');
   end;

   set(cointtest_boot_gui,'UserData',boot_cointtest,...
         'HandleVisibility','callback');

case 'output'
   if curr_ini.texoutputformat>=2;
      file = strrep(lower(get(boot_cointtest.summarymenu,'UserData')),'.txt','.ltx');
      txt_str = readtext(file);
      fout = fopen(tm.outputfile,'at');
      fprintf(fout,'\\subsection*{Bootstrap Simulation of Cointegration Space Tests} \n\n');
      for i=1:size(txt_str,2);
         fprintf(fout,'%s\n',txt_str{i});
      end;
      fclose(fout);
   else;
      txt_str = readtext(lower(get(boot_cointtest.summarymenu,'UserData')));
      fout = fopen(tm.outputfile,'at');
      fprintf(fout,'            Bootstrap Simulation of Cointegration Tests\n            -------------------------------------------\n');
      for i=5:size(txt_str,2)-4;
         fprintf(fout,'%s\n',txt_str{i});
      end;
      fprintf(fout,'\n===============================================================================\n\n');
      fclose(fout);
   end;
case 'display_bootstrap'
   epsfile = get(boot_cointtest.bootstrapgraph,'UserData');
   testfile = get(boot_cointtest.bootstrapgraphmenu,'UserData');
   my_T = get(boot_cointtest.obs,'UserData');
   rep = get(boot_cointtest.rep,'UserData');
   if rep<4999;
      answer = 'Yes';
   else;
      check_txt = ['Your bootstrap setup includes ' num2str(rep) ' draws of the residuals. With ' num2str(tm.n) ' series and ' num2str(my_T) ' observations, this yields ' num2str(rep*tm.n*my_T) ' observations. Are you sure you want to load that much data into memory?'];
      answer = query(check_txt,'warning',120,'Exit',500,'no');
   end;
   if strcmp(answer,'Yes')==1;
      %
      txt_str = '';
      %
      set(cointtest_boot_gui,'Visible','off');
      drawnow;
      thisgraph = bootgraphdlg('init',tm,epsfile,testfile,txt_str,tm.beta(:,1:tm.r),rep,my_T,tm.r);
      bootgraph = get(thisgraph,'UserData');
      set(bootgraph.show,'UserData','done');
      killguipid(thisgraph);
      set(cointtest_boot_gui,'Visible','on');
      drawnow;
   end;
case 'fixobscontrol'
   if get(boot_cointtest.parametric,'Value')==0;
      T_str = get(boot_cointtest.obs,'String');
      my_T = mystr2num(strtrim(T_str(get(boot_cointtest.obs,'Value'),:)));
      set(boot_cointtest.obs,'Value',1,'UserData',my_T,'Enable','off');
      set(boot_cointtest.obstext,'Enable','off');
   elseif (tm.q1+tm.q0==0)&(isempty(tm.deterfile)==1);
      set(boot_cointtest.obs,'Enable','on');
      set(boot_cointtest.obstext,'Enable','on');
   end;
   cointtest_bootstrap('check');
case 'interpolate'
   tm.interpolate_value = get(boot_cointtest.interpolate,'Value');
   interpol_vec = strvcat('nearest','linear','spline','cubic','knorm','kepan','krect','ktria','kbiwe','ktriw','klapl','klogi');
   tm.interpolate = strtrim(interpol_vec(tm.interpolate_value,:));
   if tm.interpolate_value>=5;
      set(boot_cointtest.adaptive,'Enable','on');
   else;
      set(boot_cointtest.adaptive,'Enable','off','Value',0);
   end;
case 'matfile'
   coint_test_sorted = get(boot_cointtest.display,'UserData');
   rep = get(boot_cointtest.rep,'UserData');
   my_T = get(boot_cointtest.obs,'UserData');
   my_const_model = get(boot_cointtest.displaymenu,'UserData');
   if get(boot_cointtest.parametric,'Value')==1;
      bootstyle = '';
   else;
      bootstyle = ['np' num2str(get(boot_cointtest.block,'Value')) '-'];
   end;
   if my_const_model(1)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-full-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
   elseif my_const_model(2)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-full-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
   elseif my_const_model(3)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-full-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
   elseif my_const_model(4)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-full-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
   elseif my_const_model(5)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-full-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
   end;
   if fileexist(full_mat)==1;
      my_text = ['The file "' getfilename(full_mat) '" already exists. Are you sure you want to overwrite it?'];
      answer = query(my_text,'question',120,'Save to mat-file',500,'no');
   else;
      answer = 'Yes';
   end;
   if strcmp(answer,'Yes')==1;
      setlogtext('Savings results to mat-files...');
      Number = (1:1:rep)';
      save(full_mat,'coint_test_sorted');
   end;
case 'check'
   T_str = get(boot_cointtest.obs,'String');
   my_T = mystr2num(strtrim(T_str(get(boot_cointtest.obs,'Value'),:)));
   if strcmp(get(boot_cointtest.my_r,'Enable'),'on')==1;
      tm.r = get(boot_cointtest.my_r,'Value');
      %
      % make sure the largest non-zero eigenvalue is less than unity
      %
      eigenvalues = companion(tm.Z0,tm.Z1,tm.Z2,tm.r,tm.p,tm.n,tm.q1,tm.q0,tm.d,tm.T);
      eigenvalues = abs(sort(eigenvalues));
      i = size(eigenvalues,1);
      while i>=1;
         tm.evalue = eigenvalues(i,1);
         if strcmp(num2str(tm.evalue,'%1.10f'),'1.0000000000')==1;
            i = i-1;
         else;
            i = 0;
         end;
      end;
      if tm.evalue>1;
         some_txt = ['For the cointegration rank ' num2str(tm.r,'%0.0f') ' the largest non-unit eigenvalue is ' num2str(tm.evalue,'%0.4f') '. Explosive systems should not be bootstrapped.'];
         about(some_txt,'warning','Explosive Model...',120,350);
         tm.r = get(boot_cointtest.my_r,'UserData');
         set(boot_cointtest.my_r,'Value',tm.r);
      else;
         tm.alpha = (tm.S_01*tm.beta(:,1:tm.r))/(tm.beta(:,1:tm.r)'*tm.S_11*tm.beta(:,1:tm.r));
         if isempty(tm.Z2)==0;
            tm.Psi = (tm.M_02/tm.M_22)-(tm.alpha*tm.beta(:,1:tm.r)'*(tm.M_12/tm.M_22));
            tm.epsilon = tm.Z0-(tm.alpha*tm.beta(:,1:tm.r)'*tm.Z1)-(tm.Psi*tm.Z2);
         else;
            tm.Psi = [];
            tm.epsilon = tm.Z0-(tm.alpha*tm.beta(:,1:tm.r)'*tm.Z1);
         end;
         tm.Omega = (1/tm.T)*tm.epsilon*tm.epsilon';
         set(boot_cointtest.my_r,'UserData',tm.r);
      end;
   end;
   repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
   rep_val = get(boot_cointtest.rep,'Value');
   rep = repvalues(rep_val);
   set(boot_cointtest.rep,'UserData',rep);
   set(boot_cointtest.obs,'UserData',my_T);
   %
   % adjusting the view text buttons
   %
   if get(boot_cointtest.parametric,'Value')==1;
      bootstyle = '';
      set(boot_cointtest.blocktext,'Enable','off');
      set(boot_cointtest.block,'Enable','off','Value',1);
   else;
      if strcmp(get(boot_cointtest.block,'Enable'),'off')==1;
         set(boot_cointtest.blocktext,'Enable','on');
         set(boot_cointtest.block,'Enable','on','Value',curr_ini.blocksize);
      end;
      bootstyle = ['np' num2str(get(boot_cointtest.block,'Value')) '-'];
   end;
   full_mat = '';
   if tm.const_model(1)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-full-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
      mod_type = 'noconst';
   elseif tm.const_model(2)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-full-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
      mod_type = 'resconst';
   elseif tm.const_model(3)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-full-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
      mod_type = 'const';
   elseif tm.const_model(4)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-full-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
      mod_type = 'restrend';
   elseif tm.const_model(5)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-full-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
      mod_type = 'trend';
   end;
   if fileexist(full_mat)==1;
      full_enable = 'on';
      if rep>=5000;
         this_text = strvcat(' ',['Collecting data from ' getfilename(full_mat) '...'],'Please hold!');
         mywait = waitdlg(this_text,'information');
         waitf = get(mywait,'UserData');
      end;
      cointtest_mat = load(full_mat);
      coint_test_sorted = cointtest_mat.coint_test_sorted;
      if rep>=5000;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
      end;
      %
      % adjusting the Graph Distrbution button
      %
      set(boot_cointtest.display,'Enable','on','UserData',coint_test_sorted);
      set(boot_cointtest.displaymenu,'Enable','on','UserData',tm.const_model);
      set(boot_cointtest.histogram,'Enable','on');
      set(boot_cointtest.histogrammenu,'Enable','on');
      set(boot_cointtest.matfilebutton,'Enable','on');
      set(boot_cointtest.matfilemenu,'Enable','on');
   else;
      full_mat = '';
      full_enable = 'off';
      set(boot_cointtest.display,'Enable','off','UserData',[]);
      set(boot_cointtest.displaymenu,'Enable','off','UserData',tm.const_model);
      set(boot_cointtest.histogram,'Enable','off');
      set(boot_cointtest.histogrammenu,'Enable','off');
      set(boot_cointtest.matfilebutton,'Enable','off');
      set(boot_cointtest.matfilemenu,'Enable','off');
   end;
   %
   % Checking if residuals file exists
   %
   epsfile = [curr_ini.simulatedir tm.modelfile '-' 'cointtest-epsilon-' num2str(tm.scale_endo,'%0.4f') '-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '-' num2str(rep) '-' mod_type '.mat'];
   testfile = strrep(epsfile,'.mat',['-' 'cointtest-data.mat']);
   %
   if (fileexist(epsfile)==1)&(fileexist(testfile)==1);
      set(boot_cointtest.bootstrapgraph,'Enable','on','UserData',epsfile);
      set(boot_cointtest.bootstrapgraphmenu,'Enable','on','UserData',testfile);
   else;
      set(boot_cointtest.bootstrapgraph,'Enable','off','UserData',[]);
      set(boot_cointtest.bootstrapgraphmenu,'Enable','off','UserData','');
   end;
   %
   set(boot_cointtest.fullmenu,'Enable',full_enable,'UserData',full_mat);
   set(boot_cointtest.full,'Enable',full_enable);
   summary_txt = '';
   if tm.const_model(1)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-summary-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.txt'];
   elseif tm.const_model(2)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-summary-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
   elseif tm.const_model(3)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-summary-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
   elseif tm.const_model(4)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-summary-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
   elseif tm.const_model(5)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-summary-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
   end;
%   if curr_ini.texoutputformat>=2;
%      summary_txt = strrep(summary_txt,'.txt','.ltx');
%   end;
   if fileexist(summary_txt)==1;
      summary_enable = 'on';
   else;
      summary_txt = '';
      summary_enable = 'off';
   end;
   if curr_ini.noprint==0;
      set(boot_cointtest.output,'Enable',summary_enable);
   end;
   set(boot_cointtest.summarymenu,'Enable',summary_enable,'UserData',summary_txt);
   set(boot_cointtest.summary,'Enable',summary_enable);
   set(cointtest_boot_gui,'UserData',boot_cointtest);
case 'summary'
   set(cointtest_boot_gui,'Visible','off');
   drawnow;
   file = lower(get(boot_cointtest.summarymenu,'UserData'));
   prtgui = printgui('init',file,'Structural VAR - Fluctuation Tests Bootstrap Simulation Summary',[(tm.realscrsz(3)-700)/2 (tm.realscrsz(4)-500)/2 700 500],'Results',40);
   myprint = get(prtgui,'UserData');
   set(myprint.print,'UserData','done');
   killguipid(prtgui);
   set(cointtest_boot_gui,'Visible','on');
   drawnow;
   set(cointtest_boot_gui,'UserData',boot_cointtest);
case 'full'
   set(cointtest_boot_gui,'Visible','off');
   drawnow;
   rep = get(boot_cointtest.rep,'UserData');
   full_mat = lower(get(boot_cointtest.fullmenu,'UserData'));
   my_T = get(boot_cointtest.obs,'UserData');
   %
   myvars = strtrim(tm.evars);
   if tm.q1>0;
      myvars = [myvars ' ' strtrim(tm.xvars1)];
   end;
   myvars = strtrim([myvars ' ' tm.restvec]);
   myvars = vecstr(myvars);
   test_str = 'LR';
   if curr_ini.sscorrect==1;
      test_str = ' F'
   end;
   sp_str = spacestr(curr_ini.decimals-2);
   if curr_ini.decimals>=4;
      add_sp_str = '';
   else;
      add_sp_str = spacestr(4-curr_ini.decimals);
   end;
   prt_val = ['%' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
   prt_str = '%7.0f   ';
   head_txt = strvcat(' ',' ',' Number   ');
   for i=1:size(tm.beta,1);
      prt_str = [prt_str prt_val '   '];
      var_str = strvcat(test_str,'exclude',myvars(i,:));
      head_txt = [head_txt var_str strvcat(' ',' ',['    ' sp_str])];
   end;
   for i=1:tm.n;
      prt_str = [prt_str prt_val '   ' add_sp_str];
      var_str = strvcat(test_str,'stationary',myvars(i,:));
      head_txt = [head_txt var_str strvcat(' ',' ',[' ' sp_str add_sp_str]);];
   end;
   prt_str = [prt_str prt_val];
   head_txt = [head_txt strvcat(test_str,'deterministics','test')];
   %
   my_text = strvcat(' ',head_txt);
   abort = '';
   if rep>=5000;
      input_var.title = ['Progress for ' int2str(rep) ' replications'];
      input_var.facecolor = curr_ini.progress_facecolor;
      input_var.startfacecolor = curr_ini.progress_startfacecolor;
      input_var.edgecolor = curr_ini.progress_edgecolor;
      input_var.bgcolor = curr_ini.progress_bgcolor;
      input_var.label = 'Replication number:';
      input_var.stop = 0;
      input_var.clock = 1;
      input_var.name = ['Data in ' getname(full_mat)];
      mywait = progressdlg(0,input_var);
      set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
      drawnow;
   end;
   cointtest_mat = load(full_mat);
   my_data = [cointtest_mat.Number cointtest_mat.coint_test_sorted.exclude cointtest_mat.coint_test_sorted.stat cointtest_mat.coint_test_sorted.deter];
   for i=1:size(my_data,1);
      if rep>=5000;
         abort = get(mywait,'UserData');
         if strcmp(abort,'cancel')==1;
            break;
         else;
            progressdlg([(i/rep) i]);
         end;
      end;
      out = sprintf(prt_str,my_data(i,:)');
      my_text = strvcat(my_text,out);
   end;
   my_text = strvcat(my_text,' ');
   if rep>=5000;
      set(mywait,'UserData','done');
      close(mywait);
      drawnow;
   end;
   if strcmp(abort,'cancel')==0;
      textgui(my_text,'Structural VAR - Fluctuation Tests Bootstrap Simulation',[(tm.realscrsz(3)-700)/2 (tm.realscrsz(4)-500)/2 700 500],'Results',40);
   end;
   set(cointtest_boot_gui,'Visible','on');
   drawnow;
   set(cointtest_boot_gui,'UserData',boot_cointtest);
case 'display'
   coint_test_sorted = get(boot_cointtest.display,'UserData');
   pos = [(tm.realscrsz(3)-600)/2 (tm.realscrsz(4)-400)/2];
   rep = get(boot_cointtest.rep,'UserData');
   my_T = get(boot_cointtest.obs,'UserData');
   %
   % need to fix the rest
   %
   my_const_model = get(boot_cointtest.displaymenu,'UserData');
   if my_const_model(1)==1;
      this_mod = '(no constant)';
   elseif my_const_model(2)==1;
      this_mod = '(restricted constant)';
   elseif my_const_model(3)==1;
      this_mod = '(constant)';
   elseif my_const_model(4)==1;
      this_mod = '(restricted trend)';
   elseif my_const_model(5)==1;
      this_mod = '(trend)';
   end;
   cell_value = get(boot_cointtest.cells,'Value');
   cell_vec = [20 25 30 35 40 45 50 55 60 65 70 75 80 85 90 95 100];
   numcells = cell_vec(cell_value);
   my_80 = floor(0.8*rep);
   my_90 = floor(0.9*rep);
   my_95 = floor(0.95*rep);
   my_975 = floor(0.98*rep);
   my_99 = floor(0.99*rep);
   %
   if curr_ini.colors==1;
      col.vec_1 = [0 0 1];
      col.vec_2 = [1 0 0];
      col.vec_3 = [0 0.75 0];
      col.vec_4 = [1 0.5 0];
      col.vec_5 = [0 0.75 0.75];
      col.vec_6 = [0 0 0];
      col.vec_7 = (1/255)*[255 28 28];
      col.vec_8 = [0 1 0];
   else;
      col.vec_1 = [0 0 0];
      col.vec_2 = [0.7 0.7 0.7];
      col.vec_3 = [0.6 0.6 0.6];
      col.vec_4 = [0.5 0.5 0.5];
      col.vec_5 = [0.4 0.4 0.4];
      col.vec_6 = [0.3 0.3 0.3];
      col.vec_7 = [0.8 0.8 0.8];
      col.vec_8 = [0.2 0.2 0.2];
   end;
   %
   myvars = strtrim(tm.evars);
   if tm.q1>0;
      myvars = [myvars ' ' strtrim(tm.xvars1)];
   end;
   myvars = strtrim([myvars ' ' tm.restvec]);
   myvars = vecstr(myvars);
   spec_plot = [];
   %
   % exclusion tests
   %
   exclude_series = [];
   %
   if (gcbo==boot_cointtest.display)|(gcbo==boot_cointtest.displaymenu);
      [exclude_series,exclude_quant,exclude_table] = asymp_series(coint_test_sorted.exclude_df(1,:),curr_ini.sscorrect);
   end;
   %
   for i=1:size(coint_test_sorted.exclude,2);
      exclude_sorted = coint_test_sorted.exclude(:,i);
      if ((gcbo==boot_cointtest.display)|(gcbo==boot_cointtest.displaymenu))&(get(boot_cointtest.pqplot,'Value')==1);
         [p_series,pp_series,qq_series] = pq_plot_series(exclude_sorted,exclude_quant,exclude_table,coint_test_sorted.exclude_df(1,:),curr_ini.sscorrect);
      end;
      %
      if curr_ini.sscorrect==1;
         add_name = ['F(' num2str(coint_test_sorted.exclude_df(1,1),'%0.0f') ',' num2str(coint_test_sorted.exclude_df(1,2),'%0.0f') ')'];
      else;
         add_name = ['LR(' num2str(coint_test_sorted.exclude_df(1,1),'%0.0f') ')'];
      end;
      %
      if ((gcbo==boot_cointtest.display)|(gcbo==boot_cointtest.displaymenu))&(get(boot_cointtest.pqplot,'Value')==1);
         %
         % plotting p-value plots etc.
         %
         [pos,spec_ploti] = pq_plot(pos,['exclude-pq-plot-' strtrim(myvars(i,:)) '-'],['P-value and Quantile Plots for ' add_name ' Exclusion Test - ' strtrim(myvars(i,:))],['P-value plot of ' add_name ' for ' strtrim(myvars(i,:))],['P-value discrepancy plot of ' add_name ' for ' strtrim(myvars(i,:))],['PP plot of ' add_name ' for ' strtrim(myvars(i,:))],['QQ plot of ' add_name ' for ' strtrim(myvars(i,:))],tm,exclude_quant,exclude_table,p_series,pp_series,qq_series,col);
         spec_plot = [spec_plot spec_ploti];
      end;
      %
      % plotting the distributions
      %
      [pos,spec_ploti] = dist_plot(pos,['exclude-' strtrim(myvars(i,:)) '-'],['Density for ' add_name ' Exclusion Tests - ' strtrim(myvars(i,:))],[add_name ' exclusions test for ' strtrim(myvars(i,:)) ' ' this_mod ' with ' num2str(tm.n) ' variables and ' num2str(tm.r) ' cointegration vectors'],tm,curr_ini,boot_cointtest,exclude_sorted,exclude_series,1,0,0,col,my_80,my_90,my_95,my_975,my_99,numcells,coint_test_sorted.exclude_df(1,:));
      spec_plot = [spec_plot spec_ploti];
   end;
   %
   % stationarity tests
   %
   stat_series = [];
   %
   if (gcbo==boot_cointtest.display)|(gcbo==boot_cointtest.displaymenu);
      [stat_series,stat_quant,stat_table] = asymp_series(coint_test_sorted.stat_df(1,:),curr_ini.sscorrect);
   end;
   %
   for i=1:tm.n;
      stat_sorted = coint_test_sorted.stat(:,i);
      if ((gcbo==boot_cointtest.display)|(gcbo==boot_cointtest.displaymenu))&(get(boot_cointtest.pqplot,'Value')==1);
         [p_series,pp_series,qq_series] = pq_plot_series(stat_sorted,stat_quant,stat_table,coint_test_sorted.stat_df(1,:),curr_ini.sscorrect);
      end;
      %
      if curr_ini.sscorrect==1;
         add_name = ['F(' num2str(coint_test_sorted.stat_df(1,1),'%0.0f') ',' num2str(coint_test_sorted.stat_df(1,2),'%0.0f') ')'];
      else;
         add_name = ['LR(' num2str(coint_test_sorted.stat_df(1,1),'%0.0f') ')'];
      end;
      %
      if ((gcbo==boot_cointtest.display)|(gcbo==boot_cointtest.displaymenu))&(get(boot_cointtest.pqplot,'Value')==1);
         %
         % plotting p-value plots etc.
         %
         [pos,spec_ploti] = pq_plot(pos,['stationarity-pq-plot-' strtrim(tm.myvars(i,:)) '-'],['P-value and Quantile Plots for ' add_name ' Stationarity Test - ' strtrim(tm.myvars(i,:))],['P-value plot of ' add_name ' for ' strtrim(tm.myvars(i,:))],['P-value discrepancy plot of ' add_name ' for ' strtrim(tm.myvars(i,:))],['PP plot of ' add_name ' for ' strtrim(tm.myvars(i,:))],['QQ plot of ' add_name ' for ' strtrim(tm.myvars(i,:))],tm,stat_quant,stat_table,p_series,pp_series,qq_series,col);
         spec_plot = [spec_plot spec_ploti];
      end;
      %
      % plotting the distributions
      %
      [pos,spec_ploti] = dist_plot(pos,['stationarity-' strtrim(tm.myvars(i,:)) '-'],['Density for ' add_name ' Stationarity Tests - ' strtrim(tm.myvars(i,:))],[add_name ' stationarity test for ' strtrim(tm.myvars(i,:)) ' ' this_mod ' with ' num2str(tm.n) ' variables and ' num2str(tm.r) ' cointegration vectors'],tm,curr_ini,boot_cointtest,stat_sorted,stat_series,1,0,0,col,my_80,my_90,my_95,my_975,my_99,numcells,coint_test_sorted.stat_df(1,:));
      spec_plot = [spec_plot spec_ploti];
   end;
   %
   % test for deterministics
   %
   if strcmp(tm.test_type,'uconst')==1;
      deter_txt = 'Unrestricted vs. Restricted Constant';
      deter_str = 'unres-res-const-';
   elseif strcmp(tm.test_type,'rconst')==1;
      deter_txt = 'Restricted vs. Zero Constant';
      deter_str = 'res-zero-const-';
   elseif strcmp(tm.test_type,'utrend')==1;
      deter_txt = 'Unrestricted vs. Restricted Linear Trend';
      deter_str = 'unres-res-trend-';
   elseif strcmp(tm.test_type,'rtrend')==1;
      deter_txt = 'Restricted vs. Zero Linear Trend';
      deter_str = 'res-zero-trend-';
   end;
   %
   deter_series = [];
   %
   if (gcbo==boot_cointtest.display)|(gcbo==boot_cointtest.displaymenu);
      [deter_series,deter_quant,deter_table] = asymp_series(coint_test_sorted.deter_df(1,:),curr_ini.sscorrect);
   end;
   %
   deter_sorted = coint_test_sorted.deter;
   if ((gcbo==boot_cointtest.display)|(gcbo==boot_cointtest.displaymenu))&(get(boot_cointtest.pqplot,'Value')==1);
      [p_series,pp_series,qq_series] = pq_plot_series(deter_sorted,deter_quant,deter_table,coint_test_sorted.deter_df(1,:),curr_ini.sscorrect);
   end;
   %
   if curr_ini.sscorrect==1;
      add_name = ['F(' num2str(coint_test_sorted.deter_df(1,1),'%0.0f') ',' num2str(coint_test_sorted.deter_df(1,2),'%0.0f') ')'];
   else;
      add_name = ['LR(' num2str(coint_test_sorted.deter_df(1,1),'%0.0f') ')'];
   end;
   %
   if ((gcbo==boot_cointtest.display)|(gcbo==boot_cointtest.displaymenu))&(get(boot_cointtest.pqplot,'Value')==1);
      %
      % plotting p-value plots etc.
      %
      [pos,spec_ploti] = pq_plot(pos,[deter_str 'pq-plot-'],['P-value and Quantile Plots for ' add_name ' Test - ' deter_txt],['P-value plot of ' add_name],['P-value discrepancy plot of ' add_name],['PP plot of ' add_name],['QQ plot of ' add_name],tm,deter_quant,deter_table,p_series,pp_series,qq_series,col);
      spec_plot = [spec_plot spec_ploti];
   end;
   %
   % plotting the distributions
   %
   [pos,spec_ploti] = dist_plot(pos,deter_str,['Density for ' add_name ' Test'],[add_name ' test for ' lower(deter_txt) ' with ' num2str(tm.n) ' variables and ' num2str(tm.r) ' cointegration vectors'],tm,curr_ini,boot_cointtest,deter_sorted,deter_series,1,0,0,col,my_80,my_90,my_95,my_975,my_99,numcells,coint_test_sorted.deter_df(1,:));
   spec_plot = [spec_plot spec_ploti];
   %
   % show the plots
   %
   if curr_ini.external==0;
      set(spec_plot,'Visible','on');
   else;
      stats = [];
      file_names = '';
      this_mod = strrep(this_mod,'(','');
      this_mod = strrep(this_mod,')','');
      this_mod = strtrim(this_mod);
      this_mod = strrep(this_mod,' ','.');
      stats = [];
      file_names = '';
      for i=1:size(spec_plot,2);
         if (gcbo==boot_cointtest.histogram)|(gcbo==boot_cointtest.histogrammenu);
            file = [curr_ini.simulatedir tm.modelfile '-cointtest-hist-boot-' get(spec_plot(1,i),'Tag') num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-' this_mod];
         else;
            file = [curr_ini.simulatedir tm.modelfile '-cointtest-boot-' get(spec_plot(1,i),'Tag') num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-' this_mod];
         end;
         set(0,'CurrentFigure',spec_plot(1,i));
         stats = [stats autosavefigure(spec_plot(1,i),file)];
         file_names = strvcat(file_names,file);
      end;
      if isempty(stats)==0;
         for i=1:size(stats,2);
            if stats(i)==0;
               autoshowfigure(strtrim(file_names(i,:)));
            end;
         end;
      end;
   end;
   set(cointtest_boot_gui,'UserData',boot_cointtest);
   %
   % case simulate
   %
case 'simulate'
   tm.eigen_run = 1;
   set(cointtest_boot_gui,'Visible','off');
   drawnow;
   %
   % collect values
   %
   T_str = get(boot_cointtest.obs,'String');
   my_T = mystr2num(strtrim(T_str(get(boot_cointtest.obs,'Value'),:)));
   repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
   rep_val = get(boot_cointtest.rep,'Value');
   rep = repvalues(rep_val);
   set(boot_cointtest.simulate,'UserData',rep);
   blocksize = get(boot_cointtest.block,'Value');
   block_txt = '';
   if blocksize>1;
      block_txt = ['Applying block bootstrap with block length ' num2str(blocksize,'%0.0f') '...'];
   end;
   if get(boot_cointtest.parametric,'Value')==1;
      bootstyle = '';
   else;
      bootstyle = ['np' num2str(get(boot_cointtest.block,'Value')) '-'];
   end;
   %
   % initialize:
   %
   % compute exclusions tests and save parameters from restricted models
   %
   [tm.exclude_tests,tm.exclude_df,pvals,exclude_params] = coint_exclusion(tm.S_00,tm.S_01,tm.S_10,tm.S_11,tm.M_02,tm.M_22,tm.M_12,tm.Z0,tm.Z1,tm.Z2,tm.epsilon,tm.r,tm.q1,tm.dcoint,tm.df,curr_ini.sscorrect);
   %
   % compute stationarity tests and save parameters from restricted models
   %
   if (tm.deterselect(1,1)==1)|(tm.deterselect(1,3)==1);
      [tm.stat_tests,tm.stat_df,pvals,stat_params] = coint_stationarity(tm.Z0,tm.Z1,tm.Z2,tm.epsilon,tm.r,tm.q1,tm.dcoint,tm.df,curr_ini.sscorrect);
   else;
      [tm.stat_tests,tm.stat_df,pvals,stat_params] = coint_stationarity_dcoint(tm.Z0,tm.Z1,tm.Z2,tm.myvars,tm.epsilon,tm.beta(:,1:tm.r),tm.r,tm.q1,tm.dcoint,tm.df,curr_ini.sscorrect,curr_ini.convcrit,curr_ini.betagrad,curr_ini.maxit,0);
   end;
   %
   % compute test for deterministic variable and save parameters from restricted model
   %
   [tm.deter_test,tm.deter_df,pval,deter_params] = rest_const_trend(tm.test_type,tm.epsilon,tm.r,tm.Z0,tm.Z1,tm.Z2,tm.df,curr_ini.sscorrect);
   %
   coint_test.exclude = zeros(rep,size(tm.exclude_tests,1));
   coint_test.stat = zeros(rep,tm.n);
   coint_test.deter = zeros(rep,1);
   %
   if curr_ini.symmetric==0;
      Omega_sig = chol(tm.Omega)';
   else;
      Omega_sig = symm(tm.Omega);
   end;
   abort = '';
   draw = 1;
   est_status = 0;
   showprog = get(boot_cointtest.progress,'Value');
   if showprog==1;
      input_var.title = ['Progress for ' int2str(rep) ' replications'];
      input_var.facecolor = curr_ini.progress_facecolor;
      input_var.startfacecolor = curr_ini.progress_startfacecolor;
      input_var.edgecolor = curr_ini.progress_edgecolor;
      input_var.bgcolor = curr_ini.progress_bgcolor;
      input_var.clock = get(boot_cointtest.clock,'Value');
      input_var.label = 'Replication number:';
      input_var.stop = 0;
      mywait = progressdlg(0,input_var);
      set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
   else;
      this_text = strvcat('Bootstrapping. The art of pulling oneself up by the bootstraps. Attempt started at...',' ',['Time: ' datestr(now,14)],' ','Please hold!');
      mywait = waitdlg(this_text,'bootstrap','Beta Bootstrap Simulation');
      waitf = get(mywait,'UserData');
      tic;
   end;
   if tm.const_model(2)==1;
      setlogtext(strvcat(' ','Bootstrapping distributions for cointegration','space tests...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Restricted constant',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(tm.r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
      if showprog==1;
         set(mywait,'Name',['Restricted constant model with ' num2str(my_T,'%0.0f') ' obs']);
         drawnow;
      end;
      mod_type = 'resconst';
   elseif tm.const_model(3)==1;
      setlogtext(strvcat(' ','Bootstrapping distributions for cointegration','space tests...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Unrestricted constant',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(tm.r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
      if showprog==1;
         set(mywait,'Name',['Constant model with ' num2str(my_T,'%0.0f') ' obs']);
         drawnow;
      end;
      mod_type = 'const';
   elseif tm.const_model(4)==1;
      setlogtext(strvcat(' ','Bootstrapping distributions for cointegration','space tests...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Restricted linear trend',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(tm.r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
      if showprog==1;
         set(mywait,'Name',['Restricted trend model with ' num2str(my_T,'%0.0f') ' obs']);
         drawnow;
      end;
      mod_type = 'restrend';
   elseif tm.const_model(5)==1;
      setlogtext(strvcat(' ','Bootstrapping distributions for cointegration','space tests...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Linear trend',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(tm.r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
      if showprog==1;
         set(mywait,'Name',['Linear trend model with ' num2str(my_T,'%0.0f') ' obs']);
         drawnow;
      end;
      mod_type = 'trend';
   end;
   if get(boot_cointtest.bootstrap,'Value')==1;
      %
      % epsilon-file
      %
      epsfile = [curr_ini.simulatedir tm.modelfile '-' 'cointtest-epsilon-' num2str(tm.scale_endo,'%0.4f') '-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '-' num2str(rep) '-' mod_type '.mat'];
      if fileexist(epsfile)==1;
         load_eps = 1;
         %
         % load old epsilons
         %
         eps_data = load(epsfile);
      else;
         load_eps = 0;
      end;
   else;
      load_eps = 0;
   end;
   old_alpha = tm.alpha;
   old_Omega = tm.Omega;
   old_Psi = tm.Psi;
   old_beta = tm.beta;
   %
   % replicating
   %
   while (draw<=rep);  % should be until rep
      if showprog==1;
         abort = get(mywait,'UserData');
         if strcmp(abort,'cancel')==1;
            break;
         else;
            progressdlg([(draw/rep) draw]);
         end;
      end;
      %
      % check for bootstrap style
      %
      if load_eps==0;
         if get(boot_cointtest.parametric,'Value')==1;
            %
            % reset the random number generator
            %
            if (curr_ini.random_state==2)&(est_status==0);
               randn('state',draw);
            elseif curr_ini.random_state==3;
               randn('state',sum(100*clock));
            else;
               randn('state',sum(100*clock)+draw);
            end;
            %
            Epr = randn(tm.n,my_T+50);
            Epr = Epr(:,51:my_T+50);
            %
            % make sure draws in Epr have identity covariance matrix
            %
            Sig = (1/my_T)*Epr*Epr';
            P_sig = chol(Sig)';
            Epr = P_sig\Epr;
            Epr = Omega_sig*Epr;
         else;
            %
            % reset the random number generator
            %
            if (curr_ini.random_state==2)&(est_status==0);
               rand('state',draw);
            elseif curr_ini.random_state==3;
               rand('state',sum(100*clock));
            else;
               rand('state',sum(100*clock)+draw);
            end;
            %
            % resample from estimated epsilons
            %
            uni_draws = rand([1 my_T+50]);
            uni_draws = uni_draws(1,51:my_T+50);
            Epr = boot_draw(uni_draws,tm.epsilon,blocksize);
         end;
         if get(boot_cointtest.bootstrap,'Value')==1;
            bootstrap(draw).epsilon = Epr;
         end;
      else;
         Epr = eps_data.bootstrap(draw).epsilon;
      end;
      %
      % exclusion tests
      %
      for i=1:size(coint_test.exclude,2);
         tm.alpha = exclude_params.variable(i).alpha;
         tm.beta = exclude_params.variable(i).beta;
         tm.Psi = exclude_params.variable(i).Psi;
         tm.Omega = exclude_params.variable(i).Omega;
         %
         % change the drawn residuals
         %
         if curr_ini.symmetric==0;
            new_Omega_sig = chol(tm.Omega)';
         else;
            new_Omega_sig = symm(tm.Omega);
         end;
         new_Epr = new_Omega_sig*inverse(Omega_sig)*Epr;
         %
         % create a new bootstrap sample for each exclusion test
         %
         boot = bootstrap_sample(tm,tm.beta,new_Epr);
         %
         % compute S_ij and M_ij matrices from boot structure
         %
         [S_00,S_01,S_10,S_11,M_02,M_22,M_12,beta,lambda,trace_tst] = mlcointbasic(boot.Z0,boot.Z1,boot.Z2,tm.r);
         %
         % estimate the residuals from this model
         %
         alpha = S_01*beta*inverse(beta'*S_11*beta);
         if isempty(boot.Z2)==0;
            Psi = M_02*inverse(M_22)-(alpha*beta'*M_12*inverse(M_22));
            epsilon = boot.Z0-(alpha*beta'*boot.Z1)-(Psi*boot.Z2);
         else;
            Psi = [];
            epsilon = boot.Z0-(alpha*beta'*boot.Z1);
         end;
         %
         % compute tests
         %
         [exclude_tests,exclude_df,pvals] = coint_exclusion(S_00,S_01,S_10,S_11,M_02,M_22,M_12,boot.Z0,boot.Z1,boot.Z2,epsilon,tm.r,tm.q1,tm.dcoint,tm.df,curr_ini.sscorrect);
         coint_test.exclude(draw,i) = exclude_tests(i,1);
      end;
      %
      % stationarity tests
      %
      for i=1:tm.n;
         tm.alpha = stat_params.variable(i).alpha;
         tm.beta = stat_params.variable(i).beta;
         tm.Psi = stat_params.variable(i).Psi;
         tm.Omega = stat_params.variable(i).Omega;
         %
         % change the drawn residuals
         %
         if curr_ini.symmetric==0;
            new_Omega_sig = chol(tm.Omega)';
         else;
            new_Omega_sig = symm(tm.Omega);
         end;
         new_Epr = new_Omega_sig*inverse(Omega_sig)*Epr;
         %
         % create a new bootstrap sample for each stationarity test
         %
         boot = bootstrap_sample(tm,tm.beta,new_Epr);
         %
         % compute S_ij and M_ij matrices from boot structure
         %
         [S_00,S_01,S_10,S_11,M_02,M_22,M_12,beta,lambda,trace_tst] = mlcointbasic(boot.Z0,boot.Z1,boot.Z2,tm.r);
         %
         % estimate the residuals from this model
         %
         alpha = S_01*beta*inverse(beta'*S_11*beta);
         if isempty(boot.Z2)==0;
            Psi = M_02*inverse(M_22)-(alpha*beta'*M_12*inverse(M_22));
            epsilon = boot.Z0-(alpha*beta'*boot.Z1)-(Psi*boot.Z2);
         else;
            Psi = [];
            epsilon = boot.Z0-(alpha*beta'*boot.Z1);
         end;
         %
         % compute tests
         %
         if (tm.deterselect(1,1)==1)|(tm.deterselect(1,3)==1);
            [stat_tests,stat_df,pvals] = coint_stationarity(boot.Z0,boot.Z1,boot.Z2,epsilon,tm.r,tm.q1,tm.dcoint,tm.df,curr_ini.sscorrect);
         else;
            [stat_tests,stat_df,pvals] = coint_stationarity_dcoint(boot.Z0,boot.Z1,boot.Z2,tm.myvars,epsilon,beta,tm.r,tm.q1,tm.dcoint,tm.df,curr_ini.sscorrect,curr_ini.convcrit,curr_ini.betagrad,curr_ini.maxit,0);
         end;
         coint_test.stat(draw,i) = stat_tests(i,1);
      end;
      %
      % and now for the deterministic variable restriction test
      %
      tm.alpha = deter_params.alpha;
      tm.beta = deter_params.beta;
      tm.Psi = deter_params.Psi;
      tm.Omega = deter_params.Omega;
      %
      % change the drawn residuals
      %
      if curr_ini.symmetric==0;
         new_Omega_sig = chol(tm.Omega)';
      else;
         new_Omega_sig = symm(tm.Omega);
      end;
      new_Epr = new_Omega_sig*inverse(Omega_sig)*Epr;
      %
      % create a new bootstrap sample for each stationarity test
      %
      boot = bootstrap_sample(tm,tm.beta,new_Epr);
      %
      % compute S_ij and M_ij matrices from boot structure
      %
      [S_00,S_01,S_10,S_11,M_02,M_22,M_12,beta,lambda,trace_tst] = mlcointbasic(boot.Z0,boot.Z1,boot.Z2,tm.r);
      %
      % estimate the residuals from this model
      %
      alpha = S_01*beta*inverse(beta'*S_11*beta);
      if isempty(boot.Z2)==0;
         Psi = M_02*inverse(M_22)-(alpha*beta'*M_12*inverse(M_22));
         epsilon = boot.Z0-(alpha*beta'*boot.Z1)-(Psi*boot.Z2);
      else;
         Psi = [];
         epsilon = boot.Z0-(alpha*beta'*boot.Z1);
      end;
      %
      % compute the test
      %
      [deter_test,deter_df,pval] = rest_const_trend(tm.test_type,epsilon,tm.r,boot.Z0,boot.Z1,boot.Z2,tm.df,curr_ini.sscorrect);
      coint_test.deter(draw,1) = deter_test;
      draw = draw+1;
   end;
   %
   % restore estimated parameters
   %
   tm.alpha = old_alpha;
   tm.Omega = old_Omega;
   tm.Psi = old_Psi;
   tm.beta = old_beta;
   %
   % bootstrap has finished
   %
   if showprog==1;
      set(mywait,'UserData','done');
      close(mywait);
      drawnow;
   else;
      set(waitf.text,'UserData','done');
      delete(mywait);
      drawnow;
      new_time = toc;
      my_hrs = '00';
      my_min = '00';
      my_sec = num2str(new_time,'%0.2f');
      if new_time>=60;
         ch_min = floor(new_time/60);
         my_sec = num2str(new_time-(ch_min*60),'%0.2f');
         my_min = num2str(ch_min,'%0.0f');
         if ch_min>=60;
            ch_hrs = floor(ch_min/60);
            my_min = num2str(ch_min-(ch_hrs*60),'%0.0f');
            my_hrs = num2str(ch_hrs,'%0.0f');
         end;
      end;
      if size(my_sec,2)==4;
         my_sec = ['0' my_sec];
      end;
      if size(my_min,2)==1;
         my_min = ['0' my_min];
      end;
      if size(my_hrs,2)==1;
         my_hrs = ['0' my_hrs];
      end;
      clock_str = [my_hrs ':' my_min ':' my_sec];
      this_text = strvcat('The bootstrapping process took:',' ',['    ' clock_str ' (hrs:min:sec)']);
      about(this_text,'bootstrap','Simulation Time',120,350);
   end;
   %
   % if we don't cancel
   %
   if strcmp(abort,'cancel')==0;
      this_text = strvcat(' ','Saving bootstrap results to disk...','Please hold!');
      mywait = waitdlg(this_text,'bootstrap','Cointegration Space Tests Bootstrap Simulation');
      waitf = get(mywait,'UserData');
      if get(boot_cointtest.bootstrap,'Value')==1;
         if load_eps==0;
            this_text = strvcat(' ','Saving bootstrapped residuals to disk...','Please hold!');
            set(waitf.text,'String',this_text);
            save(epsfile,'bootstrap');
         end;
         clear('bootstrap');
         testfile = strrep(epsfile,'.mat',['-' 'cointtest-data.mat']);
         test_data = coint_test;
         save(testfile,'test_data');
         clear('test_data');
         set(boot_cointtest.bootstrapgraph,'Enable','on','UserData',epsfile);
         set(boot_cointtest.bootstrapgraphmenu,'Enable','on','UserData',testfile);
      end;
      setlogtext(['Bootstrap simulation completed at: ' datestr(now,14) '!']);
      %
      % sort the tests
      %
      coint_test_sorted.exclude = zeros(size(coint_test.exclude));
      for i=1:size(coint_test.exclude,2);
         coint_test_sorted.exclude(:,i) = sort(coint_test.exclude(:,i));
      end;
      coint_test_sorted.exclude_df = exclude_df;
      coint_test_sorted.stat = zeros(rep,tm.n);
      for i=1:tm.n;
         coint_test_sorted.stat(:,i) = sort(coint_test.stat(:,i));
      end;
      coint_test_sorted.stat_df = stat_df;
      coint_test_sorted.deter = sort(coint_test.deter);
      coint_test_sorted.deter_df = deter_df;
      %
      clear('coint_test');
      set(boot_cointtest.rep,'UserData',rep);
      set(boot_cointtest.obs,'UserData',my_T);
      set(boot_cointtest.displaymenu,'Enable','on','UserData',tm.const_model);
      if tm.const_model(2)==1;
         my_mod = 'Restricted constant';
      elseif tm.const_model(3)==1;
         my_mod = 'Constant';
      elseif tm.const_model(4)==1;
         my_mod = 'Restricted linear trend';
      elseif tm.const_model(5)==1;
         my_mod = 'Linear trend';
      end;
      %
      % save full simulations
      %
      if get(boot_cointtest.save,'Value')==1;
         this_text = strvcat(' ','Saving bootstrapped Hansen-Johansen fluctuation tests to disk...','Please hold!');
         set(waitf.text,'String',this_text);
         setlogtext('Saving results to mat-files...');
         if tm.const_model(1)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-full-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
         elseif tm.const_model(2)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-full-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
         elseif tm.const_model(3)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-full-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
         elseif tm.const_model(4)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-full-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
         elseif tm.const_model(5)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-full-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
         end;
         Number = (1:1:rep)';
         save(full_mat,'Number','coint_test_sorted');
         set(boot_cointtest.fullmenu,'Enable','on','UserData',full_mat);
         set(boot_cointtest.full,'Enable','on');
      end;
      setlogtext('Saving simulation summary to text file...');
      %
      % dealing with the size of the test
      %
      boot_size = [];
      boot_pval = [];
      this_text = strvcat(' ','Determining the empirical size of the cointegration space exclusion tests...','Please hold!');
      set(waitf.text,'String',this_text);
      boot_size.exclude = zeros(size(coint_test_sorted.exclude,2),5);
      for j=1:size(coint_test_sorted.exclude,2);
         if curr_ini.sscorrect==1;
            my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],coint_test_sorted.exclude_df(j,1)*ones(5,1),coint_test_sorted.exclude_df(j,2)*ones(5,1));
         else;
            my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],coint_test_sorted.exclude_df(j,1)*ones(5,1));
         end;
         for i=1:5;
            for j1=1:rep;
               if my_cv(i,1)>=coint_test_sorted.exclude(rep+1-j1,j);
                  boot_size.exclude(j,i) = (rep+1-j1)/rep;
                  break;
               end;
            end;
         end;
      end;
      %
      this_text = strvcat(' ','Determining the empirical size of the cointegration space stationarity tests...','Please hold!');
      set(waitf.text,'String',this_text);
      boot_size.stat = zeros(tm.n,5);
      for j=1:tm.n;
         if curr_ini.sscorrect==1;
            my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],coint_test_sorted.stat_df(j,1)*ones(5,1),coint_test_sorted.stat_df(j,2)*ones(5,1));
         else;
            my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],coint_test_sorted.stat_df(j,1)*ones(5,1));
         end;
         for i=1:5;
            for j1=1:rep;
               if my_cv(i,1)>=coint_test_sorted.stat(rep+1-j1,j);
                  boot_size.stat(j,i) = (rep+1-j1)/rep;
                  break;
               end;
            end;
         end;
      end;
      %
      myvars = strtrim(tm.evars);
      if tm.q1>0;
         myvars = [myvars ' ' strtrim(tm.xvars1)];
      end;
      myvars = strtrim([myvars ' ' tm.restvec]);
      myvars = vecstr(myvars);
      if strcmp(tm.test_type,'uconst')==1;
         deter_txt = 'unrestricted vs. restricted constant model';
         deter_str = 'Testing Unrestricted vs. Restricted Constant Model';
         deter_underline = '--------------------------------------------------';
      elseif strcmp(tm.test_type,'rconst')==1;
         deter_txt = 'restricted vs. zero constant model';
         deter_str = 'Testing Restricted vs. Zero Constant Model';
         deter_underline = '------------------------------------------';
      elseif strcmp(tm.test_type,'utrend')==1;
         deter_txt = 'unrestricted vs. restricted linear trend model';
         deter_str = 'Testing Unrestricted vs. Restricted Linear Trend Model';
         deter_underline = '------------------------------------------------------';
      elseif strcmp(tm.test_type,'rtrend')==1;
         deter_txt = 'restricted vs. zero linear trend model';
         deter_str = 'Testing Restricted vs. Zero Linear Trend Model';
         deter_underline = '----------------------------------------------';
      end;
      this_text = strvcat(' ',['Determining the empirical size of the cointegration space test of ' deter_txt '...'],'Please hold!');
      set(waitf.text,'String',this_text);
      boot_size.deter = zeros(1,5);
      if curr_ini.sscorrect==1;
         my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],coint_test_sorted.deter_df(1,1)*ones(5,1),coint_test_sorted.deter_df(1,2)*ones(5,1));
      else;
         my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],coint_test_sorted.deter_df(1,1)*ones(5,1));
      end;
      for i=1:5;
         for j1=1:rep;
            if my_cv(i,1)>=coint_test_sorted.deter(rep+1-j1,1);
               boot_size.deter(1,i) = (rep+1-j1)/rep;
               break;
            end;
         end;
      end;
      %
      if my_T==tm.T;
         %
         % exclusion tests
         %
         boot_pval.exclude = zeros(1,size(coint_test_sorted.exclude,2));
         for i=1:size(coint_test_sorted.exclude,2);
            for j=1:rep;
               if tm.exclude_tests(i,1)>=coint_test_sorted.exclude(rep+1-j,i);
                  boot_pval.exclude(1,i) = (j-1)/rep;
                  break;
               end;
               if j==rep;
                  boot_pval.exclude(1,i) = 1;
               end;
            end;
         end;
         %
         % stationarity tests
         %
         boot_pval.stat = zeros(1,tm.n);
         for i=1:tm.n;
            for j=1:rep;
               if tm.stat_tests(i,1)>=coint_test_sorted.stat(rep+1-j,i);
                  boot_pval.stat(1,i) = (j-1)/rep;
                  break;
               end;
               if j==rep;
                  boot_pval.stat(1,i) = 1;
               end;
            end;
         end;
         %
         % deterministics test
         %
         boot_pval.deter = 0;
         for j=1:rep;
            if tm.deter_test>=coint_test_sorted.deter(rep+1-j,1);
               boot_pval.deter = (j-1)/rep;
               break;
            end;
            if j==rep;
               boot_pval.deter = 1;
            end;
         end;
      end;
      %
      this_text = strvcat(' ','Writing bootstrap summary information to disk...','Please hold!');
      set(waitf.text,'String',this_text);
      %
      % write summary to file
      %
      my_80 = floor(0.8*rep);
      my_90 = floor(0.9*rep);
      my_95 = floor(0.95*rep);
      my_975 = floor(0.98*rep);
      my_99 = floor(0.99*rep);
      sp_str = spacestr(curr_ini.decimals-2);
      if size(myvars,2)<10;
         add_str = spacestr(10-size(myvars,2));
      else;
         add_str = '';
      end;
      prt_val = ['%' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
      res_str = strvcat(' ','**************************************************************','*                          Results                           *');
      res_str = strvcat(res_str,'**************************************************************',' ',['  Model:                   ' my_mod],['  Endogenous variables:    ' num2str(tm.n,'%0.0f')],['  Cointegration relations: ' num2str(tm.r,'%0.0f')],['  Replications:            ' num2str(rep,'%0.0f')],['  Draws per replication:   ' num2str(my_T,'%0.0f')],' ');
      if blocksize>1;
         res_str = strvcat(res_str,strrep(block_txt,'.',''),' ');
      end;
      res_str = strvcat(res_str,'            Cointegration Space Exclusion Tests','            -----------------------------------',' ',['Variable        80%   ' sp_str '   90%   ' sp_str '   95%   ' sp_str '   98%   ' sp_str '   99%  ' sp_str '    Mean ' sp_str ' Std. Dev.']);
      for i=1:size(coint_test_sorted.exclude,2);
         s_std = sqrt( (1/rep)*sum( ( coint_test_sorted.exclude(:,i) - ( (1/rep)*sum(coint_test_sorted.exclude(:,i)) ) ).*( coint_test_sorted.exclude(:,i) - ( (1/rep)*sum(coint_test_sorted.exclude(:,i)) ) ) ) );
         res_str = strvcat(res_str,sprintf([' %s ' add_str prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val],myvars(i,:),coint_test_sorted.exclude(my_80,i),coint_test_sorted.exclude(my_90,i),coint_test_sorted.exclude(my_95,i),coint_test_sorted.exclude(my_975,i),coint_test_sorted.exclude(my_99,i),(1/rep)*sum(coint_test_sorted.exclude(:,i)),s_std));
      end;
      if curr_ini.sscorrect==1;
         my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],coint_test_sorted.exclude_df(1,1)*ones(5,1),coint_test_sorted.exclude_df(1,2)*ones(5,1));
         res_str = strvcat(res_str,['From the F(' num2str(coint_test_sorted.exclude_df(1,1),'%0.0f') ',' num2str(coint_test_sorted.exclude_df(1,2),'%0.0f') ') distribution we have the following:'],sprintf(['            ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1)),' ');
      else;
         my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],coint_test_sorted.exclude_df(1,1)*ones(5,1));
         res_str = strvcat(res_str,['From the Chi-square(' num2str(coint_test_sorted.exclude_df(1,1),'%0.0f') ') distribution we have the following:'],sprintf(['            ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),coint_test_sorted.exclude_df(1,1),sqrt(2*coint_test_sorted.exclude_df(1,1))),' ');
      end;
      res_str = strvcat(res_str,'                      Empirical size','                      --------------',' ','Test level     20%    10%     5%     2%     1%');
      for i=1:size(coint_test_sorted.exclude,2);
         res_str = strvcat(res_str,sprintf([' %s ' add_str ' %6.2f %6.2f %6.2f %6.2f %6.2f'],myvars(i,:),100*(1-boot_size.exclude(i,5)),100*(1-boot_size.exclude(i,4)),100*(1-boot_size.exclude(i,3)),100*(1-boot_size.exclude(i,2)),100*(1-boot_size.exclude(i,1))));
      end;
      res_str = strvcat(res_str,' ');
      %
      if tm.T==my_T;
         res_str = strvcat(res_str,'                    Empirical p-values','                    ------------------',' ');
         if curr_ini.sscorrect==1;
            for i=1:size(coint_test_sorted.exclude,2);
               res_str = strvcat(res_str,sprintf([' %s ' add_str 'F(%0.0f,%0.0f) = ' prt_val ',  p-value = %' num2str(2+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'],myvars(i,:),coint_test_sorted.exclude_df(1,1),coint_test_sorted.exclude_df(1,2),tm.exclude_tests(i,1),boot_pval.exclude(1,i)));
            end;
         else;
            for i=1:size(coint_test_sorted.exclude,2);
               res_str = strvcat(res_str,sprintf([' %s ' add_str 'LR(%0.0f) = ' prt_val ',  p-value = %' num2str(2+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'],myvars(i,:),coint_test_sorted.exclude_df(1,1),tm.exclude_tests(i,1),boot_pval.exclude(1,i)));
            end;
         end;
         res_str = strvcat(res_str,' ');
      end;
      %
      res_str = strvcat(res_str,'            Cointegration Space Stationarity Tests','            --------------------------------------',' ',['Variable        80%   ' sp_str '   90%   ' sp_str '   95%   ' sp_str '   98%   ' sp_str '   99%  ' sp_str '    Mean ' sp_str ' Std. Dev.']);
      for i=1:tm.n;
         s_std = sqrt( (1/rep)*sum( ( coint_test_sorted.stat(:,i) - ( (1/rep)*sum(coint_test_sorted.stat(:,i)) ) ).*( coint_test_sorted.stat(:,i) - ( (1/rep)*sum(coint_test_sorted.stat(:,i)) ) ) ) );
         res_str = strvcat(res_str,sprintf([' %s ' add_str prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val],myvars(i,:),coint_test_sorted.stat(my_80,i),coint_test_sorted.stat(my_90,i),coint_test_sorted.stat(my_95,i),coint_test_sorted.stat(my_975,i),coint_test_sorted.stat(my_99,i),(1/rep)*sum(coint_test_sorted.stat(:,i)),s_std));
      end;
      if curr_ini.sscorrect==1;
         my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],coint_test_sorted.stat_df(1,1)*ones(5,1),coint_test_sorted.stat_df(1,2)*ones(5,1));
         res_str = strvcat(res_str,['From the F(' num2str(coint_test_sorted.stat_df(1,1),'%0.0f') ',' num2str(coint_test_sorted.stat_df(1,2),'%0.0f') ') distribution we have the following:'],sprintf(['            ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1)),' ');
      else;
         my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],coint_test_sorted.stat_df(1,1)*ones(5,1));
         res_str = strvcat(res_str,['From the Chi-square(' num2str(coint_test_sorted.stat_df(1,1),'%0.0f') ') distribution we have the following:'],sprintf(['            ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),coint_test_sorted.stat_df(1,1),sqrt(2*coint_test_sorted.stat_df(1,1))),' ');
      end;
      res_str = strvcat(res_str,'                      Empirical size','                      --------------',' ','Test level     20%    10%     5%     2%     1%');
      for i=1:tm.n;
         res_str = strvcat(res_str,sprintf([' %s ' add_str ' %6.2f %6.2f %6.2f %6.2f %6.2f'],myvars(i,:),100*(1-boot_size.stat(i,5)),100*(1-boot_size.stat(i,4)),100*(1-boot_size.stat(i,3)),100*(1-boot_size.stat(i,2)),100*(1-boot_size.stat(i,1))));
      end;
      res_str = strvcat(res_str,' ');
      %
      if tm.T==my_T;
         res_str = strvcat(res_str,'                    Empirical p-values','                    ------------------',' ');
         if curr_ini.sscorrect==1;
            for i=1:tm.n;
               res_str = strvcat(res_str,sprintf([' %s ' add_str 'F(%0.0f,%0.0f) = ' prt_val ',  p-value = %' num2str(2+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'],myvars(i,:),coint_test_sorted.stat_df(1,1),coint_test_sorted.stat_df(1,2),tm.stat_tests(i,1),boot_pval.stat(1,i)));
            end;
         else;
            for i=1:tm.n;
               res_str = strvcat(res_str,sprintf([' %s ' add_str 'LR(%0.0f) = ' prt_val ',  p-value = %' num2str(2+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'],myvars(i,:),coint_test_sorted.stat_df(1,1),tm.stat_tests(i,1),boot_pval.stat(1,i)));
            end;
         end;
         res_str = strvcat(res_str,' ');
      end;
      %
      res_str = strvcat(res_str,['            ' deter_str],['            ' deter_underline],' ',['      80%   ' sp_str '   90%   ' sp_str '   95%   ' sp_str '   98%   ' sp_str '   99%   ' sp_str '   Mean ' sp_str ' Std. Dev.']);
      s_std = sqrt( (1/rep)*sum( ( coint_test_sorted.deter - ( (1/rep)*sum(coint_test_sorted.deter) ) ).*( coint_test_sorted.deter - ( (1/rep)*sum(coint_test_sorted.deter) ) ) ) );
      res_str = strvcat(res_str,sprintf(['  ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val],coint_test_sorted.deter(my_80,1),coint_test_sorted.deter(my_90,1),coint_test_sorted.deter(my_95,1),coint_test_sorted.deter(my_975,1),coint_test_sorted.deter(my_99,1),(1/rep)*sum(coint_test_sorted.deter),s_std));
      if curr_ini.sscorrect==1;
         my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],coint_test_sorted.deter_df(1,1)*ones(5,1),coint_test_sorted.deter_df(1,2)*ones(5,1));
         res_str = strvcat(res_str,['From the F(' num2str(coint_test_sorted.deter_df(1,1),'%0.0f') ',' num2str(coint_test_sorted.deter_df(1,2),'%0.0f') ') distribution we have the following:'],sprintf(['  ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1)),' ');
      else;
         my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],coint_test_sorted.deter_df(1,1)*ones(5,1));
         res_str = strvcat(res_str,['From the Chi-square(' num2str(coint_test_sorted.deter_df(1,1),'%0.0f') ') distribution we have the following:'],sprintf(['  ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),coint_test_sorted.deter_df(1,1),sqrt(2*coint_test_sorted.deter_df(1,1))),' ');
      end;
      res_str = strvcat(res_str,'                      Empirical size','                      --------------',' ','Test level     20%    10%     5%     2%     1%');
      res_str = strvcat(res_str,sprintf('             %6.2f %6.2f %6.2f %6.2f %6.2f',100*(1-boot_size.deter(1,5)),100*(1-boot_size.deter(1,4)),100*(1-boot_size.deter(1,3)),100*(1-boot_size.deter(1,2)),100*(1-boot_size.deter(1,1))),' ');
      if tm.T==my_T;
         res_str = strvcat(res_str,'                    Empirical p-value','                    -----------------',' ');
         if curr_ini.sscorrect==1;
            res_str = strvcat(res_str,sprintf(['    F(%0.0f,%0.0f) = ' prt_val ',  p-value = %' num2str(2+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'],coint_test_sorted.deter_df(1,1),coint_test_sorted.deter_df(1,2),tm.deter_test,boot_pval.deter),' ');
         else;
            res_str = strvcat(res_str,sprintf(['    LR(%0.0f) = ' prt_val ',  p-value = %' num2str(2+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'],coint_test_sorted.deter_df,tm.deter_test,boot_pval.deter),' ');
         end;
      end;
      res_str = strvcat(res_str,' ');
      %
      res_str = strvcat(res_str,'**************************************************************',' ');
      %
      if tm.const_model(1)==1;
         file_txt = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-summary-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.txt'];
      elseif tm.const_model(2)==1;
         file_txt = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-summary-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
      elseif tm.const_model(3)==1;
         file_txt = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-summary-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
      elseif tm.const_model(4)==1;
         file_txt = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-summary-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
      elseif tm.const_model(5)==1;
         file_txt = [curr_ini.simulatedir  tm.modelfile '-cointtest-boot-summary-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
      end;
      fid_txt = fopen(file_txt,'wt');
      for i=1:size(res_str,1);
         fprintf(fid_txt,[strrep(res_str(i,:),'%','%%') '\n']);
      end;
      fprintf(fid_txt,['Output created on: ' datestr(now,0) '\n']);
      fclose(fid_txt);
      %
      % write to tex file
      %
      prt_val = ['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'];
      file_tex = strrep(file_txt,'.txt','.ltx');
      f_id = fopen(file_tex,'wt');
      fprintf(f_id,'\\begin{tabular}{ll}\n');
      fprintf(f_id,['Model: & ' my_mod ' \\\\\n']);
      fprintf(f_id,['\\#Endogenous variables: & ' num2str(tm.n,'%0.0f') ' \\\\\n']);
      fprintf(f_id,['\\#Cointegration relations: & ' num2str(tm.r,'%0.0f') ' \\\\\n']);
      fprintf(f_id,['\\#Replications: & ' num2str(rep,'%0.0f') ' \\\\\n']);
      fprintf(f_id,['\\#Draws per replication: & ' num2str(my_T,'%0.0f') ' \\\\\n']);
      if blocksize>1;
         fprintf(f_id,['Block size length: & ' num2str(blocksize,'%0.0f') ' \\\\\n']);
      end;
      fprintf(f_id,'\\end{tabular}\n\n');
      %
      % exclusion tests
      %
      fprintf(f_id,'\\begin{tabular}{rrrrrrrr}\n');
      fprintf(f_id,'\\multicolumn{8}{c}{Cointegration Space Exclusion Tests} \\\\\n');
      fprintf(f_id,'variable & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% & Mean & Std. Dev. \\\\\n');
      for i=1:size(coint_test_sorted.exclude,2);
         s_std = sqrt( (1/rep)*sum( ( coint_test_sorted.exclude(:,i) - ( (1/rep)*sum(coint_test_sorted.exclude(:,i)) ) ).*( coint_test_sorted.exclude(:,i) - ( (1/rep)*sum(coint_test_sorted.exclude(:,i)) ) ) ) );
         fprintf(f_id,['%s & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' \\\\ \n'],txt2ltxmath(strtrim(myvars(i,:))),coint_test_sorted.exclude(my_80,i),coint_test_sorted.exclude(my_90,i),coint_test_sorted.exclude(my_95,i),coint_test_sorted.exclude(my_975,i),coint_test_sorted.exclude(my_99,i),(1/rep)*sum(coint_test_sorted.exclude(:,i)),s_std);
      end;
      fprintf(f_id,'\\multicolumn{8}{c}{ } \\\\\n');
      if curr_ini.sscorrect==1;
         addres_str = ' & ';
         my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],coint_test_sorted.exclude_df(1,1)*ones(5,1),coint_test_sorted.exclude_df(1,2)*ones(5,1));
         fprintf(f_id,'\\multicolumn{8}{c}{From the asymptotic F(%0.0f,%0.0f) distribution we have the following quantile values:} \\\\\n',coint_test_sorted.exclude_df(1,1),coint_test_sorted.exclude_df(1,2));
      else;
         addres_str = sprintf([prt_val ' & ' prt_val],coint_test_sorted.exclude_df(1,1),sqrt(2*coint_test_sorted.exclude_df(1,1)));
%         addres_str = [num2str(coint_test_sorted.exclude_df(1,1),'%0.0f') ' & ' num2str(sqrt(2*coint_test_sorted.exclude_df(1,1)),'%0.0f')];
         my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],coint_test_sorted.exclude_df(1,1)*ones(5,1));
         fprintf(f_id,'\\multicolumn{8}{c}{From the asymptotic $\\chi^2 (%0.0f)$ distribution we have the following quantile values:} \\\\\n',coint_test_sorted.exclude_df(1,1));
      end;
      fprintf(f_id,[' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & %s \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),addres_str);
      fprintf(f_id,'\\end{tabular}\n\n');
      fprintf(f_id,'\\vspace*{2mm}\n\n\\begin{tabular}{rrrrrr}\n');
      fprintf(f_id,'\\multicolumn{6}{c}{Empirical size} \\\\\n');
      fprintf(f_id,'Variable & 20\\%% & 10\\%% & 5\\%% & 2\\%% & 1\\%% \\\\\n');
      for i=1:size(coint_test_sorted.exclude,2);
         fprintf(f_id,'%s & %0.2f & %0.2f & %0.2f & %0.2f & %0.2f \\\\\n',txt2ltxmath(strtrim(myvars(i,:))),100*(1-boot_size.exclude(i,5)),100*(1-boot_size.exclude(i,4)),100*(1-boot_size.exclude(i,3)),100*(1-boot_size.exclude(i,2)),100*(1-boot_size.exclude(i,1)));
      end;
      fprintf(f_id,'\\end{tabular}\n\n');
      if tm.T==my_T;
         fprintf(f_id,'\\vspace*{2mm}\n\n\\begin{tabular}{lll}\n');
         fprintf(f_id,'\\multicolumn{3}{c}{Empirical $p$-values} \\\\\n');
         if curr_ini.sscorrect==1;
            fprintf(f_id,'Variable & F & $p$-value \\\\\n');
         else;
            fprintf(f_id,'Variable & LR & $p$-value \\\\\n');
         end;
         for i=1:size(coint_test_sorted.exclude,2);
            fprintf(f_id,['%s & ' prt_val ' & ' prt_val ' \\\\ \n'],txt2ltxmath(strtrim(myvars(i,:))),tm.exclude_tests(i,1),boot_pval.exclude(1,i));
         end;
         fprintf(f_id,'\\end{tabular}\n\n');
      end;
      %
      % stationarity tests
      %
      fprintf(f_id,'\\halfruler\n\n\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrrr}\n');
      fprintf(f_id,'\\multicolumn{8}{c}{Cointegration Space Stationarity Tests} \\\\\n');
      fprintf(f_id,'variable & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% & Mean & Std. Dev. \\\\\n');
      for i=1:tm.n;
         s_std = sqrt( (1/rep)*sum( ( coint_test_sorted.stat(:,i) - ( (1/rep)*sum(coint_test_sorted.stat(:,i)) ) ).*( coint_test_sorted.stat(:,i) - ( (1/rep)*sum(coint_test_sorted.stat(:,i)) ) ) ) );
         fprintf(f_id,['%s & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' \\\\ \n'],txt2ltxmath(strtrim(tm.myvars(i,:))),coint_test_sorted.stat(my_80,i),coint_test_sorted.stat(my_90,i),coint_test_sorted.stat(my_95,i),coint_test_sorted.stat(my_975,i),coint_test_sorted.stat(my_99,i),(1/rep)*sum(coint_test_sorted.stat(:,i)),s_std);
      end;
      fprintf(f_id,'\\multicolumn{8}{c}{ } \\\\\n');
      if curr_ini.sscorrect==1;
         addres_str = ' & ';
         my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],coint_test_sorted.stat_df(1,1)*ones(5,1),coint_test_sorted.stat_df(1,2)*ones(5,1));
         fprintf(f_id,'\\multicolumn{8}{c}{From the asymptotic F(%0.0f,%0.0f) distribution we have the following quantile values:} \\\\\n',coint_test_sorted.stat_df(1,1),coint_test_sorted.stat_df(1,2));
      else;
         addres_str = sprintf([prt_val ' & ' prt_val],coint_test_sorted.stat_df(1,1),sqrt(2*coint_test_sorted.stat_df(1,1)));
         my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],coint_test_sorted.stat_df(1,1)*ones(5,1));
         fprintf(f_id,'\\multicolumn{8}{c}{From the asymptotic $\\chi^2 (%0.0f)$ distribution we have the following quantile values:} \\\\\n',coint_test_sorted.stat_df(1,1));
      end;
      fprintf(f_id,[' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & %s \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),addres_str);
      fprintf(f_id,'\\end{tabular}\n\n');
      fprintf(f_id,'\\vspace*{2mm}\n\n\\begin{tabular}{rrrrrr}\n');
      fprintf(f_id,'\\multicolumn{6}{c}{Empirical size} \\\\\n');
      fprintf(f_id,'Variable & 20\\%% & 10\\%% & 5\\%% & 2\\%% & 1\\%% \\\\\n');
      for i=1:tm.n;
         fprintf(f_id,'%s & %0.2f & %0.2f & %0.2f & %0.2f & %0.2f \\\\\n',txt2ltxmath(strtrim(tm.myvars(i,:))),100*(1-boot_size.stat(i,5)),100*(1-boot_size.stat(i,4)),100*(1-boot_size.stat(i,3)),100*(1-boot_size.stat(i,2)),100*(1-boot_size.stat(i,1)));
      end;
      fprintf(f_id,'\\end{tabular}\n\n');
      if tm.T==my_T;
         fprintf(f_id,'\\vspace*{2mm}\n\n\\begin{tabular}{lll}\n');
         fprintf(f_id,'\\multicolumn{3}{c}{Empirical $p$-values} \\\\\n');
         if curr_ini.sscorrect==1;
            fprintf(f_id,'Variable & F & $p$-value \\\\\n');
         else;
            fprintf(f_id,'Variable & LR & $p$-value \\\\\n');
         end;
         for i=1:tm.n;
            fprintf(f_id,['%s & ' prt_val ' & ' prt_val ' \\\\ \n'],txt2ltxmath(strtrim(tm.myvars(i,:))),tm.stat_tests(i,1),boot_pval.stat(1,i));
         end;
         fprintf(f_id,'\\end{tabular}\n\n');
      end;
      %
      % test on deterministics
      %
      fprintf(f_id,'\\halfruler\n\n\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrr}\n');
      fprintf(f_id,'\\multicolumn{7}{c}{%s} \\\\\n',deter_str);
      fprintf(f_id,'80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% & Mean & Std. Dev. \\\\\n');
      s_std = sqrt( (1/rep)*sum( ( coint_test_sorted.deter - ( (1/rep)*sum(coint_test_sorted.deter) ) ).*( coint_test_sorted.deter - ( (1/rep)*sum(coint_test_sorted.deter) ) ) ) );
      fprintf(f_id,[prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' \\\\ \n'],coint_test_sorted.deter(my_80,1),coint_test_sorted.deter(my_90,1),coint_test_sorted.deter(my_95,1),coint_test_sorted.deter(my_975,1),coint_test_sorted.deter(my_99,1),(1/rep)*sum(coint_test_sorted.deter),s_std);
      fprintf(f_id,'\\multicolumn{7}{c}{ } \\\\\n');
      if curr_ini.sscorrect==1;
         addres_str = ' & ';
         my_cv = fdist_inv([0.99;0.98;0.95;0.9;0.8],coint_test_sorted.deter_df(1,1)*ones(5,1),coint_test_sorted.deter_df(1,2)*ones(5,1));
         fprintf(f_id,'\\multicolumn{7}{c}{From the asymptotic F(%0.0f,%0.0f) distribution we have the following quantile values:} \\\\\n',coint_test_sorted.deter_df(1,1),coint_test_sorted.deter_df(1,2));
      else;
         addres_str = sprintf([prt_val ' & ' prt_val],coint_test_sorted.deter_df(1,1),sqrt(2*coint_test_sorted.deter_df(1,1)));
         my_cv = chisq_inv([0.99;0.98;0.95;0.9;0.8],coint_test_sorted.deter_df(1,1)*ones(5,1));
         fprintf(f_id,'\\multicolumn{7}{c}{From the asymptotic $\\chi^2 (%0.0f)$ distribution we have the following quantile values:} \\\\\n',coint_test_sorted.deter_df(1,1));
      end;
      fprintf(f_id,[prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & %s \\\\ \n'],my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),addres_str);
      fprintf(f_id,'\\end{tabular}\n\n');
      fprintf(f_id,'\\vspace*{2mm}\n\n\\begin{tabular}{rrrrr}\n');
      fprintf(f_id,'\\multicolumn{5}{c}{Empirical size} \\\\\n');
      fprintf(f_id,'20\\%% & 10\\%% & 5\\%% & 2\\%% & 1\\%% \\\\\n');
      fprintf(f_id,'%0.2f & %0.2f & %0.2f & %0.2f & %0.2f \\\\\n',100*(1-boot_size.deter(1,5)),100*(1-boot_size.deter(1,4)),100*(1-boot_size.deter(1,3)),100*(1-boot_size.deter(1,2)),100*(1-boot_size.deter(1,1)));
      fprintf(f_id,'\\end{tabular}\n\n');
      if tm.T==my_T;
         fprintf(f_id,'\\vspace*{2mm}\n\n\\begin{tabular}{lll}\n');
         fprintf(f_id,'\\multicolumn{2}{c}{Empirical $p$-value} \\\\\n');
         if curr_ini.sscorrect==1;
            fprintf(f_id,'F & $p$-value \\\\\n');
         else;
            fprintf(f_id,'LR & $p$-value \\\\\n');
         end;
         fprintf(f_id,[prt_val ' & ' prt_val ' \\\\ \n'],tm.deter_test,boot_pval.deter);
         fprintf(f_id,'\\end{tabular}\n\n');
      end;
      fprintf(f_id,'\\ruler\n\n%%*************************************************************\n');
      fclose(f_id);
      %
      %
      set(boot_cointtest.display,'UserData',coint_test_sorted);
      clear('coint_test_sorted');
      %
      if curr_ini.noprint==0;
         set(boot_cointtest.output,'Enable','on');
      end;
      set(boot_cointtest.summarymenu,'Enable','on','UserData',file_txt);
      set(boot_cointtest.summary,'Enable','on');
      set(boot_cointtest.display,'Enable','on');
      set(boot_cointtest.displaymenu,'Enable','on');
      set(boot_cointtest.histogram,'Enable','on');
      set(boot_cointtest.histogrammenu,'Enable','on');
      set(boot_cointtest.matfilebutton,'Enable','on');
      set(boot_cointtest.matfilemenu,'Enable','on');
      set(waitf.text,'UserData','done');
      delete(mywait);
      drawnow;
   else;
      setlogtext('Cancelled...');
   end;
   tm.eigen_run = 0;
   set(cointtest_boot_gui,'Visible','on');
case 'done'
   if tm.eigen_run==0;
      set(boot_cointtest.done,'UserData','done');
      pid = get(boot_cointtest.filemenu,'UserData');
      if isempty(pid)==1;
         delete(cointtest_boot_gui);
      else;
         close(cointtest_boot_gui);
      end;
   end;
end;

if strcmp(selector,'init')==1;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(cointtest_boot_gui,'Name') ' ' fix_filepath([pwd '\icons\bootstrap.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(boot_cointtest.filemenu,'UserData',pid);
         set(cointtest_boot_gui,'CloseRequestFcn','killwinpid');
      end;
   end;
   set(cointtest_boot_gui,'Visible','on');
end;

if strcmp(selector,'done')==0;
   curr_ini.models = tm;
   curr_ini.images = button_images;
   set(boot_cointtest.matfilebutton,'UserData',curr_ini);
end;

if my_exit==1;
   waitfor(boot_cointtest.done,'UserData','done');
end;

%
% end of cointtest_bootstrap.m
%
