%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for displaying distribution         %
%          properties                                            %
%                                                                %
%          Function: distdlg                                     %
%                                                                %
%          Input:                                                %
%                       selector: case switch function           %
%                                                                %
%          Output:                                               %
%                       h: handle                                %
%                                                                %
%          This version:        July 4, 2006                     %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function h = distdlg(selector,cbs)

if strcmp(selector,'init')==1;
   curr_ini = find_inisettings;
   thisexit = 0;
   quantile_str = '50 percent';
   for i=51:99;
      quantile_str = [quantile_str '|' num2str(i,'%0.0f') ' percent'];
   end;
else;
   thisexit = 1;
   distgui = get(0,'CurrentFigure');
   control = get(distgui,'UserData');
   curr_ini = get(control.quantiles,'UserData');
end;

%
% Set screen size directly instead of using
% get(0,'ScreenSize')!
%

realscrsz = get(0,'ScreenSize');

switch selector;
   case 'init';
      distgui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','distdlg.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(realscrsz(3)-600)/2 (realscrsz(4)-290)/2 600 290], ...
         'Tag','FigParent', ...
         'Resize','off', ...
         'Visible','off', ...
         'Name','Distribution', ...
         'NumberTitle','off', ...
         'CloseRequestFcn','distdlg done', ...
         'ToolBar','none');

      if matlabnumber>=7.0;
         set(distgui,'DockControl','off');
      end;

      %
      % Axes box for distribution specifics
      %

      axesbox([2 54 400 226],'Distribution Specifics',200,[0.5 1]);

      %
      % Enter test value
      %

      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[24 230 176 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'String','Value of Random Variable:', ...
         'HorizontalAlignment','left', ...
         'Tag','TestValueText');

      control.testvalue = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[200 235 180 20], ...
         'Style','edit', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Callback','distdlg check_test', ...
         'String','1.00', ...
         'UserData','1.00', ...
         'Tag','TestValueEdit');

      %
      % select chi-square distribution
      %

      control.chisqdist = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[24 180 176 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','radio', ...
         'Callback','distdlg check_dist', ...
         'Value',1, ...
         'String','Chi-square Distribution', ...
         'HorizontalAlignment','left', ...
         'Tag','ChiSqDistRadio');


      %
      % select F distribution
      %

      control.fdist = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[24 150 176 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','radio', ...
         'Callback','distdlg check_dist', ...
         'Value',0, ...
         'String','F Distribution', ...
         'HorizontalAlignment','left', ...
         'Tag','FDistRadio');

      %
      % Degrees of freedom controls
      %

      control.icon = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[200 175 180 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'String','Degrees of Freedon', ...
         'HorizontalAlignment','center', ...
         'Tag','DFText');

      control.df_1 = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[200 150 85 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','edit', ...
         'Callback','distdlg check_df', ...
         'String','1', ...
         'UserData','1', ...
         'HorizontalAlignment','left', ...
         'Tag','DF1Edit');

      control.df_2 = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[295 150 85 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','edit', ...
         'Enable','off', ...
         'Callback','distdlg check_df', ...
         'String','1', ...
         'UserData','1', ...
         'HorizontalAlignment','left', ...
         'Tag','DF2Edit');

      %
      % Select p-value
      %

      control.pvalue = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[24 100 176 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','radio', ...
         'Callback','distdlg check_pq', ...
         'Value',1, ...
         'String','p-value', ...
         'HorizontalAlignment','left', ...
         'Tag','PvalueRadio');

      %
      % Select quantile
      %

      control.quantile = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[24 70 176 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','radio', ...
         'Callback','distdlg check_pq', ...
         'Value',0, ...
         'String','Quantile:', ...
         'HorizontalAlignment','left', ...
         'Tag','QuantileRadio');

      control.quantiles = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[200 75 180 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'String',quantile_str, ...
         'Enable','off', ...
         'Tag','QuantilePopup',...
         'Value',cbs-49);

      %
      %
      %
      
      axesbox([420 54 178 226],'Result',60,[0.5 1]);
      
      %
      % create a text control
      %

      control.textaxes = axes('Units','pixels', ...
         'Box','on', ...
         'TickLength',[0 0], ...
         'CameraUpVector',[0 1 0], ...
         'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[430 64 158 206], ...
         'XTickLabelMode','manual', ...
         'YTickLabelMode','manual', ...
         'Tag','AxisText', ...
         'XColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'YColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'ZColor',get(0,'defaultuicontrolbackgroundcolor'));

      control.result = text('Parent',control.textaxes, ...
         'Position',[0.5 0.5], ...
         'String','No computation made', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'HorizontalAlignment','center', ...
         'Color',curr_ini.gui_foreground_color);

      %
      % Create compute button
      %

      control.compute = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[390 20 90 20], ...
         'String','Compute', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','distdlg compute', ...
         'Enable','on', ...
         'Tag','Compute');

      %
      %  Done button
      %

      control.done = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[490 20 90 20], ...
         'String','Done', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','distdlg done', ...
         'Enable','on', ...
         'UserData','waiting', ...
         'Tag','Done');

      set(distgui,'UserData',control,...
         'HandleVisibility','callback');

   case 'check_pq'
      %
      % check if p-values of quantiles have been selected
      %
      if gcbo==control.pvalue;
         set(control.pvalue,'Value',1);
         set(control.quantile,'Value',0);
         q_str = 'off';
      else;
         set(control.pvalue,'Value',0);
         set(control.quantile,'Value',1);
         q_str = 'on';
      end;
      set(control.quantiles,'Enable',q_str);
   case 'check_dist'
      if gcbo==control.chisqdist;
         set(control.chisqdist,'Value',1);
         set(control.fdist,'Value',0);
         df_str = 'off';
         bg_color = get(0,'defaultuicontrolbackgroundcolor');
      else;
         set(control.chisqdist,'Value',0);
         set(control.fdist,'Value',1);
         df_str = 'on';
         bg_color = [1 1 1];
      end;
      set(control.df_2,'Enable',df_str,'BackgroundColor',bg_color);
   case 'check_df'
      %
      % check if degrees of freedom is an integer
      %
      new_str = strtrim(get(gcbo,'String'));
      if strcmp(new_str,'')==1;
         set(gcbo,'String',get(gcbo,'UserData'));
      else;
         %
         % the string is not empty. now we test if the string can be
         % converted to a number
         %
         new_val = mystr2num(new_str);
         if (isempty(new_val)==0)&(isint(new_val)==1)&(new_val>=1);
            set(gcbo,'UserData',new_str);
         else;
            set(gcbo,'String',get(gcbo,'UserData'));
         end;
      end;
   case 'check_test'
      new_str = strtrim(get(control.testvalue,'String'));
      if strcmp(new_str,'')==1;
         set(control.testvalue,'String',get(control.testvalue,'UserData'));
      else;
         new_val = mystr2num(new_str);
         if (isempty(new_val)==0)&(new_val>=0);
            set(control.testvalue,'UserData',new_str);
         else;
            set(control.testvalue,'String',get(control.testvalue,'UserData'));
         end;
      end;
   case 'compute'
      %
      % check if we should calculate a p-value of a quantile value
      %
      df_1 = mystr2num(strtrim(get(control.df_1,'String')));
      df_2 = mystr2num(strtrim(get(control.df_2,'String')));
      if get(control.pvalue,'Value')==1;
         %
         % p-value
         %
         test_val = mystr2num(strtrim(get(control.testvalue,'String')));
         if get(control.chisqdist,'Value')==1;
            %
            % Chi-square distribution
            %
            pval = 1-chis_cdf(test_val,df_1);
            show_txt = {['Distribution: \chi^{2} (' num2str(df_1,'%0.0f') ')'] ['Random variable value = ' strtrim(get(control.testvalue,'String'))] ['p-value = ' num2str(pval,['%0.' num2str(curr_ini.decimals) 'f'])]};
         else;
            %
            % F distribution
            %
            pval = 1-fdis_cdf(test_val,df_1,df_2);
            show_txt = {['Distribution: F (' num2str(df_1,'%0.0f') ',' num2str(df_2,'%0.0f') ')'] ['Random variable value = ' strtrim(get(control.testvalue,'String'))] ['p-value = ' num2str(pval,['%0.' num2str(curr_ini.decimals) 'f'])]};
         end;
      else;
         %
         % quantile value
         %
         cbs = get(control.quantiles,'Value')+49;
         if get(control.chisqdist,'Value')==1;
            %
            % chi-square distribution
            %
            my_cv = chisq_inv(cbs/100,df_1);
            show_txt = {['Distribution: \chi^{2} (' num2str(df_1,'%0.0f') ')'] [num2str(cbs,'%0.0f') '% quantile value = ' num2str(my_cv,['%0.' num2str(curr_ini.decimals) 'f'])]};
         else;
            %
            % F distribution
            %
            my_cv = fdist_inv(cbs/100,df_1,df_2);
            show_txt = {['Distribution: F (' num2str(df_1,'%0.0f') ',' num2str(df_2,'%0.0f') ')'] [num2str(cbs,'%0.0f') '% quantile value = ' num2str(my_cv,['%0.' num2str(curr_ini.decimals) 'f'])]};
         end;
      end;
      set(control.result,'String',show_txt);
   case 'done'
      set(control.done,'UserData','done');
end;

if nargout==1;
   h = distgui;
end;

if strcmp(selector,'done')==0;
   set(control.quantiles,'UserData',curr_ini);
   set(distgui,'UserData',control);
end;

if thisexit==0;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(distgui,'Name') ' ' fix_filepath([pwd '\icons\pvalue.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(control.icon,'UserData',pid);
      end;
   end;
   %
   set(distgui,'Visible','on');
   drawnow;
   if (iswinnt==1)&(iscompiled==1)&(matlabnumber<7);
      drawnow;
      prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(distgui,'Name') ' 1'];
      dos(prog);
      drawnow;
   elseif matlabnumber>=7;
      uicontrol(control.done);
   end;
   waitfor(control.done,'UserData','done');
end;

%
% end of distdlg.m
%
