function [results,dfmat,pvals] = exclude_firstdiffs(Psi,alpha,beta,p,pe,epsilon,Z1,Z2,q1,q0,d,t,Sigma_theta,sscorrect,modelsdir,modelfile,c_ind)

[n T] = size(epsilon);
Omega = (1/T)*epsilon*epsilon';
%
% initialize results, p-values, and degrees of freedom structures
%
results.individual = zeros(n*(((n-1)*(p>1))+(q1*(pe>0))+q0),1);
dfmat.individual = zeros(n*(((n-1)*(p>1))+(q1*(pe>0))+q0),1+sscorrect);
pvals.individual = ones(n*(((n-1)*(p>1))+(q1*(pe>0))+q0),1);

if ((p>1)&(n>2))&((q0>0)|((q1>0)&(pe>0)));
   results.full = zeros(n,1);
   dfmat.full = zeros(n,1+sscorrect);
   pvals.full = ones(n,1);
end;

if (n>2)&(p>1);
   results.endo = zeros(n,1);
   dfmat.endo = zeros(n,1+sscorrect);
   pvals.endo = ones(n,1);
end;
if ((q1>0)&(pe>0))|(q0>0);
   results.exo = zeros(n,1);
   dfmat.exo = zeros(n,1+sscorrect);
   pvals.exo = ones(n,1);
end;

if isempty(alpha)==0;
   r = size(alpha,2);
   w = [Z2;beta'*Z1];
else;
   r = 0;
   w = Z2;
end;
%
% set up restrictions the model already satisfies that involve the C matrix
%
if c_ind==1;
   file = strcat(modelsdir,'C-',int2str(n),'x',int2str(r),'-',modelfile,'.rest');
   F = loaddata(file);
   [Rmat_C,rvec_C] = rmatrix(F,n,n);
   if r<n;
      C = cmat(Psi,alpha,beta,epsilon,Z1,Z2,p,d,0);
   else;
      C = cmat_stat(Psi,alpha,beta,epsilon,Z1,Z2,p,d,0,[]);
   end;
   xi = xi_mat(C,Psi,alpha,p,pe,r,d,q1,q0);
   Rmat_C = Rmat_C*kron(xi',C);
end;
%
% construct the estimated asymptotic covariance matrix if it is not
% supplied to the function
%
if isempty(Sigma_theta)==1;
   inv_ww = inverse(w*w');
   Sigma_theta = kron(inv_ww,Omega);
end;

theta = vec([Psi alpha]);

num = 1;
In = eye(n);
Ip1 = eye(p-1);
if (q1>0)&(pe>0);
   Iq1 = eye(q1);
   Ipe1 = eye(pe);
end;
if q0>0;
   Iq0 = eye(q0);
   Ipe0 = eye(pe+1);
end;
for i=1:n;
   %
   % the lagged first differences of endogenous variables
   %
   R_mat_full = [];
   r_vec_full = [];
   R_mat_endo = [];
   r_vec_endo = [];
   R_mat_exo = [];
   r_vec_exo = [];
   ei = In(:,i);
   %
   if p>1;
      for j=1:n;
         if i~=j;
            Rmatj = [];
            if d>0;
               Rmatj = zeros(p-1,n*d);
            end;
            ej = In(:,j);
            Kj = kron(Ip1,ej);
            Rmatj = [Rmatj kron(Kj',ei')];
            if (q1>0)&(pe>0);
               Rmatj = [Rmatj zeros(p-1,n*q1*pe)];
            end;
            if q0>0;
               Rmatj = [Rmatj zeros(p-1,n*q0*(pe+1))];
            end;
            if r>0;
               Rmatj = [Rmatj zeros(p-1,n*r)];
            end;
            rvecj = zeros(p-1,1);
            %
            % In case C is restricted, we need to take this into account
            %
            if c_ind==1;
               R_mat_test = [Rmat_C;Rmatj];
               if rank(R_mat_test)<size(R_mat_test,1);
                  %
                  % need to find the redundant restrictions
                  %
                  [red_rest,use_rest] = getdelvars(R_mat_test',[]);
                  use_rest = use_rest-size(Rmat_C,1);
                  use_rest = use_rest(use_rest>0);
                  if isempty(use_rest)==0;
                     R_mat = Rmatj(use_rest,:);
                     r_vec = rvecj(use_rest,1);
                  else;
                     R_mat = [];
                     r_vec = [];
                  end;
               else;
                  R_mat = Rmatj;
                  r_vec = rvecj;
               end;
            else;
               R_mat = Rmatj;
               r_vec = rvecj;
            end;
            %
            % calculate the test
            %
            if isempty(R_mat)==0;
               W = ((theta'*R_mat')-r_vec')*inverse(R_mat*Sigma_theta*R_mat')*((R_mat*theta)-r_vec);
               if sscorrect==0;
                  results.individual(num,1) = W;
                  dfmat.individual(num,1) = size(R_mat,1);
                  pvals.individual(num,1) = 1-chis_cdf(W,size(R_mat,1));
               else;
                  dfmat.individual(num,:) = [size(R_mat,1) t+size(R_mat,1)];
                  results.individual(num,1) = ((t+size(R_mat,1))/(T*size(R_mat,1)))*W;
                  pvals.individual(num,1) = 1-fdis_cdf(results.individual(num,1),size(R_mat,1),t+size(R_mat,1));
               end;
            else;
               results.individual(num,1) = 0;
            end;
            R_mat_endo = [R_mat_endo;Rmatj];
            r_vec_endo = [r_vec_endo;rvecj];
            num = num+1;
         end;
      end;
   end;
   if (n>2)&(p>1);
      %
      % First fix restrictions for full test if C is restricted and requires this
      %
      if c_ind==1;
         R_mat_test = [Rmat_C;R_mat_endo];
         if rank(R_mat_test)<size(R_mat_test,1);
            %
            % need to find the redundant restrictions
            %
            [red_rest,use_rest] = getdelvars(R_mat_test',[]);
            use_rest = use_rest-size(Rmat_C,1);
            use_rest = use_rest(use_rest>0);
            if isempty(use_rest)==0;
               R_mat = R_mat_endo(use_rest,:);
               r_vec = r_vec_endo(use_rest,1);
            else;
               R_mat = [];
               r_vec = [];
            end;
         else;
            R_mat = R_mat_endo;
            r_vec = r_vec_endo;
         end;
      else;
         R_mat = R_mat_endo;
         r_vec = r_vec_endo;
      end;
      %
      % Now we do the full endo test
      %
      if isempty(R_mat)==0;
         W = ((theta'*R_mat')-r_vec')*inverse(R_mat*Sigma_theta*R_mat')*((R_mat*theta)-r_vec);
         if sscorrect==0;
            results.endo(i,1) = W;
            dfmat.endo(i,1) = size(R_mat,1);
            pvals.endo(i,1) = 1-chis_cdf(W,size(R_mat,1));
         else;
            dfmat.endo(i,:) = [size(R_mat,1) t+size(R_mat,1)];
            results.endo(i,1) = ((t+size(R_mat,1))/(T*size(R_mat,1)))*W;
            pvals.endo(i,1) = 1-fdis_cdf(results.endo(i,1),size(R_mat,1),t+size(R_mat,1));
         end;
      else;
         results.endo(i,1) = 0;
      end;
      R_mat_full = R_mat_endo;
      r_vec_full = r_vec_endo;
   end;
   %
   % the lagged exogenous I(1)
   %
   if (q1>0)&(pe>0);
      for j=1:q1;
         if (p>1)|(d>0);
            Rmatj = zeros(pe,n*((n*(p-1))+d));
         else;
            Rmatj = [];
         end;
         ej = Iq1(:,j);
         Kj = kron(Ipe1,ej);
         Rmatj = [Rmatj kron(Kj',ei')];
         if q0>0;
            Rmatj = [Rmatj zeros(pe,n*q0*(pe+1))];
         end;
         if r>0;
            Rmatj = [Rmatj zeros(pe,n*r)];
         end;
         rvecj = zeros(pe,1);
         %
         % compute the individual test test
         %
         W = ((theta'*Rmatj')-rvecj')*inverse(Rmatj*Sigma_theta*Rmatj')*((Rmatj*theta)-rvecj);
         if sscorrect==0;
            results.individual(num,1) = W;
            dfmat.individual(num,1) = pe;
            pvals.individual(num,1) = 1-chis_cdf(W,pe);
         else;
            results.individual(num,1) = ((t+pe)/(T*pe))*W;
            dfmat.individual(num,:) = [pe t+pe];
            pvals.individual(num,1) = 1-fdis_cdf(results.individual(num,1),pe,t+pe);
         end;
         R_mat_exo = [R_mat_exo;Rmatj];
         r_vec_exo = [r_vec_exo;rvecj];
         num = num+1;
      end;
   end;
   %
   % the lagged exogenous I(0)
   %
   if q0>0;
      for j=1:q0;
         if (p>1)|(d>0)|(q1*pe>0);
            Rmatj = zeros(pe+1,n*((n*(p-1))+d+(q1*pe)));
         else;
            Rmatj = [];
         end;
         ej = Iq0(:,j);
         Kj = kron(Ipe0,ej);
         Rmatj = [Rmatj kron(Kj',ei')];
         if r>0;
            Rmatj = [Rmatj zeros(pe+1,n*r)];
         end;
         rvecj = zeros(pe+1,1);
         %
         % compute the individual test
         %
         W = ((theta'*Rmatj')-rvecj')*inverse(Rmatj*Sigma_theta*Rmatj')*((Rmatj*theta)-rvecj);
         if sscorrect==0;
            results.individual(num,1) = W;
            dfmat.individual(num,1) = pe+1;
            pvals.individual(num,1) = 1-chis_cdf(W,pe+1);
         else;
            results.individual(num,1) = ((t+pe+1)/(T*(pe+1)))*W;
            dfmat.individual(num,:) = [pe+1 t+pe+1];
            pvals.individual(num,1) = 1-fdis_cdf(results.individual(num,1),pe+1,t+pe+1);
         end;
         R_mat_exo = [R_mat_exo;Rmatj];
         r_vec_exo = [r_vec_exo;rvecj];
         num = num+1;
      end;
   end;
   %
   % The full test for exogenous variables
   %
   if (isempty(R_mat_exo)==0)&(q1+q0>1);
      W = ((theta'*R_mat_exo')-r_vec_exo')*inverse(R_mat_exo*Sigma_theta*R_mat_exo')*((R_mat_exo*theta)-r_vec_exo);
      if sscorrect==0;
         results.exo(i,1) = W;
         dfmat.exo(i,1) = size(R_mat_exo,1);
         pvals.exo(i,1) = 1-chis_cdf(W,size(R_mat_exo,1));
      else;
         results.exo(i,1) = ((t+size(R_mat_exo,1))/(T*size(R_mat_exo,1)))*W;
         dfmat.exo(i,:) = [size(R_mat_exo,1) t+size(R_mat_exo,1)];
         pvals.exo(i,1) = 1-fdis_cdf(results.exo(i,1),size(R_mat_exo,1),t+size(R_mat_exo,1));
      end;
   end;
   %
   % the full test for both endogenous and exogenous variables
   %
   if (isempty(R_mat_endo)==0)&(isempty(R_mat_exo)==0);
      R_mat_full = [R_mat_endo;R_mat_exo];
      r_vec_full = [r_vec_endo;r_vec_exo];
      %
      % In case of C restrictions, remove redundant restrictions if need be
      %
      if c_ind==1;
         R_mat_test = [Rmat_C;R_mat_full];
         if rank(R_mat_test)<size(R_mat_test,1);
            %
            % need to find the redundant restrictions
            %
            [red_rest,use_rest] = getdelvars(R_mat_test',[]);
            use_rest = use_rest-size(Rmat_C,1);
            use_rest = use_rest(use_rest>0);
            if isempty(use_rest)==0;
               R_mat_full = R_mat_full(use_rest,:);
               r_vec_full = r_vec_full(use_rest,1);
            else;
               R_mat_full = [];
               r_vec_full = [];
            end;
         end;
      end;
      %
      if isempty(R_mat_full)==0;
         W = ((theta'*R_mat_full')-r_vec_full')*inverse(R_mat_full*Sigma_theta*R_mat_full')*((R_mat_full*theta)-r_vec_full);
         if sscorrect==0;
            results.full(i,1) = W;
            dfmat.full(i,1) = size(R_mat_full,1);
            pvals.full(i,1) = 1-chis_cdf(W,size(R_mat_full,1));
         else;
            results.full(i,1) = ((t+size(R_mat_full,1))/(T*size(R_mat_full,1)))*W;
            dfmat.full(i,:) = [size(R_mat_full,1) t+size(R_mat_full,1)];
            pvals.full(i,1) = 1-fdis_cdf(results.full(i,1),size(R_mat_full,1),t+size(R_mat_full,1));
         end;
      else;
         results.full(i,1) = 0;
      end;
   end;
end;

%
% end of exclude_firstdiffs.m
%
