function cm = get_cmatrices(cm)

cm.rank(1).norm_beta = [];
cm.rank(cm.n+1).norm_beta = (1:1:cm.n);
file = [cm.modelsdir cm.modelfile '-ranknorm-' num2str(cm.n,'%0.0f') '.norm'];
if fileexist(file)==1;
   %
   % apply user defined normalizations
   %
   cm.rank_norm_beta = loaddata(file);
   for i=1:cm.n-1;
      rank_norm_beta = cm.rank_norm_beta(i,:) .* (1:1:cm.n);
      rank_norm_beta = rank_norm_beta(rank_norm_beta>0);
      cm.rank(i+1).norm_beta = rank_norm_beta;
   end;
else;
   for i=1:cm.n-1;
      beta = cm.rank(i+1).beta;
      %
      % premultiply beta by scaling factors
      %
      scale_beta = sqrt(cm.scale_n);
      if size(beta,1)>cm.n;
         scale_beta = [scale_beta;ones(size(beta,1)-cm.n,1)];
      end;
      scale_beta = diag(scale_beta);
      beta = scale_beta*beta;
      %
      % compare all cases
      %
      if ispc==1;
         file = [pwd '\mat\states-' num2str(cm.n,'%0.0f') '.' num2str(i,'%0.0f') '.mat'];
      else;
         file = [pwd '/mat/states-' num2str(cm.n,'%0.0f') '.' num2str(i,'%0.0f') '.mat'];
      end;
      %
      % we need to make sure that the file exists. otherwise we need to create it
      %
      if fileexist(file)==1;
         states_data = load(file);
         states = states_data.states;
         clear('states_data');
      else;
         %
         % show a wait dialog
         %
         txt = strvcat(' ',['Determining the number of combinations of ' num2str(cm.n,'%0.0f') ' states to choose normalization of beta...'],'Please hold!');
         mywait = waitdlg(txt,'information');
         waitf = get(mywait,'UserData');
         states = var_comb(cm.n);
         txt = strvcat(' ','Saving data to file...','Please hold!');
         set(waitf.text,'String',txt);
         %
         % save to disk
         %
         if ispc==1;
            file = [pwd '\mat\states-' num2str(cm.n,'%0.0f') '.' num2str(cm.n,'%0.0f') '.mat'];
         else;
            file = [pwd '/mat/states-' num2str(cm.n,'%0.0f') '.' num2str(cm.n,'%0.0f') '.mat'];
         end;
         %
         save(file,'states');
         %
         f_states = states;
         clear('states');
         %
         if cm.n>1;
            for j=1:cm.n-1;
               if j<cm.n-1;
                  states = [];
                  for k=1:size(f_states,1);
                     stat_r = f_states(k,:);
                     stat_r = stat_r(stat_r~=0);
                     if size(stat_r,2)<=j;
                        states = [states;f_states(k,:)];
                     end;
                  end;
               else;
                  states = f_states(1:size(f_states,1)-1,:);
               end;
               if ispc==1;
                  file = [pwd '\mat\states-' num2str(cm.n,'%0.0f') '.' num2str(j,'%0.0f') '.mat'];
               else;
                  file = [pwd '/mat/states-' num2str(cm.n,'%0.0f') '.' num2str(j,'%0.0f') '.mat'];
               end;
               save(file,'states');
            end;
            clear('states');
         end;
         clear('f_states');
         %
         % now load the correct file with states
         %
         if ispc==1;
            file = [pwd '\mat\states-' num2str(cm.n,'%0.0f') '.' num2str(i,'%0.0f') '.mat'];
         else;
            file = [pwd '/mat/states-' num2str(cm.n,'%0.0f') '.' num2str(i,'%0.0f') '.mat'];
         end;
         states_data = load(file);
         states = states_data.states;
         clear('states_data');
         %
         % close wait dialog
         %
         set(waitf.text,'UserData','done');
         delete(mywait);
      end;
      %
      max_beta_det = [];
      for j=1:size(states,1);
         norm_beta = states(j,:);
         norm_beta = norm_beta(norm_beta~=0);
         if i==size(norm_beta,2);
            beta_det = abs(det(beta(norm_beta,:)));
            if isempty(max_beta_det)==0;
               if beta_det>max_beta_det;
                  max_beta_det = beta_det;
                  cm.rank(i+1).norm_beta = norm_beta;
               end;
            else;
               max_beta_det = beta_det;
               cm.rank(i+1).norm_beta = norm_beta;
            end;
         end;
      end;
   end;
end;
%
% now we transform beta and alpha appropriately
%
i_mat = eye(cm.n+cm.q1+cm.dcoint);
for i=1:cm.n;
   corr_mat = cm.rank(i+1).beta(cm.rank(i+1).norm_beta,:);
   cm.rank(i+1).beta = cm.rank(i+1).beta*inverse(corr_mat);
   cm.rank(i+1).alpha = cm.rank(i+1).alpha*corr_mat';
   cm.rank(i+1).c_mat = i_mat(:,cm.rank(i+1).norm_beta);
   cm.rank(i+1).c_mat_orth = null(cm.rank(i+1).c_mat','r');
end;

%
% end of get_cmatrices.m
%
