%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab function for determining model description     %
%                                                                %
%          Function: getmodeldesc                                %
%                                                                %
%          Input:                                                %
%                       curr_model: structure with model info    %
%                                                                %
%          Output:                                               %
%          	            modeldesc: structured text array with    %
%                          LaTeX syntax for describing selected  %
%                          model                                 %
%                                                                %
%          This version:        June 1, 2004                     %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2004          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function modeldesc = getmodeldesc(curr_model,newdeterselect,newmodeltype,newseasonal);

if nargin==1;
   newseasonal = curr_model.newseasonal;
   newmodeltype = curr_model.newmodeltype;
   newdeterselect = curr_model.newdeterselect;
end;

if fileexist(curr_model.endofile)==1;
   if newseasonal(1,1)==1;
      if newmodeltype(1,1)==1;
         if newdeterselect(1,1)==1;
            %
            % with cointegration estimation
            %
            if curr_model.cointvalue==1;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \alpha\beta\primey_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0+ \delta_2S_t + \delta_3D_t + \alpha\beta\primey_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \delta_3D_t + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            %
            % without cointegration estimation
            %
            else;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \Piy_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \Piy_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \delta_3D_t + \Piy_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \delta_3D_t + \Piy_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            end;
         elseif newdeterselect(1,2)==1;
            %
            % with cointegration estimation
            %
            if curr_model.cointvalue==1;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \delta_2S_t + \alpha\beta\primey_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \delta_2S_t + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \delta_2S_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \delta_2S_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \delta_2S_t + \delta_3D_t + \alpha\beta\primey_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \delta_2S_t + \delta_3D_t + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \delta_2S_t + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \delta_2S_t + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            %
            % without cointegration estimation
            %
            else;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \Piy_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \Piy_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \delta_3D_t + \Piy_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \delta_3D_t + \Piy_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            end;
         elseif newdeterselect(1,3)==1;
            %
            % with cointegration estimation
            %
            if curr_model.cointvalue==1;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \alpha\beta\primey_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \delta_3D_t + \alpha\beta\primey_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \delta_3D_t + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            %
            % without cointegration estimation
            %
            else;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \Piy_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \Piy_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \delta_3D_t + \Piy_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \delta_3D_t + \Piy_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            end;
         elseif newdeterselect(1,4)==1;
            %
            % with cointegration estimation
            %
            if curr_model.cointvalue==1;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \delta_2S_t + \alpha\beta\primey_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \delta_2S_t + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \delta_2S_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \delta_2S_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \delta_2S_t + \delta_3D_t + \alpha\beta\primey_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \delta_2S_t + \delta_3D_t + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \delta_2S_t + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \delta_2S_t + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            %
            % without cointegration estimation
            %
            else;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \Piy_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \Piy_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \delta_3D_t + \Piy_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \delta_3D_t + \Piy_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            end;
         end;
      elseif newmodeltype(1,2)==1;
         if newdeterselect(1,1)==1;
            %
            % with cointegration estimation
            %
            if curr_model.cointvalue==1;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \alpha\beta\primey_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \delta_3D_t + \alpha\beta\primey_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \delta_3D_t + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            %
            % without cointegration estimation
            %
            else;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \Piy_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \Piy_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \delta_3D_t + \Piy_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \delta_3D_t + \Piy_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            end;
         elseif newdeterselect(1,2)==1;
            %
            % with cointegration estimation
            %
            if curr_model.cointvalue==1;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \delta_2S_t + \alpha\beta\primey_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \delta_2S_t + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \delta_2S_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \delta_2S_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \delta_2S_t + \delta_3D_t + \alpha\beta\primey_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \delta_2S_t + \delta_3D_t + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \delta_2S_t + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \delta_2S_t + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            %
            % without cointegration estimation
            %
            else;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \Piy_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \Piy_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \delta_3D_t + \Piy_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \delta_3D_t + \Piy_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_2S_t + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            end;
         elseif newdeterselect(1,3)==1;
            %
            % with cointegration estimation
            %
            if curr_model.cointvalue==1;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \alpha\beta\primey_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \delta_3D_t + \alpha\beta\primey_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \delta_3D_t + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            %
            % without cointegration estimation
            %
            else;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \Piy_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \Piy_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \delta_3D_t + \Piy_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \delta_3D_t + \Piy_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            end;
         elseif newdeterselect(1,4)==1;
            %
            % with cointegration estimation
            %
            if curr_model.cointvalue==1;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \delta_2S_t + \alpha\beta\primey_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \delta_2S_t + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \delta_2S_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \delta_2S_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \delta_2S_t + \delta_3D_t + \alpha\beta\primey_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \delta_2S_t + \delta_3D_t + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \delta_2S_t + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \delta_2S_t + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            %
            % without cointegration estimation
            %
            else;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \Piy_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \Piy_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \delta_3D_t + \Piy_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \delta_3D_t + \Piy_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_2S_t + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            end;
         end;
      end;
   elseif newseasonal(1,2)==1;
      if newmodeltype(1,1)==1;
         if newdeterselect(1,1)==1;
            %
            % with cointegration estimation
            %
            if curr_model.cointvalue==1;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\beta\primey_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_3D_t + \alpha\beta\primey_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_3D_t + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            %
            % without cointegration estimation
            %
            else;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \Piy_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \Piy_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_3D_t + \Piy_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_3D_t + \Piy_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            end;
         elseif newdeterselect(1,2)==1;
            %
            % with cointegration estimation
            %
            if curr_model.cointvalue==1;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \alpha\beta\primey_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \delta_3D_t + \alpha\beta\primey_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \delta_3D_t + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            %
            % without cointegration estimation
            %
            else;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \Piy_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \Piy_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_3D_t + \Piy_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_3D_t + \Piy_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            end;
         elseif newdeterselect(1,3)==1;
            %
            % with cointegration estimation
            %
            if curr_model.cointvalue==1;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \alpha\beta\primey_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_3D_t + \alpha\beta\primey_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_3D_t + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            %
            % without cointegration estimation
            %
            else;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \Piy_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \Piy_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_3D_t + \Piy_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_3D_t + \Piy_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            end;
         elseif newdeterselect(1,4)==1;
            %
            % with cointegration estimation
            %
            if curr_model.cointvalue==1;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \alpha\beta\primey_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \delta_3D_t + \alpha\beta\primey_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \delta_3D_t + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            %
            % without cointegration estimation
            %
            else;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \Piy_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \Piy_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_3D_t + \Piy_{t-1} + B\eta_t'};
                  modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_3D_t + \Piy_{t-1} + \Phi(L)x_{0,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + B\eta_t'};
                     modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + B\eta_t'};
                        modeldesc(2) = {'\eta_t \sim N(0,I),  BB\prime = \Omega,  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            end;
         end;
      elseif newmodeltype(1,2)==1;
         if newdeterselect(1,1)==1;
            %
            % with cointegration estimation
            %
            if curr_model.cointvalue==1;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\beta\primey_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_3D_t + \alpha\beta\primey_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_3D_t + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            %
            % without cointegration estimation
            %
            else;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \Piy_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \Piy_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_3D_t + \Piy_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_3D_t + \Piy_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            end;
         elseif newdeterselect(1,2)==1;
            %
            % with cointegration estimation
            %
            if curr_model.cointvalue==1;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \alpha\beta\primey_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \delta_3D_t + \alpha\beta\primey_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \delta_3D_t + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \alpha\mu_0 + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            %
            % without cointegration estimation
            %
            else;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \Piy_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \Piy_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_3D_t + \Piy_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_3D_t + \Piy_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            end;
         elseif newdeterselect(1,3)==1;
            %
            % with cointegration estimation
            %
            if curr_model.cointvalue==1;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \alpha\beta\primey_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_3D_t + \alpha\beta\primey_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_3D_t + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            %
            % without cointegration estimation
            %
            else;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \Piy_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \Piy_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_3D_t + \Piy_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_3D_t + \Piy_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            end;
         elseif newdeterselect(1,4)==1;
            %
            % with cointegration estimation
            %
            if curr_model.cointvalue==1;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \alpha\beta\primey_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \delta_3D_t + \alpha\beta\primey_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \delta_3D_t + \alpha\beta\primey_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \alpha\mu_1t + \delta_3D_t + \alpha\beta\primeY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            %
            % without cointegration estimation
            %
            else;
               if strcmp(curr_model.deterfile,'')==1;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \Piy_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \Piy_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               else;
                  modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_3D_t + \Piy_{t-1} + \epsilon_t'};
                  modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  if strcmp(curr_model.exo0file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_3D_t + \Piy_{t-1} + \Phi(L)x_{0,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega)'};
                  end;
                  if strcmp(curr_model.exo1file,'')==0;
                     modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \epsilon_t'};
                     modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     if strcmp(curr_model.exo0file,'')==0;
                        modeldesc(1) = {'\Gamma(L)\Deltay_t = \delta_0 + \delta_1t + \delta_3D_t + \PiY_{t-1} + \Psi(L)\Deltax_{1,t} + \Phi(L)x_{0,t} + \epsilon_t'};
                        modeldesc(2) = {'\epsilon_t \sim N(0,\Omega),  Y_t = (y_t,x_{1,t})'};
                     end;
                  end;
               end;
            end;
         end;
      end;
   end;
else;
   modeldesc(1) = {'No'};
   modeldesc(2) = {'Model'};
end;

%
% end of getmodeldesc.m
%
