function [out,filename,warns,abort] = gibbs_beta(tm,curr_ini)

%
% generates draws from the full conditional posteriors for the various possible
% cointegration ranks
%

out = [];
abort = '';
filename = '';
warns = zeros(1,5);
%
draw = 1;
%
% initial values for rank r are given by the ML estimates
%
alpha = tm.beta_rest.alpha;
beta = tm.beta_rest.beta;
Omega = tm.beta_rest.Omega;
alpha_n = alpha;
beta_n = beta;
Omega_n = Omega;

if tm.amat_type==1;
   if tm.amat_lag==1;
      A = tm.rank(tm.n+1).Omega;
   else;
      A = tm.amat_val;
   end;
   q = tm.n+2;
else;
   A = tm.lambda_a*eye(tm.n);
   q = tm.q_parm;
end;
Psi = tm.beta_rest.Psi;
epsilon = tm.beta_rest.epsilon;
Z0 = tm.Z0;
Z1 = tm.Z1;
if tm.d>0;
   delta = Psi(:,1:tm.d);
   D = tm.Z2(1:tm.d,:);
else;
   delta = [];
   D = [];
end;
if (isempty(tm.Z2)==0)&(size(Psi,2)>tm.d);
   Gamma = Psi(:,tm.d+1:size(Psi,2));
   Z2 = tm.Z2(1+tm.d:size(tm.Z2,1),:);
else;
   Gamma = [];
   Z2 = [];
end;
%
% The restriction matrices for vec(beta) = h + H*psi
%
h_vec = tm.beta_rest.h_vec;
H_mat = tm.beta_rest.H_mat;
%
% From the prior distributions for the shortrun dynamics get mean vectors and covariance matrices
% The latter are inverted if non-empty
%
D_mu = tm.prior.deter.mu;
D_sigma = tm.prior.deter.sigma;
G_mu = tm.prior.shortrun.mu;
G_sigma = tm.prior.shortrun.sigma;
%
% compute posterior mode for rank r
%
setlogtext(strvcat(' ','Computing the posterior mode...'));
%
%  Compute posterior mode. These estimates are used as initial values for the Gibbs sampler
%
out.posterior_mode = posterior_mode(tm,curr_ini,tm.r,tm.beta_rest.tot_free,A,q,D_sigma,G_sigma,tm.prior_inf_alpha,tm.prior_inf_omega,1);
alpha = out.posterior_mode.alpha;
beta = out.posterior_mode.beta;
Omega = out.posterior_mode.Omega;
delta = out.posterior_mode.delta;
Gamma = out.posterior_mode.Gamma;
old_alpha = alpha;
old_beta = beta;
old_Omega = Omega;
old_delta = delta;
old_Gamma = Gamma;
%
% The integration matrix N
%
if (tm.prior_inf_shortrun==2)&(tm.prior_inf_deter==2);
   %
   % improper priors on delta and Gamma
   %
   if isempty(tm.Z2)==0;
      Z = tm.Z2;
      N = eye(tm.T)-Z'*inverse(Z*Z')*Z;
   else;
      N = eye(tm.T);
   end;
elseif (tm.prior_inf_shortrun==1)&(tm.prior_inf_deter==2);
   %
   % improper prior on delta
   %
   if isempty(tm.Z2)==0;
      if tm.d>0;
         M_D = eye(tm.T)-(D'*inverse(D*D')*D);
      else;
         M_D = eye(tm.T);
      end;
      if size(tm.Z2,1)>tm.d;
         N = M_D-(M_D*Z2'*inverse(((Z2*M_D*Z2')+inverse(G_sigma)))*Z2*M_D);
      else;
         N = M_D;
      end;
   else;
      N = eye(tm.T);
   end;
elseif (tm.prior_inf_shortrun==2)&(tm.prior_inf_deter==1);
   %
   % improper prior on Gamma
   %
   if isempty(tm.Z2)==0;
      if tm.d>0;
         if size(tm.Z2)>tm.d;
            M_Z2 = eye(tm.T)-(Z2'*inverse(Z2*Z2')*Z2);
            N = M_Z2-(M_Z2*D'*inverse(((D*M_Z2*D')+inverse(D_sigma)))*D*M_Z2);
         else;
            N = eye(tm.T)-D'*inverse(((D*D')+inverse(D_sigma)))*D;
         end;
      else;
         M_Z2 = eye(tm.T)-(Z2'*inverse(Z2*Z2')*Z2);
         N = M_Z2;
      end;
   else;
      N = eye(tm.T);
   end;
else;
   %
   % proper priors on delta and Gamma
   %
   if isempty(tm.Z2)==0;
      Z = tm.Z2;
      if tm.d>0;
         if size(tm.Z2)>tm.d;
            F_sigma = [[D_sigma zeros(tm.d,size(G_sigma,1))];[zeros(size(G_sigma,1),tm.d) G_sigma]];
         else;
            F_sigma = D_sigma;
         end;
      else;
         F_sigma = G_sigma;
      end;
      N = eye(tm.T)-(Z'*inverse(((Z*Z')+inverse(F_sigma)))*Z);
   else;
      N = eye(tm.T);
   end;
end;
C_0 = Z0*N*Z1';
C_1 = Z1*N*Z1';
if tm.prior_inf_alpha==1;
   C_1 = C_1+(1/tm.lambda_alpha^2)*eye(tm.n);
end;
%
% Contruct string matrix with information about the prior being used
%
prior_txt = 'Prior for computations:';
if tm.prior_inf_omega==1;
   prior_txt = strvcat(prior_txt,'   Omega: Inverted Wishart');
else;
   prior_txt = strvcat(prior_txt,'   Omega: Non-informative');
end;
if tm.prior_inf_deter==1;
   prior_txt = strvcat(prior_txt,'   delta: Normal conditional on Omega');
else;
   prior_txt = strvcat(prior_txt,'   delta: Non-informative');
end;
if tm.prior_inf_shortrun==1;
   prior_txt = strvcat(prior_txt,'   Gamma: Normal conditional on Omega');
else;
   prior_txt = strvcat(prior_txt,'   Gamma: Non-informative');
end;
if tm.prior_inf_alpha==1;
   prior_txt = strvcat(prior_txt,'   alpha: Normal conditional on beta, Omega');
else;
   prior_txt = strvcat(prior_txt,'   alpha: Non-informative');
end;
prior_txt = strvcat(prior_txt,'   beta:  Uniform on space');
%
% we are now ready to startup the Gibbs sampler for beta estimation
%
burn_in = 0;
stop_run = 0;
save_draws = 1;
save_freq = 1;
show_prog = 0;
bad_draw = 0;
num_baddraws = 0;
if tm.burn_in>0;
   txt = ['Initializing the Gibbs sampler for beta restrictions using ' num2str(tm.burn_in,'%0.0f') ' burn-in draws. Please wait!'];
   setlogtext(strvcat('Initializing the Gibbs sampler for beta restrictions...','Using posterior mode estimates...',prior_txt,['Started at: ' datestr(now,14)],['  Number of burn-in draws: ' num2str(tm.burn_in,'%0.0f')]));
   mywait = waitdlg(strvcat(' ',txt),'information');
   waitf = get(mywait,'UserData');
   burn_in = 1;
else;
   setlogtext(strvcat('Gibbs sampling for beta restrictions...','Using posterior mode estimates...',prior_txt,['Started at: ' datestr(now,14)]));
   show_prog = 1;
end;

if tm.beta_rest.tot_free>0;
   gibbs_draws.psi = zeros(tm.beta_rest.tot_free,tm.burn_in+(tm.save_draws*tm.save_freq));
   gibbs_draws.psi_n = zeros(tm.beta_rest.tot_free,draw);
end;
gibbs_draws.alpha = zeros(tm.n*tm.r,tm.burn_in+(tm.save_draws*tm.save_freq));
gibbs_draws.alpha_n = gibbs_draws.alpha;
gibbs_draws.Omega = zeros((tm.n*(tm.n+1))/2,tm.burn_in+(tm.save_draws*tm.save_freq));
gibbs_draws.Omega_n = gibbs_draws.Omega;
if isempty(D)==0;
   gibbs_draws.delta = zeros(tm.n*tm.d,tm.burn_in+(tm.save_draws*tm.save_freq));
end;
if isempty(Z2)==0;
   gibbs_draws.Gamma = zeros(size(Z2,1)*tm.n,tm.burn_in+(tm.save_draws*tm.save_freq));
end;

while stop_run==0;
   %
   % display a progress dialog
   %
   if show_prog==1;
      show_prog = 0;
      input_var.title = ['Progress for ' num2str(tm.save_draws,'%0.0f') ' draws to save'];
      input_var.facecolor = curr_ini.progress_facecolor;
      input_var.startfacecolor = curr_ini.progress_startfacecolor;
      input_var.edgecolor = curr_ini.progress_edgecolor;
      input_var.bgcolor = curr_ini.progress_bgcolor;
      input_var.stop = 0;
      input_var.clock = 1;
      input_var.label = 'Draw number:';
      input_var.name = 'Gibbs Sampling For Beta Restrictions';
      mywait = progressdlg(0,input_var);
      set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
      drawnow;
      txt = strvcat(['  Number of draws to save: ' num2str(tm.save_draws,'%0.0f')],['  Draw saving frequency:   ' num2str(100/tm.save_freq,'%0.1f') '%']);
      setlogtext(txt);
   end;
   %
   % Update the progress dialog
   %
   if draw>tm.burn_in;
      abort = get(mywait,'UserData');
      if (strcmp(abort,'cancel')==1)|(strcmp(abort,'done')==1);
         break;
      else;
         progressdlg([save_draws/tm.save_draws draw-tm.burn_in]);
      end;
   end;
   %
   % control the random number generator state
   %
   if curr_ini.random_state==2;
      randn('state',draw);
   elseif curr_ini.random_state==3;
      randn('state',sum(100*clock));
   elseif curr_ini.random_state==4;
      randn('state',sum(100*clock)+draw);
   end;
   %
   % generate Omega draw from the full conditional posterior
   %
   W = Z0-(alpha_n*beta_n'*Z1);
   sigma = epsilon*epsilon';
   sigma_n = W*N*W';
   df_Omega = 0;
   if tm.prior_inf_omega==1;
      sigma = sigma+A;
      sigma_n = sigma_n+A;
      df_Omega = q;
   end;
   if tm.prior_inf_alpha==1;
      sigma = sigma+((1/(tm.lambda_alpha^2))*(alpha*beta'*beta*alpha'));
      df_Omega = df_Omega+tm.r;
      sigma_n = sigma_n+((1/(tm.lambda_alpha^2))*(alpha_n*beta_n'*beta_n*alpha_n'));
   end;
   if isempty(D_sigma)==0;
      sigma = sigma+(delta*inverse(D_sigma)*delta');
      df_Omega = df_Omega+size(D_sigma,1);
   end;
   if isempty(G_sigma)==0;
      sigma = sigma+(Gamma*inverse(G_sigma)*Gamma');
      df_Omega = df_Omega+size(G_sigma,1);
   end;
   [inv_Omega,warn] = wish_rnd(inverse(sigma),tm.T+df_Omega,curr_ini.symmetric);
   if tm.bad_draws==0;
      warns(1,1) = warn;
   end;
   if (warn>0)&(tm.bad_draws==0);
      %
      % need to close any open dialogs and then return
      %
      if burn_in==1;
         %
         % close down the burn_in dialog
         %
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
      else;
         %
         % Close the progress dialog
         %
         set(mywait,'UserData','done');
         close(mywait);
         drawnow;
      end;
      return;
   elseif warn==0;
      Omega = inverse(inv_Omega);
   else;
      Omega = old_Omega;
      bad_draw = 1;
   end;
   %
   % draw from "marginal" Omega
   %
   [inv_Omega_n,warn_n] = wish_rnd(inverse(sigma_n),tm.T+df_Omega-size(tm.Z2,1),curr_ini.symmetric);
   if warn_n==0;
      Omega_n = inverse(inv_Omega_n);
   else;
      Omega_n = ((tm.T+df_Omega)/(tm.T+df_Omega-size(tm.Z2,1)))*Omega;
   end;
   %
   % Generate draw from the full conditional posterior for delta
   %
   if tm.d>0;
      [new_delta,warn] = delta_rank_rnd(Z0,Z1,Z2,D,tm.r,tm.n,tm.d,Omega,Gamma,alpha,beta,D_mu,D_sigma,curr_ini.symmetric);
      if tm.bad_draws==0;
         warns(1,2) = warn;
      end;
      %
      if (warn>0)&(tm.bad_draws==0);
         %
         % need to close any open dialogs and then return
         %
         if burn_in==1;
            %
            % close down the burn_in dialog
            %
            set(waitf.text,'UserData','done');
            delete(mywait);
            drawnow;
         else;
            %
            % Close the progress dialog
            %
            set(mywait,'UserData','done');
            close(mywait);
            drawnow;
         end;
         return;
      elseif warn==0;
         delta = new_delta;
      else;
         bad_draw = 1;
      end;
   end;
   %
   % Generate draw from the full conditional posterior for Gamma
   %
   if isempty(Z2)==0;
      [new_Gamma,warn] = gamma_rank_rnd(Z0,Z1,Z2,D,tm.r,tm.n,size(Gamma,2),Omega,delta,alpha,beta,G_mu,G_sigma,curr_ini.symmetric);
      if tm.bad_draws==0;
         warns(1,3) = warn;
      end;
      %
      if (warn>0)&(tm.bad_draws==0);
         %
         % need to close any open dialogs and then return
         %
         if burn_in==1;
            %
            % close down the burn_in dialog
            %
            set(waitf.text,'UserData','done');
            delete(mywait);
            drawnow;
         else;
            %
            % Close the progress dialog
            %
            set(mywait,'UserData','done');
            close(mywait);
            drawnow;
         end;
         return;
      elseif warn==0;
         Gamma = new_Gamma;
      else;
         bad_draw = 1;
      end;
   end;
   Psi = [delta Gamma];
   %
   % Generate draw from the full conditional posterior for alpha 
   %
   [new_alpha,warn] = alpha_rnd(Z0,Z1,Z2,D,tm.n,tm.r,Omega,delta,Gamma,beta,tm.lambda_alpha,curr_ini.symmetric,tm.prior_inf_alpha);
   if tm.bad_draws==0;
      warns(1,4) = warn;
   end;
   %
   if (warn>0)&(tm.bad_draws==0);
      %
      % need to close any open dialogs and then return
      %
      if burn_in==1;
         %
         % close down the burn_in dialog
         %
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
      else;
         %
         % Close the progress dialog
         %
         set(mywait,'UserData','done');
         close(mywait);
         drawnow;
      end;
      return;
   elseif warn==0;
      alpha = new_alpha;
   else;
      bad_draw = 1;
   end;
   %
   % draw from "marginal" alpha
   %
   [new_alpha_n,warn_n] = alpha_marg_norm_rnd(C_0,C_1,tm.n,tm.r,Omega_n,beta_n,curr_ini.symmetric);
   if warn_n==0;
      alpha_n = new_alpha_n;
   else;
      alpha_n = alpha;
   end;
   %
   % Generate draw from the full conditional posterior of beta
   %
   if tm.beta_rest.tot_free>0;
      [new_beta,warn] = beta_rnd(Z0,Z1,Z2,D,h_vec,H_mat,tm.n+tm.q1+tm.dcoint,tm.r,Omega,delta,Gamma,alpha,tm.lambda_alpha,curr_ini.symmetric,tm.prior_inf_alpha);
   else;
      warn = 0;
      new_beta = beta;
   end;
   if tm.bad_draws==0;
      warns(1,5) = warn;
   end;
   if (warn>0)&(tm.bad_draws==0);
      %
      % need to close any open dialogs and then return
      %
      if burn_in==1;
         %
         % close down the burn_in dialog
         %
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
      else;
         %
         % Close the progress dialog
         %
         set(mywait,'UserData','done');
         close(mywait);
         drawnow;
      end;
      return;
   elseif warn==0;
      beta = new_beta;
   else;
      bad_draw = 1;
   end;
   %
   % draw from "marginal" beta
   %
   if tm.beta_rest.tot_free>0;
      [new_beta_n,warn_n] = beta_marg_norm_rnd(C_0,C_1,h_vec,H_mat,tm.n+tm.q1+tm.dcoint,tm.r,Omega_n,alpha_n,curr_ini.symmetric);
   else;
      warn_n = 0;
      new_beta_n = beta_n;
   end;
   if warn_n==0;
      beta_n = new_beta_n;
   else;
      beta_n = beta;
   end;
   %
   % compute new residuals
   %
   epsilon = Z0;
   if isempty(tm.Z2)==0;
      epsilon = epsilon-(Psi*tm.Z2);
   end;
   epsilon = epsilon-(alpha*beta'*Z1);
   %
   % check if burn_in phase is over
   %
   if (draw>tm.burn_in)&(bad_draw==0);
      %
      % check if we can begin saving draws
      %
      e_values = companionrest(alpha,Psi,beta,tm.p,tm.n,tm.d);
      e_values = sort(abs(e_values));
      for i1=1:size(e_values,1);
         max_evalue = e_values(size(e_values,1)-i1+1,1);
         if strcmp(num2str(max_evalue,'%1.10f'),'1.0000000000')==0;
            break;
         end;
      end;
      allow_save = 1;
      if (tm.discard_explosive==1)&(max_evalue>1);
         allow_save = 0;
      end;
      if allow_save==1;
         if save_freq==tm.save_freq;
            save_freq = 1;
            %
            % save the draws from the full posterior in a temporary structure
            %
            gibbs_results.posterior(save_draws).delta = delta;
            gibbs_results.posterior(save_draws).Gamma = Gamma;
            gibbs_results.posterior(save_draws).Psi = Psi;
            gibbs_results.posterior(save_draws).Omega = Omega;
            gibbs_results.posterior(save_draws).alpha = alpha;
            gibbs_results.posterior(save_draws).beta = beta;
            gibbs_results.posterior(save_draws).epsilon = epsilon;
            gibbs_results.posterior(save_draws).max_evalue = max_evalue;
            gibbs_results.posterior(save_draws).alpha_n = alpha_n;
            gibbs_results.posterior(save_draws).beta_n = beta_n;
            gibbs_results.posterior(save_draws).Omega_n = Omega_n;
            save_draws = save_draws+1;
         else;
            save_freq = save_freq+1;
         end;
      end;
      %
      if save_draws>tm.save_draws;
         out.gibbs.draws = draw;
         out.gibbs.burn_in = tm.burn_in;
         out.gibbs.real_draws = draw-tm.burn_in;
         out.gibbs.discard_draws = draw-tm.burn_in-tm.save_draws;
         out.gibbs.discard_explosive_draws = draw-tm.burn_in-(tm.save_freq*tm.save_draws);
         stop_run = 1;
      end;
   end;
   %
   % increase the number of draws
   %
   if draw==tm.burn_in;
      if burn_in==1;
         %
         % close down the burn_in dialog
         %
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
         burn_in = 0;
         show_prog = 1;
      end;
   end;
   if bad_draw==0;
      num_baddraws = 0;
      %
      % store all beta results
      %
      if tm.beta_rest.tot_free>0;
         gibbs_draws.psi(:,draw-num_baddraws) = inverse(H_mat'*H_mat)*H_mat'*(vec(beta)-h_vec);
         gibbs_draws.psi_n(:,draw-num_baddraws) = inverse(H_mat'*H_mat)*H_mat'*(vec(beta_n)-h_vec);
      end;
      gibbs_draws.alpha(:,draw-num_baddraws) = vec(alpha);
      gibbs_draws.alpha_n(:,draw-num_baddraws) = vec(alpha_n);
      gibbs_draws.Omega(:,draw-num_baddraws) = vech(Omega);
      gibbs_draws.Omega_n(:,draw-num_baddraws) = vech(Omega_n);
      if isempty(D)==0;
         gibbs_draws.delta(:,draw-num_baddraws) = vec(delta);
      end;
      if isempty(Z2)==0;
         gibbs_draws.Gamma(:,draw-num_baddraws) = vec(Gamma);
      end;
   else;
      alpha = old_alpha;
      beta = old_beta;
      Omega = old_Omega;
      Gamma = old_Gamma;
      delta = old_delta;
      drawnow;
      num_baddraws = num_baddraws+1;
      bad_draw = 0;
      if num_baddraws>=1000;
         %
         % need to close any open dialogs and then return
         %
         if burn_in==1;
            %
            % close down the burn_in dialog
            %
            set(waitf.text,'UserData','done');
            delete(mywait);
            drawnow;
         else;
            %
            % Close the progress dialog
            %
            set(mywait,'UserData','done');
            close(mywait);
            drawnow;
         end;
         txt = 'The maximum number of 1000 bad draws in a row has been reached. Gibbs sampling is aborted.';
         about(txt,'information','Too many bad draws...',120,400);
         abort = 'cancel';
         return;
      end;
   end;
   draw = draw+1;
end;
%
% Close the progress dialog
%
set(mywait,'UserData','done');
close(mywait);
drawnow;
if strcmp(abort,'cancel')==1;
   out = [];
   setlogtext(strvcat('Gibbs sampling for beta restrictions aborted...',' '));
   return;
else;
   setlogtext(strvcat('Gibbs sampling completed for beta restrictions...',['Completed at: ' datestr(now,14)]));
end;
%
% save the draws for rank r to file with structure gibbs_results
%
setlogtext('Saving output to file...');
%
file = [curr_ini.simulatedir tm.modelfile '-beta-' num2str(tm.r) '-gibbs-' num2str(tm.scale_endo,'%0.4f') '-' tm.determodel num2str(tm.burn_in,'%0.0f') '.' num2str(tm.save_draws,'%0.0f') '.' num2str(tm.save_freq,'%0.0f') '.' num2str(tm.discard_explosive,'%0.0f') '-' num2str(tm.prior_inf_shortrun,'%0.0f') '.' num2str(tm.prior_inf_deter,'%0.0f') '-' num2str(tm.lambda_alpha,'%0.3f')];
if tm.prior_inf_omega==1;
   if tm.amat_type==1;
      file = [file '-1'];
   else;
      file = [file '-0.' num2str(tm.lambda_a,'%0.2f') '.' num2str(tm.q_parm,'%0.0f')];
   end;
end;
if tm.prior_inf_shortrun==1;
   file = [file '.' num2str(tm.lambda_b,'%0.3f') '.' num2str(tm.lambda_theta,'%0.3f') '.' num2str(tm.lambda_l,'%0.3f') '.' num2str(tm.lambda_e,'%0.3f')];
end;
if tm.prior_inf_deter==1;
   file = [file '.' num2str(tm.lambda_d,'%0.3f')];
end;
file = [file '-' datestr(now,1) '-' strrep(datestr(now,13),':','') '.mat'];
save(file,'gibbs_results','gibbs_draws');
filename = file;
%
% compute posterior mode for rank r
%
%setlogtext('Computing the posterior mode...');
%
%  An alternative: not implemented as this stage
%
%out.posterior_mode = posterior_mode(tm,curr_ini,tm.r,tm.beta_rest.tot_free,A,q,D_sigma,G_sigma,tm.prior_inf_alpha,tm.prior_inf_omega,1);
%
%out.posterior_mode = posterior_beta_mode(gibbs_results,tm,tm.r);
%
% Compute x% confidence bands from full posterior
%
setlogtext(strvcat('Computing the posterior median...',['Computing ' num2str(tm.cbs,'%0.0f') '% confidence bands...']));
[out.confidence_bands,out.posterior_median] = posterior_confidence_bands(tm,gibbs_results,tm.r);
if tm.beta_rest.dfbeta==0;
   %
   % compute the posterior mean cointegration space estimator of beta
   % with cointegration space variation estimate
   %
   % This is only meaningful when beta is exactly identified
   %
   setlogtext('And the posterior mean cointegration space estimator...');
   out.pmcs = pmcs(gibbs_results,tm,tm.r);
else;
   %
   % compute posterior means
   %
   setlogtext('And the posterior mean...');
   out.posterior_mean = posterior_mean(gibbs_results,tm,tm.r);
end;

%
% end of gibbs_beta.m
%
