%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for settings GUI colors             %
%                                                                %
%          Function: gui_colors_fcn                              %
%                                                                %
%          Input:                                                %
%                       selector: case value string              %
%                       curr_ini: var.ini settings               %
%                       name: figure name                        %
%                       axesbox_name: name for frame             %
%                       height: height of GUI                    %
%                       width: width of GUI                      %
%                       color_mat: px3 matrix with colors        %
%                       text_mat: p dimensional text matrix with %
%                          descriptions of which colors are used %
%                          for what                              %
%                                                                %
%          Output:                                               %
%          	            h: handle to figure                      %
%                                                                %
%          This version:        April 4, 2006                    %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function h = gui_colors_fcn(selector,curr_ini,name,axesbox_name,height,width,color_mat,text_mat)

if strcmp(selector,'init')==1;
   tm.ini = curr_ini;
   tm.realscrsz = get(0,'ScreenSize');
   tm.color_mat = color_mat;
   tm.orig_color_mat = color_mat;
else;
   colors_gui = findobj('Type','figure','Tag','GUIColorsDlg');
   gui_controls = get(colors_gui,'UserData');
   tm = get(gui_controls.apply,'UserData');
   curr_ini = tm.ini;
end;

switch selector;
   case 'init';
      colors_gui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','gui_colors_fcn.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(tm.realscrsz(3)-width)/2 (tm.realscrsz(4)-height)/2 width height], ...
         'Tag','GUIColorsDlg', ...
         'Visible','off', ...
         'Resize','off', ...
         'Name',name, ...
         'NumberTitle','off', ...
         'WindowStyle','modal', ...
         'CloseRequestFcn','gui_colors_fcn done', ...
         'ToolBar','none');

      if matlabnumber>=7.0;
         set(colors_gui,'DockControl','off');
      end;

      axesbox([2 2 width-2 height-10],axesbox_name,85,[0.5 1],'on',curr_ini);

      %
      % setting up color buttons and text
      %
      
      gui_controls = [];

      for i=1:size(tm.color_mat,1);

         btn = uicontrol('Units','pixels', ...
            'BackgroundColor',color_mat(size(tm.color_mat,1)-i+1,1:3), ...
            'Position',[30 60+(30*(i-1)) 100 25], ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'CallBack','gui_colors_fcn setcolor', ...
            'Enable','on', ...
            'Tag',['ColorButton' num2str(size(tm.color_mat,1)-i+1,'%0.0f')]);
         
         txt = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[160 60+(30*(i-1)) width-170 20], ...
            'Style','text', ...
            'String',strtrim(text_mat(size(tm.color_mat,1)-i+1,:)), ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'HorizontalAlignment','left', ...
            'Tag',['ColorText' num2str(size(tm.color_mat,1)-i+1,'%0.0f')]);
         if i==1;
            gui_controls.icon = txt;
         end;
         gui_controls = setfield(gui_controls,['button' num2str(size(tm.color_mat,1)-i+1,'%0.0f')],btn);

      end;

      gui_controls.done = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-295 20 90 20], ...
         'String','OK', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','gui_colors_fcn done', ...
         'Enable','on', ...
         'UserData','waiting', ...
         'Tag','Done');

      gui_controls.cancel = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-200 20 90 20], ...
         'String','Cancel', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','gui_colors_fcn cancel', ...
         'Enable','on', ...
         'Tag','Cancel');

      gui_controls.apply = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-105 20 90 20], ...
         'String','Apply', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','gui_colors_fcn apply', ...
         'UserData',tm, ...
         'Enable','off', ...
         'Tag','Apply');

      set(colors_gui,'UserData',gui_controls,...
         'HandleVisibility','callback');

   case 'setcolor'
      %
      % get the current control
      %
      curr_handle = gcbo;
      curr_tag = get(curr_handle,'Tag');
      tag_num = mystr2num(strtrim(strrep(curr_tag,'ColorButton','')));
      curr_color = get(curr_handle,'BackgroundColor');
      txt_handle = findobj(colors_gui,'Type','uicontrol','Style','text','Tag',['ColorText' num2str(tag_num,'%0.0f')]);
      curr_txt = get(txt_handle,'String');
      new_color = uisetcolor(curr_color,['Set ' curr_txt]);
      %
      % check if we have a new color
      %
      if (isnumeric(new_color)==1)&(size(new_color,2)==3);
         if max(abs(new_color-curr_color))>0;
            %
            % we have a new color
            %
            set(curr_handle,'BackgroundColor',new_color);
            set(gui_controls.apply,'Enable','on');
         end;
      end;
   case 'cancel'
      tm.color_mat = tm.orig_color_mat;
      for i=1:size(tm.color_mat,1);
         set(getfield(gui_controls,['button' num2str(i,'%0.0f')]),'BackgroundColor',tm.color_mat(i,1:3));
      end;
      set(gui_controls.apply,'Enable','off','UserData',tm);
   case 'apply'
      for i=1:size(tm.color_mat,1);
         tm.color_mat(i,1:3) = get(getfield(gui_controls,['button' num2str(i,'%0.0f')]),'BackgroundColor');
      end;
      set(gui_controls.apply,'Enable','off','UserData',tm);
   case 'done'
      set(gui_controls.done,'UserData','done');
end;

if strcmp(selector,'init')==1;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(colors_gui,'Name') ' ' fix_filepath([pwd '\icons\colors.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(gui_controls.icon,'UserData',pid);
      end;
   end;
   %
   set(colors_gui,'Visible','on');
   drawnow;
   drawnow;
   if (iswinnt==1)&(iscompiled==1)&(matlabnumber<7);
      drawnow;
      prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(colors_gui,'Name') ' 3'];
      dos(prog);
      drawnow;
   elseif matlabnumber>=7;
      uicontrol(gui_controls.done);
   end;
   waitfor(gui_controls.done,'UserData','done');
end;

if nargout==1;
   h = colors_gui;
end;



%
% end of gui_colors_fcn.m
%
