%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for selecting default values        %
%          for the hyperparameters of the variances in the       %
%          prior distribution of the short-run dynamics          %
%                                                                %
%          Function: lambda_dlg                                  %
%                                                                %
%          Input:                                                %
%                       selector: case value string              %
%                       curr_ini: var.ini settings               %
%                                                                %
%          Output:                                               %
%          	            h: handle to figure                      %
%                                                                %
%          This version:        March 16, 2006                   %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function h = lambda_dlg(selector,curr_ini)

if strcmp(selector,'init')==1;
   tm.ini = curr_ini;
   tm.lambda_b = curr_ini.lambda_b;
   tm.lambda_theta = curr_ini.lambda_theta;
   tm.lambda_l = curr_ini.lambda_l;
   tm.lambda_e = curr_ini.lambda_e;
   tm.old.lambda_b = curr_ini.lambda_b;
   tm.old.lambda_theta = curr_ini.lambda_theta;
   tm.old.lambda_l = curr_ini.lambda_l;
   tm.old.lambda_e = curr_ini.lambda_e;
   tm.realscrsz = get(0,'ScreenSize');
   width = 500;
   height = 330;
else;
   lambda_gui = findobj('Type','figure','Tag','LambdaDlg');
   lambda_controls = get(lambda_gui,'UserData');
   tm = get(lambda_controls.apply,'UserData');
   curr_ini = tm.ini;
end;

switch selector;
   case 'init';
      lambda_gui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','lambda_dlg.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(tm.realscrsz(3)-width)/2 (tm.realscrsz(4)-height)/2 width height], ...
         'Tag','LambdaDlg', ...
         'Visible','off', ...
         'Resize','off', ...
         'Name','Hyperparameters - Prior for Short-run Dynamics', ...
         'NumberTitle','off', ...
         'WindowStyle','modal', ...
         'CloseRequestFcn','lambda_dlg done', ...
         'ToolBar','none');

      if matlabnumber>=7.0;
         set(lambda_gui,'DockControl','off');
      end;

      axesbox([2 2 width-2 height-10],'Short-run Dynamics',92,[0.5 1]);

      %
      % GUI Header
      %

      mycons = getstoredimages;
      header_txt = 'Hyperparameters for Prior Distribution';
      desc_txt = 'The prior distribution for the parameters on the short-run dynamics is Gaussian with zero mean, zero covariances, and variances determined by the formula presented in the help file. Press the "Apply" button to save your changes, the "Cancel" button to reset the values, and the "OK" button to finish.';
      lambda_controls.icon = dialog_header_fcn([16 height-109 width-30 85],mirrorimage(maketrans(mycons.lambdabig_image,[160 160 164],[1 1 1])),header_txt,desc_txt);
      lambda_controls.icon = lambda_controls.icon(1,1);
      
      axesbox([16 55 width-30 height-180],'Hyperparameters',82,[0.5 1]);
      
      %
      % create the header text and popup controls
      %
      
      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[30 height-170 165 20], ...
         'Style','text', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'HorizontalAlignment','left', ...
         'String','Baseline shrinkage:', ...
         'Tag','LambdaBaselineText');

      lambda_controls.lambda_b = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[width-230 height-165 200 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Visible','on', ...
         'Value',1, ...
         'Callback','lambda_dlg baseline', ...
         'String','0.01|0.02|0.03|0.04|0.05|0.06|0.07|0.08|0.09|0.10|0.15|0.20|0.25|0.30|0.35|0.40|0.45|0.50|0.55|0.60|0.65|0.70|0.75|0.80|0.85|0.90|0.95|1.00|1.10|1.20|1.30|1.40|1.50|1.60|1.70|1.80|1.90|2.00|2.10|2.20|2.30|2.40|2.50|2.60|2.70|2.80|2.90|3.00|3.10|3.20|3.30|3.40|3.50|3.60|3.70|3.80|3.90|4.00|4.10|4.20|4.30|4.40|4.50|4.60|4.70|4.80|4.90|5.00|5.25|5.50|5.75|6.00|6.25|6.50|6.75|7.00|7.25|7.50|7.75|8.00|8.25|8.50|8.75|9.00|9.25|9.50|9.75|10.00|11.00|12.00|13.00|14.00|15.00|16.00|17.00|18.00|19.00|20.00|21.00|22.00|23.00|24.00|25.00|26.00|27.00|28.00|29.00|30.00|35.00|40.00|45.00|50.00|55.00|60.00|65.00|70.00|75.00|80.00|85.00|90.00|95.00|100.00', ...
         'Tag','LambdaBaselinePopup');

      b_str = get(lambda_controls.lambda_b,'String');
      for i=1:size(b_str,1);
         bs_val = mystr2num(strtrim(b_str(i,:)));
         if curr_ini.lambda_b==bs_val;
            b_val = i;
            break;
         end;
      end;

      set(lambda_controls.lambda_b,'Value',b_val);
         
      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[30 height-200 165 20], ...
         'Style','text', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'HorizontalAlignment','left', ...
         'String','Lag length shrinkage:', ...
         'Tag','LambdaLagText');


      lambda_controls.lambda_l = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[width-230 height-195 200 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Visible','on', ...
         'Value',round(2*curr_ini.lambda_l), ...
         'Callback','lambda_dlg lag', ...
         'String','0.5|1.0|1.5|2.0|2.5|3.0|3.5|4.0|4.5|5.0|5.5|6.0|6.5|7.0|7.5|8.0|8.5|9.0|9.5|10.0', ...
         'Tag','LambdaLagPopup');

      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[30 height-230 165 20], ...
         'Style','text', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'HorizontalAlignment','left', ...
         'String','Off-diagonal/correlation shrinkage:', ...
         'Tag','LambdaOffDiagonalText');

      lambda_controls.lambda_theta = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[width-230 height-225 200 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Visible','on', ...
         'Value',1, ...
         'Callback','lambda_dlg offdiag', ...
         'String','-0.95|-0.90|-0.85|-0.80|-0.75|-0.70|-0.65|-0.60|-0.55|-0.50|-0.45|-0.40|-0.35|-0.30|-0.25|-0.20|-0.15|-0.10|-0.05|0.00|0.05|0.10|0.15|0.20|0.25|0.30|0.35|0.40|0.45|0.50|0.55|0.60|0.65|0.70|0.75|0.80|0.85|0.90|0.95', ...
         'Tag','LambdaOffDiagonalPopup');

      t_str = get(lambda_controls.lambda_theta,'String');
      for i=1:size(t_str,1);
         ts_val = mystr2num(strtrim(t_str(i,:)));
         if curr_ini.lambda_theta==ts_val;
            t_val = i;
            break;
         end;
      end;
      
      set(lambda_controls.lambda_theta,'Value',t_val);

      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[30 height-260 165 20], ...
         'Style','text', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'HorizontalAlignment','left', ...
         'String','Exogeneity shrinkage:', ...
         'Tag','LambdaExogeneityText');

      lambda_controls.lambda_e = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[width-230 height-255 200 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Visible','on', ...
         'Value',1, ...
         'Callback','lambda_dlg exogeneity', ...
         'String','0.001|0.01|0.02|0.03|0.04|0.05|0.06|0.07|0.08|0.09|0.10|0.15|0.20|0.25|0.30|0.35|0.40|0.45|0.50|0.55|0.60|0.65|0.70|0.75|0.80|0.85|0.90|0.95|1.00', ...
         'Tag','LambdaExogeneityPopup');

      e_str = get(lambda_controls.lambda_e,'String');
      for i=1:size(e_str,1);
         es_val = mystr2num(strtrim(e_str(i,:)));
         if curr_ini.lambda_e==es_val;
            e_val = i;
            break;
         end;
      end;

      set(lambda_controls.lambda_e,'Value',e_val);

      %
      % Buttons
      %

      lambda_controls.helpbutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[16 20 20 20], ...
         'String','?', ...
         'TooltipString','Open the help file', ...
         'FontWeight','bold', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'ForegroundColor',[0.5 0 0], ...
         'Enable','on', ...
         'Callback','help_fcn(''PriorDistributions'');', ...
         'Tag','HelpButton');

      lambda_controls.done = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-295 20 90 20], ...
         'String','OK', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','lambda_dlg done', ...
         'Enable','on', ...
         'UserData','waiting', ...
         'Tag','Done');

      lambda_controls.cancel = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-200 20 90 20], ...
         'String','Cancel', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','lambda_dlg cancel', ...
         'Enable','on', ...
         'Tag','Cancel');

      lambda_controls.apply = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-105 20 90 20], ...
         'String','Apply', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','lambda_dlg apply', ...
         'UserData',tm, ...
         'Enable','off', ...
         'Tag','Apply');

      set(lambda_gui,'UserData',lambda_controls,...
         'HandleVisibility','callback');

   case 'baseline'
      b_val = get(lambda_controls.lambda_b,'Value');
      b_str = get(lambda_controls.lambda_b,'String');
      newlambda_b = mystr2num(strtrim(b_str(b_val,:)));
      if abs(newlambda_b-tm.lambda_b)>0;
         tm.lambda_b = newlambda_b;
         set(lambda_controls.apply,'Enable','on','UserData',tm);
      end;
   case 'lag'
      newlambda_l = get(lambda_controls.lambda_l,'Value')/2;
      if abs(newlambda_l-tm.lambda_l)>0;
         tm.lambda_l = newlambda_l;
         set(lambda_controls.apply,'Enable','on','UserData',tm);
      end;
   case 'offdiag'
      t_val = get(lambda_controls.lambda_theta,'Value');
      t_str = get(lambda_controls.lambda_theta,'String');
      newlambda_theta = mystr2num(strtrim(t_str(t_val,:)));
      if abs(newlambda_theta-tm.lambda_theta)>0;
         tm.lambda_theta = newlambda_theta;
         set(lambda_controls.apply,'Enable','on','UserData',tm);
      end;
   case 'exogeneity'
      e_val = get(lambda_controls.lambda_e,'Value');
      e_str = get(lambda_controls.lambda_e,'String');
      newlambda_e = mystr2num(strtrim(e_str(e_val,:)));
      if abs(newlambda_e-tm.lambda_e)>0;
         tm.lambda_e = newlambda_e;
         set(lambda_controls.apply,'Enable','on','UserData',tm);
      end;
   case 'cancel'
      tm.lambda_b = tm.old.lambda_b;
      tm.lambda_theta = tm.old.lambda_theta;
      tm.lambda_l = tm.old.lambda_l;
      tm.lambda_e = tm.old.lambda_e;
      curr_ini.lambda_b = tm.lambda_b;
      curr_ini.lambda_theta = tm.lambda_theta;
      curr_ini.lambda_l = tm.lambda_l;
      curr_ini.lambda_e = tm.lambda_e;
      tm.ini = curr_ini;
      set(lambda_controls.apply,'Enable','off','UserData',tm);
      %
      % Now we fix the controls
      %
      b_str = get(lambda_controls.lambda_b,'String');
      for i=1:size(b_str,1);
         bs_val = mystr2num(strtrim(b_str(i,:)));
         if curr_ini.lambda_b==bs_val;
            b_val = i;
            break;
         end;
      end;
      set(lambda_controls.lambda_b,'Value',b_val);
      %
      set(lambda_controls.lambda_l,'Value',round(2*curr_ini.lambda_l));
      %
      t_str = get(lambda_controls.lambda_theta,'String');
      for i=1:size(t_str,1);
         ts_val = mystr2num(strtrim(t_str(i,:)));
         if curr_ini.lambda_theta==ts_val;
            t_val = i;
            break;
         end;
      end;
      set(lambda_controls.lambda_theta,'Value',t_val);
      %
      e_str = get(lambda_controls.lambda_e,'String');
      for i=1:size(e_str,1);
         es_val = mystr2num(strtrim(e_str(i,:)));
         if curr_ini.lambda_e==es_val;
            e_val = i;
            break;
         end;
      end;
      set(lambda_controls.lambda_e,'Value',e_val);
   case 'apply'
      curr_ini.lambda_b = tm.lambda_b;
      curr_ini.lambda_theta = tm.lambda_theta;
      curr_ini.lambda_l = tm.lambda_l;
      curr_ini.lambda_e = tm.lambda_e;
      tm.ini = curr_ini;
      set(lambda_controls.apply,'Enable','off','UserData',tm);
   case 'done'
      set(lambda_controls.done,'UserData','done');
end;

if strcmp(selector,'init')==1;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(lambda_gui,'Name') ' ' fix_filepath([pwd '\icons\lambda_params.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(lambda_controls.icon,'UserData',pid);
      end;
   end;
   %
   set(lambda_gui,'Visible','on');
   drawnow;
   drawnow;
   if (iswinnt==1)&(iscompiled==1)&(matlabnumber<7);
      drawnow;
      prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(lambda_gui,'Name') ' 3'];
      dos(prog);
      drawnow;
   elseif matlabnumber>=7;
      uicontrol(lambda_controls.done);
   end;
   waitfor(lambda_controls.done,'UserData','done');
end;

if nargout==1;
   h = lambda_gui;
end;

%
% end of lambda_dlg.m
%
