%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI for estimating a structural VAR model      %
%          with cointegration restrictions and identifying       %
%          restrictions on the contemporaneous and the long      %
%          run responses                                         %
%                                                                %
%          Function: maindlg                                     %
%                                                                %
%          Input:                                                %
%                        selector: optional parameter            %
%                            can be a filename for a stored      %
%                            model or command line switches      %
%                        opt: string with options                %
%                                                                %
%          Output:                                               %
%          	             Graphical User Interface                %
%                                                                %
%          First version:       July 4, 2006                     %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function mygui = maindlg(selector,opt)

%#function runmaindlg_fcn moveaxis_var textgui_resize_fcn printgui_resize_fcn show_main_status_fcn change_context_menus show_pdf show_links run_links link_pointer killwinpid killrestpid about_help_fcn textgui_copy_fcn center_figure_fcn

%
% checking if selector is a handle. If so then set maingui to
% selector
%

fig_file = '';
if ishandle(selector)==1;
   maingui = selector;
   selector = 'runnow';
elseif (isfield(selector,'maingui')==1)&(ishandle(selector.maingui)==1);
   maingui = selector.maingui;
   fig_file = selector.fig_file;
   selector = 'figmode';
elseif (strcmp(lower(getext(selector)),'.fig')==1)|(strcmp(selector,'figure')==1);
   fig_file = selector;
   selector = 'init';
end;

%
% checking for options
%

if nargin==0;
   selector = '';
   input1 = 0;
   options = '';
elseif nargin==1;
   if size(findstr('--',selector),1)==1;
      input1 = 0;
      options = selector;
      selector = '';
   else;
      if strcmp(selector,'init')==1;
         input1 = 0;
         selector = '';
      else;
         input1 = 1;
      end;
      options = '';
   end;
else;
   if size(findstr('--',selector),1)==1;
      checkopt = selector;
      selector = opt;
      options = checkopt;
      input1 = 2;
   else;
      options = opt;
      input1 = 2;
   end;
end;

if nargin>0;
   if size(findstr('.',selector),1)==1;
      if fileexist(selector)==0;
         input1 = 0;
         selector = '';
      end;
   end;
end;

%
% Set screen size directly instead of using
% get(0,'ScreenSize')! Compute adjustment
% factor for figure to appear in the right place
%

scrsz = [1 1 1024 768];
realscrsz = get(0,'ScreenSize');
adjscrsz = realscrsz(4)-768;

%
% initializing
%

openmodel = 0;
if (input1==0)|((fileexist(selector)==1)&(strcmp(getext(selector),'.var')));
   status_str = '';
   %
   % check if iswinnt.txt has been created
   %
   if fileexist('iswinnt.txt')==0;
      mytemp_var = iswinnt;
   end;
   openmodel = 1;
   model_var.newoutputpath = 0;
   %
   % read the var.ini file if it exists
   %
   var_ini = initialize_inifile;
   %
   % check ini-file and fix if necessary
   %
   fixvarini(size(fieldnames(var_ini),1));
   %
   % read ini-file
   %
   [read_status,var_ini] = read_inifile;
   if read_status==1;
      var_ini = initialize_inifile;
   end;
   %
   % reading button images into image structure
   %
   button_images = read_images;
   %
   printenable = 'off';
   %
   if strcmp(var_ini.helpexe,'')==1;
      helpenable = 'off';
   else;
      helpenable = 'on';
   end;
   if strcmp(selector,'')==1;
      if var_ini.uselastfile==1;
         if fileexist(var_ini.lastfile)==1;
            input1 = 1;
            selector = var_ini.lastfile;
         end;
      end;
   end;
   model_var.endosheet = '';
   model_var.exo1sheet = '';
   model_var.exo0sheet = '';
   model_var.detersheet = '';
end;

%
% defining string variables, later to be set via GUI
%

if input1==0;
   selector = 'init';
   model_var.spectest = [0 0 0 0];
   model_var.modeltype = [1 0];
   model_var.seasonal = [0 1];
   model_var.freq = '';
   model_var.runvar = 0;
   %
   model_var.newp = 1;
   model_var.lagexo = 1;
   model_var.newh = 40;
   model_var.newc = 46;
   model_var.endofile = pwd;
   runenable = 'off';
   model_var.modelsdir = '';
   model_var.exo1file = '';
   model_var.exo0file = '';
   model_var.deterfile = '';
   model_var.cointvalue = 1;
   model_var.evars = '';
   model_var.xvars1 = '';
   model_var.xvars0 = '';
   model_var.deter = '';
   model_var.beginyear = '';
   model_var.beginperiod = '';
   model_var.endyear = '';
   model_var.endperiod = '';
   model_var.subbeginyear = '';
   model_var.subbeginperiod = '';
   model_var.subendyear = '';
   model_var.subendperiod = '';
   model_var.nameinput = '';
   model_var.deterselect = [1 0 0 0];
   model_var.shocks = '';
   model_var.scale_endo = 1;
   if strcmp(var_ini.reopenlist,'')==0;
      [model_var.reopenfile,var_ini.reopenlist] = fixlist(var_ini.reopenlist);
      reorderenable = 'on';
   else;
      model_var.reopenfile = '';
      reorderenable = 'off';
   end;
   lagstring = '1';
   for i = 2:var_ini.maxlag;
      lagstring = strcat(lagstring,'|',num2str(i));
   end;
   respstring = '1';
   for i=2:var_ini.maxresp;
      respstring = strcat(respstring,'|',num2str(i));
   end;
   if model_var.newh>var_ini.maxresp;
      model_var.newh = var_ini.maxresp;
   end;
   model_var.basedir = model_var.modelsdir;
   numchar = size(model_var.basedir,2);
   if numchar>=1;
      model_var.basedir = model_var.basedir(1,1:numchar-1);
   end;
   i = numchar-1;
   while i>=1;
      if strcmp(model_var.basedir(1,i),'\')==1;
         model_var.basedir = model_var.basedir(1,1:i-1);
         i = 0;
      elseif strcmp(model_var.basedir(1,i),'/')==1;
         model_var.basedir = model_var.basedir(1,1:i-1);
         i = 0;
      else;
         i = i-1;
      end;
   end;
   mypwd = pwd;
   if strcmp(mypwd(1,1),'/')==1;
      model_var.inputfile = strcat(pwd,'/model.var');
      if var_ini.dirstructure==1;
         model_var.outputfile = strcat(pwd,'/output.txt');
      else;
         model_var.outputfile = strcat(pwd,'/results/output.txt');
      end;
   else;
      model_var.inputfile = strcat(pwd,'\model.var');
      if var_ini.dirstructure==1;
         model_var.outputfile = strcat(pwd,'\output.txt');
      else;
         model_var.outputfile = strcat(pwd,'\results\output.txt');
      end;
   end;
   model_var.newdeterselect = model_var.deterselect;
   model_var.newmodeltype = model_var.modeltype;
   model_var.newseasonal = model_var.seasonal;
   oldmodel_var = model_var;
   if strcmp(runenable,'off')==1;
      bgclr = get(0,'defaultuicontrolbackgroundcolor');
      brw = button_images.browsedisable;
   else;
      bgclr = [1 1 1];
      brw = button_images.browse;
   end;
   status_str = ['Structural VAR, version ' num2str(myvers,'%0.2f')];
elseif ((input1>0)&(openmodel==1))==1;
   model_var.nameinput = '';
   model_var.runvar = 0;
   model_var.lagexo = 0;
   model_var.scale_endo = 1;
   %
   % check if the file has the extension .var
   %
   status_str = 'Ready';
   if strcmp(getext(selector),'.var')==1;
      %
      % check to make sure data files exist
      %
      badfile = 0;
      mv = model_var;
      mv.inputfile = selector;
      if fileexist(mv.inputfile)==1;
         [mv,renable] = load_model_fcn(mv);
         check_datafile = [];
         if fileexist(mv.endofile)==0;
            check_datafile.endogenous = mv.endofile;
         end;
         if strcmp(strtrim(lower(mv.exo1file)),'')==0;
            if fileexist(mv.exo1file)==0;
               check_datafile.exogenousi1 = mv.exo1file;
            end;
         end;
         if strcmp(strtrim(lower(mv.exo1file)),'')==0;
            if fileexist(mv.exo1file)==0;
               check_datafile.exogenousi0 = mv.exo1file;
            end;
         end;
         if strcmp(strtrim(lower(mv.deterfile)),'')==0;
            if fileexist(mv.deterfile)==0;
               check_datafile.deterministic = mv.deterfile;
            end;
         end;
         %
         % prepare error message if needed
         %
         if isempty(check_datafile)==0;
            txt = ['The model file "' getname(mv.inputfile) '" contains references to data files that don''t exist. Specifically, the following files could not be found:'];
            txt_add = '';
            if isfield(check_datafile,'endogenous')==1;
               txt_add = strvcat(txt_add,['     Endogenous - ' check_datafile.endogenous]);
            end;
            if isfield(check_datafile,'exogenousi1')==1;
               txt_add = strvcat(txt_add,['     Exogenous I(1) -' check_datafile.exogenousi1]);
            end;
            if isfield(check_datafile,'exogenousi0')==1;
               txt_add = strvcat(txt_add,['     Exogenous I(0) - ' check_datafile.exogenousi0]);
            end;
            if isfield(check_datafile,'deterministic')==1;
               txt_add = strvcat(txt_add,['     Deterministic - ' check_datafile.deterministic]);
            end;
            txt = strvcat(txt,' ',txt_add);
            about(txt,'error','Error Loading Model',160,600);
            badfile = 1;
         end;
      else;
         badfile = 1;
      end;
      %
      % open model file if it has been OK'ed
      %
      if badfile==0;
         if strcmp(var_ini.reopenlist,'')==0;
            [model_var.reopenfile,var_ini.reopenlist] = fixlist(var_ini.reopenlist);
            if strcmp(getext(selector),'.var')==1;
               if isempty(findstr(selector,var_ini.reopenlist))==1;
                  if size(model_var.reopenfile,1)>=10;
                     model_var.reopenfile = model_var.reopenfile(1:9,:);
                  end;
                  var_ini.reopenlist = [selector '|' var_ini.reopenlist];
                  model_var.reopenfile = strvcat(selector,model_var.reopenfile);
               end;
            end;
            reorderenable = 'on';
         else;
            if strcmp(getext(selector),'.var')==1;
               model_var.reopenfile = [selector '|'];
            end;
            reorderenable = 'off';
         end;
         %
         model_var.inputfile = selector;
         mypwd = pwd;
         if strcmp(mypwd(1,1),'/')==1;
            if var_ini.dirstructure==1;
               model_var.outputfile = strcat(pwd,'/output.txt');
            else;
               model_var.outputfile = strcat(pwd,'/results/output.txt');
            end;
         else;
            if var_ini.dirstructure==1;
               model_var.outputfile = strcat(pwd,'\output.txt');
            else;
               model_var.outputfile = strcat(pwd,'\results\output.txt');
            end;
         end;
         %
         % read var-file
         %
         if fileexist(model_var.inputfile)==1;
            model_var.nameinput = selector;
            [model_var,runenable] = load_model_fcn(model_var);
         end;
         %
         model_var.basedir = model_var.modelsdir;
         numchar = size(model_var.basedir,2);
         if numchar>=1;
            model_var.basedir = model_var.basedir(1,1:numchar-1);
         end;
         i = numchar-1;
         while i>=1;
            if strcmp(model_var.basedir(1,i),'\')==1;
               model_var.basedir = model_var.basedir(1,1:i-1);
               i = 0;
            elseif strcmp(model_var.basedir(1,i),'/')==1;
               model_var.basedir = model_var.basedir(1,1:i-1);
               i = 0;
            else;
               i = i-1;
            end;
         end;
         oldmodel_var.basedir = model_var.basedir;
         respstring = '1';
         for i=2:max(var_ini.maxresp,model_var.newh);
            respstring = strcat(respstring,'|',num2str(i));
         end;
         %
         % Setting up the string with possible lag orders
         %
         lagstring = '1';
         for i = 2:max(var_ini.maxlag,max([model_var.lagexo model_var.newp]));
            lagstring = strcat(lagstring,'|',num2str(i));
         end;
         model_var.newdeterselect = model_var.deterselect;
         model_var.newmodeltype = model_var.modeltype;
         model_var.newseasonal = model_var.seasonal;
         oldmodel_var = model_var;
      else;
         selector = 'init';
         model_var.spectest = [0 0 0 0];
         model_var.modeltype = [1 0];
         model_var.seasonal = [0 1];
         model_var.freq = '';
         model_var.runvar = 0;
         %
         model_var.newp = 1;
         model_var.lagexo = 1;
         model_var.newh = 40;
         model_var.newc = 46;
         model_var.endofile = pwd;
         runenable = 'off';
         model_var.modelsdir = '';
         model_var.exo1file = '';
         model_var.exo0file = '';
         model_var.deterfile = '';
         model_var.cointvalue = 1;
         model_var.evars = '';
         model_var.xvars1 = '';
         model_var.xvars0 = '';
         model_var.deter = '';
         model_var.beginyear = '';
         model_var.beginperiod = '';
         model_var.endyear = '';
         model_var.endperiod = '';
         model_var.subbeginyear = '';
         model_var.subbeginperiod = '';
         model_var.subendyear = '';
         model_var.subendperiod = '';
         model_var.nameinput = '';
         model_var.deterselect = [1 0 0 0];
         model_var.shocks = '';
         model_var.scale_endo = 1;
         if strcmp(var_ini.reopenlist,'')==0;
            [model_var.reopenfile,var_ini.reopenlist] = fixlist(var_ini.reopenlist);
            reorderenable = 'on';
         else;
            model_var.reopenfile = '';
            reorderenable = 'off';
         end;
         lagstring = '1';
         for i = 2:var_ini.maxlag;
            lagstring = strcat(lagstring,'|',num2str(i));
         end;
         respstring = '1';
         for i=2:var_ini.maxresp;
            respstring = strcat(respstring,'|',num2str(i));
         end;
         if model_var.newh>var_ini.maxresp;
            model_var.newh = var_ini.maxresp;
         end;
         model_var.basedir = model_var.modelsdir;
         numchar = size(model_var.basedir,2);
         if numchar>=1;
            model_var.basedir = model_var.basedir(1,1:numchar-1);
         end;
         i = numchar-1;
         while i>=1;
            if strcmp(model_var.basedir(1,i),'\')==1;
               model_var.basedir = model_var.basedir(1,1:i-1);
               i = 0;
            elseif strcmp(model_var.basedir(1,i),'/')==1;
               model_var.basedir = model_var.basedir(1,1:i-1);
               i = 0;
            else;
               i = i-1;
            end;
         end;
         mypwd = pwd;
         if strcmp(mypwd(1,1),'/')==1;
            model_var.inputfile = strcat(pwd,'/model.var');
            if var_ini.dirstructure==1;
               model_var.outputfile = strcat(pwd,'/output.txt');
            else;
               model_var.outputfile = strcat(pwd,'/results/output.txt');
            end;
         else;
            model_var.inputfile = strcat(pwd,'\model.var');
            if var_ini.dirstructure==1;
               model_var.outputfile = strcat(pwd,'\output.txt');
            else;
               model_var.outputfile = strcat(pwd,'\results\output.txt');
            end;
         end;
         model_var.newdeterselect = model_var.deterselect;
         model_var.newmodeltype = model_var.modeltype;
         model_var.newseasonal = model_var.seasonal;
         oldmodel_var = model_var;
         if strcmp(runenable,'off')==1;
            bgclr = get(0,'defaultuicontrolbackgroundcolor');
            brw = button_images.browsedisable;
         else;
            bgclr = [1 1 1];
            brw = button_images.browse;
         end;
         status_str = ['Structural VAR, version ' num2str(myvers,'%0.2f')];
         runenable = 'off';
      end;
   end;
   selector = 'init';
   if strcmp(runenable,'off')==1;
      bgclr = get(0,'defaultuicontrolbackgroundcolor');
      brw = button_images.browsedisable;
   else;
      brw = button_images.browse;
      bgclr = [1 1 1];
   end;
end;

if strcmp(selector,'init')==1;
   %
   % Checking the frequency variable
   %
   seasonenable = 'off';
   if strcmp(model_var.freq,'')==0;
      seasonenable = 'on';
   end;
   %
   % checking if output file exists
   %
   editorenable = 'off';
   if fileexist(model_var.outputfile)==1;
      printenable = 'on';
      if strcmp(var_ini.editor,'')==0;
         editorenable = 'on';
      end;
   else;
      printenable = 'off';
   end;
   %
   % check if geometry is invalid and adjust accordingly
   %
   if (var_ini.geometry(1,1)+var_ini.geometry(1,2))>0;
      if var_ini.geometry(1,1)>realscrsz(3)-(scrsz(3)/2);
         var_ini.geometry(1,1)=realscrsz(3)-(scrsz(3)/2);
      end;
      if var_ini.geometry(1,2)>realscrsz(4)-240-(scrsz(4)/2);
         var_ini.geometry(1,2)=realscrsz(4)-240-(scrsz(4)/2);
      end;
      if var_ini.geometry(1,1)<0;
         var_ini.geometry(1,1) = 0;
      end;
      if var_ini.geometry(1,2)<0;
         var_ini.geometry(1,2) = 0;
      end;
   end;
   %
   % checking if exogenous variable files exist
   %
   exo1enable = 'off';
   if fileexist(model_var.exo1file)==1;
      exo1enable = 'on';
   else;
      model_var.xvars1 = '';
      oldmodel_var.xvars1 = '';
   end;
   %
   exo0enable = 'off';
   if fileexist(model_var.exo0file)==1;
      exo0enable = 'on';
   else;
      model_var.xvars0 = '';
      oldmodel_var.xvars0 = '';
   end;
   %
   deterenable = 'off';
   if fileexist(model_var.deterfile)==1;
      deterenable = 'on';
   else;
      model_var.deter = '';
      oldmodel_var.deter = '';
   end;
   %
   % determining which model has been specified
   %
   modeldesc = getmodeldesc(model_var);
else;
   if strcmp(selector,'runnow')==1;
      selector = 'run';
   elseif strcmp(selector,'figmode')==0;
      maingui = findobj('Type','figure','Tag','StructuralVAR');
   end;
   model = get(maingui,'UserData');
   var_ini = get(model.openmenu,'UserData');
   button_images = var_ini.images;
   model_var = var_ini.model;
   oldmodel_var = var_ini.oldmodel;
   drawnow;
end;

if model_var.cointvalue==1;
   model_var.nocointvalue = 0;
else;
   model_var.nocointvalue = 1;
end;

if oldmodel_var.cointvalue==1;
   oldmodel_var.nocointvalue = 0;
else;
   oldmodel_var.nocointvalue = 1;
end;

%
%  load gui
%

switch selector
   case 'init'

      maingui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','maindlg.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[var_ini.geometry [scrsz(3)/2+60 scrsz(4)/2+225]], ...
         'Tag','StructuralVAR', ...
         'Resize','off', ...
         'Visible','off', ...
         'Name',['Structural VAR' model_var.nameinput], ...
         'NumberTitle','off', ...
         'CloseRequestFcn','maindlg checkrun', ...
         'DeleteFcn','maindlg wayout', ...
         'Toolbar','none');

      if var_ini.edit_context==1;
         set(maingui,'DoubleBuffer','on');
      end;
      
      if matlabnumber>=7.0;
         set(maingui,'DockControl','off');
      end;

      model_var.inistartrun = var_ini.startrun;
      if strcmp(options,'--run')==1;
         model_var.inistartrun = 1;
      else;
         model_var.inistartrun = 0;
      end;

      %
      % File menu
      %

      model.filemenu = uimenu('Parent',maingui, ...
         'Label','&File', ...
         'Tag','FileMenu');

      %
      % Objects on Model menu
      %

      model.openmenu = uimenu('Parent',model.filemenu, ...
         'Label','&Open Model...', ...
         'Callback','maindlg openmodel', ...
         'Enable','on', ...
         'Accelerator','O', ...
         'Tag','OpenModel');

      model.savemenu = uimenu('Parent',model.filemenu, ...
         'Label','&Save Model...', ...
         'Callback','maindlg store', ...
         'Enable','off', ...
         'UserData',button_images.mycons, ...
         'Accelerator','S', ...
         'Tag','SaveModel');

      model.estimate = uimenu('Parent',model.filemenu, ...
         'Label','&Estimate Model...', ...
         'Callback','maindlg run', ...
         'Enable',runenable, ...
         'Accelerator','E', ...
         'Tag','EstimateModel');

      model.clearmenu = uimenu('Parent',model.filemenu, ...
         'Label','&Undo Model Changes', ...
         'Enable','on', ...
         'Separator','on', ...
         'Accelerator','U', ...
         'Callback','maindlg clear', ...
         'Tag','ClearModel');

      model.close = uimenu('Parent',model.filemenu, ...
         'Label','&Close Model', ...
         'Callback','maindlg close', ...
         'Separator','on', ...
         'Enable',runenable, ...
         'Tag','CloseModel');

      model.reopen = uimenu('Parent',model.filemenu, ...
         'Label','&Reopen Model', ...
         'UserData','', ...
         'Tag','ReopenMenu');

      model.clearlist = uimenu('Parent',model.reopen, ...
         'Label','&Clear List', ...
         'Callback','maindlg clearlist', ...
         'Tag','ClearListMenu');

      model.reorderlist = uimenu('Parent',model.reopen, ...
         'Label','&Reorder List', ...
         'Enable',reorderenable, ...
         'Separator','on', ...
         'Accelerator','R', ...
         'Callback','maindlg reorderlist', ...
         'Tag','ReorderListMenu');

      num = 1;
      for i=1:size(model_var.reopenfile,1);
         thisfile = strtrim(model_var.reopenfile(i,:));
         if strcmp(model_var.inputfile,thisfile)==0;
            if num==1;
               model.thisfile = uimenu('Parent',model.reopen, ...
                  'Label',['&1. ' getfilename(thisfile)], ...
                  'Callback','maindlg reopen', ...
                  'Separator','on', ...
                  'Accelerator','1', ...
                  'UserData',thisfile, ...
                  'Tag',['1-' getfilename(thisfile)]);
            else;
               if num<10;
                  model.thisfile = uimenu('Parent',model.reopen, ...
                     'Label',['&' num2str(num) '. ' getfilename(thisfile)], ...
                     'Callback','maindlg reopen', ...
                     'Accelerator',num2str(num), ...
                     'UserData',thisfile, ...
                     'Tag',[num2str(num) '-' getfilename(thisfile)]);
               else;
                  model.thisfile = uimenu('Parent',model.reopen, ...
                     'Label',['1&0. ' getfilename(thisfile)], ...
                     'Callback','maindlg reopen', ...
                     'Accelerator','0', ...
                     'UserData',thisfile, ...
                     'Tag',['10-' getfilename(thisfile)]);
               end;
            end;
            num = num+1;
         end;
      end;

      model.printmenu = uimenu('Parent',model.filemenu, ...
         'Label','&Print', ...
         'Callback','maindlg print', ...
         'Separator','on', ...
         'Enable',printenable, ...
         'Accelerator','P', ...
         'Tag','PrintPreviewMenu');

      if ispc==1;
         model.printsetup = uimenu('Parent',model.filemenu, ...
         'Label','Prin&t Setup...', ...
         'Accelerator','T', ...
         'Callback','uimenufcn(gcbf,''FilePrintSetup'')', ...
         'Enable','on', ...
         'Tag','PrintSetupMenu');
      end;

      model.printpreviewmenu = uimenu('Parent',model.filemenu, ...
         'Label','Pr&int Preview...', ...
         'Callback','maindlg printpreview', ...
         'Enable',printenable, ...
         'Accelerator','I', ...
         'Tag','PrintPreviewMenu');

      model.quitdata = uimenu('Parent',model.filemenu, ...
         'Label','&Quit', ...
         'Callback','maindlg stop', ...
         'Separator','on', ...
         'Enable','on', ...
         'Accelerator','Q', ...
         'Tag','QuitData');

      if (ispc==1)&(var_ini.edit_context==0);

         %
         % Edit menu
         %

         data.fieldstr = cellstr(strvcat('editmenu','editundo','editcut','editcopy','editpaste','editselectall'))';
         data.parentstr = cellstr(strvcat('editmenu','editmenu','editmenu','editmenu','editmenu'))';
         data.labelstr = cellstr(strvcat('&Edit','&Undo','Cu&t','&Copy','&Paste','Select &All'))';
         data.callbackstr = cellstr(strvcat(' ','maindlg undo','maindlg cut','maindlg copy','maindlg paste','maindlg selectall'))';
         data.acceleratorstr = cellstr(strvcat(' ','Z','X','C','V','A'))';
         data.enablestr = cellstr(strvcat('on','on','on','on','on','on'))';
         data.separatorstr = cellstr(strvcat('off','off','on','off','off','on'))';
         data.tagstr = cellstr(strvcat('MyEditMenu','MyEditUndo','MyEditCut','MyEditCopy','MyEditPaste','MyEditSelectAll'))';
         ud(1).userdata = [];
         ud(2).userdata = [];
         ud(3).userdata = [];
         ud(4).userdata = [];
         ud(5).userdata = [];
         ud(6).userdata = [];

         model = make_uimenu(model,maingui,data,ud);

      end;

      %
      % Tools menu
      %

      data.fieldstr = cellstr(strvcat('toolsmenu','datamenu','endomenu','exo1menu','exo0menu','determenu','namesmenu','endonamesmenu','exo1namesmenu','exo0namesmenu','deternamesmenu','shocknamesmenu','model_select','scale_menu','scale_1','scale_2','scale_3','scale_4','scale_5','scale_6','scale_7','scale_8','scale_9','outputmenu','editormenu','dvimenu','psmenu','pdfmenu','preferencesmenu'))';
      data.parentstr = cellstr(strvcat('toolsmenu','datamenu','datamenu','datamenu','datamenu','toolsmenu','namesmenu','namesmenu','namesmenu','namesmenu','namesmenu','toolsmenu','toolsmenu','scale_menu','scale_menu','scale_menu','scale_menu','scale_menu','scale_menu','scale_menu','scale_menu','scale_menu','toolsmenu','toolsmenu','toolsmenu','toolsmenu','toolsmenu','toolsmenu'))';
      data.labelstr = cellstr(strvcat('&Tools','&Data','&Endogenous...','Exogenous I(&1)...','Exogenous I(&0)...','&Deterministic...','&Names','&Endogenous...','Exogenous I(&1)...','Exogenous I(&0)...','&Deterministic...','&Shocks...','&Model Selection','S&cale Variables','&Multiply by 0.0001','M&ultiply by 0.001','Mu&ltiply by 0.01','Mul&tiply by 0.1','Mult&iply by 1','Multi&ply by 10','Multipl&y by 100','Multiply &by 1000','Multiply by &10000','&Output File...','Open &Editor','&LaTeX Preview','Post&Script Preview','PD&F Preview','&Preferences...'))';
      data.callbackstr = cellstr(strvcat(' ',' ','maindlg open','maindlg openexo1','maindlg openexo0','maindlg opendeter',' ','maindlg endonames','maindlg exo1names','maindlg exo0names','maindlg deternames','maindlg shocknames','maindlg model_select',' ','maindlg scaleoption','maindlg scaleoption','maindlg scaleoption','maindlg scaleoption','maindlg scaleoption','maindlg scaleoption','maindlg scaleoption','maindlg scaleoption','maindlg scaleoption','maindlg openoutput','maindlg editor','maindlg viewdvi','maindlg viewps','maindlg viewpdf','maindlg preferences'))';
      data.acceleratorstr = cellstr(strvcat(' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ','F'))';
      data.enablestr = cellstr(strvcat('on','on','on',runenable,runenable,runenable,'on',runenable,exo1enable,exo0enable,deterenable,runenable,runenable,'on','on','on','on','on','on','on','on','on','on','on',editorenable,'off','off','off','on'))';
      data.separatorstr = cellstr(strvcat('off','off','off','off','off','off','off','off','off','off','off','on','on','on','off','off','off','off','off','off','off','off','off','on','off','on','off','off','on'))';
      data.tagstr = cellstr(strvcat('ToolsMenu','DataMenu','EndoData','Exo1Data','Exo0Data','DeterData','NamesMenu','EndoNamesMenu','Exo1NamesMenu','Exo0NamesMenu','DeterNamesMenu','ShockNamesMenu','ModelSelect','ScaleEndo','ScaleOne','ScaleTwo','ScaleThree','ScaleFour','ScaleFive','ScaleSix','ScaleSeven','ScaleEight','ScaleNine','OutputData','Editor','DVIMenu','PSMenu','PDFMenu','PrefData'))';
      ud(1).userdata = [];
      ud(2).userdata = [];
      ud(3).userdata = [];
      ud(4).userdata = [];
      ud(5).userdata = [];
      ud(6).userdata = [];
      ud(7).userdata = [];
      ud(8).userdata = [];
      ud(9).userdata = [];
      ud(10).userdata = [];
      ud(11).userdata = [];
      ud(12).userdata = [];
      ud(13).userdata = [];
      ud(14).userdata = [];
      ud(15).userdata = 0.0001;
      ud(16).userdata = 0.001;
      ud(17).userdata = 0.01;
      ud(18).userdata = 0.1;
      ud(19).userdata = 1;
      ud(20).userdata = 10;
      ud(21).userdata = 100;
      ud(22).userdata = 1000;
      ud(23).userdata = 10000;
      ud(24).userdata = [];
      ud(25).userdata = [];
      ud(26).userdata = [];
      ud(27).userdata = [];
      ud(28).userdata = [];
      ud(29).userdata = [];
      model = make_uimenu(model,maingui,data,ud);

      if model_var.scale_endo==0.0001;
         set(model.scale_1,'Check','on');
      elseif model_var.scale_endo==0.001;
         set(model.scale_2,'Check','on');
      elseif model_var.scale_endo==0.01;
         set(model.scale_3,'Check','on');
      elseif model_var.scale_endo==0.1;
         set(model.scale_4,'Check','on');
      elseif model_var.scale_endo==1;
         set(model.scale_5,'Check','on');
      elseif model_var.scale_endo==10;
         set(model.scale_6,'Check','on');
      elseif model_var.scale_endo==100;
         set(model.scale_7,'Check','on');
      elseif model_var.scale_endo==1000;
         set(model.scale_8,'Check','on');
      elseif model_var.scale_endo==10000;
         set(model.scale_9,'Check','on');
      end;

      %
      % check if we should enable viewing of dvi, ps, and pdf formats of output
      %
      if islatexformat(model_var.outputfile)==1;
         stat_dvi = check_dvi(var_ini);
         if stat_dvi==0;
            set(model.dvimenu,'Enable','on');
         end;
         [stat_ps,dvips] = check_ps(var_ini);
         if stat_ps==0;
            set(model.psmenu,'Enable','on');
         end;
         [stat_pdf,prog_seq] = check_pdf(var_ini);
         if stat_pdf==0;
            set(model.pdfmenu,'Enable','on');
         end;
      end;

      %
      % Graphics menu
      %

      if iscompiled==1;
         data.fieldstr = cellstr(strvcat('graphicsmenu','newfiguremenu','fig11','fig12','fig21','fig22','fig23','fig24','fig31','fig32','fig33','fig41','fig42','fig43','fig44','menuviewgraphics','endographicsmenu','exo1graphicsmenu','exo0graphicsmenu','detergraphicsmenu'))';
         data.parentstr = cellstr(strvcat('graphicsmenu','newfiguremenu','newfiguremenu','newfiguremenu','newfiguremenu','newfiguremenu','newfiguremenu','newfiguremenu','newfiguremenu','newfiguremenu','newfiguremenu','newfiguremenu','newfiguremenu','newfiguremenu','graphicsmenu','graphicsmenu','graphicsmenu','graphicsmenu','graphicsmenu'))';
         data.labelstr = cellstr(strvcat('&Graphics','&New Figure','&One Row One Column...','O&ne Row Two Columns...','&Two Rows One Column...','T&wo Rows Two Columns...','Two &Rows Three Columns...','Two Rows &Four Columns...','T&hree Rows One Column','Three Row&s Two Columns...','Thr&ee Rows Three Columns...','Fo&ur Rows One Column...','Four Rows Two &Columns','Four Rows Three Co&lumns...','Four Rows Four Colu&mns...','&Open Figure...','&Endogenous...','Exogenous I(&1)...','Exogenous I(&0)...','&Deterministic...'))';
         data.callbackstr = cellstr(strvcat(' ',' ','new_figure_fcn','new_figure_fcn(1,2)','new_figure_fcn(2,1)','new_figure_fcn(2,2)','new_figure_fcn(2,3)','new_figure_fcn(2,4)','new_figure_fcn(3,1)','new_figure_fcn(3,2)','new_figure_fcn(3,3)','new_figure_fcn(4,1)','new_figure_fcn(4,2)','new_figure_fcn(4,3)','new_figure_fcn(4,4)','maindlg viewgraphics','maindlg endographs','maindlg exo1graphs','maindlg exo0graphs','maindlg detergraphs'))';
         data.acceleratorstr = cellstr(strvcat(' ',' ','W',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' ','G',' ',' ',' ',' '))';
         data.enablestr = cellstr(strvcat('on','on','on','on','on','on','on','on','on','on','on','on','on','on','on','on',runenable,exo1enable,exo0enable,deterenable))';
         data.separatorstr = cellstr(strvcat('off','off','off','off','off','off','off','off','off','off','off','off','off','off','off','on','on','off','off','off'))';
         data.tagstr = cellstr(strvcat('GraphicsMenu','NewFigureMenu','Fig11','Fig12','Fig21','Fig22','Fig23','Fig24','Fig31','Fig32','Fig33','Fig41','Fig42','Fig43','Fig44','ViewGraphicsMenu','EndoGraphicsMenu','Exo1GraphicsMenu','Exo0GraphicsMenu','DeterGraphicsMenu'))';
         ud(1).userdata = [];
         ud(2).userdata = [];
         ud(3).userdata = [];
         ud(4).userdata = [];
         ud(5).userdata = [];
         ud(6).userdata = [];
         ud(7).userdata = [];
         ud(8).userdata = [];
         ud(9).userdata = [];
         ud(10).userdata = [];
         ud(11).userdata = [];
         ud(12).userdata = [];
         ud(13).userdata = [];
         ud(14).userdata = [];
         ud(15).userdata = [];
         ud(16).userdata = [];
         ud(17).userdata = [];
         ud(18).userdata = [];
         ud(19).userdata = [];
         ud(20).userdata = [];
      else;
         data.fieldstr = cellstr(strvcat('graphicsmenu','menuviewgraphics','endographicsmenu','exo1graphicsmenu','exo0graphicsmenu','detergraphicsmenu'))';
         data.parentstr = cellstr(strvcat('graphicsmenu','graphicsmenu','graphicsmenu','graphicsmenu','graphicsmenu'))';
         data.labelstr = cellstr(strvcat('&Graphics','&Open Figure...','&Endogenous...','Exogenous I(&1)...','Exogenous I(&0)...','&Deterministic...'))';
         data.callbackstr = cellstr(strvcat(' ','maindlg viewgraphics','maindlg endographs','maindlg exo1graphs','maindlg exo0graphs','maindlg detergraphs'))';
         data.acceleratorstr = cellstr(strvcat(' ','G',' ',' ',' ',' '))';
         data.enablestr = cellstr(strvcat('on','on',runenable,exo1enable,exo0enable,deterenable))';
         data.separatorstr = cellstr(strvcat('off','off','on','off','off','off'))';
         data.tagstr = cellstr(strvcat('GraphicsMenu','ViewGraphicsMenu','EndoGraphicsMenu','Exo1GraphicsMenu','Exo0GraphicsMenu','DeterGraphicsMenu'))';
         ud(1).userdata = [];
         ud(2).userdata = [];
         ud(3).userdata = [];
         ud(4).userdata = [];
         ud(5).userdata = [];
         ud(6).userdata = [];
      end;

      model = make_uimenu(model,maingui,data,ud);

      %
      % Help menu
      %

      data.fieldstr = cellstr(strvcat('helpmenu','menuhelp','helplicense','helpreadme','helpchanges','helpscreen','helpabout'))';
      data.parentstr = cellstr(strvcat('helpmenu','helpmenu','helpmenu','helpmenu','helpmenu','helpmenu'))';
      data.labelstr = cellstr(strvcat('&Help','&Help Topics','&License...','&Readme File...','&Changes...','Help &Screen...','&About...'))';
      data.callbackstr = cellstr(strvcat(' ','maindlg help','maindlg license','maindlg readme','maindlg progchanges','var(''-h'',''-v'')','maindlg about'))';
      data.acceleratorstr = cellstr(strvcat(' ','H','L','M','N',' ','B'))';
      data.enablestr = cellstr(strvcat('on',helpenable,'on','on','on','on','on'))';
      data.separatorstr = cellstr(strvcat('off','off','on','off','off','off','on'))';
      data.tagstr = cellstr(strvcat('HelpMenu','ShowHelp','LicenseHelp','ReadmeHelp','ChangesHelp','HelpScreen','AboutHelp'))';
      ud(1).userdata = [];
      ud(2).userdata = [];
      ud(3).userdata = [];
      ud(4).userdata = [];
      ud(5).userdata = [];
      ud(6).userdata = [];
      ud(7).userdata = [];
      model = make_uimenu(model,maingui,data,ud);

      %
      % delete model.helpreadme if var.exe doesn't exist in current directory
      %
      if ispc==1;
         a_file = '\var.exe';
         r_file = '\readme.txt';
      else;
         a_file = '/var.exe';
         r_file = '/readme.txt';
      end;
      if fileexist([pwd a_file])==1;
         if fileexist([pwd r_file])==0;
            delete(model.helpreadme);
         end;
      else;
         delete(model.helpreadme);
      end;

      if (ispc==1)&(iscompiled==1);
         model.homepage = uimenu('Parent',model.helpmenu, ...
            'Label','SVAR on the Web', ...
            'Separator','on', ...
            'Position',2, ...
            'Callback','maindlg homepage', ...
            'Tag','MenuHomepage');
         model.updates = uimenu('Parent',model.helpmenu, ...
            'Label','Check for Updates...', ...
            'Position',3, ...
            'Callback','maindlg updates', ...
            'Tag','MenuUpdates');
      end;

      %
      % Toolbar
      %

%      xline([1 scrsz(4)/2+257 (scrsz(3)/2)],[0.5 1]);

      model.xline = xline([1 (scrsz(4)/2)+224 (scrsz(3)/2)+60],[0.5 1],var_ini);

      btndata(1).cdata = button_images.open;
      btndata(1).userdata = model_var.inputfile;
      btndata(2).cdata = button_images.save;
      btndata(2).userdata = [];
      btndata(3).cdata = button_images.estimate;
      btndata(3).userdata = [];
      btndata(4).cdata = button_images.undo;
      btndata(4).userdata = [];
      btndata(5).cdata = button_images.clear;
      btndata(5).userdata = [];
      btndata(6).cdata = button_images.printenable;
      btndata(6).userdata = [];
      btndata(7).cdata = button_images.printpreviewenable;
      btndata(7).userdata = [];
      addbtn = 0;
      cell_flds = '';
      cell_type = '';
      cell_tooltipstr = '';
      cell_callbackstr = '';
      cell_enablestr = '';
      cell_separatorstr = '';
      cell_statestr = '';
      cell_tagstr = '';
      if (ispc==1)&(var_ini.edit_context==0);
         btndata(8).cdata = button_images.cut;
         btndata(8).userdata = [];
         btndata(9).cdata = button_images.copy;
         btndata(9).userdata = [];
         btndata(10).cdata = button_images.paste;
         btndata(10).userdata = [];
         btndata(11).cdata = button_images.selectall;
         btndata(11).userdata = [];
         addbtn = 4;
         cell_flds = strvcat('cutbtn','copybtn','pastebtn','selectallbtn');
         cell_type = strvcat('push','push','push','push');
         cell_tooltipstr = strvcat('Cut','Copy','Paste','Select All');
         cell_callbackstr = strvcat('maindlg cut','maindlg copy','maindlg paste','maindlg selectall');
         cell_enablestr = strvcat('on','on','on','on');
         cell_separatorstr = strvcat('on','off','off','off');
         cell_statestr = strvcat(' ',' ',' ',' ');
         cell_tagstr = strvcat('CutButton','CopyButton','PasteButton','SelectAllButton');
      end;
      btndata(8+addbtn).cdata = button_images.viewgraphics;
      btndata(8+addbtn).userdata = [];
      btndata(9+addbtn).cdata = button_images.endo;
      btndata(9+addbtn).userdata = model_var.evars;
      btndata(10+addbtn).cdata = button_images.exo1;
      btndata(10+addbtn).userdata = model_var.xvars1;
      btndata(11+addbtn).cdata = button_images.exo0;
      btndata(11+addbtn).userdata = model_var.xvars0;
      btndata(12+addbtn).cdata = button_images.deter;
      btndata(12+addbtn).userdata = model_var.deter;
      btndata(13+addbtn).cdata = button_images.preferences;
      btndata(13+addbtn).userdata = [];
      btndata(14+addbtn).cdata = button_images.help;
      btndata(14+addbtn).userdata = [];
      btndata(15+addbtn).cdata = button_images.about;
      btndata(15+addbtn).userdata = [];
      btndata(16+addbtn).cdata = button_images.close;
      btndata(16+addbtn).userdata = 'waiting';

      flds = cellstr(strvcat('toolbar','open','store','run','undo','clear','print','printpreview',cell_flds,'viewgraphics','endonames','exo1names','exo0names','deternames','preferences','help','about','leave'))';
      buttons.type = cellstr(strvcat('push','push','push','push','push','push','push',cell_type,'push','push','push','push','push','push','push','push','push'))';
      buttons.tooltipstr = cellstr(strvcat('Open Model','Save Model','Estimate Model','Undo Model Changes','Close Model','Print','Print Preview',cell_tooltipstr,'Open Figure','Endogenous Variables','Exogenous I(1) Variables','Exogenous I(0) Variables','Deterministic Variables','Preferences','Help Topics','About','Quit'))';
      buttons.callbackstr = cellstr(strvcat('maindlg openmodel','maindlg store','maindlg run','maindlg clear','maindlg close','maindlg print','maindlg printpreview',cell_callbackstr,'maindlg viewgraphics','maindlg endographs','maindlg exo1graphs','maindlg exo0graphs','maindlg detergraphs','maindlg preferences','maindlg help','maindlg about','maindlg stop'))';
      buttons.enablestr = cellstr(strvcat('on','off',runenable,'on',runenable,printenable,printenable,cell_enablestr,'on',runenable,exo1enable,exo0enable,deterenable,'on',helpenable,'on','on'))';
      buttons.separatorstr = cellstr(strvcat('off','off','off','on','off','on','off',cell_separatorstr,'on','on','off','off','off','on','on','on','on'))';
      buttons.statestr = cellstr(strvcat(' ',' ',' ',' ',' ',' ',' ',cell_statestr,' ',' ',' ',' ',' ',' ',' ',' ',' '))';
      buttons.tagstr = cellstr(strvcat('OpenButton','StoreButton','RunButton','UndoButton','ClearButton','PrintButton','PrintPreviewButton',cell_tagstr,'GraphicsButton','EndoNamesButton','Exo1NamesButton','Exo0NamesButton','DeterNamesButton','PrefButton','HelpButton','AboutButton','ExitButton'))';

      model = make_toolbar(model,maingui,flds,btndata,buttons);

      if var_ini.method(1,3)==1;
         set(model.estimate,'Label','Analyse Model...');
         set(model.run,'TooltipString','Analyse Model');
      end;
      set(model.openmenu,'UserData',var_ini);
      set(maingui,'UserData',model);

      %
      % Outer axis
      %

      axesbox([2 21 (scrsz(3)/2)+58 scrsz(4)/2+194],'Model Specification',96,[0.5 1],'on',var_ini);

      %
      % Outer axis for current model
      %

      axesbox([14 scrsz(4)/2+142 (scrsz(3)/2)+34 57],'Model',33,[0.5 1],'on',var_ini);

      %
      % Text displaying general model
      %

      model.textaxes = axes('Units','pixels', ...
         'Box','on', ...
         'TickLength',[0 0], ...
         'CameraUpVector',[0 1 0], ...
         'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[16 scrsz(4)/2+144 (scrsz(3)/2)+30 53], ...
         'XTickLabelMode','manual', ...
         'YTickLabelMode','manual', ...
         'Tag','AxisText', ...
         'XColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'YColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'ZColor',get(0,'defaultuicontrolbackgroundcolor'));

      model.text = text('Parent',model.textaxes,'Position',[0.5 0.5],'String',modeldesc,'FontSize',var_ini.gui_fontsize+2,'FontName',var_ini.gui_fontname,'HorizontalAlignment','center','Color',var_ini.gui_foreground_color);

      %
      % setting up a tab dialog
      %

      input_var.fldnames = {'tab1' 'tab2' 'tab3'};
      input_var.tags = {'tab1' 'tab2' 'tab3'};
      input_var.strings = {'Data' 'Parameters' 'Output'};
      input_var.visible = {'on' 'on' 'on'};
      input_var.callbackstr = {'maindlg tab' 'maindlg tab' 'maindlg tab'};
      model = tabbed_dialog(model,var_ini,[14 34 545 456],3,input_var,[76.4 74.4]);

      %
      % Tab data
      %

      %
      % Outer axis for data files
      %

      model.dataselect = axesbox([28 152 516 320],'Files',25,[0.5 1],'on',var_ini);

      %
      % Outer axis for sample selection
      %

      model.sampleselect = axesbox([28 48 516 90],'Sample Selections',90,[0.5 1],'on',var_ini);

      %
      % Show input file for endogenous variables
      %

      if var_ini.edit_context==0;
         add_height = 0;
      else;
         add_height = 3;
      end;

      model.endogenoustext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 433+add_height 484 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'HorizontalAlignment','left', ...
         'String',['Endogenous variables:  ' model_var.evars], ...
         'Tag','ListBoxText1');

      if strcmp(strtrim(model_var.evars),'')==1;
         set(model.endogenoustext,'String','Endogenous variables:  None');
      end;

      if var_ini.edit_context==0;
         model.endogenous = uicontrol('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[44 413 419 22], ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Style','edit', ...
            'HorizontalAlignment','left', ...
            'String',model_var.endofile, ...
            'Callback','maindlg checkendo', ...
            'Enable','on', ...
            'UserData',model_var.modelsdir, ...
            'Tag','EditBox1');
      else;
         model.endogenous = editbox('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[44 413 419 22], ...
            'FontName',get(model.endogenoustext,'FontName'), ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'HorizontalAlignment','left', ...
            'String',model_var.endofile, ...
            'Callback','maindlg checkendo', ...
            'Enable','on', ...
            'UserData',model_var.modelsdir, ...
            'Tag','EditBox1');
      end;

      %
      % Button for selecting input file for endogenous variables
      %

      model.endobutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[468 413 60 22], ...
         'TooltipString','Browse', ...
         'CData',button_images.browse, ...
         'Callback','maindlg open', ...
         'Enable','on', ...
         'Tag','OpenEditBox1');

      model.change_endonames = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[468 383 60 22], ...
         'TooltipString','Names for Endogenous Variables', ...
         'CData',button_images.rename, ...
         'Callback','maindlg endonames', ...
         'Enable',runenable, ...
         'Tag','ChangeEndoNamesButton');

      if strcmp(runenable,'off')==1;
         set(model.change_endonames,'CData',button_images.renamedisable);
      end;

      model.endosheettext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 385 419 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'HorizontalAlignment','right', ...
         'String','Data sheet: None', ...
         'Tag','EndoSheetText');

      if isempty(model_var.endosheet)==0;
         set(model.endosheettext,'String',['Data sheet: ' model_var.endosheet]);
      end;

      %
      % Show input file for exogenous I(1) variables
      %

      model.exogenous1text = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 363+add_height 419 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Enable',runenable, ...
         'HorizontalAlignment','left', ...
         'String',['Exogenous I(1) variables:  ' model_var.xvars1], ...
         'Tag','ListBoxText2');

      if strcmp(strtrim(model_var.xvars1),'')==1;
         set(model.exogenous1text,'String','Exogenous I(1) variables:  None');
      end;

      if var_ini.edit_context==0;
         model.exogenous1 = uicontrol('Units','pixels', ...
            'BackgroundColor',bgclr, ...
            'Position',[44 343 419 22], ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Style','edit', ...
            'HorizontalAlignment','left', ...
            'Callback','maindlg checkother', ...
            'Enable',runenable, ...
            'String',model_var.exo1file, ...
            'Tag','EditBox2');
      else;
         model.exogenous1 = editbox('Units','pixels', ...
            'BackgroundColor',bgclr, ...
            'Position',[44 343 419 22], ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'FontName',get(model.endogenoustext,'FontName'), ...
            'HorizontalAlignment','left', ...
            'Callback','maindlg checkother', ...
            'Enable',runenable, ...
            'String',model_var.exo1file, ...
            'Tag','EditBox2');
      end;

      %
      % Button for selecting input file for exogenous I(1) variables
      %

      model.exo1button = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[468 343 60 22], ...
         'TooltipString','Browse', ...
         'CData',brw, ...
         'Callback','maindlg openexo1', ...
         'Enable',runenable, ...
         'Tag','OpenEditBox2');

      model.change_exo1names = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[468 313 60 22], ...
         'TooltipString','Names for Exogenous I(1) Variables', ...
         'CData',button_images.rename, ...
         'Callback','maindlg exo1names', ...
         'Enable',exo1enable, ...
         'Tag','ChangeExo1NamesButton');

      if strcmp(exo1enable,'off')==1;
         set(model.change_exo1names,'CData',button_images.renamedisable);
      end;

      model.exo1sheettext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 315 419 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'HorizontalAlignment','right', ...
         'String','Data sheet: None', ...
         'Tag','Exo1SheetText');

      if isempty(model_var.exo1sheet)==0;
         set(model.exo1sheettext,'String',['Data sheet: ' model_var.exo1sheet]);
      end;

      %
      % Show input file for exogenous I(0) variables
      %

      model.exogenous0text = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 293+add_height 419 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Enable',runenable, ...
         'HorizontalAlignment','left', ...
         'String',['Exogenous I(0) variables:  ' model_var.xvars0], ...
         'Tag','ListBoxText3');

      if strcmp(strtrim(model_var.xvars0),'')==1;
         set(model.exogenous0text,'String','Exogenous I(0) variables:  None');
      end;

      if var_ini.edit_context==0;
         model.exogenous0 = uicontrol('Units','pixels', ...
            'BackgroundColor',bgclr, ...
            'Position',[44 273 419 22], ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Style','edit', ...
            'HorizontalAlignment','left', ...
            'Callback','maindlg checkother', ...
            'String',model_var.exo0file, ...
            'Enable',runenable, ...
            'Tag','EditBox3');
      else;
         model.exogenous0 = editbox('Units','pixels', ...
            'BackgroundColor',bgclr, ...
            'Position',[44 273 419 22], ...
            'FontName',get(model.endogenoustext,'FontName'), ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'HorizontalAlignment','left', ...
            'Callback','maindlg checkother', ...
            'String',model_var.exo0file, ...
            'Enable',runenable, ...
            'Tag','EditBox3');
      end;

      %
      % Button for selecting input file for exogenous I(0) variables
      %

      model.exo0button = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[468 273 60 22], ...
         'TooltipString','Browse', ...
         'CData',brw, ...
         'Callback','maindlg openexo0', ...
         'Enable',runenable, ...
         'Tag','OpenEditBox3');

      model.change_exo0names = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[468 243 60 22], ...
         'TooltipString','Names for Exogenous I(0) Variables', ...
         'CData',button_images.rename, ...
         'Callback','maindlg exo0names', ...
         'Enable',exo0enable, ...
         'Tag','ChangeExo0NamesButton');

      if strcmp(exo0enable,'off')==1;
         set(model.change_exo0names,'CData',button_images.renamedisable);
      end;

      model.exo0sheettext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 245 419 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'HorizontalAlignment','right', ...
         'String','Data sheet: None', ...
         'Tag','Exo0SheetText');

      if isempty(model_var.exo0sheet)==0;
         set(model.exo0sheettext,'String',['Data sheet: ' model_var.exo0sheet]);
      end;

      %
      % Show input file for deterministic variables
      %

      model.deterministictext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 223+add_height 419 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Enable',runenable, ...
         'HorizontalAlignment','left', ...
         'String',['Deterministic variables:  ' model_var.deter], ...
         'Tag','ListBoxText4');

      if strcmp(strtrim(model_var.deter),'')==1;
         set(model.deterministictext,'String','Deterministic variables:  None');
      end;

      if var_ini.edit_context==0;
         model.deterministic = uicontrol('Units','pixels', ...
            'BackgroundColor',bgclr, ...
            'Position',[44 203 419 22], ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Style','edit', ...
            'HorizontalAlignment','left', ...
            'Callback','maindlg checkother', ...
            'String',model_var.deterfile, ...
            'Enable',runenable, ...
            'Tag','EditBox4');
      else;
         model.deterministic = editbox('Units','pixels', ...
            'BackgroundColor',bgclr, ...
            'Position',[44 203 419 22], ...
            'FontName',get(model.endogenoustext,'FontName'), ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'HorizontalAlignment','left', ...
            'Callback','maindlg checkother', ...
            'String',model_var.deterfile, ...
            'Enable',runenable, ...
            'Tag','EditBox4');
      end;

      %
      % Button for selecting input file for deterministic variables
      %

      model.deterbutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[468 203 60 22], ...
         'TooltipString','Browse', ...
         'CData',brw, ...
         'Callback','maindlg opendeter', ...
         'Enable',runenable, ...
         'Tag','OpenEditBox4');

      model.change_deternames = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[468 173 60 22], ...
         'TooltipString','Names for Deterministic Variables', ...
         'CData',button_images.rename, ...
         'Callback','maindlg deternames', ...
         'Enable',deterenable, ...
         'Tag','ChangeDeterNamesButton');

      if strcmp(deterenable,'off')==1;
         set(model.change_deternames,'CData',button_images.renamedisable);
      end;

      model.detersheettext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 175 419 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'HorizontalAlignment','right', ...
         'String','Data sheet: None', ...
         'Tag','DeterSheetText');

      if isempty(model_var.detersheet)==0;
         set(model.detersheettext,'String',['Data sheet: ' model_var.detersheet]);
      end;

      %
      % Control for selecting actual sample
      %

      model.sample = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 96 100 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Enable',runenable, ...
         'HorizontalAlignment','left', ...
         'String','Actual Sample:', ...
         'Tag','SampleText1');

      model.beginyear = uicontrol('Units','pixels', ...
         'BackgroundColor',bgclr, ...
         'Position',[144 101 40 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','edit', ...
         'HorizontalAlignment','left', ...
         'String',model_var.beginyear, ...
         'Callback','maindlg checksample', ...
         'Enable',runenable, ...
         'TooltipString','Enter from year', ...
         'Tag','EditYear1');

      model.beginperiod = uicontrol('Units','pixels', ...
         'BackgroundColor',bgclr, ...
         'Position',[189 101 25 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','edit', ...
         'HorizontalAlignment','left', ...
         'String',model_var.beginperiod, ...
         'Callback','maindlg checksample', ...
         'Enable',runenable, ...
         'TooltipString','Enter from period', ...
         'Tag','EditPeriod1');

      model.sampleseparator = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[214 101 10 20], ...
         'FontSize',10, ...
         'Style','text', ...
         'HorizontalAlignment','center', ...
         'String','-', ...
         'Tag','SampleText2');

      model.endyear = uicontrol('Units','pixels', ...
         'BackgroundColor',bgclr, ...
         'Position',[224 101 40 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','edit', ...
         'HorizontalAlignment','left', ...
         'String',model_var.endyear, ...
         'Callback','maindlg checksample', ...
         'Enable',runenable, ...
         'TooltipString','Enter to year', ...
         'Tag','EditYear2');

      model.endperiod = uicontrol('Units','pixels', ...
         'BackgroundColor',bgclr, ...
         'Position',[269 101 25 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','edit', ...
         'HorizontalAlignment','left', ...
         'String',model_var.endperiod, ...
         'Callback','maindlg checksample', ...
         'Enable',runenable, ...
         'TooltipString','Enter to period', ...
         'Tag','EditPeriod2');

      %
      % Control for selecting estimation sample
      %

      model.subsample = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 61 100 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Enable',runenable, ...
         'HorizontalAlignment','left', ...
         'String','Selected Sample:', ...
         'Tag','SubSampleText1');

      model.subbeginyear = uicontrol('Units','pixels', ...
         'BackgroundColor',bgclr, ...
         'Position',[144 66 40 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','edit', ...
         'HorizontalAlignment','left', ...
         'String',model_var.subbeginyear, ...
         'Callback','maindlg checksample', ...
         'Enable',runenable, ...
         'TooltipString','Enter from year', ...
         'Tag','SubEditYear1');

      model.subbeginperiod = uicontrol('Units','pixels', ...
         'BackgroundColor',bgclr, ...
         'Position',[189 66 25 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','edit', ...
         'HorizontalAlignment','left', ...
         'String',model_var.subbeginperiod, ...
         'Callback','maindlg checksample', ...
         'Enable',runenable, ...
         'TooltipString','Enter from period', ...
         'Tag','SubEditPeriod1');

      model.subsampleseparator = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[214 66 10 20], ...
         'FontSize',10, ...
         'Style','text', ...
         'HorizontalAlignment','center', ...
         'String','-', ...
         'Tag','SubSampleText2');

      model.subendyear = uicontrol('Units','pixels', ...
         'BackgroundColor',bgclr, ...
         'Position',[224 66 40 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','edit', ...
         'HorizontalAlignment','left', ...
         'String',model_var.subendyear, ...
         'Callback','maindlg checksample', ...
         'Enable',runenable, ...
         'TooltipString','Enter to year', ...
         'Tag','SubEditYear2');

      model.subendperiod = uicontrol('Units','pixels', ...
         'BackgroundColor',bgclr, ...
         'Position',[269 66 25 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','edit', ...
         'HorizontalAlignment','left', ...
         'String',model_var.subendperiod, ...
         'Callback','maindlg checksample', ...
         'Enable',runenable, ...
         'TooltipString','Enter to period', ...
         'Tag','SubEditPeriod2');

      %
      % Tab parameters
      %

      %
      % Outer axis for cointegration radio controls
      %

      model.cointegrationselect = axesbox([28 365 251 107],'Cointegration Selection',112,[0.5 1],'off',var_ini);
%      set(model.cointegrationselect,'Visible','off');

      %
      % Outer axis for deterministic variable selections
      %

      model.deterministicselect = axesbox([28 48 251 303],'Deterministic Variables Selections',160,[0.5 1],'off',var_ini);
%      set(model.deterministicselect,'Visible','off');

      %
      % Outer axis for model type specification
      %

      model.modelselect = axesbox([293 365 251 107],'Model Type Selection',108,[0.5 1],'off',var_ini);
%      set(model.modelselect,'Visible','off');

      %
      % Outer axis for parameter controls
      %

      model.parameterselect = axesbox([293 209 251 142],'Parameter Selections',104,[0.5 1],'off',var_ini);
%      set(model.parameterselect,'Visible','off');

      %
      % Outer axis for specification test controls
      %scrsz(4)/2-262

      model.specificationselect = axesbox([293 48 251 147],'Specification Test Selections',140,[0.5 1],'off',var_ini);
%      set(model.specificationselect,'Visible','off');

      %
      % Radio buttons for selecting whether to use cointegration or not
      %

      model.radiocoint = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 425 210 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','radiobutton', ...
         'Value',model_var.cointvalue, ...
         'Enable',runenable, ...
         'Visible','off', ...
         'Max',1, ...
         'HorizontalAlignment','left', ...
         'Callback','maindlg radio', ...
         'String','Cointegration Estimation', ...
         'Tag','Radio1');

      model.radionocoint = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 395 210 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','radiobutton', ...
         'Value',model_var.nocointvalue, ...
         'Enable',runenable, ...
         'Visible','off', ...
         'Max',1, ...
         'HorizontalAlignment','left', ...
         'Callback','maindlg radio', ...
         'String','No Cointegration Estimation', ...
         'Tag','Radio2');

      %
      %  Deterministic variables
      %

      model.uconstant = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 271 210 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','radiobutton', ...
         'Value',model_var.deterselect(1,1), ...
         'Enable',runenable, ...
         'Visible','off', ...
         'Max',1, ...
         'HorizontalAlignment','left', ...
         'Callback','maindlg deterselect', ...
         'String','Unrestricted Constant', ...
         'UserData',1, ...
         'Tag','DeterRadio1');

      model.rconstant = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 301 210 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','radiobutton', ...
         'Value',model_var.deterselect(1,2), ...
         'Enable',runenable, ...
         'Visible','off', ...
         'Max',1, ...
         'HorizontalAlignment','left', ...
         'Callback','maindlg deterselect', ...
         'String','Restricted Constant', ...
         'UserData',2, ...
         'Tag','DeterRadio2');

      model.utrend = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 211 210 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','radiobutton', ...
         'Value',model_var.deterselect(1,3), ...
         'Enable',runenable, ...
         'Visible','off', ...
         'Max',1, ...
         'HorizontalAlignment','left', ...
         'Callback','maindlg deterselect', ...
         'String','Constant and Linear Trend', ...
         'UserData',3, ...
         'Tag','DeterRadio3');

      model.rtrend = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 241 210 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','radiobutton', ...
         'Value',model_var.deterselect(1,4), ...
         'Enable',runenable, ...
         'Visible','off', ...
         'Max',1, ...
         'HorizontalAlignment','left', ...
         'Callback','maindlg deterselect', ...
         'String','Constant and Restricted Linear Trend', ...
         'UserData',4, ...
         'Tag','DeterRadio4');

      model.seasonal = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 91 210 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','radiobutton', ...
         'Value',model_var.seasonal(1,1), ...
         'Enable',seasonenable, ...
         'Visible','off', ...
         'Max',1, ...
         'HorizontalAlignment','left', ...
         'Callback','maindlg seasonal', ...
         'String','Centered Seasonal Dummies', ...
         'UserData',model_var.freq, ...
         'Tag','DeterRadio5');

      model.noseasonal = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 61 210 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','radiobutton', ...
         'Value',model_var.seasonal(1,2), ...
         'Enable',seasonenable, ...
         'Visible','off', ...
         'Max',1, ...
         'HorizontalAlignment','left', ...
         'Callback','maindlg seasonal', ...
         'String','No Seasonal Dummies', ...
         'Tag','DeterRadio6');

      %
      % Radio buttons for selecting model type
      %

      model.structural = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[307 425 210 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','radiobutton', ...
         'Value',model_var.modeltype(1,1), ...
         'Enable',runenable, ...
         'Max',1, ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','maindlg modeltype', ...
         'String','Structural Form', ...
         'Tag','ModelRadio1');

      model.reduced = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[307 395 210 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','radiobutton', ...
         'Value',model_var.modeltype(1,2), ...
         'Enable',runenable, ...
         'Max',1, ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','maindlg modeltype', ...
         'String','Reduced Form', ...
         'Tag','ModelRadio2');

      model.shock_names = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[468 383 60 22], ...
         'TooltipString','Names for Structural Shocks', ...
         'CData',button_images.rename, ...
         'Visible','off', ...
         'Callback','maindlg shocknames', ...
         'Enable',runenable, ...
         'Tag','ChangeShockNamesButton');

      %
      % Lag order controls
      %

      model.mypopuptext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[307 310 170 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'HorizontalAlignment','left', ...
         'Visible','off', ...
         'Enable',runenable, ...
         'String','Lag Order (endogenous variables):', ...
         'Tag','ListBoxText1');

      model.mypopup = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[477 315 50 20], ...
         'Style','popupmenu', ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Enable',runenable, ...
         'Value',model_var.newp, ...
         'Visible','off', ...
         'String',lagstring, ...
         'CallBack','maindlg change', ...
         'Tag','ListBoxLag');

      model.lagexotext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[307 280 170 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'HorizontalAlignment','left', ...
         'Visible','off', ...
         'Enable','off', ...
         'String','Lag Order (exogenous variables):', ...
         'Tag','LagExoText');

      model.lagexo = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[477 285 50 20], ...
         'Style','popupmenu', ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Enable','off', ...
         'Value',model_var.lagexo+1, ...
         'Visible','off', ...
         'String',['0|' lagstring], ...
         'CallBack','maindlg change', ...
         'Tag','ListBoxLag');

      if (strcmp(exo1enable,'on')==1)|(strcmp(exo0enable,'on')==1);
         set(model.lagexotext,'Enable','on');
         set(model.lagexo,'Enable','on');
      end;

      %
      % Number of impulse responses control
      %

      model.mypopuphtext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[307 250 130 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Enable',runenable, ...
         'HorizontalAlignment','left', ...
         'Visible','off', ...
         'Style','text', ...
         'String','Number of Responses:', ...
         'Tag','ListBoxText2');

      model.mypopuph = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[477 255 50 20], ...
         'Style','popupmenu', ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Enable',runenable, ...
         'Visible','off', ...
         'Value',model_var.newh, ...
         'String',respstring, ...
         'CallBack','maindlg change', ...
         'Tag','ListBoxHorizon');

      %
      % Confidence region size control
      %

      model.mypopupctext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[307 220 132 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Enable',runenable, ...
         'HorizontalAlignment','left', ...
         'Visible','off', ...
         'Style','text', ...
         'String','Confidence Band Size:', ...
         'Tag','ListBoxText2');

      model.mypopupc = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[477 225 50 20], ...
         'Style','popupmenu', ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Enable',runenable, ...
         'Visible','off', ...
         'Value',model_var.newc, ...
         'String','50|51|52|53|54|55|56|57|58|59|60|61|62|63|64|65|66|67|68|69|70|71|72|73|74|75|76|77|78|79|80|81|82|83|84|85|86|87|88|89|90|91|92|93|94|95|96|97|98|99', ...
         'CallBack','maindlg change', ...
         'Tag','ListBoxHorizon');

      %
      % Specification tests
      %

      model.serial = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[307 151 210 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',model_var.spectest(1,1), ...
         'Enable',runenable, ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','maindlg spectest', ...
         'String','Serial Correlation Tests', ...
         'Tag','CheckSerial');

      model.arch = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[307 121 210 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',model_var.spectest(1,2), ...
         'Enable',runenable, ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','maindlg spectest', ...
         'String','ARCH Tests', ...
         'Tag','CheckARCH');

      model.normality = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[307 91 210 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',model_var.spectest(1,3), ...
         'Enable',runenable, ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','maindlg spectest', ...
         'String','Normality Tests', ...
         'Tag','CheckNormality');

      model.constancy = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[307 61 210 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',model_var.spectest(1,4), ...
         'Enable',runenable, ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','maindlg spectest', ...
         'String','Parameter Constancy Tests', ...
         'Tag','CheckConstancy');

      %
      % Tab output
      %

      %
      % Outer axis for output file
      %

      model.outputselect = axesbox([28 397 516 75],'Output Selection',84,[0.5 1],'off',var_ini);
%      set(model.outputselect,'Visible','off');

      %
      % outer axis for estimation log
      %

      model.estimationlog = axesbox([28 48 516 335],'Estimation Log',75,[0.5 1],'off',var_ini);
%      set(model.estimationlog,'Visible','off');

      %
      % Show output file
      %

      model.outputfiletext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[44 433+add_height 150 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Output file:', ...
         'Tag','ListBoxText5');

      if var_ini.edit_context==0;
         model.outputfile = uicontrol('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[44 413 419 22], ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Style','edit', ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'String',model_var.outputfile, ...
            'Callback','maindlg checkother', ...
            'Enable','on', ...
            'Tag','EditBox5');
      else;
         model.outputfile = editbox('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[44 413 419 22], ...
            'FontName',get(model.endogenoustext,'FontName'), ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'String',model_var.outputfile, ...
            'Callback','maindlg checkother', ...
            'Enable','on', ...
            'Tag','EditBox5');
      end;

      %
      % Button for selecting output file
      %

      model.outputbutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[468 413 60 22], ...
         'TooltipString','Browse', ...
         'Visible','off', ...
         'CData',button_images.browse, ...
         'Callback','maindlg openoutput', ...
         'Enable','on', ...
         'Tag','OpenEditBox5');

      %
      % Estimation log listbox
      %

      model.estimation_log = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[44 64 484 303], ...
         'FontSize',10, ...
         'FontName','FixedWidth', ...
         'Style','listbox', ...
         'Enable','inactive', ...
         'Visible','off', ...
         'UserData',1, ...
         'Min',0, ...
         'Max',2, ...
         'ListboxTop',1, ...
         'HorizontalAlignment','left', ...
         'String','', ...
         'Tag','EstimationLogListBox', ...
         'Value',[]);

      %
      % adding a statusbar
      %

      model.statusbar = statusbar('String',status_str,'Position',[2 2 570 16],'ExtraPixel',1);
      set(model.quitdata,'UserData',status_str);

      set(maingui,'UserData',model, ...
         'WindowButtonMotionFcn','show_main_status_fcn', ...
         'HandleVisibility','callback');

   case 'tab'
      oldtab = get(model.tab1,'UserData');
      newtab = get(gco,'Tag');
      newtab = strrep(newtab,'tab','');
      newtab = mystr2num(newtab);
      if abs(oldtab-newtab)>0;
         if (iswinxp==1)&(matlabnumber>=7);
            fixtabs(model,oldtab,newtab);
         end;
         set(model.tab1,'UserData',newtab);
         if newtab==1;
            set(model.frame3tab1,'Visible','off');
            set(model.frame3tab2,'Visible','on');
            set(model.frame3tab3,'Visible','on');
            set(model.frame1tab2,'Position',[90.4 480 74.4 11]);
            set(model.frame1tab3,'Position',[165.8 480 74.4 11]);
            set(model.tab1,'Position',[14 488 76.4 25]);
            set(model.tab2,'Position',[90.4 488 74.4 23]);
            set(model.tab3,'Position',[165.8 488 74.4 23]);
            %
            % Tab parameters
            %
            set(model.radiocoint,'Visible','off');
            set(model.radionocoint,'Visible','off');
            set(model.uconstant,'Visible','off');
            set(model.rconstant,'Visible','off');
            set(model.utrend,'Visible','off');
            set(model.rtrend,'Visible','off');
            set(model.seasonal,'Visible','off');
            set(model.noseasonal,'Visible','off');
            set(model.structural,'Visible','off');
            set(model.shock_names,'Visible','off');
            set(model.reduced,'Visible','off');
            set(model.mypopuptext,'Visible','off');
            set(model.mypopup,'Visible','off');
            set(model.lagexotext,'Visible','off');
            set(model.lagexo,'Visible','off');
            set(model.mypopuphtext,'Visible','off');
            set(model.mypopuph,'Visible','off');
            set(model.mypopupctext,'Visible','off');
            set(model.mypopupc,'Visible','off');
            set(model.serial,'Visible','off');
            set(model.arch,'Visible','off');
            set(model.normality,'Visible','off');
            set(model.constancy,'Visible','off');
            set(model.modelselect,'Visible','off');
            set(model.parameterselect,'Visible','off');
            set(model.cointegrationselect,'Visible','off');
            set(model.deterministicselect,'Visible','off');
            set(model.specificationselect,'Visible','off');
            %
            % Tab output
            %
            set(model.outputselect,'Visible','off');
            set(model.outputfiletext,'Visible','off');
            set(model.outputbutton,'Visible','off');
            if strcmp(get(model.endogenous,'Type'),'uicontrol')==1;
               set(model.outputfile,'Visible','off');
            else;
               editbox(model.outputfile,'Visible','off');
            end;
            set(model.estimationlog,'Visible','off');
            set(model.estimation_log,'Visible','off');
            drawnow;
            %
            % Tab data
            %
            set(model.endogenoustext,'Visible','on');
            set(model.endobutton,'Visible','on');
            set(model.exogenous1text,'Visible','on');
            set(model.exo1button,'Visible','on');
            set(model.exogenous0text,'Visible','on');
            set(model.exo0button,'Visible','on');
            set(model.deterministictext,'Visible','on');
            set(model.deterbutton,'Visible','on');
            if strcmp(get(model.endogenous,'Type'),'uicontrol')==1;
               set(model.endogenous,'Visible','on');
               set(model.exogenous1,'Visible','on');
               set(model.exogenous0,'Visible','on');
               set(model.deterministic,'Visible','on');
            else;
               editbox(model.endogenous,'Visible','on');
               editbox(model.exogenous1,'Visible','on');
               editbox(model.exogenous0,'Visible','on');
               editbox(model.deterministic,'Visible','on');
            end;
            set(model.sample,'Visible','on');
            set(model.beginyear,'Visible','on');
            set(model.beginperiod,'Visible','on');
            set(model.sampleseparator,'Visible','on');
            set(model.endyear,'Visible','on');
            set(model.endperiod,'Visible','on');
            set(model.subsample,'Visible','on');
            set(model.subbeginyear,'Visible','on');
            set(model.subbeginperiod,'Visible','on');
            set(model.subsampleseparator,'Visible','on');
            set(model.subendyear,'Visible','on');
            set(model.subendperiod,'Visible','on');
            set(model.sampleselect,'Visible','on');
            set(model.dataselect,'Visible','on');
            set(model.change_endonames,'Visible','on');
            set(model.change_exo1names,'Visible','on');
            set(model.change_exo0names,'Visible','on');
            set(model.change_deternames,'Visible','on');
            set(model.endosheettext,'Visible','on');
            set(model.exo1sheettext,'Visible','on');
            set(model.exo0sheettext,'Visible','on');
            set(model.detersheettext,'Visible','on');
            drawnow;
         elseif newtab==2;
            checkvis = strcmp(get(model.endogenous,'Visible'),'on');
            set(model.frame3tab1,'Visible','on');
            set(model.frame3tab2,'Visible','off');
            set(model.frame3tab3,'Visible','on');
            set(model.frame1tab2,'Position',[89.4 480 76.4 11]);
            set(model.frame1tab3,'Position',[165.8 480 74.4 11]);
            set(model.tab1,'Position',[15 488 74.4 23]);
            set(model.tab2,'Position',[89.4 488 76.4 25]);
            set(model.tab3,'Position',[165.8 488 74.4 23]);
            %
            % Tab output
            %
            set(model.outputselect,'Visible','off');
            set(model.outputfiletext,'Visible','off');
            set(model.outputbutton,'Visible','off');
            if strcmp(get(model.endogenous,'Type'),'uicontrol')==1;
               set(model.outputfile,'Visible','off');
            else;
               editbox(model.outputfile,'Visible','off');
            end;
            set(model.estimationlog,'Visible','off');
            set(model.estimation_log,'Visible','off');
            if checkvis==0;
               drawnow;
            end;
            %
            % Tab data
            %
            set(model.endogenoustext,'Visible','off');
            set(model.endobutton,'Visible','off');
            set(model.exogenous1text,'Visible','off');
            set(model.exo1button,'Visible','off');
            set(model.exogenous0text,'Visible','off');
            set(model.exo0button,'Visible','off');
            set(model.deterministictext,'Visible','off');
            set(model.deterbutton,'Visible','off');
            if strcmp(get(model.endogenous,'Type'),'uicontrol')==1;
               set(model.endogenous,'Visible','off');
               set(model.exogenous1,'Visible','off');
               set(model.exogenous0,'Visible','off');
               set(model.deterministic,'Visible','off');
            else;
               editbox(model.endogenous,'Visible','off');
               editbox(model.exogenous1,'Visible','off');
               editbox(model.exogenous0,'Visible','off');
               editbox(model.deterministic,'Visible','off');
            end;
            set(model.sample,'Visible','off');
            set(model.beginyear,'Visible','off');
            set(model.beginperiod,'Visible','off');
            set(model.sampleseparator,'Visible','off');
            set(model.endyear,'Visible','off');
            set(model.endperiod,'Visible','off');
            set(model.subsample,'Visible','off');
            set(model.subbeginyear,'Visible','off');
            set(model.subbeginperiod,'Visible','off');
            set(model.subsampleseparator,'Visible','off');
            set(model.subendyear,'Visible','off');
            set(model.subendperiod,'Visible','off');
            set(model.sampleselect,'Visible','off');
            set(model.dataselect,'Visible','off');
            set(model.change_endonames,'Visible','off');
            set(model.change_exo1names,'Visible','off');
            set(model.change_exo0names,'Visible','off');
            set(model.change_deternames,'Visible','off');
            set(model.endosheettext,'Visible','off');
            set(model.exo1sheettext,'Visible','off');
            set(model.exo0sheettext,'Visible','off');
            set(model.detersheettext,'Visible','off');
            if checkvis==1;
               drawnow;
            end;
            %
            % Tab parameters
            %
            set(model.radiocoint,'Visible','on');
            set(model.radionocoint,'Visible','on');
            set(model.uconstant,'Visible','on');
            set(model.rconstant,'Visible','on');
            set(model.utrend,'Visible','on');
            set(model.rtrend,'Visible','on');
            set(model.seasonal,'Visible','on');
            set(model.noseasonal,'Visible','on');
            set(model.structural,'Visible','on');
            set(model.shock_names,'Visible','on');
            set(model.reduced,'Visible','on');
            set(model.mypopuptext,'Visible','on');
            set(model.mypopup,'Visible','on');
            set(model.lagexotext,'Visible','on');
            set(model.lagexo,'Visible','on');
            set(model.mypopuphtext,'Visible','on');
            set(model.mypopuph,'Visible','on');
            set(model.mypopupctext,'Visible','on');
            set(model.mypopupc,'Visible','on');
            set(model.serial,'Visible','on');
            set(model.arch,'Visible','on');
            set(model.normality,'Visible','on');
            set(model.constancy,'Visible','on');
            set(model.modelselect,'Visible','on');
            set(model.parameterselect,'Visible','on');
            set(model.cointegrationselect,'Visible','on');
            set(model.deterministicselect,'Visible','on');
            set(model.specificationselect,'Visible','on');
         elseif newtab==3;
            set(model.frame3tab1,'Visible','on');
            set(model.frame3tab2,'Visible','on');
            set(model.frame3tab3,'Visible','off');
            set(model.frame1tab2,'Position',[90.4 480 74.4 11]);
            set(model.frame1tab3,'Position',[164.8 480 76.4 11]);
            set(model.tab1,'Position',[15 488 74.4 23]);
            set(model.tab2,'Position',[90.4 488 74.4 23]);
            set(model.tab3,'Position',[164.8 488 76.4 25]);
            %
            % Tab data
            %
            set(model.endogenoustext,'Visible','off');
            set(model.endobutton,'Visible','off');
            set(model.exogenous1text,'Visible','off');
            set(model.exo1button,'Visible','off');
            set(model.exogenous0text,'Visible','off');
            set(model.exo0button,'Visible','off');
            set(model.deterministictext,'Visible','off');
            set(model.deterbutton,'Visible','off');
            if strcmp(get(model.endogenous,'Type'),'uicontrol')==1;
               set(model.endogenous,'Visible','off');
               set(model.exogenous1,'Visible','off');
               set(model.exogenous0,'Visible','off');
               set(model.deterministic,'Visible','off');
            else;
               editbox(model.endogenous,'Visible','off');
               editbox(model.exogenous1,'Visible','off');
               editbox(model.exogenous0,'Visible','off');
               editbox(model.deterministic,'Visible','off');
            end;
            set(model.sample,'Visible','off');
            set(model.beginyear,'Visible','off');
            set(model.beginperiod,'Visible','off');
            set(model.sampleseparator,'Visible','off');
            set(model.endyear,'Visible','off');
            set(model.endperiod,'Visible','off');
            set(model.subsample,'Visible','off');
            set(model.subbeginyear,'Visible','off');
            set(model.subbeginperiod,'Visible','off');
            set(model.subsampleseparator,'Visible','off');
            set(model.subendyear,'Visible','off');
            set(model.subendperiod,'Visible','off');
            set(model.sampleselect,'Visible','off');
            set(model.dataselect,'Visible','off');
            set(model.change_endonames,'Visible','off');
            set(model.change_exo1names,'Visible','off');
            set(model.change_exo0names,'Visible','off');
            set(model.change_deternames,'Visible','off');
            set(model.endosheettext,'Visible','off');
            set(model.exo1sheettext,'Visible','off');
            set(model.exo0sheettext,'Visible','off');
            set(model.detersheettext,'Visible','off');
            drawnow;
            %
            % Tab parameters
            %
            set(model.radiocoint,'Visible','off');
            set(model.radionocoint,'Visible','off');
            set(model.uconstant,'Visible','off');
            set(model.rconstant,'Visible','off');
            set(model.utrend,'Visible','off');
            set(model.rtrend,'Visible','off');
            set(model.seasonal,'Visible','off');
            set(model.noseasonal,'Visible','off');
            set(model.structural,'Visible','off');
            set(model.shock_names,'Visible','off');
            set(model.reduced,'Visible','off');
            set(model.mypopuptext,'Visible','off');
            set(model.mypopup,'Visible','off');
            set(model.lagexotext,'Visible','off');
            set(model.lagexo,'Visible','off');
            set(model.mypopuphtext,'Visible','off');
            set(model.mypopuph,'Visible','off');
            set(model.mypopupctext,'Visible','off');
            set(model.mypopupc,'Visible','off');
            set(model.serial,'Visible','off');
            set(model.arch,'Visible','off');
            set(model.normality,'Visible','off');
            set(model.constancy,'Visible','off');
            set(model.modelselect,'Visible','off');
            set(model.parameterselect,'Visible','off');
            set(model.cointegrationselect,'Visible','off');
            set(model.deterministicselect,'Visible','off');
            set(model.specificationselect,'Visible','off');
            %
            % Tab output
            %
            set(model.outputselect,'Visible','on');
            set(model.outputfiletext,'Visible','on');
            set(model.outputbutton,'Visible','on');
            if strcmp(get(model.endogenous,'Type'),'uicontrol')==1;
               set(model.outputfile,'Visible','on');
            else;
               editbox(model.outputfile,'Visible','on');
            end;
            set(model.estimationlog,'Visible','on');
            set(model.estimation_log,'Visible','on');
            drawnow;
         end;
      end;
   case 'reorderlist'
      if model_var.runvar==0;
         model_var.runvar = 1;
         currmodel = get(model.open,'UserData');
         thisupdown = updowndlg('init',str2mat_fcn(var_ini.reopenlist),'Reorder Model Files','Current Model List',90);
         updown = get(thisupdown,'UserData');
         newreopenfile = mat2str_fcn(get(updown.cancel,'UserData'));
         set(updown.apply,'UserData','done');
         killguipid(thisupdown);
         %
         % Fix list if necessary
         %
         if isequal(var_ini.reopenlist,newreopenfile)==0;
            var_ini.reopenlist = newreopenfile;
            model_var.reopenfile = fixlist(var_ini.reopenlist);
            model = fix_model_menu(model,model_var);
            set(maingui,'UserData',model);
         end;
         model_var.runvar = 0;
      end;
   case 'scaleoption'
      if model_var.runvar==0;
         model_var.runvar = 1;
         new_scale = get(gcbo,'UserData');
         if abs(new_scale-model_var.scale_endo)>0;
            model_var.scale_endo = new_scale;
            set(model.scale_1,'Check','off');
            set(model.scale_2,'Check','off');
            set(model.scale_3,'Check','off');
            set(model.scale_4,'Check','off');
            set(model.scale_5,'Check','off');
            set(model.scale_6,'Check','off');
            set(model.scale_7,'Check','off');
            set(model.scale_8,'Check','off');
            set(model.scale_9,'Check','off');
            if model_var.scale_endo==0.0001;
               set(model.scale_1,'Check','on');
            elseif model_var.scale_endo==0.001;
               set(model.scale_2,'Check','on');
            elseif model_var.scale_endo==0.01;
               set(model.scale_3,'Check','on');
            elseif model_var.scale_endo==0.1;
               set(model.scale_4,'Check','on');
            elseif model_var.scale_endo==1;
               set(model.scale_5,'Check','on');
            elseif model_var.scale_endo==10;
               set(model.scale_6,'Check','on');
            elseif model_var.scale_endo==100;
               set(model.scale_7,'Check','on');
            elseif model_var.scale_endo==1000;
               set(model.scale_8,'Check','on');
            elseif model_var.scale_endo==10000;
               set(model.scale_9,'Check','on');
            end;
            %
            % Update save model controls
            %
            set(model.savemenu,'Enable','on');
            set(model.store,'Enable','on');
         end;
         model_var.runvar = 0;
      end;
   case 'close'
      if model_var.runvar==0;
         model_var.runvar = 1;
         [model,model_var,var_ini,oldmodel_var] = main_close_fcn(model,model_var,var_ini,button_images);
         set(maingui,'Name','Structural VAR','UserData',model);
         model_var.runvar = 0;
      end;
   case 'reopen'
      if model_var.runvar==0;
         model_var.runvar = 1;
         %
         % Determine which file to open
         %
         whichelem = gcbo;
         thisinputfile = get(whichelem,'Userdata');
         newinputfile = get(model.open,'UserData');
         if fileexist(newinputfile)==0;
            newinputfile = '';
         end;
         %
         % Fix file lists
         %
         if strcmp(newinputfile,'')==0;
            if isempty(findstr(newinputfile,var_ini.reopenlist))==1;
               if size(model_var.reopenfile,1)>=10;
                  myreopenfile = model_var.reopenfile(10,:);
                  if strcmp(strrep(myreopenfile,' ',''),thisinputfile)==0;
                     model_var.reopenfile = model_var.reopenfile(1:9,:);
                  else;
                     model_var.reopenfile = strvcat(model_var.reopenfile(1:8,:),model_var.reopenfile(10,:));
                  end;
%                  var_ini.reopenlist = invlist(model_var.reopenfile);
               end;
               model_var.reopenfile = strvcat(newinputfile,model_var.reopenfile);
               var_ini.reopenlist = [newinputfile '|' var_ini.reopenlist];
            end;
         end;
         %
         % Delete objects in file list
         %
         thish = findobj('Type','uimenu','Callback','maindlg reopen')';
         if isempty(thish)==0;
            delete(thish);
         end;
         %
         %
         % recreate objects in file list menu
         %
         num = 1;
         for i=1:size(model_var.reopenfile,1);
            thisfile = strtrim(model_var.reopenfile(i,:));
            if strcmp(thisinputfile,thisfile)==0;
               if num==1;
                  model.thisfile = uimenu('Parent',model.reopen, ...
                     'Label',['&1. ' getfilename(thisfile)], ...
                     'Callback','maindlg reopen', ...
                     'Accelerator','1', ...
                     'Separator','on', ...
                     'UserData',thisfile, ...
                     'Tag',['1-' getfilename(thisfile)]);
               else;
                  if num<10;
                     model.thisfile = uimenu('Parent',model.reopen, ...
                        'Label',['&' num2str(num) '. ' getfilename(thisfile)], ...
                        'Callback','maindlg reopen', ...
                        'Accelerator',num2str(num), ...
                        'UserData',thisfile, ...
                        'Tag',[num2str(num) '-' getfilename(thisfile)]);
                  else;
                     model.thisfile = uimenu('Parent',model.reopen, ...
                        'Label',['1&0. ' getfilename(thisfile)], ...
                        'Callback','maindlg reopen', ...
                        'Accelerator','0', ...
                        'UserData',thisfile, ...
                        'Tag',['10-' getfilename(thisfile)]);
                  end;
               end;
               num = num+1;
            end;
         end;
         model_var.inputfile = thisinputfile;
         set(model.reopen,'UserData',thisinputfile);
         model_var.runvar = 0;
      end;
      var_ini.images = button_images;
      var_ini.model = model_var;
      var_ini.oldmodel = oldmodel_var;
      set(model.openmenu,'UserData',var_ini);
      set(maingui,'UserData',model);
      maindlg('openmodel');
   case 'clearlist'
      if model_var.runvar==0;
         model_var.runvar = 1;
         newinputfile = get(model.open,'UserData');
         if strcmp(var_ini.reopenlist,'')==0;
            thish = findobj('Type','uimenu','Callback','maindlg reopen')';
            if isempty(thish)==0;
               delete(thish);
            end;
            %
            var_ini.reopenlist = '';
            model_var.reopenfile = '';
            if strcmp(getext(newinputfile),'.var')==1;
               var_ini.reopenlist = [newinputfile '|'];
               model_var.reopenfile = newinputfile;
            end;
         end;
         set(model.reorderlist,'Enable','off');
         set(maingui,'UserData',model);
         model_var.runvar = 0;
      end;
   case 'store'
      if model_var.runvar==0;
         model_var.runvar = 1;
         [model,model_var,var_ini] = main_store_fcn(model,model_var,var_ini,maingui);
         set(maingui,'UserData',model);
         model_var.runvar = 0;
      end;
   case 'openmodel'
      if model_var.runvar==0;
         model_var.runvar = 1;
         [model,model_var,oldmodel_var,var_ini] = main_openmodel_fcn(model,model_var,oldmodel_var,var_ini,button_images,maingui);
         model_var.runvar = 0;
         var_ini.images = button_images;
         var_ini.model = model_var;
         var_ini.oldmodel = oldmodel_var;
         set(model.openmenu,'UserData',var_ini);
         set(maingui,'UserData',model);
      end;
   case 'clear'
      if model_var.runvar==0;
         model_var.runvar = 1;
         [model,model_var,var_ini,oldmodel_var] = main_clear_fcn(model,model_var,var_ini,oldmodel_var,button_images,maingui);
         set(maingui,'UserData',model);
         model_var.runvar = 0;
      end;
   case 'run'
      if model_var.runvar==0;
         model_var.runvar = 1;
         var_ini.images = button_images;
         var_ini.model = model_var;
         var_ini.oldmodel = oldmodel_var;
         set(model.openmenu,'UserData',var_ini);
         [model,model_var,var_ini] = main_run_fcn(model,model_var,var_ini,maingui);
         set(maingui,'UserData',model);
         model_var.runvar = 0;
      end;
      if (var_ini.openmyoutput==1)&(var_ini.noprint==0);
         maindlg('printpreview');
      end;
   case 'model_select'
      if model_var.runvar==0;
         model_var.runvar = 1;
         var_ini.images = button_images;
         var_ini.model = model_var;
         var_ini.oldmodel = oldmodel_var;
         set(model.openmenu,'UserData',var_ini);
         [model,model_var,var_ini] = main_model_select_fcn(model,model_var,var_ini,maingui);
         set(maingui,'UserData',model);
         model_var.runvar = 0;
      end;
   case 'open'
      if model_var.runvar==0;
         model_var.runvar = 1;
         [model,model_var,var_ini,oldmodel_var] = main_open_fcn(model,model_var,var_ini,oldmodel_var,button_images,maingui);
         set(maingui,'UserData',model);
         model_var.runvar = 0;
      end;
   case 'openexo1'
      if model_var.runvar==0;
         model_var.runvar = 1;
         [model,model_var,oldmodel_var] = main_openexo1_fcn(model,model_var,var_ini,oldmodel_var,button_images,maingui);
         set(maingui,'UserData',model);
         model_var.runvar = 0;
      end;
   case 'openexo0'
      if model_var.runvar==0;
         model_var.runvar = 1;
         [model,model_var,oldmodel_var] = main_openexo0_fcn(model,model_var,var_ini,oldmodel_var,button_images,maingui);
         set(maingui,'UserData',model);
         model_var.runvar = 0;
      end;
   case 'opendeter'
      if model_var.runvar==0;
         model_var.runvar = 1;
         [model,model_var,oldmodel_var] = main_opendeter_fcn(model,model_var,var_ini,oldmodel_var,button_images,maingui);
         set(maingui,'UserData',model);
         model_var.runvar = 0;
      end;
   case 'openoutput'
      if model_var.runvar==0;
         model_var.runvar = 1;
         model_var.outputfile = get(model.outputfile,'String');
         [savefile,savepath] = uiputfile(model_var.outputfile, 'Select file or enter filename');
         drawnow;
         if isnumeric(savefile)==0;
            %
            % append .txt if extension is left out
            %
            numchar = size(savefile,2);
            charpos = 0;
            i = numchar;
            while i>=1;
               thischar = savefile(1,i);
               if thischar=='.'
                  charpos = i;
                  i = 0;
               else;
                  i = i-1;
               end;
            end;
            if charpos==0;
               savefile = strcat(savefile,'.txt');
            end;
            if strcmp(model_var.outputfile,strcat(savepath,savefile))==0;
               if strcmp(getpath(model_var.outputfile),savepath)==0;
                  model_var.newoutputpath = 1;
               end;
               oldmodel_var.outputfile = model_var.outputfile;
               model_var.outputfile = strcat(savepath,savefile);
               set(model.outputfile,'String',model_var.outputfile);
               set(model.store,'Enable','on');
               set(model.savemenu,'Enable','on');
               if fileexist(model_var.outputfile)==1;
                  set(model.printpreview,'Enable','on');
                  set(model.print,'Enable','on');
                  set(model.printmenu,'Enable','on');
                  set(model.printpreviewmenu,'Enable','on');
                  if islatexformat(model_var.outputfile)==1;
                     stat_dvi = check_dvi(var_ini);
                     if stat_dvi==0;
                        set(model.dvimenu,'Enable','on');
                     else;
                        set(model.dvimenu,'Enable','off');
                     end;
                     [stat_ps,dvips] = check_ps(var_ini);
                     if stat_ps==0;
                        set(model.psmenu,'Enable','on');
                     else;
                        set(model.psmenu,'Enable','off');
                     end;
                     [stat_pdf,prog_seq] = check_pdf(var_ini);
                     if stat_pdf==0;
                        set(model.pdfmenu,'Enable','on');
                     else;
                        set(model.pdfmenu,'Enable','off');
                     end;
                  else;
                     set(model.dvimenu,'Enable','off');
                     set(model.psmenu,'Enable','off');
                     set(model.pdfmenu,'Enable','off');
                  end;
               else;
                  fid = fopen(model_var.outputfile,'wt');
                  fclose(fid);
                  set(model.printpreview,'Enable','off');
                  set(model.print,'Enable','off');
                  set(model.printmenu,'Enable','off');
                  set(model.printpreviewmenu,'Enable','off');
                  set(model.dvimenu,'Enable','off');
                  set(model.psmenu,'Enable','off');
                  set(model.pdfmenu,'Enable','off');
               end;
            end;
            if fileexist(model_var.outputfile)==1;
               if strcmp(var_ini.editor,'')==0;
                  set(model.editormenu,'Enable','on');
               else;
                  set(model.editormenu,'Enable','off');
               end;
            end;
         end;
         set(maingui,'UserData',model);
         model_var.runvar = 0;
      end;
   case 'change'
      if model_var.runvar==0;
         model_var.runvar = 1;
         check = abs(get(model.mypopup,'Value')-model_var.newp);
         check = check+abs(get(model.lagexo,'Value')-1-model_var.lagexo);
         check = check+abs(get(model.mypopuph,'Value')-model_var.newh);
         check = check+abs(get(model.mypopupc,'Value')-model_var.newc);
         if check>0;
            set(model.store,'Enable','on');
            set(model.savemenu,'Enable','on');
         end;
         set(maingui,'UserData',model);
         model_var.runvar = 0;
      end;
   case 'undo'
      editmenufcn(maingui,'EditUndo');
      maindlg('checkendo');
      maindlg('checkother');
   case 'copy'
      editmenufcn(maingui,'EditCopy');
      maindlg('checkendo');
      maindlg('checkother');
   case 'cut'
      editmenufcn(maingui,'EditCut');
      maindlg('checkendo');
      maindlg('checkother');
   case 'paste'
      editmenufcn(maingui,'EditPaste');
      maindlg('checkendo');
      maindlg('checkother');
   case 'editclear'
      editmenufcn(maingui,'EditClear');
      maindlg('checkendo');
      maindlg('checkother');
   case 'selectall'
      editmenufcn(maingui,'EditSelectAll');
      maindlg('checkendo');
      maindlg('checkother');
   case 'print'
      if model_var.runvar==0;
         model_var.runvar = 1;
         var_ini.images = button_images;
         var_ini.model = model_var;
         var_ini.oldmodel = oldmodel_var;
         set(model.openmenu,'UserData',var_ini);
         myoutput = get(model.outputfile,'String');
         if ispc==1;
            if strcmp(var_ini.txtprint,'')==1;
               prog = ['notepad.exe /p ' fix_path(myoutput) ' &'];
            else;
               prog = fix_path(var_ini.txtprint);
               if strcmp(var_ini.txtprintcmd,'')==0;
                  prog = [prog ' ' var_ini.txtprintcmd];
               end;
               prog = [prog ' ' fix_path(myoutput) ' &'];
            end;
            prog = fixcmd(prog);
            dos(prog);
            drawnow;
         else;
            if isunix==1;
               if strcmp(var_ini.txtprint,'')==1;
                  prog = ['lpr ' myoutput];
               else;
                  prog = var_ini.txtprint;
                  if strcmp(var_ini.txtprintcmd,'')==0;
                     prog = [prog ' ' var_ini.txtprintcmd];
                  end;
                  prog = [prog ' ' myoutput];
               end;
               unix(prog);
               drawnow;
            else;
               txt = 'Currently Structural VAR cannot print files under Mac. If you know how to solve this, please let me know.';
               about(txt,'warning','Print - Mac Message',135,350);
            end;
         end;
         model_var.runvar = 0;
      end;
   case 'printpreview'
      model_var.outputfile = get(model.outputfile,'String');
      %
      % open the print gui
      %
      prtgui = printgui('init',model_var.outputfile);
      myprint = get(prtgui,'UserData');
      set(myprint.print,'UserData','done');
      killguipid(prtgui);
      set(maingui,'UserData',model);
   case 'viewgraphics'
      if model_var.runvar==0;
         model_var.runvar = 1;
         %
         % run graphics viewer function
         %
         view_graphics_fcn;
         model_var.runvar = 0;
      end;
   case 'figmode'
      %
      % open a MatLab figure file
      %
      fig_handle = view_fig_fcn(fig_file,maingui);
      if (isempty(fig_handle)==0)&(ishandle(fig_handle)==1);
         waitfor(fig_handle);
      end;
      set(model.leave,'UserData','done');
      set(maingui,'UserData',model);
   case 'checkendo'
      [model,model_var,oldmodel_var] = main_checkendo_fcn(model,model_var,var_ini,oldmodel_var,button_images,maingui);
      set(maingui,'UserData',model);
   case 'checkother'
      [model,model_var,oldmodel_var] = main_checkother_fcn(model,model_var,oldmodel_var,button_images);
      set(maingui,'UserData',model);
   case 'radio'
      whichobj = gco;
      checkvalue = get(whichobj,'Value');
      set(whichobj,'Value',1);
      if whichobj==model.radiocoint;
         set(model.radionocoint,'Value',0);
         newcointvalue = 0;
      else;
         set(model.radiocoint,'Value',0);
         newcointvalue = 1;
      end;
      if checkvalue==1;
         if newcointvalue==model_var.cointvalue;
            set(model.store,'Enable','on');
            set(model.savemenu,'Enable','on');
         end;
      end;
      model_var.cointvalue = get(model.radiocoint,'Value');
      model_var.nocointvalue = get(model.radionocoint,'Value');
      model_var.newdeterselect(1,1) = get(model.uconstant,'Value');
      model_var.newdeterselect(1,2) = get(model.rconstant,'Value');
      model_var.newdeterselect(1,3) = get(model.utrend,'Value');
      model_var.newdeterselect(1,4) = get(model.rtrend,'Value');
      model_var.newmodeltype(1,1) = get(model.structural,'Value');
      model_var.newmodeltype(1,2) = get(model.reduced,'Value');
      model_var.newseasonal(1,1) = get(model.seasonal,'Value');
      model_var.newseasonal(1,2) = get(model.noseasonal,'Value');
      modeldesc = getmodeldesc(model_var);
      set(model.text,'String',modeldesc);
      set(maingui,'UserData',model);
   case 'deterselect'
      whichobj = gco;
      checkvalue = get(whichobj,'UserData');
      set(whichobj,'Value',1);
      if whichobj==model.uconstant;
         set(model.rconstant,'Value',0);
         set(model.utrend,'Value',0);
         set(model.rtrend,'Value',0);
      elseif whichobj==model.rconstant;
         set(model.uconstant,'Value',0);
         set(model.utrend,'Value',0);
         set(model.rtrend,'Value',0);
      elseif whichobj==model.utrend;
         set(model.uconstant,'Value',0);
         set(model.rconstant,'Value',0);
         set(model.rtrend,'Value',0);
      elseif whichobj==model.rtrend;
         set(model.uconstant,'Value',0);
         set(model.rconstant,'Value',0);
         set(model.utrend,'Value',0);
      end;
      model_var.newdeterselect(1,1) = get(model.uconstant,'Value');
      model_var.newdeterselect(1,2) = get(model.rconstant,'Value');
      model_var.newdeterselect(1,3) = get(model.utrend,'Value');
      model_var.newdeterselect(1,4) = get(model.rtrend,'Value');
      if sum(abs(model_var.newdeterselect-model_var.deterselect))>0;
         set(model.store,'Enable','on');
         set(model.savemenu,'Enable','on');
      end;
      model_var.newmodeltype(1,1) = get(model.structural,'Value');
      model_var.newmodeltype(1,2) = get(model.reduced,'Value');
      model_var.newseasonal(1,1) = get(model.seasonal,'Value');
      model_var.newseasonal(1,2) = get(model.noseasonal,'Value');
      modeldesc = getmodeldesc(model_var);
      set(model.text,'String',modeldesc);
      set(maingui,'UserData',model);
   case 'modeltype'
      whichobj = gco;
      checkvalue = get(whichobj,'UserData');
      set(whichobj,'Value',1);
      if whichobj==model.structural;
         set(model.reduced,'Value',0);
      elseif whichobj==model.reduced;
         set(model.structural,'Value',0);
      end;
      model_var.newmodeltype(1,1) = get(model.structural,'Value');
      model_var.newmodeltype(1,2) = get(model.reduced,'Value');
      if sum(abs(model_var.newmodeltype-model_var.modeltype))>0;
         set(model.store,'Enable','on');
         set(model.savemenu,'Enable','on');
      end;
      model_var.newdeterselect(1,1) = get(model.uconstant,'Value');
      model_var.newdeterselect(1,2) = get(model.rconstant,'Value');
      model_var.newdeterselect(1,3) = get(model.utrend,'Value');
      model_var.newdeterselect(1,4) = get(model.rtrend,'Value');
      model_var.newseasonal(1,1) = get(model.seasonal,'Value');
      model_var.newseasonal(1,2) = get(model.noseasonal,'Value');
      modeldesc = getmodeldesc(model_var);
      set(model.text,'String',modeldesc);
      set(maingui,'UserData',model);
   case 'seasonal'
      whichobj = gco;
      checkvalue = get(whichobj,'UserData');
      set(whichobj,'Value',1);
      if whichobj==model.seasonal;
         set(model.noseasonal,'Value',0);
      elseif whichobj==model.noseasonal;
         set(model.seasonal,'Value',0);
      end;
      model_var.newseasonal(1,1) = get(model.seasonal,'Value');
      model_var.newseasonal(1,2) = get(model.noseasonal,'Value');
      if sum(abs(model_var.newseasonal-model_var.seasonal))>0;
         set(model.store,'Enable','on');
         set(model.savemenu,'Enable','on');
      end;
      model_var.newdeterselect(1,1) = get(model.uconstant,'Value');
      model_var.newdeterselect(1,2) = get(model.rconstant,'Value');
      model_var.newdeterselect(1,3) = get(model.utrend,'Value');
      model_var.newdeterselect(1,4) = get(model.rtrend,'Value');
      model_var.newmodeltype(1,1) = get(model.structural,'Value');
      model_var.newmodeltype(1,2) = get(model.reduced,'Value');
      modeldesc = getmodeldesc(model_var);
      set(model.text,'String',modeldesc);
      set(maingui,'UserData',model);
   case 'preferences'
      if model_var.runvar==0;
         model_var.runvar = 1;
         var_ini.images = button_images;
         var_ini.model = model_var;
         var_ini.oldmodel = oldmodel_var;
         old_gui_light_color = var_ini.gui_light_color;
         old_gui_shade_color = var_ini.gui_shade_color;
         old_gui_dark_color = var_ini.gui_dark_color;
         old_frame_light_color = var_ini.frame_light_color;
         old_frame_shade_color = var_ini.frame_shade_color;
         old_frame_dark_color = var_ini.frame_dark_color;
         set(model.openmenu,'UserData',var_ini);
         set(model.preferences,'Enable','off');
         set(model.preferencesmenu,'Enable','off');
         olddirstructure = var_ini.dirstructure;
         var_ini.lastfile = get(model.open,'UserData');
         optionsdlg('init',var_ini);
         drawnow;
         %
         % read the var.ini file if it exists
         %
         [read_status,var_ini] = read_inifile;
         if read_status==1;
            var_ini = initialize_inifile;
         end;
         if strcmp(var_ini.helpexe,'')==1;
            set(model.menuhelp,'Enable','off');
            set(model.help,'Enable','off');
         else;
            set(model.menuhelp,'Enable','on');
            set(model.help,'Enable','on');
         end;
         if var_ini.method(1,3)==0;
            set(model.estimate,'Label','Estimate Model...');
            set(model.run,'TooltipString','Estimate Model');
         else;
            set(model.estimate,'Label','Analyse Model...');
            set(model.run,'TooltipString','Analyse Model');
         end;
         %
         % check if GUI font has changed
         %
         fontname = get(model.endogenoustext,'FontName');
         fontsize = get(model.endogenoustext,'FontSize');
         fontweight = get(model.endogenoustext,'FontWeight');
         fontangle = get(model.endogenoustext,'FontAngle');
         if (strcmp(var_ini.gui_fontname,fontname)==0)|(isequal(var_ini.gui_fontsize,fontsize)==0)|(strcmp(var_ini.gui_fontweight,fontweight)==0)|(strcmp(var_ini.gui_fontangle,fontangle)==0);
            %
            % font has changed. adjust all GUI controls that rely on the GUI font
            %
            all_obj = findobj(maingui,'FontName',fontname,'FontSize',fontsize,'FontWeight',fontweight,'FontAngle',fontangle);
            if isempty(all_obj)==0;
               set(all_obj,'FontName',var_ini.gui_fontname,'FontSize',var_ini.gui_fontsize,'FontWeight',var_ini.gui_fontweight,'FontAngle',var_ini.gui_fontangle);
            end;
            set(model.text,'FontName',var_ini.gui_fontname,'FontSize',var_ini.gui_fontsize+2);
            txt_obj = findobj(maingui,'Type','uicontrol','Tag','FrameText')';
            if isempty(txt_obj)==0;
               for i=1:size(txt_obj,2);
                  pos = get(txt_obj(1,i),'Position');
                  ext = get(txt_obj(1,i),'Extent');
                  ud = get(txt_obj(1,i),'UserData');
                  set(txt_obj(1,i),'Position',[pos(1) ud+((15-ext(1,4))/2) ext(1,3:4)]);
               end;
               set(txt_obj,'ForegroundColor',var_ini.frame_color);
            end;
         else;
            txt_obj = findobj(maingui,'Type','uicontrol','Tag','FrameText');
            if isempty(txt_obj)==0;
               set(txt_obj,'ForegroundColor',var_ini.frame_color);
            end;
         end;
         model_color = get(model.text,'Color');
         if max(abs(model_color-var_ini.gui_foreground_color))>0;
            set(model.text,'Color',var_ini.gui_foreground_color);
         end;
         %
         % GUI coloring
         %
         if max(abs(var_ini.gui_light_color-old_gui_light_color))>0;
            l_obj = findobj(maingui,'Type','axes','Tag','gui','XColor',old_gui_light_color);
            if isempty(l_obj)==0;
               set(l_obj,'XColor',var_ini.gui_light_color,'YColor',var_ini.gui_light_color,'ZColor',var_ini.gui_light_color);
            end;
            if max(abs(get(model.frame1tab1,'ForegroundColor')-old_gui_light_color))==0;
               set(model.frame1tab1,'ForegroundColor',var_ini.gui_light_color);
            end;
            if max(abs(get(model.frame2tab1,'ForegroundColor')-old_gui_light_color))==0;
               set(model.frame2tab1,'ForegroundColor',var_ini.gui_light_color);
            end;
            if max(abs(get(model.frame3tab1,'ForegroundColor')-old_gui_light_color))==0;
               set(model.frame3tab1,'ForegroundColor',var_ini.gui_light_color);
            end;
            if max(abs(get(model.frame1tab2,'ForegroundColor')-old_gui_light_color))==0;
               set(model.frame1tab2,'ForegroundColor',var_ini.gui_light_color);
            end;
            if max(abs(get(model.frame3tab2,'ForegroundColor')-old_gui_light_color))==0;
               set(model.frame3tab2,'ForegroundColor',var_ini.gui_light_color);
            end;
            if max(abs(get(model.frame1tab3,'ForegroundColor')-old_gui_light_color))==0;
               set(model.frame1tab3,'ForegroundColor',var_ini.gui_light_color);
            end;
            if max(abs(get(model.frame3tab3,'ForegroundColor')-old_gui_light_color))==0;
               set(model.frame3tab3,'ForegroundColor',var_ini.gui_light_color);
            end;
         end;
         if max(abs(var_ini.gui_shade_color-old_gui_shade_color))>0;
            l_obj = findobj(maingui,'Type','axes','Tag','gui','XColor',old_gui_shade_color);
            if isempty(l_obj)==0;
               set(l_obj,'XColor',var_ini.gui_shade_color,'YColor',var_ini.gui_shade_color,'ZColor',var_ini.gui_shade_color);
            end;
         end;
         if max(abs(var_ini.gui_dark_color-old_gui_dark_color))>0;
            l_obj = findobj(maingui,'Type','axes','Tag','gui','XColor',old_gui_dark_color);
            if isempty(l_obj)==0;
               set(l_obj,'XColor',var_ini.gui_dark_color,'YColor',var_ini.gui_dark_color,'ZColor',var_ini.gui_dark_color);
            end;
         end;
         %
         % frame coloring
         %
         if max(abs(var_ini.frame_light_color-old_frame_light_color))>0;
            l_obj = findobj(maingui,'Type','axes','Tag','frame','XColor',old_frame_light_color);
            if isempty(l_obj)==0;
               set(l_obj,'XColor',var_ini.frame_light_color,'YColor',var_ini.frame_light_color,'ZColor',var_ini.frame_light_color);
            end;
         end;
         if max(abs(var_ini.frame_shade_color-old_frame_shade_color))>0;
            l_obj = findobj(maingui,'Type','axes','Tag','frame','XColor',old_frame_shade_color);
            if isempty(l_obj)==0;
               set(l_obj,'XColor',var_ini.frame_shade_color,'YColor',var_ini.frame_shade_color,'ZColor',var_ini.frame_shade_color);
            end;
         end;
         if max(abs(var_ini.frame_dark_color-old_frame_dark_color))>0;
            l_obj = findobj(maingui,'Type','axes','Tag','frame','XColor',old_frame_dark_color);
            if isempty(l_obj)==0;
               set(l_obj,'XColor',var_ini.frame_dark_color,'YColor',var_ini.frame_dark_color,'ZColor',var_ini.frame_dark_color);
            end;
         end;
         %
         % make changes to gui based on options
         %
         %
         % reset lags
         %
         lagstring = '1';
         for i = 2:max(var_ini.maxlag,max([get(model.lagexo,'Value')-1 get(model.mypopup,'Value')]));
            lagstring = strcat(lagstring,'|',num2str(i));
         end;
         %
         % reset response horizon
         %
         respstring = '1';
         for i=2:max(var_ini.maxresp,get(model.mypopuph,'Value'));
            respstring = strcat(respstring,'|',num2str(i));
         end;
         if abs(olddirstructure-var_ini.dirstructure)>0;
            %
            % fix basedir, modelsdir, resultsdir and outputfile
            %
            if fileexist(model_var.inputfile)==0;
               if strcmp(pwd,model_var.endofile)==0;
                  newbasedir = getpath(model_var.endofile);
                  mypwd = pwd;
                  if var_ini.dirstructure==1;
                     if strcmp(mypwd(1,1),'/')==1;
                        model_var.basedir = newbasedir;
                        model_var.modelsdir = strcat(model_var.basedir,'/');
                        resultsdir = model_var.modelsdir;
                        outputfilename = getfilename(model_var.outputfile);
                        model_var.outputfile = strcat(resultsdir,outputfilename);
                     else;
                        numchar = size(newbasedir,2);
                        model_var.basedir = newbasedir(1,1:numchar-1);
                        model_var.modelsdir = strcat(model_var.basedir,'\');
                        resultsdir = model_var.modelsdir;
                        outputfilename = getfilename(model_var.outputfile);
                        model_var.outputfile = strcat(resultsdir,outputfilename);
                     end;
                  else;
                     if strcmp(mypwd(1,1),'/')==1;
                        model_var.basedir = getpath(newbasedir);
                        model_var.modelsdir = strcat(model_var.basedir,'/models/');
                        resultsdir = strcat(model_var.basedir,'/results/');
                        outputfilename = getfilename(model_var.outputfile);
                        model_var.outputfile = strcat(resultsdir,outputfilename);
                     else;
                        numchar = size(newbasedir,2);
                        model_var.basedir = newbasedir(1,1:numchar-1);
                        model_var.basedir = getpath(model_var.basedir);
                        numchar = size(model_var.basedir,2);
                        model_var.basedir = model_var.basedir(1,1:numchar-1);
                        model_var.modelsdir = strcat(model_var.basedir,'\models\');
                        resultsdir = strcat(model_var.basedir,'\results\');
                        outputfilename = getfilename(model_var.outputfile);
                        model_var.outputfile = strcat(resultsdir,outputfilename);
                     end;
                  end;
                  %
                  % making the settings "permanent"
                  %
                  if fileexist(model_var.outputfile)==1;
                     set(model.printpreview,'Enable','on');
                     set(model.print,'Enable','on');
                     set(model.printmenu,'Enable','on');
                     set(model.printpreviewmenu,'Enable','on');
                     if islatexformat(model_var.outputfile)==1;
                        stat_dvi = check_dvi(var_ini);
                        if stat_dvi==0;
                           set(model.dvimenu,'Enable','on');
                        else;
                           set(model.dvimenu,'Enable','off');
                        end;
                        [stat_ps,dvips] = check_ps(var_ini);
                        if stat_ps==0;
                           set(model.psmenu,'Enable','on');
                        else;
                           set(model.psmenu,'Enable','off');
                        end;
                        [stat_pdf,prog_seq] = check_pdf(var_ini);
                        if stat_pdf==0;
                           set(model.pdfmenu,'Enable','on');
                        else;
                           set(model.pdfmenu,'Enable','off');
                        end;
                     else;
                        set(model.dvimenu,'Enable','off');
                        set(model.psmenu,'Enable','off');
                        set(model.pdfmenu,'Enable','off');
                     end;
                  else;
                     set(model.printpreview,'Enable','off');
                     set(model.print,'Enable','off');
                     set(model.printmenu,'Enable','off');
                     set(model.printpreviewmenu,'Enable','off');
                     set(model.dvimenu,'Enable','off');
                     set(model.psmenu,'Enable','off');
                     set(model.pdfmenu,'Enable','off');
                  end;
                  set(model.endogenous,'UserData',model_var.modelsdir);
                  set(model.outputfile,'String',model_var.outputfile);
                  if strcmp(get(model.store,'Enable'),'off')==1;
                     if strcmp(model_var.outputfile,oldmodel_var.outputfile)==0;
                        set(model.store,'Enable','on');
                     end;
                  else;
                     if strcmp(model_var.outputfile,oldmodel_var.outputfile)==1;
                        set(model.store,'Enable','off');
                     end;
                  end;
               end;
            end;
         end;
         if fileexist(model_var.outputfile)==1;
            if strcmp(var_ini.editor,'')==0;
               set(model.editormenu,'Enable','on');
            else;
               set(model.editormenu,'Enable','off');
            end;
            if islatexformat(model_var.outputfile)==1;
               stat_dvi = check_dvi(var_ini);
               if stat_dvi==0;
                  set(model.dvimenu,'Enable','on');
               else;
                  set(model.dvimenu,'Enable','off');
               end;
               [stat_ps,dvips] = check_ps(var_ini);
               if stat_ps==0;
                  set(model.psmenu,'Enable','on');
               else;
                  set(model.psmenu,'Enable','off');
               end;
               [stat_pdf,prog_seq] = check_pdf(var_ini);
               if stat_pdf==0;
                  set(model.pdfmenu,'Enable','on');
               else;
                  set(model.pdfmenu,'Enable','off');
               end;
            else;
               set(model.dvimenu,'Enable','off');
               set(model.psmenu,'Enable','off');
               set(model.pdfmenu,'Enable','off');
            end;
         else;
            set(model.dvimenu,'Enable','off');
            set(model.psmenu,'Enable','off');
            set(model.pdfmenu,'Enable','off');
         end;
         set(model.mypopup,'String',lagstring);
         set(model.lagexo,'String',['0|' lagstring]);
         set(model.mypopuph,'String',respstring);
         set(model.preferences,'Enable','on');
         set(model.preferencesmenu,'Enable','on');
         set(maingui,'UserData',model);
         model_var.runvar = 0;
      end;
   case 'checkrun'
      if model_var.runvar==0;
         %
         % Deleting any temporary movie files
         %
         file1 = [model_var.modelsdir 'svar-temp-1.mat'];
         file0 = [model_var.modelsdir 'svar-temp-0.mat'];
         if fileexist(file1)==1;
            delete_file_fcn(file1);
         end;
         if fileexist(file0)==1;
            delete_file_fcn(file0);
         end;
         %
         % make sure all editing controls are set to off
         %
         my_textobj = findobj(maingui,'Type','text')';
         for i=1:size(my_textobj,2);
            set(my_textobj(1,i),'Editing','off');
         end;
         set(model.leave,'UserData','done');
         set(maingui,'UserData',model);
      end;
   case 'checksample'
      [model,model_var] = main_checksample_fcn(model,model_var);
      set(maingui,'UserData',model);
   case 'spectest'
      checkspectest(1,1) = get(model.serial,'Value');
      checkspectest(1,2) = get(model.arch,'Value');
      checkspectest(1,3) = get(model.normality,'Value');
      checkspectest(1,4) = get(model.constancy,'Value');
      if sum(abs(checkspectest-model_var.spectest))>0;
         set(model.store,'Enable','on');
         set(model.savemenu,'Enable','on');
      end;
      set(maingui,'UserData',model);
   case 'progchanges'
      textgui('changes.txt','Structural VAR - Changes',[(realscrsz(3)-735)/2 (realscrsz(4)-400)/2 740 500],'Changes',45,0);
   case 'license'
      textgui('gpl.txt','GNU General Public License',[(realscrsz(3)-700)/2 (realscrsz(4)-400)/2 700 500],'License',40,0);
   case 'readme'
      textgui('readme.txt','Structural VAR - Readme File',[(realscrsz(3)-735)/2 (realscrsz(4)-400)/2 740 500],'Readme File',60,0);
   case 'about'
      if model_var.runvar==0;
         model_var.runvar = 1;
         txt = ['Structural VAR   ---   version ' num2str(myvers,'%0.2f') ' release ' num2str(myrelease,'%0.0f')];
         mytext = ['Copyright  2001-' datestr(now,10) ' Anders Warne'];
         txt = strvcat(txt,mytext);
         txt = strvcat(txt,' ');
         if (ispc==1)&(iscompiled==1);
            var_ini.model = model_var;
            var_ini.oldmodel = oldmodel_var;
            set(model.openmenu,'UserData',var_ini);
            about_links(txt,'logo',var_homepage,var_email,'About',130,350);
         else;
            txt = strvcat(txt,['Web site: ' var_homepage]);
            txt = strvcat(txt,['Email:       ' var_email]);
            about(txt,'logo','About',130,350);
         end;
         model_var.runvar = 0;
      end;
   case 'homepage'
      prog = ['bin\run_browser.exe ' var_homepage];
      dos(prog);
   case 'updates'
      %
      % check if we have already downloaded "svar-version.txt"
      %
      txt_msg = '';
      if fileexist('svar-version.txt')==0;
         %
         % download "svar-version.txt" to check the latest version
         %
         prog = ['bin\version.exe ' getbaseurl(var_homepage) 'download/svar-version.txt ' fix_path([pwd '\svar-version.txt'])];
         dos(prog);
         %
         % wait for version.log and then check content
         %
         version_log = [pwd '\version.log'];
         stat = waitfor_filewrite(version_log,'t');
         if stat==0;
            %
            % read content of version.log
            %
            txt = readtext(version_log);
            txt_msg = txt{1};
         end;
         delete_file_fcn(version_log);
      end;
      if fileexist('svar-version.txt')==1;
         version_txt = readtext('svar-version.txt');
         vers_txt = version_txt{1};
         %
         % check current version
         %
         old_version = myvers;
         old_release = myrelease;
         pos = findstr(vers_txt,'-');
         new_version = mystr2num(vers_txt(1,1:pos-1));
         new_release = mystr2num(vers_txt(1,pos+1:size(vers_txt,2)));
         old_num = old_version+(old_release/1000);
         new_num = new_version+(new_release/1000);
         if new_num>old_num;
            %
            % an update is available - make sure file is not already in download directory
            %
            download_file = ['setup-svar-' version_txt{1} '.exe'];
            dwn_file = [pwd '\downloads\' download_file];
            if fileexist(dwn_file)==0;
               txt = ['A new version of Structural VAR is available for download. The new version is ' vers_txt(1,1:pos-1) ' with release number ' vers_txt(1,pos+1:size(vers_txt,2)) '. Would you like to download it now?'];
               answer = query(txt,'logo',120,'Check for Updates...',350);
               if strcmp(answer,'Yes')==1;
                  %
                  % make sure directory exists
                  %
                  down_dir = [pwd '\downloads\'];
                  if direxist(down_dir)==0;
                     mystatus = makedirs(down_dir,1);
                  end;
                  %
                  % download update
                  %
                  prog = ['bin\download.exe ' getbaseurl(var_homepage) 'download/' download_file ' ' fix_path([pwd '\downloads\' download_file])];
                  dos(prog);
               end;
            else;
               txt = ['You have already downloaded the latest version of ' download_file '. It is located in the directory "' getpath(dwn_file) '".'];
               about(txt,'internet','File downloaded...',120,350);
            end;
         else;
            %
            % we have the latest version
            %
            txt = 'You already have the latest version.';
            about(txt,'logo','Check for Updates...',120,350);
         end;
      else;
         if strcmp(strtrim(txt_msg),'offline')==0;
            if strcmp(txt_msg,'')==1;
               txt = ['Unable to connect to ' getbaseurl(var_homepage) '. If you can connect to the internet and you have a proxy that requires authentication or uses an automatic configuration script, then this may explain the failure.'];
            else;
               txt = ['Unable to connect to ' getbaseurl(var_homepage) ' due to the following failure:  ' txt_msg '.'];
            end;
            about(txt,'internet','Internet Connection Failure...',120,350);
         end;
      end;
   case 'stop'
      if model_var.runvar==0;
         if var_ini.sillyq==0;
            answer = query('Are you sure you want to quit Structural VAR?','exit',120,'Exit',350);
         else;
            answer = 'Yes';
         end;
         if strcmp(answer,'Yes');
            set(model.leave,'UserData','done');
         end;
         set(maingui,'UserData',model);
      end;
   case 'endographs'
      if model_var.runvar==0;
         model_var.runvar = 1;
         var_ini.images = button_images;
         var_ini.model = model_var;
         var_ini.oldmodel = oldmodel_var;
         set(model.openmenu,'UserData',var_ini);
         curr_model = model_var;
         curr_model.beginyear = strrep(get(model.beginyear,'String'),' ','');
         curr_model.beginperiod = strrep(get(model.beginperiod,'String'),' ','');
         curr_model.endyear = strrep(get(model.endyear,'String'),' ','');
         curr_model.endperiod = strrep(get(model.endperiod,'String'),' ','');
         curr_model.subbeginyear = curr_model.beginyear;
         curr_model.subbeginperiod = curr_model.beginperiod;
         curr_model.subendyear = curr_model.endperiod;
         curr_model.subendperiod = curr_model.endperiod;
         set(maingui,'UserData',model);
         curr_model.outputdir = getpath(model_var.outputfile);
         thisgraph = graphdlg('init','Endogenous',curr_model);
         graph = get(thisgraph,'UserData');
         set(graph.show,'UserData','done');
         killguipid(thisgraph);
         model_var.runvar = 0;
      end;
   case 'exo1graphs'
      if model_var.runvar==0;
         model_var.runvar = 1;
         var_ini.images = button_images;
         var_ini.model = model_var;
         var_ini.oldmodel = oldmodel_var;
         set(model.openmenu,'UserData',var_ini);
         curr_model = model_var;
         curr_model.beginyear = strrep(get(model.beginyear,'String'),' ','');
         curr_model.beginperiod = strrep(get(model.beginperiod,'String'),' ','');
         curr_model.endyear = strrep(get(model.endyear,'String'),' ','');
         curr_model.endperiod = strrep(get(model.endperiod,'String'),' ','');
         curr_model.subbeginyear = curr_model.beginyear;
         curr_model.subbeginperiod = curr_model.beginperiod;
         curr_model.subendyear = curr_model.endperiod;
         curr_model.subendperiod = curr_model.endperiod;
         set(maingui,'UserData',model);
         curr_model.outputdir = getpath(model_var.outputfile);
         thisgraph = graphdlg('init','Exogenous I(1)',curr_model);
         graph = get(thisgraph,'UserData');
         set(graph.show,'UserData','done');
         killguipid(thisgraph);
         model_var.runvar = 0;
      end;
   case 'exo0graphs'
      if model_var.runvar==0;
         model_var.runvar = 1;
         var_ini.images = button_images;
         var_ini.model = model_var;
         var_ini.oldmodel = oldmodel_var;
         set(model.openmenu,'UserData',var_ini);
         curr_model = model_var;
         curr_model.beginyear = strrep(get(model.beginyear,'String'),' ','');
         curr_model.beginperiod = strrep(get(model.beginperiod,'String'),' ','');
         curr_model.endyear = strrep(get(model.endyear,'String'),' ','');
         curr_model.endperiod = strrep(get(model.endperiod,'String'),' ','');
         curr_model.subbeginyear = curr_model.beginyear;
         curr_model.subbeginperiod = curr_model.beginperiod;
         curr_model.subendyear = curr_model.endperiod;
         curr_model.subendperiod = curr_model.endperiod;
         set(maingui,'UserData',model);
         curr_model.outputdir = getpath(model_var.outputfile);
         thisgraph = graphdlg('init','Exogenous I(0)',curr_model);
         graph = get(thisgraph,'UserData');
         set(graph.show,'UserData','done');
         killguipid(thisgraph);
         model_var.runvar = 0;
      end;
   case 'detergraphs'
      if model_var.runvar==0;
         model_var.runvar = 1;
         var_ini.images = button_images;
         var_ini.model = model_var;
         var_ini.oldmodel = oldmodel_var;
         set(model.openmenu,'UserData',var_ini);
         curr_model = model_var;
         curr_model.beginyear = strrep(get(model.beginyear,'String'),' ','');
         curr_model.beginperiod = strrep(get(model.beginperiod,'String'),' ','');
         curr_model.endyear = strrep(get(model.endyear,'String'),' ','');
         curr_model.endperiod = strrep(get(model.endperiod,'String'),' ','');
         curr_model.subbeginyear = curr_model.beginyear;
         curr_model.subbeginperiod = curr_model.beginperiod;
         curr_model.subendyear = curr_model.endperiod;
         curr_model.subendperiod = curr_model.endperiod;
         set(maingui,'UserData',model);
         curr_model.outputdir = getpath(model_var.outputfile);
         thisgraph = graphdlg('init','Deterministic',curr_model);
         graph = get(thisgraph,'UserData');
         set(graph.show,'UserData','done');
         killguipid(thisgraph);
         model_var.runvar = 0;
      end;
   case 'shocknames'
      if model_var.runvar==0;
         model_var.runvar = 1;
         var_ini.images = button_images;
         var_ini.model = model_var;
         var_ini.oldmodel = oldmodel_var;
         set(model.openmenu,'UserData',var_ini);
         thisnames = namesdlg('init',model_var.endofile,model_var.endosheet,model_var.shocks,'Shock');
         names = get(thisnames,'UserData');
         newshocks = get(names.listbox,'UserData');
         changed_names = get(names.button,'UserData');
         set(names.clear,'UserData','done');
         killguipid(thisnames);
         if (strcmp(model_var.shocks,newshocks)==0)&(changed_names==1);
            set(model.store,'Enable','on');
            set(model.savemenu,'Enable','on');
            oldmodel_var.shocks = model_var.shocks;
            model_var.shocks = newshocks;
         end;
         set(maingui,'UserData',model);
         model_var.runvar = 0;
      end;
   case 'endonames'
      if model_var.runvar==0;
         model_var.runvar = 1;
         var_ini.images = button_images;
         var_ini.model = model_var;
         var_ini.oldmodel = oldmodel_var;
         set(model.openmenu,'UserData',var_ini);
         thisnames = namesdlg('init',model_var.endofile,model_var.endosheet,model_var.evars,'Endogenous');
         names = get(thisnames,'UserData');
         newevars = get(names.listbox,'UserData');
         set(names.clear,'UserData','done');
         killguipid(thisnames);
         if strcmp(model_var.evars,newevars)==0;
            set(model.endogenoustext,'String',['Endogenous variables:  ' newevars]);
            set(model.store,'Enable','on');
            set(model.savemenu,'Enable','on');
            oldmodel_var.evars = model_var.evars;
            model_var.evars = newevars;
            set(model.endonames,'UserData',model_var.evars);
         end;
         set(maingui,'UserData',model);
         model_var.runvar = 0;
      end;
   case 'exo1names'
      if model_var.runvar==0;
         model_var.runvar = 1;
         var_ini.images = button_images;
         var_ini.model = model_var;
         var_ini.oldmodel = oldmodel_var;
         set(model.openmenu,'UserData',var_ini);
         thisnames = namesdlg('init',model_var.exo1file,model_var.exo1sheet,model_var.xvars1,'Exogenous I(1)');
         names = get(thisnames,'UserData');
         newxvars1 = get(names.listbox,'UserData');
         set(names.clear,'UserData','done');
         killguipid(thisnames);
         if strcmp(model_var.xvars1,newxvars1)==0;
            set(model.exogenous1text,'String',['Exogenous I(1) variables:  ' newxvars1]);
            set(model.store,'Enable','on');
            set(model.savemenu,'Enable','on');
            oldmodel_var.xvars1 = model_var.xvars1;
            model_var.xvars1 = newxvars1;
            set(model.exo1names,'UserData',model_var.xvars1);
         end;
         set(maingui,'UserData',model);
         model_var.runvar = 0;
      end;
   case 'exo0names'
      if model_var.runvar==0;
         model_var.runvar = 1;
         var_ini.images = button_images;
         var_ini.model = model_var;
         var_ini.oldmodel = oldmodel_var;
         set(model.openmenu,'UserData',var_ini);
         thisnames = namesdlg('init',model_var.exo0file,model_var.exo0sheet,model_var.xvars0,'Exogenous I(0)');
         names = get(thisnames,'UserData');
         newxvars0 = get(names.listbox,'UserData');
         set(names.clear,'UserData','done');
         killguipid(thisnames);
         if strcmp(model_var.xvars0,newxvars0)==0;
            set(model.exogenous0text,'String',['Exogenous I(0) variables:  ' newxvars0]);
            set(model.store,'Enable','on');
            set(model.savemenu,'Enable','on');
            oldmodel_var.xvars0 = model_var.xvars0;
            model_var.xvars0 = newxvars0;
            set(model.exo0names,'UserData',model_var.xvars0);
         end;
         set(maingui,'UserData',model);
         model_var.runvar = 0;
      end;
   case 'deternames'
      if model_var.runvar==0;
         model_var.runvar = 1;
         var_ini.images = button_images;
         var_ini.model = model_var;
         var_ini.oldmodel = oldmodel_var;
         set(model.openmenu,'UserData',var_ini);
         thisnames = namesdlg('init',model_var.deterfile,model_var.detersheet,model_var.deter,'Deterministic');
         names = get(thisnames,'UserData');
         newdeter = get(names.listbox,'UserData');
         set(names.clear,'UserData','done');
         killguipid(thisnames);
         if strcmp(model_var.deter,newdeter)==0;
            set(model.deterministictext,'String',['Deterministic variables:  ' newdeter]);
            set(model.store,'Enable','on');
            set(model.savemenu,'Enable','on');
            oldmodel_var.deter = model_var.deter;
            model_var.deter = newdeter;
            set(model.deternames,'UserData',model_var.deter);
         end;
         set(maingui,'UserData',model);
         model_var.runvar = 0;
      end;
   case 'help'
      if ispc==1;
         if strcmp(lower(getfilename(var_ini.helpexe)),'winhlp32.exe')==1;
            prog = 'winhlp32.exe doc\svar.hlp &';
         elseif strcmp(lower(getfilename(var_ini.helpexe)),'hh.exe')==1;
            prog = 'hh.exe doc\svar.chm &';
         else;
            if iscompiled==1;
               prog = ['bin\run_browser.exe ' pwd '\doc\html\index.html &'];
            else;
               html_doc = [pwd '\doc\html\index.html'];
               html_doc = ['file:///' strrep(html_doc,'\','/')];
               stat = web_fcn(html_doc);
               return;
            end;
         end;
         prog = fixcmd(prog);
         dos(prog);
      else;
         if isunix==1;
            prog = [var_ini.helpexe ' ' pwd '/doc/html/index.html &'];
            unix(prog);
         else;
            txt = 'Currently Structural VAR cannot run programs under Mac. If you know of a technique for such systems, please let know.';
            txt = strvcat(txt,' ',['Email: ' var_email]);
            about(txt,'warning','Help Topics - Mac',135,350);
         end;
      end;
   case 'editor'
      myoutputfile = get(model.outputfile,'String');
      if fileexist(myoutputfile)==0;
         myoutputfile = '';
      end;
      if ispc==1;
         prog = fix_path(var_ini.editor);
         prog = [prog ' ' fix_path(myoutputfile) ' &'];
         prog = fixcmd(prog);
         dos(prog);
      else;
         if isunix==1;
            prog = [var_ini.editor ' ' myoutputfile ' &'];
            unix(prog);
         else;
            txt = 'Currently Structural VAR cannot run programs under Mac. If you know of a technique for such systems, please let know.';
            txt = strvcat(txt,' ',['Email: ' var_email]);
            about(txt,'warning','Open Output File in Editor - Mac',135,350);
         end;
      end;
   case 'viewdvi'
      if model_var.runvar==0;
         model_var.runvar==1;
         wbmf = get(maingui,'WindowButtonMotionFcn');
         set(maingui,'WindowButtonMotionFcn','');
         drawnow;
         myoutputfile = get(model.outputfile,'String');
         if ispc==1;
            prog = fix_filepath(var_ini.latex);
            if iswinnt==0;
               prog = [prog ' ''--interaction=nonstopmode'''];
            else;
               prog = [prog ' --interaction=nonstopmode'];
            end;
            if strcmp(getext(myoutputfile),'.ltx')==1;
               tex_file = [getpath(myoutputfile) getname(myoutputfile) '.tex'];
            else;
               tex_file = [getpath(myoutputfile) getname(myoutputfile) '.ltx'];
            end;
            dvi_file = [getpath(myoutputfile) getname(myoutputfile) '.dvi'];
            log_file = [getpath(myoutputfile) getname(myoutputfile) '.log'];
            aux_file = [getpath(myoutputfile) getname(myoutputfile) '.aux'];
            prog = [prog ' ' fix_filepath(getfilename(tex_file))];
            delete_file_fcn(dvi_file);
            %
            % read myoutputfile and write to tex_file
            %
            this_text = strvcat(' ','Preparing LaTeX File...',' ',' ',' ','Please hold!');
            mywait = waitdlg(this_text,'latex','LaTeX Preview',600);
            waitf = get(mywait,'UserData');
            %
            str_txt = readtext(myoutputfile);
            f_id = fopen(tex_file,'wt');
            for i=1:size(str_txt,2);
               fprintf(f_id,'%s\n',str_txt{i});
            end;
            fprintf(f_id,'\\end{document}\n');
            fclose(f_id);
            stat = waitfor_filewrite(tex_file,'t');
            %
            if stat==0;
               my_cmd = prog;
               if iscompiled==1;
                  prog = [fix_path([pwd '\bin\run_exe.exe']) ' ' prog];
               else;
                  prog = [prog '>test.junk'];
               end;
               %
               if size(my_cmd,2)>=100;
                  my_cmd = [my_cmd(1,1:100) '...'];
               end;
               set(mywait,'Position',[(realscrsz(3)-600)/2 (realscrsz(4)-124)/2 600 124]);
               this_text = strvcat(' ','Running the command:',' ',strrep(my_cmd,'''','"'),' ','Please hold!');
               set(waitf.text,'String',this_text);
               %
               old_dir = pwd;
               cd(getpath(tex_file));
               dos(prog);
               drawnow;
               cd(old_dir);
               stat_dvi = waitfor_filewrite(dvi_file,'b');
               if iscompiled==0;
                  delete_file_fcn([getpath(tex_file) 'test.junk']);
               end;
               if stat_dvi==0;
                  delete_file_fcn(log_file);
                  delete_file_fcn(aux_file);
                  prog = fix_filepath(var_ini.dviviewer);
                  prog = [prog ' ' fix_filepath(dvi_file) ' &'];
                  prog = fixcmd(prog);
                  dos(prog);
               end;
               delete_file_fcn(tex_file);
            end;
            %
            set(waitf.text,'UserData','done');
            delete(mywait);
            drawnow;
            %
         else;
            if isunix==1;
               prog = var_ini.latex;
               if strcmp(getext(myoutputfile),'.ltx')==1;
                  tex_file = [getpath(myoutputfile) '/' getname(myoutputfile) '.tex'];
               else;
                  tex_file = [getpath(myoutputfile) '/' getname(myoutputfile) '.ltx'];
               end;
               dvi_file = [getpath(myoutputfile) '/' getname(myoutputfile) '.dvi'];
               log_file = [getpath(myoutputfile) '/' getname(myoutputfile) '.log'];
               aux_file = [getpath(myoutputfile) '/' getname(myoutputfile) '.aux'];
               prog = [prog ' ' tex_file];
               delete_file_fcn(dvi_file);
               %
               % read myoutputfile and write to tex_file
               %
               str_txt = readtext(myoutputfile);
               f_id = fopen(tex_file,'wt');
               for i=1:size(str_txt,2);
                  fprintf(f_id,'%s\n',str_txt{i});
               end;
               fprintf(f_id,'\\end{document}\n');
               fclose(f_id);
               stat = waitfor_filewrite(tex_file,'t');
               if stat==0;
                  prog = [prog '>' getpath(tex_file) '/test.junk'];
                  old_dir = pwd;
                  cd(getpath(tex_file));
                  unix(prog);
                  drawnow;
                  cd(old_dir);
                  delete_file_fcn([getpath(tex_file) '/test.junk']);
                  stat_dvi = waitfor_filewrite(dvi_file,'b');
                  if stat_dvi==0;
                     delete_file_fcn(log_file);
                     delete_file_fcn(aux_file);
                     prog = var_ini.dviviewer;
                     prog = [prog ' ' dvi_file ' &'];
                     unix(prog);
                  end;
                  delete_file_fcn(tex_file);
               end;
            else;
               txt = 'Currently Structural VAR cannot run programs under Mac. If you know of a technique for such systems, please let know.';
               txt = strvcat(txt,' ',['Email: ' var_email]);
               about(txt,'warning','LaTeX Preview - Mac',135,350);
            end;
         end;
         set(maingui,'WindowButtonMotionFcn',wbmf);
         model_var.runvar = 0;
      end;
   case 'viewps'
      if model_var.runvar==0;
         model_var.runvar==1;
         wbmf = get(maingui,'WindowButtonMotionFcn');
         set(maingui,'WindowButtonMotionFcn','');
         drawnow;
         myoutputfile = get(model.outputfile,'String');
         if ispc==1;
            prog = fix_filepath(var_ini.latex);
            if iswinnt==0;
               prog = [prog ' ''--interaction=nonstopmode'''];
            else;
               prog = [prog ' --interaction=nonstopmode'];
            end;
            if strcmp(getext(myoutputfile),'.ltx')==1;
               tex_file = [getpath(myoutputfile) getname(myoutputfile) '.tex'];
            else;
               tex_file = [getpath(myoutputfile) getname(myoutputfile) '.ltx'];
            end;
            dvi_file = [getpath(myoutputfile) getname(myoutputfile) '.dvi'];
            log_file = [getpath(myoutputfile) getname(myoutputfile) '.log'];
            aux_file = [getpath(myoutputfile) getname(myoutputfile) '.aux'];
            ps_file = [getpath(myoutputfile) getname(myoutputfile) '.ps'];
            prog = [prog ' ' fix_filepath(getfilename(tex_file))];
            delete_file_fcn(dvi_file);
            delete_file_fcn(ps_file);
            %
            % read myoutputfile and write to tex_file
            %
            this_text = strvcat(' ','Preparing LaTeX File...',' ',' ',' ','Please hold!');
            mywait = waitdlg(this_text,'postscript','PostScript Preview',600);
            waitf = get(mywait,'UserData');
            %
            str_txt = readtext(myoutputfile);
            f_id = fopen(tex_file,'wt');
            for i=1:size(str_txt,2);
               fprintf(f_id,'%s\n',str_txt{i});
            end;
            fprintf(f_id,'\\end{document}\n');
            fclose(f_id);
            stat = waitfor_filewrite(tex_file,'t');
            if stat==0;
               my_cmd = prog;
               if iscompiled==1;
                  prog = [fix_path([pwd '\bin\run_exe.exe']) ' ' prog];
               else;
                  prog = [prog '>test.junk'];
               end;
               %
               if size(my_cmd,2)>=100;
                  my_cmd = [my_cmd(1,1:100) '...'];
               end;
               set(mywait,'Position',[(realscrsz(3)-600)/2 (realscrsz(4)-124)/2 600 124]);
               this_text = strvcat(' ','Running the command:',' ',strrep(my_cmd,'''','"'),' ','Please hold!');
               set(waitf.text,'String',this_text);
               %
               % run latex
               %
               old_dir = pwd;
               cd(getpath(tex_file));
               dos(prog);
               drawnow;
               cd(old_dir);
               stat_dvi = waitfor_filewrite(dvi_file,'b');
               if iscompiled==0;
                  delete_file_fcn([getpath(tex_file) 'test.junk']);
               end;
               if stat_dvi==0;
                  delete_file_fcn(log_file);
                  delete_file_fcn(aux_file);
                  [stat_ps,dvips] = check_ps(var_ini);
                  if stat_ps==0;
                     dvips = [fix_filepath(dvips) ' ' fix_filepath(getfilename(dvi_file))];
                     my_cmd = dvips;
                     if iscompiled==1;
                        dvips = [fix_path([pwd '\bin\run_exe.exe']) ' ' dvips];
                     elseif (iscompiled==0)&(iswinnt==1);
                        dvips = [dvips ' 2>test.junk'];
                     end;
                     if size(my_cmd,2)>=100;
                        my_cmd = [my_cmd(1,1:100) '...'];
                     end;
                     this_text = strvcat(' ','Running the command:',' ',strrep(my_cmd,'''','"'),' ','Please hold!');
                     set(waitf.text,'String',this_text);
                     %
                     % run dvips
                     %
                     cd(getpath(dvi_file));
                     dos(dvips);
                     drawnow;
                     cd(old_dir);
                     stat_dvips = waitfor_filewrite(ps_file,'t');
                     if (iscompiled==0)&(iswinnt==1);
                        delete_file_fcn([getpath(tex_file) 'test.junk']);
                     end;
                     if stat_dvips==0;
                        %
                        % show file
                        %
                        prog = [fix_path(var_ini.psviewer) ' ' fix_filepath(ps_file) ' &'];
                        prog = fixcmd(prog);
                        dos(prog);
                        maximize_prog(ps_file,var_ini.psviewer);
                     end;
                  else;
%                     delete_file_fcn(dvi_file);
                  end;
               end;
               delete_file_fcn(tex_file);
            end;
            %
            set(waitf.text,'UserData','done');
            delete(mywait);
            drawnow;
            %
         else;
            if isunix==1;
               prog = var_ini.latex;
               if strcmp(getext(myoutputfile),'.ltx')==1;
                  tex_file = [getpath(myoutputfile) '/' getname(myoutputfile) '.tex'];
               else;
                  tex_file = [getpath(myoutputfile) '/' getname(myoutputfile) '.ltx'];
               end;
               dvi_file = [getpath(myoutputfile) '/' getname(myoutputfile) '.dvi'];
               log_file = [getpath(myoutputfile) '/' getname(myoutputfile) '.log'];
               aux_file = [getpath(myoutputfile) '/' getname(myoutputfile) '.aux'];
               ps_file = [getpath(myoutputfile) '/' getname(myoutputfile) '.ps'];
               prog = [prog ' ' tex_file];
               delete_file_fcn(dvi_file);
               delete_file_fcn(ps_file);
               %
               % read myoutputfile and write to tex_file
               %
               str_txt = readtext(myoutputfile);
               f_id = fopen(tex_file,'wt');
               for i=1:size(str_txt,2);
                  fprintf(f_id,'%s\n',str_txt{i});
               end;
               fprintf(f_id,'\\end{document}\n');
               fclose(f_id);
               stat = waitfor_filewrite(tex_file,'t');
               if stat==0;
                  prog = [prog '>' getpath(tex_file) '/test.junk'];
                  %
                  % run latex
                  %
                  old_dir = pwd;
                  cd(getpath(tex_file));
                  unix(prog);
                  drawnow;
                  cd(old_dir);
                  delete_file_fcn([getpath(tex_file) '/test.junk']);
                  stat_dvi = waitfor_filewrite(dvi_file,'b');
                  if stat_dvi==0;
                     delete_file_fcn(log_file);
                     delete_file_fcn(aux_file);
                     [stat_ps,dvips] = check_ps(var_ini);
                     if stat_ps==0;
                        dvips = [dvips ' ' dvi_file ' 2>' getpath(tex_file) '/test.junk'];
                        %
                        % run dvips
                        %
                        cd(getpath(dvi_file));
                        unix(dvips);
                        drawnow;
                        cd(old_dir);
%                        delete_file_fcn(dvi_file);
                        delete_file_fcn([getpath(tex_file) '/test.junk']);
                        stat_dvips = waitfor_filewrite(ps_file,'t');
                        if stat_dvips==0;
                           %
                           % show file
                           %
                           prog = [var_ini.psviewer ' ' ps_file ' &'];
                           unix(prog);
                        end;
                     else;
%                        delete_file_fcn(dvi_file);
                     end;
                  end;
                  delete_file_fcn(tex_file);
               end;
            else;
               txt = 'Currently Structural VAR cannot run programs under Mac. If you know of a technique for such systems, please let know.';
               txt = strvcat(txt,' ',['Email: ' var_email]);
               about(txt,'warning','PostScript Preview - Mac',135,350);
            end;
         end;
         set(maingui,'WindowButtonMotionFcn',wbmf);
         model_var.runvar = 0;
      end;
   case 'viewpdf'
      if model_var.runvar==0;
         model_var.runvar==1;
         f_obj = findobj(0,'type','figure');
         wbmf = get(maingui,'WindowButtonMotionFcn');
         set(maingui,'WindowButtonMotionFcn','');
         drawnow;
         myoutputfile = get(model.outputfile,'String');
         if ispc==1;
            if strcmp(getext(myoutputfile),'.ltx')==1;
               tex_file = [getpath(myoutputfile) getname(myoutputfile) '.tex'];
            else;
               tex_file = [getpath(myoutputfile) getname(myoutputfile) '.ltx'];
            end;
            dvi_file = [getpath(myoutputfile) getname(myoutputfile) '.dvi'];
            log_file = [getpath(myoutputfile) getname(myoutputfile) '.log'];
            aux_file = [getpath(myoutputfile) getname(myoutputfile) '.aux'];
            ps_file = [getpath(myoutputfile) getname(myoutputfile) '.ps'];
            pdf_file = [getpath(myoutputfile) getname(myoutputfile) '.pdf'];
            delete_file_fcn(dvi_file);
            delete_file_fcn(ps_file);
            delete_file_fcn(pdf_file);
            %
            % read myoutputfile and write to tex_file
            %
            this_text = strvcat(' ','Preparing LaTeX File...',' ',' ',' ','Please hold!');
            mywait = waitdlg(this_text,'pdf','PDF Preview',600);
            waitf = get(mywait,'UserData');
            %
            str_txt = readtext(myoutputfile);
            f_id = fopen(tex_file,'wt');
            for i=1:size(str_txt,2);
               fprintf(f_id,'%s\n',str_txt{i});
            end;
            fprintf(f_id,'\\end{document}\n');
            fclose(f_id);
            stat = waitfor_filewrite(tex_file,'t');
            if stat==0;
               [stat_pdf,prog_seq] = check_pdf(var_ini);
               if stat_pdf==0;
                  if size(prog_seq,1)==1;
                     %
                     % pdflatex
                     %
                     prog = fix_filepath(strtrim(prog_seq(1,:)));
                     if iswinnt==0;
                        prog = [prog ' ''--interaction=nonstopmode'''];
                     else;
                        prog = [prog ' --interaction=nonstopmode'];
                     end;
                     %
                     prog = [prog ' ' fix_filepath(getfilename(tex_file))];
                     my_cmd = prog;
                     if iscompiled==1;
                        prog = [fix_path([pwd '\bin\run_exe.exe']) ' ' prog];
                     elseif (iscompiled==0)&(iswinnt==1);
                        prog = [prog '>test.junk'];
                     end;
                     %
                     if size(my_cmd,2)>=100;
                        my_cmd = [my_cmd(1,1:100) '...'];
                     end;
                     set(mywait,'Position',[(realscrsz(3)-600)/2 (realscrsz(4)-124)/2 600 124]);
                     this_text = strvcat(' ','Running the command:',' ',strrep(my_cmd,'''','"'),' ','Please hold!');
                     set(waitf.text,'String',this_text);
                     %
                     old_dir = pwd;
                     cd(getpath(tex_file));
                     dos(prog);
                     drawnow;
                     cd(old_dir);
                     status_pdf = waitfor_filewrite(pdf_file,'b');
                     if (iscompiled==0)&(iswinnt==1);
                        delete_file_fcn([getpath(tex_file) 'test.junk']);
                     end;
                  elseif size(prog_seq,1)==2;
                     %
                     % latex & dvipdfm
                     %
                     old_dir = pwd;
                     for i=1:2;
                        prog = fix_filepath(strtrim(prog_seq(i,:)));
                        if i==1;
                           if iswinnt==0;
                              prog = [prog ' ''--interaction=nonstopmode'''];
                           else;
                              prog = [prog ' --interaction=nonstopmode'];
                           end;
                           prog = [prog ' ' fix_filepath(getfilename(tex_file))];
                        else;
                           prog = [prog ' ' fix_filepath(getfilename(dvi_file))];
                        end;
                        my_cmd = prog;
                        if iscompiled==1;
                           prog = [fix_path([pwd '\bin\run_exe.exe']) ' ' prog];
                        else;
                           if iswinnt==1;
                              if i==1;
                                 prog = [prog '>test.junk'];
                              else;
                                 prog = [prog '>test.junk 2>test2.junk'];
                              end;
                           end;
                        end;
                        %
                        if size(my_cmd,2)>=100;
                           my_cmd = [my_cmd(1,1:100) '...'];
                        end;
                        set(mywait,'Position',[(realscrsz(3)-600)/2 (realscrsz(4)-124)/2 600 124]);
                        this_text = strvcat(' ','Running the command:',' ',strrep(my_cmd,'''','"'),' ','Please hold!');
                        set(waitf.text,'String',this_text);
                        %
                        cd(getpath(tex_file));
                        dos(prog);
                        drawnow;
                        cd(old_dir);
                        if i==1;
                           status_dvi = waitfor_filewrite(dvi_file,'b');
                        else;
                           status_pdf = waitfor_filewrite(pdf_file,'b');
                        end;
                        if (iscompiled==0)&(iswinnt==1);
                           delete_file_fcn([getpath(tex_file) 'test.junk']);
                           delete_file_fcn([getpath(tex_file) 'test2.junk']);
                        end;
                     end;
                  elseif size(prog_seq,1)==3;
                     %
                     % latex, dvips & pstopdf program
                     %
                     old_dir = pwd;
                     for i=1:3;
                        prog = fix_filepath(strtrim(prog_seq(i,:)));
                        if iscompiled==1;
                           if i==3;
                              %
                              % unless ps2pdf is acrobat distiller, use run_exe.exe
                              %
                              if strcmp(lower(getname(strtrim(prog_seq(3,:)))),'acrodist')==0;
                                 prog = ['bin\run_exe.exe ' prog];
                                 %
                                 % if ps2pdf is ghostscript, add command line switches
                                 %
                                 if (strcmp(lower(getname(strtrim(prog_seq(3,:)))),'gs')==1)|(strcmp(lower(getname(strtrim(prog_seq(3,:)))),'gswin32c')==1)|(strcmp(lower(getname(strtrim(prog_seq(3,:)))),'mgs')==1);
                                    prog = [prog ' -q -dNOPAUSE -dBATCH -sDEVICE#pdfwrite -dCompatibilityLevel#' var_ini.pdfversion ' -sOutputFile#' fix_filepath(pdf_file)];
                                 end;
                              else;
                                 prog = ['bin\run_prog.exe ' prog];
                              end;
                           end;
                        else;
                           if i==3;
                              %
                              % if ps2pdf is ghostscript, add command line switches
                              %
                              if (strcmp(lower(getname(strtrim(prog_seq(3,:)))),'gs')==1)|(strcmp(lower(getname(strtrim(prog_seq(3,:)))),'gswin32c')==1)|(strcmp(lower(getname(strtrim(prog_seq(3,:)))),'mgs')==1);
                                 prog = [prog ' -q -dNOPAUSE -dBATCH -sDEVICE#pdfwrite -dCompatibilityLevel#' var_ini.pdfversion ' -sOutputFile#' fix_path(pdf_file)];
                              end;
                           end;
                        end;
                        if i==1;
                           if iswinnt==0;
                              prog = [prog ' ''--interaction=nonstopmode'''];
                           else;
                              prog = [prog ' --interaction=nonstopmode'];
                           end;
                           prog = [prog ' ' fix_filepath(getfilename(tex_file))];
                        elseif i==2;
                           prog = [prog ' ' fix_filepath(getfilename(dvi_file))];
                        elseif i==3;
                           prog = [prog ' ' fix_filepath(ps_file)];
                        end;
                        %
                        my_cmd = strrep(prog,'bin\run_exe.exe','');
                        my_cmd = strrep(my_cmd,'bin\run_prog.exe','');
                        %
                        if i==1;
                           if iscompiled==1;
                              prog = [fix_path([pwd '\bin\run_exe.exe']) ' ' prog];
                           elseif (iscompiled==0)&(iswinnt==1);
                              prog = [prog '>test.junk'];
                           end;
                        elseif i==2;
                           if iscompiled==1;
                              prog = [fix_path([pwd '\bin\run_exe.exe']) ' ' prog];
                           elseif (iscompiled==0)&(iswinnt==1);
                              prog = [prog ' 2>test.junk'];
                           end;
                        end;
                        %
                        if size(my_cmd,2)>=100;
                           my_cmd = [my_cmd(1,1:100) '...'];
                        end;
                        set(mywait,'Position',[(realscrsz(3)-600)/2 (realscrsz(4)-124)/2 600 124]);
                        this_text = strvcat(' ','Running the command:',' ',strrep(my_cmd,'''','"'),' ','Please hold!');
                        set(waitf.text,'String',this_text);
                        %
                        if i<3;
                           cd(getpath(tex_file));
                        end;
                        dos(prog);
                        drawnow;
                        cd(old_dir);
                        if i==1;
                           status_dvi = waitfor_filewrite(dvi_file,'b');
                        elseif i==2;
                           status_ps = waitfor_filewrite(ps_file,'t');
                        elseif i==3;
                           status_pdf = waitfor_filewrite(pdf_file,'b');
                           %
                           % if acrodist produced pdf, attempt to shut it down
                           %
                           if strcmp(lower(getname(strtrim(prog_seq(3,:)))),'acrodist')==1;
                              if (strcmp(var_ini.pstoolsdir,'')==0)&(appexist([var_ini.pstoolsdir 'pslist.exe'])==1);
                                 %
                                 % now we need to determine the pid
                                 %
                                 pid = getpid('acrodist');
                                 %
                                 if (isempty(pid)==0)&(pid>-1)&(ispid('acrodist',pid)==1);
                                    pid_prog = ['bin\runwindow.exe ' fix_path([var_ini.pstoolsdir 'pskill.exe']) ' ' num2str(pid,'%0.0f') '>' fix_path([var_ini.tempdir 'killpid.txt'])];
                                    dos(pid_prog);
                                    if ispid('acrodist',pid)==1;
                                       pid_prog = ['bin\runwindow.exe ' fix_path([var_ini.pstoolsdir 'pskill.exe']) ' ' num2str(pid,'%0.0f')];
                                       dos(pid_prog);
                                    end;
                                 end;
                              end;
                           end;
                           %
                        end;
                        if (iscompiled==0)&(iswinnt==1);
                           delete_file_fcn([getpath(tex_file) 'test.junk']);
                        end;
                     end;
                  end;
                  %
                  % prepare for viewing
                  %
                  delete_file_fcn(tex_file);
                  delete_file_fcn(log_file);
                  delete_file_fcn(aux_file);
                  %
                  if status_pdf==0;
                     prog = fix_path(var_ini.pdfviewer);
                     prog = [prog ' ' fix_filepath(pdf_file) ' &'];
                     prog = fixcmd(prog);
                     dos(prog);
                     maximize_prog(pdf_file,var_ini.pdfviewer);
                  end;
               else;
                  delete_file_fcn(tex_file);
               end;
            end;
            %
            set(waitf.text,'UserData','done');
            delete(mywait);
            drawnow;
            %
         else;
            if isunix==1;
               if strcmp(getext(myoutputfile),'.ltx')==1;
                  tex_file = [getpath(myoutputfile) '/' getname(myoutputfile) '.tex'];
               else;
                  tex_file = [getpath(myoutputfile) '/' getname(myoutputfile) '.ltx'];
               end;
               dvi_file = [getpath(myoutputfile) '/' getname(myoutputfile) '.dvi'];
               log_file = [getpath(myoutputfile) '/' getname(myoutputfile) '.log'];
               aux_file = [getpath(myoutputfile) '/' getname(myoutputfile) '.aux'];
               ps_file = [getpath(myoutputfile) '/' getname(myoutputfile) '.ps'];
               pdf_file = [getpath(myoutputfile) '/' getname(myoutputfile) '.pdf'];
               delete_file_fcn(dvi_file);
               delete_file_fcn(ps_file);
               delete_file_fcn(pdf_file);
               %
               % read myoutputfile and write to tex_file
               %
               str_txt = readtext(myoutputfile);
               f_id = fopen(tex_file,'wt');
               for i=1:size(str_txt,2);
                  fprintf(f_id,'%s\n',str_txt{i});
               end;
               fprintf(f_id,'\\end{document}\n');
               fclose(f_id);
               stat = waitfor_filewrite(tex_file,'t');
               if stat==0;
                  [stat_pdf,prog_seq] = check_pdf(var_ini);
                  if stat_pdf==0;
                     if size(prog_seq,1)==1;
                        %
                        % pdflatex
                        %
                        prog = strtrim(prog_seq(1,:));
                        %
                        prog = [prog ' ' tex_file '>' getpath(tex_file) '/test.junk'];
                        old_dir = pwd;
                        cd(getpath(tex_file));
                        unix(prog);
                        drawnow;
                        cd(old_dir);
                        delete_file_fcn([getpath(tex_file) '/test.junk']);
                        status_pdf = waitfor_filewrite(pdf_file,'b');
                     elseif size(prog_seq,1)==2;
                        %
                        % latex & dvipdfm
                        %
                        old_dir = pwd;
                        for i=1:2;
                           prog = strtrim(prog_seq(i,:));
                           if i==1;
                              prog = [prog ' ' tex_file '>' getpath(tex_file) '/test.junk'];
                           else;
                              prog = [prog ' ' dvi_file '>' getpath(tex_file) '/test.junk 2>' getpath(tex_file) '/test2.junk'];
                           end;
                           cd(getpath(tex_file));
                           unix(prog);
                           drawnow;
                           cd(old_dir);
                           delete_file_fcn([getpath(tex_file) '/test.junk']);
                           delete_file_fcn([getpath(tex_file) '/test2.junk']);
                           if i==1;
                              status_dvi = waitfor_filewrite(dvi_file,'b');
                           else;
                              status_pdf = waitfor_filewrite(pdf_file,'b');
                           end;
                        end;
                     elseif size(prog_seq,1)==3;
                        %
                        % latex, dvips & pstopdf program
                        %
                        old_dir = pwd;
                        for i=1:3;
                           prog = strtrim(prog_seq(i,:));
                           if i==3;
                              if strcmp(lower(getname(strtrim(prog_seq(3,:)))),'gs')==1;
                                 prog = [prog ' -q -dNOPAUSE -dBATCH -sDEVICE#pdfwrite -dCompatibilityLevel#' var_ini.pdfversion ' -sOutputFile#' pdf_file];
                              end;
                           end;
                           if i==1;
                              prog = [prog ' ' tex_file '>' getpath(tex_file) '/test.junk'];
                           elseif i==2;
                              prog = [prog ' ' dvi_file ' 2>' getpath(tex_file) '/test.junk'];
                           elseif i==3;
                              prog = [prog ' ' ps_file];
                           end;
                           if i<3;
                              cd(getpath(tex_file));
                           end;
                           unix(prog);
                           drawnow;
                           cd(old_dir);
                           delete_file_fcn([getpath(tex_file) '/test.junk']);
                           if i==1;
                              status_dvi = waitfor_filewrite(dvi_file,'b');
                           elseif i==2;
                              status_ps = waitfor_filewrite(ps_file,'t');
                           elseif i==3;
                              status_pdf = waitfor_filewrite(pdf_file,'b');
                           end;
                        end;
                     end;
                     %
                     % prepare for viewing
                     %
                     delete_file_fcn(tex_file);
                     delete_file_fcn(log_file);
                     delete_file_fcn(aux_file);
%                     delete_file_fcn(dvi_file);
%                     delete_file_fcn(ps_file);
                     %
                     if status_pdf==0;
                        prog = [var_ini.pdfviewer ' ' pdf_file ' &'];
                        unix(prog);
                     end;
                  else;
                     delete_file_fcn(tex_file);
                  end;
               end;
            else;
               txt = 'Currently Structural VAR cannot run programs under Mac. If you know of a technique for such systems, please let know.';
               txt = strvcat(txt,' ',['Email: ' var_email]);
               about(txt,'warning','PDF Preview - Mac',135,350);
            end;
         end;
         set(maingui,'WindowButtonMotionFcn',wbmf);
         model_var.runvar = 0;
      end;
   case 'wayout'
      if model_var.runvar==0;
         %
         % write to ini-file
         %
         write_stat = write_inifile(var_ini);
         set(model.leave,'UserData','done');
         %
         % make sure all editing controls are set to off
         %
         my_textobj = findobj(maingui,'Type','text')';
         for i=1:size(my_textobj,2);
            set(my_textobj(1,i),'Editing','off');
         end;
         %
         % Close all other windows
         %
         if iscompiled==1;
            figs = sort(findobj('Type','figure')');
            if isempty(figs)==0;
               for i=1:size(figs,2);
                  if strcmp(get(figs(1,i),'Tag'),'StructuralVAR')==0;
                     killpid(figs(1,i));
                  end;
               end;
            end;
         end;
         set(maingui,'UserData',model);
      end;
end;

if (get(model.structural,'Value')==1)&(strcmp(get(model.structural,'Enable'),'on')==1);
   set(model.shock_names,'Enable','on','CData',button_images.rename);
   set(model.shocknamesmenu,'Enable','on');
else;
   set(model.shock_names,'Enable','off','CData',button_images.renamedisable);
   set(model.shocknamesmenu,'Enable','off');
end;

if (strcmp(selector,'init')==1)&(strcmp(fig_file,'')==1);
   set(maingui,'Visible','on');
   drawnow;
   refresh(maingui);
end;

if nargout>0;
   mygui = maingui;
end;

if (strcmp(selector,'reopen')==0)&(strcmp(selector,'wayout')==0);
   var_ini.images = button_images;
   var_ini.model = model_var;
   var_ini.oldmodel = oldmodel_var;
   set(model.openmenu,'UserData',var_ini);
end;

if (strcmp(get(maingui,'Visible'),'on')==1)&(strcmp(selector,'wayout')==0);
   if strcmp(get(model.store,'Enable'),'off')==1;
      set(model.clearmenu,'Enable','off');
      set(model.undo,'Enable','off');
   else;
      set(model.clearmenu,'Enable','on');
      set(model.undo,'Enable','on');
   end;
end;

if strcmp(selector,'init')==1;
   model = get(maingui,'UserData');
   if ((var_ini.startrun==1)|(model_var.inistartrun==1))&(strcmp(fig_file,'')==1);
      if strcmp(get(model.estimate,'Enable'),'on')==1;
         maindlg(maingui);
         waitfor(model.leave,'UserData','done');
      else;
         waitfor(model.leave,'UserData','done');
      end;
   elseif strcmp(fig_file,'')==0;
      fig_mode.maingui = maingui;
      fig_mode.fig_file = fig_file;
      maindlg(fig_mode);
   else;
      waitfor(model.leave,'UserData','done');
   end;
end;

%
% end of maindlg.m
%