%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for setting variables names         %
%                                                                %
%          Function: namesdlg                                    %
%                                                                %
%          Input:                                                %
%                       selector: case switch function           %
%          	            file: Txn data file (n<T)                %
%                       sheet: name of sheet (if xls file)       %
%                       origname: string with current            %
%                           variable names                       %
%                       nametype: string defining variable       %
%                           type (Endogenous, etc.)              %
%                                                                %
%          Output:                                               %
%          	            h: handle                                %
%                                                                %
%          This version:        May 16, 2006                     %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function h = namesdlg(selector,file,sheet,origname,nametype)

if strcmp(selector,'init')==1;
   file = loaddata(file,sheet);
   tm.n = size(file,2);
   if size(file,2)>size(file,1);
      tm.n = size(file,1);
   end;
   %
   % check if origname is empty and if so generate
   % generic names
   %
   if strcmp(origname,'')==1;
      if strcmp(nametype,'Endogenous');
         for i=1:tm.n;
            if i==1;
               origname = 'y_1';
            else;
               origname = [origname ' y_' num2str(i)];
            end;
         end;
      elseif strcmp(nametype,'Exogenous I(1)')==1;
         for i=1:tm.n;
            if i==1;
               origname = 'x1_1';
            else;
               origname = [origname ' x1_' num2str(i)];
            end;
         end;
      elseif strcmp(nametype,'Exogenous I(0)')==1;
         for i=1:tm.n;
            if i==1;
               origname = 'x0_1';
            else;
               origname = [origname ' x0_' num2str(i)];
            end;
         end;
      elseif strcmp(nametype,'Deterministic')==1;
         for i=1:tm.n;
            if i==1;
               origname = 'd_1';
            else;
               origname = [origname ' d_' num2str(i)];
            end;
         end;
      elseif strcmp(nametype,'Shock')==1;
         for i=1:tm.n;
            if i==1;
               origname = 's_1';
            else;
               origname = [origname ' s_' num2str(i)];
            end;
         end;
      end;
   end;
   %
   % creating string with number of variables
   %
   numvars = '1';
   for i=2:tm.n;
      numvars = [numvars '|' num2str(i)];
   end;
   %
   % Initializing thisvariable for edit control
   %
   numchar = size(origname,2);
   for i=1:numchar;
      if strcmp(origname(1,i),' ')==1;
         thisvariable = origname(1,1:i-1);
         break;
      else;
         if i==numchar;
            thisvariable = origname;
         end;
      end;
   end;
   tm.oldthisvariable = thisvariable;
   %
   % initializing tm.namevector
   %
   i = 1;
   iold = 1;
   tm.namevector = '';
   while i<=numchar;
      if strcmp(origname(1,i),' ')==1;
         tm.namevector = strvcat(tm.namevector,origname(1,iold:i-1));
         iold = i+1;
      end;
      if i==numchar;
         tm.namevector = strvcat(tm.namevector,origname(1,iold:numchar));
      end;
      i = i+1;
   end;
   tm.oldnamevector = tm.namevector;
   %
   % initialize some variables
   %
   tm.myorigname = origname;
   tm.oldmyorigname = origname;
   tm.showorigname = [' ' tm.myorigname];
   tm.showorigname = strvcat(' ',' ',tm.showorigname);
   thisexit = 0;
   curr_ini = find_inisettings;
else;
   thisexit = 1;
   namesgui = get(0,'CurrentFigure');
   names = get(namesgui,'UserData');
   tm = get(names.popup,'UserData');
end;

%
% Set screen size directly instead of using
% get(0,'ScreenSize')!
%

realscrsz = get(0,'ScreenSize');

switch selector;
   case 'init';
      namesgui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','namesdlg.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(realscrsz(3)-461)/2 (realscrsz(4)-340)/2 461 340], ...
         'Tag','FigParent', ...
         'Resize','off', ...
         'Name',[nametype ' Variables'], ...
         'Visible','off', ...
         'WindowStyle','modal', ...
         'NumberTitle','off', ...
         'CloseRequestFcn','namesdlg exit', ...
         'ToolBar','none');

      if matlabnumber>=7.0;
         set(namesgui,'DockControl','off');
      end;

      %
      % Outer axis
      %

      axesbox([2 2 459 330],'Names Specification',100,[0.5 1]);

      %
      % GUI Header
      %

      mycons = getstoredimages;
      header_txt = 'Variable Names';
      desc_txt = ['To change the names of the ' lower(nametype(1,1)) nametype(1,2:size(nametype,2)) ' variables displayed in the listbox below first select the variable number, then enter the new variable name, and finally press the "Apply" button.'];
      dialog_header_fcn([14 247 433 70],mirrorimage(maketrans(mycons.renamebig_image,[160 160 164],[1 1 1])),header_txt,desc_txt);

      %
      % Outer axis for listbox control
      %

      axesbox([14 130 433 102],'Current Variable Names',116,[0.5 1]);

      %
      % Outer axis for change names controls
      %

      axesbox([14 14 433 102],'Change Variable Names',118,[0.5 1]);

      %
      % Listbox control with current names
      %

      names.listbox = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[30 146 401 70], ...
         'FontSize',10, ...
         'FontName','FixedWidth', ...
         'Style','listbox', ...
         'Enable','inactive', ...
         'Max',2, ...
         'HorizontalAlignment','center', ...
         'String',tm.showorigname, ...
         'UserData',tm.myorigname, ...
         'Tag','Text1',...
         'Value',[]);

      %
      % Text control to change names
      %

      names.icon = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[30 75 116 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'HorizontalAlignment','left', ...
         'String','Select Variable Number:', ...
         'Tag','PopupText');

      %
      % Popup control to change names
      %

      names.popup = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[150 80 170 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Value',1, ...
         'Callback','namesdlg changevar', ...
         'String',numvars, ...
         'Tag','PopupName');


      %
      % Text control 2 to change names
      %

      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[30 25 116 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'HorizontalAlignment','left', ...
         'String','Enter New Name:', ...
         'Tag','EditText');

      %
      % Edit control with name of variable
      %

      names.edit = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[150 30 170 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','edit', ...
         'HorizontalAlignment','left', ...
         'String',thisvariable, ...
         'Enable','on', ...
         'Tag','EditBox');

      %
      % Clear all button
      %

      names.clear = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[341 80 90 20], ...
         'String','Undo', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','namesdlg clearall', ...
         'UserData','working', ...
         'Enable','off', ...
         'Tag','ClearAll');

      %
      % Set new name button
      %

      names.button = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[341 55 90 20], ...
         'String','Apply', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'UserData',0, ...
         'CallBack','namesdlg entername', ...
         'Enable','on', ...
         'Tag','NameButton');

      %
      %  Done button
      %

      names.done = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[341 30 90 20], ...
         'String','Done', ...
         'CallBack','namesdlg done', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Enable','on', ...
         'UserData','waiting', ...
         'Tag','Done');

      set(namesgui,'UserData',names,...
         'HandleVisibility','callback');
   case 'entername'
      thisexit = 2;
      numvar = get(names.popup,'Value');
      oldname = tm.namevector(numvar,:);
      oldname = strrep(oldname,' ','');
      newname = get(names.edit,'String');
      newname = strrep(newname,' ','');
      if size(oldname,2)>=2;
         if strcmp(oldname(1,1:2),'s_')==1;
            set(names.button,'UserData',1);
         end;
      end;
      if strcmp(newname,oldname)==0;
         set(names.button,'UserData',1);
         if strcmp(newname,'');
            set(names.edit,'String',oldname);
         else;
            %
            % check tm.namevector to see if name has
            % been used previously
            %
            i = 1;
            match = 0;
            while i<=tm.n;
               checkname = tm.namevector(i,:);
               checkname = strrep(checkname,' ','');
               if strcmp(checkname,newname)==1;
                  match = 1;
                  i = tm.n+1;
               else;
                  i = i+1;
               end;
            end;
            %
            % change tm.namevector
            %
            if match==1;
               set(names.edit,'String',oldname);
            else;
               if size(tm.namevector,1)>=2;
                  if numvar==1;
                     tm.namevector = tm.namevector(2:tm.n,:);
                     tm.namevector = strvcat(newname,tm.namevector);
                  elseif numvar==tm.n;
                     tm.namevector = tm.namevector(1:tm.n-1,:);
                     tm.namevector = strvcat(tm.namevector,newname);
                  else;
                     namevec1 = tm.namevector(1:numvar-1,:);
                     namevec2 = tm.namevector(numvar+1:tm.n,:);
                     tm.namevector = strvcat(namevec1,newname,namevec2);
                  end;
               else;
                  tm.namevector = newname;
               end;
               %
               % change tm.myorigname
               %
               if size(tm.namevector,1)>=2;
                  if numvar==1;
                     tm.myorigname = strrep(tm.myorigname,[oldname ' '],[newname ' ']);
                  elseif numvar==tm.n;
                     tm.myorigname = strrep(tm.myorigname,[' ' oldname],[' ' newname]);
                  else;
                     tm.myorigname = strrep(tm.myorigname,[' ' oldname ' '],[' ' newname ' ']);
                  end;
               else;
                  tm.myorigname = strrep(tm.myorigname,oldname,newname);
               end;
               tm.showorigname = [' ' tm.myorigname];
               tm.showorigname = strvcat(' ',' ',tm.showorigname);
               set(names.listbox,'String',tm.showorigname);
               set(names.listbox,'UserData',tm.myorigname);
               set(names.clear,'Enable','on');
            end;
         end;
      end;
      if numvar<size(tm.namevector,1);
         set(names.popup,'Value',numvar+1);
         set(names.edit,'String',strrep(tm.namevector(numvar+1,:),' ',''));
      else;
         set(names.popup,'Value',1);
         set(names.edit,'String',strrep(tm.namevector(1,:),' ',''));
      end;
      set(namesgui,'UserData',names);
   case 'changevar'
      numvar = get(names.popup,'Value');
      newname = tm.namevector(numvar,:);
      newname = strrep(newname,' ','');
      set(names.edit,'String',newname);
      set(namesgui,'UserData',names);
   case 'done'
      set(names.done,'UserData','done');
      set(namesgui,'UserData',names);
   case 'clearall'
      thisexit = 2;
      tm.namevector = tm.oldnamevector;
      tm.myorigname = tm.oldmyorigname;
      tm.showorigname = [' ' tm.myorigname];
      tm.showorigname = strvcat(' ',' ',tm.showorigname);
      set(names.listbox,'String',tm.showorigname);
      set(names.listbox,'UserData',tm.myorigname);
      set(names.edit,'String',tm.oldthisvariable);
      set(names.popup,'Value',1);
      set(names.button,'UserData',0);
      set(names.clear,'Enable','off');
      set(namesgui,'UserData',names);
   case 'exit'
      set(names.done,'UserData','done');
%      if strcmp(get(names.clear,'UserData'),'done')==1;
%         delete(namesgui);
%      end;
end;

if nargout==1;
   h = namesgui;
end;

set(names.popup,'UserData',tm);

if thisexit==0;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(namesgui,'Name') ' ' fix_filepath([pwd '\icons\rename.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(names.icon,'UserData',pid);
      end;
   end;
   set(namesgui,'Visible','on');
   drawnow;
   if (iswinnt==1)&(iscompiled==1)&(matlabnumber<7);
      drawnow;
      prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(namesgui,'Name') ' 1'];
      dos(prog);
      drawnow;
   elseif matlabnumber>=7;
      uicontrol(names.done);
   end;
   waitfor(names.done,'UserData','done');
end;

%
% end of namesdlg.m
%

