function res = pmcs(in,tm,r)

%
% Computes the Posterior Mean Cointegration Space estimator of beta
%
% see Villani, M. (2005), "Bayesian Point Estimation of the Cointegration Space",
% forthcoming in Journal of Econometrics, for details
%

sum_beta = 0;
for i=1:tm.save_draws;
   beta = in.posterior(i).beta;
   sum_beta = sum_beta+((1/tm.save_draws)*(beta*inverse(beta'*beta)*beta'));
end;

[U,lambda] = eig(sum_beta);

lambda = diag(lambda,0);
[lambda2,AscInd] = sort(abs(lambda));

nr = size(AscInd,1);
DescInd = zeros(nr,1);
i = 1;
while i<=nr;
   DescInd(i)=AscInd(nr+1-i);
   i =i+1;
end;
lambda = abs(lambda(DescInd));
U = U(:,DescInd);
res.beta = U(:,1:r);
res.variation = (((tm.n+tm.q1+tm.dcoint)*(r-sum(lambda(1:r))))/(r*(tm.n+tm.q1+tm.dcoint-r)));

if isfield(in.posterior(1),'beta_n')==1;
   sum_beta = 0;
   for i=1:tm.save_draws;
      beta = in.posterior(i).beta_n;
      sum_beta = sum_beta+((1/tm.save_draws)*(beta*inverse(beta'*beta)*beta'));
   end;
   
   [U,lambda] = eig(sum_beta);
   
   lambda = diag(lambda,0);
   [lambda2,AscInd] = sort(abs(lambda));
   
   nr = size(AscInd,1);
   DescInd = zeros(nr,1);
   i = 1;
   while i<=nr;
      DescInd(i)=AscInd(nr+1-i);
      i =i+1;
   end;
   lambda = abs(lambda(DescInd));
   U = U(:,DescInd);
   res.beta_n = U(:,1:r);
   res.variation_n = (((tm.n+tm.q1+tm.dcoint)*(r-sum(lambda(1:r))))/(r*(tm.n+tm.q1+tm.dcoint-r)));
end;

%
% end of pmcs.m
%
