%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for printing output file            %
%                                                                %
%          Function: printgui                                    %
%                                                                %
%          Input:                                                %
%                       selector: case switch function           %
%          		          outputfile: file                         %
%                                                                %
%          Output:                                               %
%          		          h: handle                                %
%                                                                %
%          This version:        May 17, 2006                     %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function h = printgui(selector,outputfile,figname,position,boxtext,boxwidth)

if strcmp(selector,'init')==1;
   thisexit = 0;
   myoutput = outputfile;
   outputfiletext = readtext(outputfile);
   curr_ini = find_inisettings;
   if iscellstr(outputfiletext)==1;
      if strcmp(strtrim(outputfiletext{max(size(outputfiletext))}),'')==0;
         outputfiletext{max(size(outputfiletext))+1} = ' ';
      end;
   end;
   %
   scrsz = [1 1 1024 768];
   realscrsz = get(0,'ScreenSize');
   adjscrsz = realscrsz(4)-768;
   %
   if nargin<3;
      figname = ['Print - ' outputfile];
      position = [(realscrsz(3)-(realscrsz(4)-80))/2 32 realscrsz(4)-80 realscrsz(4)-54];
      boxtext = 'Results';
      boxwidth = 40;
   end;
else;
   thisexit = 1;
   printdlg = get(0,'CurrentFigure');
   myprint = get(printdlg,'UserData');
   curr_ini = get(myprint.text,'UserData');
   myoutput = curr_ini.myoutput;
end;

%
% Set screen size directly instead of using
% get(0,'ScreenSize')!
%

switch selector;
   case 'init';
      printdlg = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','printgui.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',position, ...
         'Tag','FigParent', ...
         'Visible','off', ...
         'DoubleBuffer','on', ...
         'Resize','on', ...
         'Name',figname, ...
         'NumberTitle','off', ...
         'ResizeFcn','printgui_resize_fcn', ...
         'CloseRequestFcn','printgui exit', ...
         'ToolBar','none');

      if matlabnumber>=7.0;
         set(printdlg,'DockControl','off');
      end;

      boxpos = [2 2 position(3)-2 position(4)-10];

      listpos = [15 75 position(3)-30 position(4)-98];

      buttonpos = [position(3)-105 20 90 20];

      %
      % Outer axis
      %

      myprint.box = axesbox(boxpos,boxtext,boxwidth,[0.5 1]);

      %
      % Listbox control with output file text
      %

      myprint.icon = uicontrol('Units','pixels','Position',[0 0 1 1],'Visible','off');

      myprint.text = uicontrol('Units','pixels', ...
         'BackgroundColor',curr_ini.text_backgroundcolor, ...
         'ForegroundColor',curr_ini.text_color, ...
         'Position',listpos, ...
         'FontSize',curr_ini.text_fontsize, ...
         'FontName',curr_ini.text_fontname, ...
         'FontWeight',curr_ini.text_fontweight, ...
         'FontAngle',curr_ini.text_fontangle, ...
         'FontUnits',curr_ini.text_fontunits, ...
         'Style','listbox', ...
         'Enable','inactive', ...
         'Max',2, ...
         'HorizontalAlignment','center', ...
         'String',outputfiletext, ...
         'Tag','Text1',...
         'Value',[]);

      if ispc==1;
         mytext.copy = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'ForegroundColor',[0 0 0], ...
            'Position',[20 20 90 20], ...
            'String','Copy', ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'CallBack','textgui_copy_fcn', ...
            'Enable','on', ...
            'Tag','Done');
      end;

      %
      % Send to printer button
      %

      myprint.print = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'ForegroundColor',[0 0 0], ...
         'Position',buttonpos+[0 25 0 0], ...
         'String','Print', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','printgui print', ...
         'Enable','on', ...
         'UserData','working', ...
         'Tag','Print');

      %
      % Done button
      %

      myprint.done = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'ForegroundColor',[0 0 0], ...
         'Position',buttonpos, ...
         'String','Done', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','printgui done', ...
         'Enable','on', ...
         'UserData','waiting', ...
         'Tag','Done');

      set(printdlg,'UserData',myprint,...
         'HandleVisibility','callback');
   case 'print'
      if ispc==1;
         if strcmp(curr_ini.txtprint,'')==1;
            prog = ['notepad.exe /p ' fix_path(myoutput) ' &'];
         else;
            prog = fix_path(curr_ini.txtprint);
            if strcmp(curr_ini.txtprintcmd,'')==0;
               prog = [prog ' ' curr_ini.txtprintcmd];
            end;
            prog = [prog ' ' fix_path(myoutput) ' &'];
         end;
         prog = fixcmd(prog);
         dos(prog);
         drawnow;
      else;
         if isunix==1;
            if strcmp(curr_ini.txtprint,'')==1;
               prog = ['lpr ' myoutput];
            else;
               prog = curr_ini.txtprint;
               if strcmp(curr_ini.txtprintcmd,'')==0;
                  prog = [prog ' ' curr_ini.txtprintcmd];
               end;
               prog = [prog ' ' myoutput];
            end;
            unix(prog);
            drawnow;
         else;
            txt = 'Currently Structural VAR cannot print files under Mac. If you know how to solve this, please let me know.';
            about(txt,'warning','Print - Mac Message',120,350);
         end;
      end;
   case 'done'
      set(myprint.done,'UserData','done');
      set(printdlg,'UserData',myprint);
   case 'exit'
      set(myprint.done,'UserData','done');
%      if strcmp(get(myprint.print,'UserData'),'done')==1;
%         delete(printdlg);
%      end;
end;

if strcmp(selector,'init')==1;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(printdlg,'Name') ' ' fix_filepath([pwd '\icons\print.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(myprint.icon,'UserData',pid);
      end;
   end;
   set(printdlg,'Visible','on');
   drawnow;
   if (iswinnt==1)&(iscompiled==1)&(matlabnumber<7);
      drawnow;
      prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(printdlg,'Name') ' 1'];
      dos(prog);
      drawnow;
   elseif matlabnumber>=7;
      uicontrol(myprint.done);
   end;
end;

if nargout==1;
   h = printdlg;
end;

curr_ini.myoutput = myoutput;

set(myprint.text,'UserData',curr_ini);

if thisexit==0;
   waitfor(myprint.done,'UserData','done');
end;

%
% end of printgui.m
%
