%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab function for estimating cointegration          %
%          relations under linear restrictions                   %
%                                                                %
%          Function: progressdlg                                 %
%                                                                %
%          Input:                                                %
%          		          x: real number between 0 and 1           %
%                         and without handle real + value of     %
%                         convergence criterion                  %
%                       whichbar: structure with 8 arguments     %
%                         whichbar.title: title bar              %
%                         whichbar.name: Figure name             %
%                         whichbar.edgecolor: Edge Color         %
%                         whichbar.facecolor: Face Color         %
%                           for patchfunction, e.g. RGB triple   %
%                         whichbar.label: label string           %
%                         whichbar.stop: 1 shows stop button     %
%                           0 no stop button                     %
%                         whichbar.clock: 1 displays clock       %
%                           0 no clock                           %
%                       or                                       %
%                         nothing                                %
%                                                                %
%          Output:                                               %
%          	          	fout: figure handle                      %
%                                                                %
%          Comment: Rewrite of waitbar function in MatLab        %
%                                                                %
%          This version:        June 16, 2006                    %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%          Other info:                                           %
%                                                                %
%          Clay M. Thompson 11-9-92                              %
%          Copyright (c) 1984-98 by The MathWorks, Inc.          %
%          $Revision: 1.14 $  $Date: 1998/09/01 21:49:34 $       %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function fout = progressdlg(x,whichbar)

%#function closeprogressdlg cancelprogessdlg stopprogressdlg

if size(x,2)==2;
   y2 = x(1,2);
elseif size(x,2)==3;
   y2 = x(1,2:3);
end;

if nargin>=2 & isstruct(whichbar)
   type_var=2; %we are initializing
   if isfield(whichbar,'title')==0;
      whichbar.title = 'No title';
   end;
   if isfield(whichbar,'edgecolor')==0;
      whichbar.edgecolor = [0 0 0];
   end;
   if isfield(whichbar,'facecolor')==0;
      whichbar.facecolor = (1/255)*[166 210 255];
   end;
   if isfield(whichbar,'startfacecolor')==0;
      whichbar.startfacecolor = (1/255)*[0 36 104];
   end;
   if isfield(whichbar,'stop')==0;
      whichbar.stop = 0;
   end;
   if isfield(whichbar,'clock')==0;
      whichbar.clock = 0;
   end;
   name=whichbar;
   my_screenSize = get(0,'ScreenSize');
elseif nargin>=2 & isnumeric(whichbar)
   type_var=1; %we are updating, given a handle
   f=whichbar;
elseif nargin==1
   my_screenSize = get(0,'ScreenSize');
   f = findobj(allchild(0),'flat','Tag','TMWprogressdlg');
   
   if isempty(f)
      type_var=2;
      name='Progress dialog';
   else
      type_var=1;
      f=f(1);
   end   
elseif nargin==2
   error('Two-argument syntax requires progressdlg(X,''title'') or progressdlg(X,H)')
end

x = max(0,min(100*x,100));

switch type_var
case 1,  % progressdlg(x)    update
   x2 = x(1,2);
   x = x(1,1);
   p = findobj(f,'Type','patch','Tag','progress');
   %
   face_color = get(p,'FaceColor');
   edge_color = get(p,'EdgeColor');
   mytitle = get(f,'Name');
   myx = num2str(x,'%0.1f');
   my_clock = findobj(f,'Tag','Clock');
   if (isempty(my_clock)==0)&(ishandle(my_clock)==1);
      new_time = toc;
      my_hrs = '00';
      my_min = '00';
      my_sec = num2str(new_time,'%0.2f');
      if new_time>=60;
         ch_min = floor(new_time/60);
         my_sec = num2str(new_time-(ch_min*60),'%0.2f');
         my_min = num2str(ch_min,'%0.0f');
         if ch_min>=60;
            ch_hrs = floor(ch_min/60);
            my_min = num2str(ch_min-(ch_hrs*60),'%0.0f');
            my_hrs = num2str(ch_hrs,'%0.0f');
         end;
      end;
      if size(my_sec,2)==4;
         my_sec = ['0' my_sec];
      end;
      if size(my_min,2)==1;
         my_min = ['0' my_min];
      end;
      if size(my_hrs,2)==1;
         my_hrs = ['0' my_hrs];
      end;
      clock_str = [my_hrs ':' my_min ':' my_sec];
      set(my_clock,'String',clock_str);
   end;

   f1 = findobj(f,'Type','uicontrol','Tag','ProgressCancel');
   ud = get(f1,'UserData');
   myxlabel = ud.myxlabel;
   oldx = ud.oldx;
   name = ud.name;
   mytitle = strrep(mytitle,[' - ' oldx '%'],'');
   mytitle = [mytitle ' - ' myx '%'];
   set(f,'Name',mytitle);
   if isempty(f) | isempty(p);
      error('Couldn''t find progressdlg handles.'); 
   end
   xpatch = get(p,'XData');
   %replace 0 with xpatch(2)
   xpatch = [xpatch(2) x x xpatch(2)];
   xpatch = [0 x x 0];
   b_map = get(f,'Colormap');
   p_color = b_map(floor((63*x)/100)+1,:);
   set(p,'XData',xpatch','FaceColor',p_color,'EdgeColor',edge_color);
%   set(p,'XData',xpatch','FaceColor',face_color,'EdgeColor',edge_color);
   oldx = myx;
   if isfield(name,'label')==0;
      mylabstr = ['Convergence criterion: ' num2str(y2)];
   else;
      if size(y2,2)==1;
         if abs(y2-round(y2))==0;
            mylabstr = [name.label ' ' num2str(y2)];
         else;
            mylabstr = [name.label ' ' num2str(y2,'%0.4f')];
         end;
      elseif size(y2,2)==2;
         mylabstr = [name.label ' (' num2str(y2(1),'%0.4f') ',' num2str(y2(2),'%0.4f') ')'];
      end;
   end;

   set(myxlabel,'String',mylabstr);
   if (iswinnt==1)&(iscompiled==1)&(ud.focus==0);
      curr_ini = ud.curr_ini;
      if curr_ini.noicon==1;
         set(f,'WindowStyle','modal');
         prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(f,'Name') ' NULL'];
         dos(prog);
         wait_fcn(curr_ini.delay);
      end;
      set(f,'Position',ud.position);
      drawnow;
      if matlabnumber<7;
         prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(findobj('Type','Figure','Tag','TMWprogressdlg')','Name') ' 1'];
         dos(prog);
         drawnow;
      else;
         cancel_btn = findobj(f,'Type','uicontrol','Tag','ProgressCancel');
         if isempty(cancel_btn)==0;
            uicontrol(cancel_btn(1,1));
         end;
      end;
      set(f,'Position',ud.position);
      ud.focus = 1;
   elseif ud.focus==0;
      set(f,'Position',ud.position);
      ud.focus = 1;
   end;
   drawnow;
case 3,
   h = get(0,'CurrentFigure');
   f1 = findobj('Type','uicontrol','Tag','ProgressCancel');
   ud = get(f1,'UserData');
   oldx = ud.oldx;
   name = ud.name;
   myxlabel = ud.myxlabel;
   set(h,'UserData','cancel');
case 2,  % progressdlg(x,name)  initialize

   oldx = '0';
   oldRootUnits = get(0,'Units');

   set(0, 'Units', 'points');
   screenSize = get(0,'ScreenSize');
   
   axFontSize=get(0,'FactoryAxesFontSize');
   
   pointsPerPixel = 72/get(0,'ScreenPixelsPerInch');
      
   width = 380 * pointsPerPixel;
   height = (75+50) * pointsPerPixel;
   pos = [screenSize(3)/2-width/2 screenSize(4)/2-height/2 width height];
   
   if isfield(name,'name')==1;
      fig_name = name.name;
      if ischar(fig_name)==1;
         fig_name = strtrim(fig_name(1,:));
         if strcmp(fig_name,'')==1;
            fig_name = 'Wait';
         end;
      else;
         fig_name = 'Wait';
      end;
   else;
      fig_name = 'Wait';
   end;

   f = figure(...
           'Units', 'points', ...
           'Position', pos, ...
           'Resize','off', ...
           'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
           'CreateFcn','', ...
           'CloseRequestFcn','closeprogressdlg', ...
           'NumberTitle','off', ...
           'IntegerHandle','off', ...
           'MenuBar', 'none', ...
           'WindowStyle','modal', ...
           'Tag','TMWprogressdlg',...
           'DoubleBuffer','on', ...
           'Name',fig_name, ...
           'UserData','working',...
           'Visible','off');
   colormap([]);
   %
   % now we create a colormap
   %
   barcolor2 = name.facecolor;
   if isfield(name,'startfacecolor')==1;
      barcolor1 = name.startfacecolor;
   else;
      barcolor1 = (1/255)*[0 36 104];
   end;
   b_map = zeros(64,3);
   for i=1:64;
      b_map(i,1:3) = barcolor1 + ((i-1)/63)*(barcolor2-barcolor1);
   end;
   set(f,'Colormap',b_map);

   if matlabnumber>=7.0;
      set(f,'DockControl','off');
   end;

   %
   % Outer axis
   %

   axesbox([2 2 (width/pointsPerPixel)-2 (height/pointsPerPixel)-10],'Progress',45,[0.5 1]);

   if name.stop==1;
      addthis = 27.5;
   else;
      addthis = 0;
   end;

   curr_ini = find_inisettings;

   if name.clock==1;
      f3 = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Units','Points',...
            'Position',[10 10 50 10], ...
            'String','00:00:00.00', ...
            'Style','text', ...
            'HorizontalAlignment','left', ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'Enable','on', ...
            'Tag','Clock');
      tic;

   end;

   axNorm=[.05 .3 .9 .2];
   axPos=axNorm.*[pos(3:4),pos(3:4)];
   axPos(2) = 45;
   
   h = axes('XLim',[0 100],...
      'YLim',[0 1],...
      'Box','on', ...
      'Units','Points',...
      'FontSize', axFontSize,...
      'Position',axPos,...
      'XTickMode','manual',...
      'YTickMode','manual',...
      'Color',name.bgcolor, ...
      'XColor',name.edgecolor, ...
      'YColor',name.edgecolor, ...
      'XTick',[],...
      'YTick',[],...
      'XTickLabelMode','manual',...
      'XTickLabel',[],...
      'YTickLabelMode','manual',...
      'YTickLabel',[]);

   if isfield(name,'label')==0;
      mylabstr = ['Convergence criterion: 1'];
   else;
      mylabstr = [name.label ' 0'];
   end;

   myxlabel = xlabel(mylabstr);

%   if my_screenSize(3)<=1280;
      set(myxlabel,'FontSize',curr_ini.gui_fontsize+2,'FontName',curr_ini.gui_fontname,'FontWeight',curr_ini.gui_fontweight,'FontAngle',curr_ini.gui_fontangle,'Color',[0 0 0]);
%   else;
%      set(myxlabel,'FontSize',7);
%   end;
%   set(myxlabel,'HorizontalAlignment','left');
   set(myxlabel,'HorizontalAlignment','center');
   set(myxlabel,'Units','pixels');
   check = get(myxlabel,'Position');
   tHandle=title(name.title);
   tHandle=get(h,'title');
   oldTitleUnits=get(tHandle,'Units');
   newpos = get(tHandle,'Position');
   set(tHandle,...
      'Units',      'points',...
      'String',     name.title);

%   if my_screenSize(3)<=1280;
      set(tHandle,'FontName',curr_ini.gui_fontname, ...
          'FontSize',curr_ini.gui_fontsize+2, ...
          'FontWeight',curr_ini.gui_fontweight, ...
          'FontAngle',curr_ini.gui_fontangle);
%   else;
%      set(tHandle,'FontSize',8);
%   end;

   tExtent=get(tHandle,'Extent');
   set(tHandle,'Units',oldTitleUnits);

   check_char = findstr(name.title,'_');

   if isempty(check_char)==0;
      old_u = get(tHandle,'Units');
      set(tHandle,'Units','pixels');
      t_pos = get(tHandle,'Position');
      t_pos(2) = t_pos(2)-5;
      set(tHandle,'Position',t_pos);
      set(tHandle,'Units',old_u);
   end;
   
   xpatch = [0 x x 0];
   ypatch = [0 0 1 1];

   %
   % Making patch height smaller
   %

   oldu = get(h,'Units');
   set(h,'Units','pixels');
   awpos = get(h,'Position');
%   set(h,'Position',[awpos(1,1:3) 18]);
   set(h,'Position',[awpos(1,1:3) 14]);
   set(h,'Units',oldu);

   p = patch('XData',xpatch,'YData',ypatch,'EdgeColor',name.edgecolor,'FaceColor',name.facecolor,'EraseMode','normal','LineWidth',1,'Tag','progress');
   %
   p1 = patch('XData',[9.5 10.5 10.5 9.5],'YData',ypatch,'EdgeColor',name.edgecolor,'FaceColor',get(0,'defaultuicontrolbackgroundcolor'),'EraseMode','none','LineWidth',1,'Tag','edge');
   p2 = patch('XData',[9.75 10.25 10.25 9.75],'YData',ypatch,'EdgeColor',get(0,'defaultuicontrolbackgroundcolor'),'FaceColor',get(0,'defaultuicontrolbackgroundcolor'),'EraseMode','none','LineWidth',1,'Tag','face');
   %
   p1 = patch('XData',[19.5 20.5 20.5 19.5],'YData',ypatch,'EdgeColor',name.edgecolor,'FaceColor',get(0,'defaultuicontrolbackgroundcolor'),'EraseMode','none','LineWidth',1,'Tag','edge');
   p2 = patch('XData',[19.75 20.25 20.25 19.75],'YData',ypatch,'EdgeColor',get(0,'defaultuicontrolbackgroundcolor'),'FaceColor',get(0,'defaultuicontrolbackgroundcolor'),'EraseMode','none','LineWidth',1,'Tag','face');
   %
   p1 = patch('XData',[29.5 30.5 30.5 29.5],'YData',ypatch,'EdgeColor',name.edgecolor,'FaceColor',get(0,'defaultuicontrolbackgroundcolor'),'EraseMode','none','LineWidth',1,'Tag','edge');
   p2 = patch('XData',[29.8 30.25 30.25 29.8],'YData',ypatch,'EdgeColor',get(0,'defaultuicontrolbackgroundcolor'),'FaceColor',get(0,'defaultuicontrolbackgroundcolor'),'EraseMode','none','LineWidth',1,'Tag','face');
   %
   p1 = patch('XData',[39.5 40.5 40.5 39.5],'YData',ypatch,'EdgeColor',name.edgecolor,'FaceColor',get(0,'defaultuicontrolbackgroundcolor'),'EraseMode','none','LineWidth',1,'Tag','edge');
   p2 = patch('XData',[39.75 40.25 40.25 39.75],'YData',ypatch,'EdgeColor',get(0,'defaultuicontrolbackgroundcolor'),'FaceColor',get(0,'defaultuicontrolbackgroundcolor'),'EraseMode','none','LineWidth',1,'Tag','face');
   %
   p1 = patch('XData',[49.5 50.5 50.5 49.5],'YData',ypatch,'EdgeColor',name.edgecolor,'FaceColor',get(0,'defaultuicontrolbackgroundcolor'),'EraseMode','none','LineWidth',1,'Tag','edge');
   p2 = patch('XData',[49.75 50.25 50.25 49.75],'YData',ypatch,'EdgeColor',get(0,'defaultuicontrolbackgroundcolor'),'FaceColor',get(0,'defaultuicontrolbackgroundcolor'),'EraseMode','none','LineWidth',1,'Tag','face');
   %
   p1 = patch('XData',[59.5 60.5 60.5 59.5],'YData',ypatch,'EdgeColor',name.edgecolor,'FaceColor',get(0,'defaultuicontrolbackgroundcolor'),'EraseMode','none','LineWidth',1,'Tag','edge');
   p2 = patch('XData',[59.75 60.25 60.25 59.75],'YData',ypatch,'EdgeColor',get(0,'defaultuicontrolbackgroundcolor'),'FaceColor',get(0,'defaultuicontrolbackgroundcolor'),'EraseMode','none','LineWidth',1,'Tag','face');
   %
   p1 = patch('XData',[69.5 70.5 70.5 69.5],'YData',ypatch,'EdgeColor',name.edgecolor,'FaceColor',get(0,'defaultuicontrolbackgroundcolor'),'EraseMode','none','LineWidth',1,'Tag','edge');
   p2 = patch('XData',[69.75 70.2 70.2 69.75],'YData',ypatch,'EdgeColor',get(0,'defaultuicontrolbackgroundcolor'),'FaceColor',get(0,'defaultuicontrolbackgroundcolor'),'EraseMode','none','LineWidth',1,'Tag','face');
   %
   p1 = patch('XData',[79.5 80.5 80.5 79.5],'YData',ypatch,'EdgeColor',name.edgecolor,'FaceColor',get(0,'defaultuicontrolbackgroundcolor'),'EraseMode','none','LineWidth',1,'Tag','edge');
   p2 = patch('XData',[79.75 80.25 80.25 79.75],'YData',ypatch,'EdgeColor',get(0,'defaultuicontrolbackgroundcolor'),'FaceColor',get(0,'defaultuicontrolbackgroundcolor'),'EraseMode','none','LineWidth',1,'Tag','face');
   %
   p1 = patch('XData',[89.5 90.5 90.5 89.5],'YData',ypatch,'EdgeColor',name.edgecolor,'FaceColor',get(0,'defaultuicontrolbackgroundcolor'),'EraseMode','none','LineWidth',1,'Tag','edge');
   p2 = patch('XData',[89.75 90.25 90.25 89.75],'YData',ypatch,'EdgeColor',get(0,'defaultuicontrolbackgroundcolor'),'FaceColor',get(0,'defaultuicontrolbackgroundcolor'),'EraseMode','none','LineWidth',1,'Tag','face');

   if name.stop==1;
      f2 = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Units','Points',...
            'Position',[width/2-52.5 10 50 15], ...
            'String','Done', ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'CallBack','stopprogressdlg', ...
            'Enable','on', ...
            'Tag','Stop');
   end;

   f1 = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Units','Points',...
         'Position',[width/2-25+addthis 10 50 15], ...
         'String','Cancel', ...
         'Tag','ProgressCancel', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','cancelprogessdlg', ...
         'Enable','on');

   ud.focus = 0;

   set(f,'HandleVisibility','callback');
   set(0, 'Units', oldRootUnits);

   if (iswinnt==1)&(iscompiled==1)&(curr_ini.noicon==1);
      set(f,'WindowStyle','normal');
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(f,'Name') ' NULL'];
      dos(prog);
      wait_fcn(curr_ini.delay);
   end;
   ud.curr_ini = curr_ini;
   ud.position = get(f,'Position');
   set(f,'Position',[0 0 1 1]);
   set(f,'Visible','on');
   drawnow;
end  % case
drawnow;

ud.oldx = oldx;
ud.name = name;
ud.myxlabel = myxlabel;
set(f1,'UserData',ud);

if nargout==1,
  fout = f;
end

%
% end of progressdlg.m
%

