%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI for determining the rank of Pi             %
%                                                                %
%          Function: rankgui                                     %
%                                                                %
%          Input:                                                %
%                    selector: case switch function              %
%                    curr_model: structure with model info       %
%                                                                %
%          Output:                                               %
%                    h: handle                                   %
%                                                                %
%          This version:        February 26, 2008                %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2008          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function h = rankgui(selector,curr_model)

if strcmp(selector,'init')==1;
   cm = curr_model;
   curr_ini = find_inisettings;
   %
   cvstr = 'Critical Values';
   if curr_ini.critval==100;
      cvstr = 'p-values';
   end;
   cm.showcritval = 0;
   cm.pvalues = [];
   cm.r = cm.n;
   cm.rvec = cm.n;
   dfc = round(((cm.n+cm.q1+cm.dcoint-cm.r)*cm.r)/cm.n);
   cm.df = cm.n*(cm.p-1)+cm.r+cm.q1*cm.pe+cm.q0*(cm.pe+1)+cm.d+dfc;
   cm.cbs = cm.c;
   cm.qsum = cm.q1+cm.q0;
   cm.bZ1t = normbeta(cm.beta)'*cm.Z1t;
   cm.bR1t = normbeta(cm.beta)'*cm.R1t;
   %
   cm.trendplace = 0;
   if cm.spectest(1,4)==1;
      if cm.deterselect(1,3)==1;
         cm.trendplace = 2;
      end;
   end;
   prependstr = '   ';
   for i=2:cm.n;
      prependstr = [prependstr;'   '];
   end;
   h0 = (0:cm.n-1);
   cm.textlambda = [num2str(h0','%2.0f') prependstr prependstr num2str(cm.trace,'%12.4f') prependstr prependstr num2str(cm.lambda,'%12.4f')];
   cm.textlambda = [prependstr cm.textlambda];
   cm.textlambda = strvcat(' ',cm.textlambda,' ');
   thisexit = 0;
   ranks = '0';
   i = 1;
   while i<=cm.n;
      ranks = [ranks '|' num2str(i)];
      i = i+1;
   end;
   %
   % get string matrices for model information
   %
   cm.model_info = getmodelinfo(cm);
   cm.model_info.info = setmodelinfo(cm.model_info.info,cm.T,cm.df,loglike(cm.epsilon));
   %
   if curr_ini.lagtest>0;
      lagenable = 'on';
   else;
      lagenable = 'off';
   end;
   %
   % import images
   %
   button_images = read_images;
   %
   if cm.critvalnum==6;
      mypicture = button_images.pvalue;
   else;
      mypicture = button_images.cv;
   end;
   recursivestatus = 'off';
   cm.running = 0;
   %
   % Obtaining the eigenvalues of the companion matrix
   %
   if (cm.p==1)&(cm.r==0);
      cm.evalue = 0;
   else;
      eigenvalues = companion(cm.Z0,cm.Z1,cm.Z2,cm.r,cm.p,cm.n,cm.q1,cm.q0,cm.d,cm.T);
      eigenvalues = abs(sort(eigenvalues));
      i = size(eigenvalues,1);
      while i>=1;
         cm.evalue = eigenvalues(i,1);
         if strcmp(num2str(cm.evalue,'%1.10f'),'1.0000000000')==1;
            i = i-1;
         else;
            i = 0;
         end;
      end;
   end;
   if cm.evalue<1;
      if round(cm.qsum)==0;
         recursivestatus = 'on';
      end;
      if cm.q1>0;
         pcstatus = 'on';
      else;
         pcstatus = 'off';
      end;
   else;
      pcstatus = 'off';
   end;
   if (cm.n==1)&(cm.q1+cm.q0==0);
      gcenable = 'off';
   else;
      gcenable = 'on';
   end;
   corrstr = '';
   if isempty(cm.bartcorr)==0;
      corrstr = ['Trace tests corrected with factors: ' num2str(cm.bartcorr(1,1),'%0.2f')];
      for i=2:cm.n;
         if i<cm.n;
           corrstr = [corrstr ', ' num2str(cm.bartcorr(i,1),'%0.2f')];
         else;
           corrstr = [corrstr ', and ' num2str(cm.bartcorr(cm.n,1),'%0.2f') '.'];
         end;
      end;
   end;
   %
   showpdfdoc = [];
   if (strcmp(curr_ini.pdfviewer,'')==0)|(strcmp(curr_ini.epsviewer,'')==0)|(strcmp(curr_ini.psviewer,'')==0);
      pdf_file = [pwd '\doc\generalized-impulse-response.pdf'];
      if isunix==1;
         pdf_file = strrep(pdf_file,'\','/');
      end;
      if fileexist(pdf_file)==1;
         showpdfdoc.gir = pdf_file;
      else;
         showpdfdoc.gir = '';
      end;
      pdf_file = [pwd '\doc\common-cycles.pdf'];
      if isunix==1;
         pdf_file = strrep(pdf_file,'\','/');
      end;
      if fileexist(pdf_file)==1;
         showpdfdoc.cc = pdf_file;
      else;
         showpdfdoc.cc = '';
      end;
   end;
else;
   thisexit = 1;
%   rankdlg = get(0,'CurrentFigure');
   rankdlg = findobj('Type','figure','Tag','RankGUI')';
   coint = get(rankdlg,'UserData');
   curr_ini = get(coint.viewdata,'UserData');
   button_images = curr_ini.images;
   cm = curr_ini.model;
end;

%
% Set screen size directly instead of using
% get(0,'ScreenSize')!
%

scrsz = [1 1 1024 768];
realscrsz = get(0,'ScreenSize');

switch selector;
   case 'init';
      if isempty(cm.bartcorr)==1;
         add_height = 0;
      else;
         add_height = 15;
      end;
      rankdlg = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','rankgui.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(realscrsz(3)-scrsz(3)/2)/2-50 (realscrsz(4)-(scrsz(4)/2)-10-add_height)/2 scrsz(3)/2+100 (scrsz(4)/2)+10+add_height], ...
         'Tag','RankGUI', ...
         'Resize','off', ...
         'Name','Structural VAR - Cointegration Rank Tests', ...
         'NumberTitle','off', ...
         'CloseRequestFcn','rankgui wayout', ...
         'DoubleBuffer','on', ...
         'Visible','off', ...
         'WindowStyle','normal', ...
         'ToolBar','none');

      if matlabnumber>=7.0;
         set(rankdlg,'DockControl','off');
      end;

      %
      % File menu
      %

      filemenu = uimenu('Parent',rankdlg, ...
         'Label','&File', ...
         'Tag','FileMenu');

      %
      % Objects on File menu
      %

      coint.viewdata = uimenu('Parent',filemenu, ...
         'Label','View &Data...', ...
         'Callback','rankgui viewdata', ...
         'Enable','on', ...
         'Tag','ViewData');

      coint.savecoint = uimenu('Parent',filemenu, ...
         'Label','Save &Cointegration Relations...', ...
         'Callback','rankgui savecoint', ...
         'Separator','on', ...
         'Enable','on', ...
         'Tag','SaveResid');

      coint.savetc = uimenu('Parent',filemenu, ...
         'Label','Save &Transitory Components...', ...
         'Callback','rankgui savetc', ...
         'Enable',pcstatus, ...
         'Accelerator','T', ...
         'Tag','SaveTC');

      coint.saveresid = uimenu('Parent',filemenu, ...
         'Label','Save &Residuals...', ...
         'Callback','rankgui saveresid', ...
         'Accelerator','D', ...
         'Enable','on', ...
         'Tag','SaveCoint');

      uimenu('Parent',filemenu, ...
         'Label','Center &Window', ...
         'Separator','on', ...
         'Accelerator','W', ...
         'Enable','on', ...
         'Callback','center_figure_fcn', ...
         'Tag','CenterMenu');

      if ((cm.n<=12)&(cm.q0==0)&(cm.q1<=11)&(cm.dummies==0))|((cm.q1==0)&(cm.q0>0)&(cm.dummies==0));
         coint.distmenu = uimenu('Parent',filemenu, ...
            'Label',['&Show ' cvstr], ...
            'Callback','rankgui dist', ...
            'Separator','on', ...
            'Enable','on', ...
            'Tag','ShowCVMenu');

         coint.dist2menu = uimenu('Parent',filemenu, ...
            'Label','&Show Eigenvalues', ...
            'Callback','rankgui dist', ...
            'Enable','off', ...
            'Tag','ShowEigenvaluesMenu');
      end;

      uimenu('Parent',filemenu, ...
         'Label','R&eturn', ...
         'Callback','rankgui quit', ...
         'Separator','on', ...
         'Enable','on', ...
         'Tag','QuitCoint');

      uimenu('Parent',filemenu, ...
         'Label','C&ontinue', ...
         'Callback','rankgui continue', ...
         'Accelerator','C', ...
         'Enable','on', ...
         'Tag','QuitCoint');

      %
      % Tools menu
      %

      testmenu = uimenu('Parent',rankdlg, ...
         'Label','&Tools', ...
         'Tag','TestMenu');

      %
      % Objects on Test menu
      %

      coint.corrtest = uimenu('Parent',testmenu, ...
         'Label','&Serial Correlation...', ...
         'Callback','rankgui corrtest', ...
         'Enable','on', ...
         'Accelerator','S', ...
         'Tag','CorrTest');

      coint.archtest = uimenu('Parent',testmenu, ...
         'Label','&ARCH...', ...
         'Callback','rankgui archtest', ...
         'Accelerator','A', ...
         'Enable','on', ...
         'Tag','ArchTest');

      coint.normalitytest = uimenu('Parent',testmenu, ...
         'Label','&Normality...', ...
         'Callback','rankgui normalitytest', ...
         'Accelerator','N', ...
         'Enable','on', ...
         'Tag','NormalityTest');

      coint.constancytest = uimenu('Parent',testmenu, ...
         'Label','&Parameter Constancy...', ...
         'Callback','rankgui constancytest', ...
         'Enable','on', ...
         'Accelerator','P', ...
         'Tag','ConstancyTest');

      coint.lagorder = uimenu('Parent',testmenu, ...
         'Label','&Lag Order...', ...
         'Callback','rankgui lagorder', ...
         'Separator','on', ...
         'Accelerator','L', ...
         'Enable',lagenable, ...
         'Tag','LagOrder');

      coint.weakexo = uimenu('Parent',testmenu, ...
         'Label','&Weak Exogeneity...', ...
         'Callback','rankgui weakexo', ...
         'Enable','off', ...
         'Tag','WeakExogeneity');

      coint.gctest = uimenu('Parent',testmenu, ...
         'Label','&Granger Causality...', ...
         'Callback','rankgui gctest', ...
         'Accelerator','G', ...
         'Enable',gcenable, ...
         'Tag','GrangerCausality');

      if cm.n>2;
         coint.multigctest = uimenu('Parent',testmenu, ...
            'Label','M&ulti-Step Granger Causality...', ...
            'Callback','rankgui multigctest', ...
            'Enable','on', ...
            'Tag','MultiGrangerCausality');
      end;

      if ((cm.p>1)&(cm.n>2))|(cm.q0>0)|((cm.q1>0)&(cm.pe>0));
         coint.exclude = uimenu('Parent',testmenu, ...
            'Label','&Exclusion', ...
            'Separator','on', ...
            'Enable','on', ...
            'Tag','ExclusionMenu');
         
         coint.firstdiffs = uimenu('Parent',coint.exclude, ...
            'Label','&First Differences', ...
            'Callback','rankgui firstdiffs', ...
            'Enable','on', ...
            'Tag','FirstDiffMenu');
      end;

      coint.space = uimenu('Parent',testmenu, ...
         'Label','Co&integration Space', ...
         'Separator','on', ...
         'Enable','off', ...
         'Tag','CointSpaceMenu');
         
      if cm.q1>0;
         set(coint.space,'Enable','on');
      end;

      coint.exclusion = uimenu('Parent',coint.space, ...
         'Label','&Exclusion...', ...
         'Callback','rankgui exclusion', ...
         'Enable','on', ...
         'Tag','CointExclusionMenu');

      coint.stationarity = uimenu('Parent',coint.space, ...
         'Label','&Stationarity...', ...
         'Callback','rankgui stationarity', ...
         'Enable','on', ...
         'Tag','CointStationarityMenu');

      coint.showbeta = uimenu('Parent',testmenu, ...
         'Label','Cointegration &Vectors...', ...
         'Callback','rankgui showbeta', ...
         'Enable','on', ...
         'Tag','ShowBeta');

      if cm.p>1;
         coint.common_cycles = uimenu('Parent',testmenu, ...
            'Label','Co&mmon Cycles...', ...
            'Callback','rankgui common_cycles', ...
            'Separator','on', ...
            'Enable','off', ...
            'Tag','ShowCommonCycles');
      end;

      if cm.deterselect(1,1)==1;
         cm.test_type = 'uconst';
         test_label = 'Unres&tricted vs. Restricted Constant...';
      elseif cm.deterselect(1,2)==1;
         cm.test_type = 'rconst';
         test_label = 'Res&tricted vs. Zero Constant...';
      elseif cm.deterselect(1,3)==1;
         cm.test_type = 'utrend';
         test_label = 'Unres&tricted vs. Restricted Trend...';
      elseif cm.deterselect(1,4)==1;
         cm.test_type = 'rtrend';
         test_label = 'Res&tricted vs. Zero Trend...';
      end;

      coint.restconsttrend = uimenu('Parent',testmenu, ...
         'Label',test_label, ...
         'Callback','rankgui restconsttrend', ...
         'Separator','on', ...
         'Enable','off', ...
         'Tag','RestConstTrend');

      if cm.datad>0;
         coint.dummy = uimenu('Parent',testmenu, ...
            'Label','&Deterministic Variables', ...
            'Enable','on', ...
            'Tag','DummyVarMenu');

         coint.dummyexclusion = uimenu('Parent',coint.dummy, ...
            'Label','&Exclusion...', ...
            'Callback','rankgui dummyexclusion', ...
            'Enable','on', ...
            'Tag','DummyExclusionMenu');

         coint.dummylongrun = uimenu('Parent',coint.dummy, ...
            'Label','&Long Run...', ...
            'Callback','rankgui dummylongrun', ...
            'Enable','off', ...
            'Tag','DummyLongRunMenu');

         if cm.datad>1;
            coint.propdummy = uimenu('Parent',coint.dummy, ...
               'Label','&Proportionality...', ...
               'Callback','rankgui dummyprop', ...
               'Enable','on', ...
               'Tag','DummyPropMenu');
         end;
         
      end;

      coint.cmat = uimenu('Parent',testmenu, ...
         'Label','&C-Matrix...', ...
         'Callback','rankgui cmat', ...
         'Separator','on', ...
         'Accelerator','M', ...
         'Enable',pcstatus, ...
         'Tag','CMatrix');

      coint.longrun_gir = uimenu('Parent',testmenu, ...
         'Label','L&ong Run GIRs...', ...
         'Callback','rankgui longrun_gir', ...
         'Separator','off', ...
         'Enable',pcstatus, ...
         'Tag','LongRunGIRsMenu');

      coint.residanalysis = uimenu('Parent',testmenu, ...
         'Label','&Residual Analysis...', ...
         'Callback','rankgui residanalysis', ...
         'Accelerator','R', ...
         'Enable','on', ...
         'Tag','ResidAnalysis');

      coint.shortdyn = uimenu('Parent',testmenu, ...
         'Label','S&hort Run Dynamics...', ...
         'Callback','rankgui shortdyn', ...
         'Accelerator','Y', ...
         'Enable','on', ...
         'Tag','ShortDyn');

      coint.distribution = uimenu('Parent',testmenu, ...
         'Label','Distri&bution...', ...
         'Callback','rankgui distribution', ...
         'Separator','on', ...
         'Enable','on', ...
         'Tag','DistributionMenu');

      %
      % Graphics menu
      %

      graphmenu = uimenu('Parent',rankdlg, ...
         'Label','&Graphics', ...
         'Tag','GraphicsMenu');

      %
      % Objects on Graphics menu
      %

      coint.menugraph = uimenu('Parent',graphmenu, ...
         'Label','&Cointegration Relations...', ...
         'Callback','rankgui graphs', ...
         'Enable','on', ...
         'Tag','MenuGraph');

      coint.menupermcomp = uimenu('Parent',graphmenu, ...
         'Label','&Permanent and Transitory Components...', ...
         'Callback','rankgui permcomp', ...
         'Enable',pcstatus, ...
         'Accelerator','E', ...
         'Tag','MenuPermComp');

      coint.menuresiduals = uimenu('Parent',graphmenu, ...
         'Label','&Residuals...', ...
         'Callback','rankgui residuals', ...
         'Accelerator','I', ...
         'Enable','on', ...
         'Tag','MenuResiduals');

      coint.menufitted = uimenu('Parent',graphmenu, ...
         'Label','Fitted &Terms...', ...
         'Callback','rankgui fitted', ...
         'Enable','on', ...
         'Tag','MenuFitted');

      coint.forecast = uimenu('Parent',graphmenu, ...
         'Label','Forec&asting...', ...
         'Callback','rankgui forecast', ...
         'Separator','on', ...
         'Enable','on', ...
         'Tag','MenuForecast');

      coint.varforecast = uimenu('Parent',graphmenu, ...
         'Label','Forecast &Variable Transformations...', ...
         'Callback','rankgui varforecast', ...
         'Enable','on', ...
         'Tag','MenuVARForecast');

      if cm.q1+cm.q0>0;
         set(coint.forecast,'Enable','off');
         set(coint.varforecast,'Enable','off');
      end;

      coint.menurecursive = uimenu('Parent',graphmenu, ...
         'Label','Recursive &Eigenvalues', ...
         'Callback','rankgui recursiveeig', ...
         'Separator','on', ...
         'Accelerator','U', ...
         'Enable',recursivestatus, ...
         'Tag','MenuRecursive');

      coint.menuchow = uimenu('Parent',graphmenu, ...
         'Label','Recursive Ch&ow Tests', ...
         'Callback','rankgui chow', ...
         'Accelerator','O', ...
         'Enable','on', ...
         'Tag','MenuChow');

      coint.menuploberger = uimenu('Parent',graphmenu, ...
         'Label','Recursive &Fluctuation Test', ...
         'Callback','rankgui ploberger', ...
         'Accelerator','F', ...
         'Enable','on', ...
         'Tag','MenuPloberger');

      if curr_ini.rectrace==1;
         coint.menutrace = uimenu('Parent',graphmenu, ...
            'Label','Rec&ursive Trace Test', ...
            'Callback','rankgui rectrace', ...
            'Enable','on', ...
            'Tag','MenuTrace');
      end;
      
      coint.genimpulse = uimenu('Parent',graphmenu, ...
         'Label','&Generalized Impulse Responses...', ...
         'Callback','rankgui genimpulse', ...
         'Separator','on', ...
         'Enable','on', ...
         'Tag','MenuGeneralizedImpulse');

%      if (isempty(cm.isdummy)==0)&(max(cm.isdummy)==1);
      if cm.datad>0;
         coint.dummyimpulse = uimenu('Parent',graphmenu, ...
            'Label','&Dummy Impulse Responses...', ...
            'Callback','rankgui dummyimpulse', ...
            'Enable','on', ...
            'Tag','MenuDummyImpulse');
      end;

      coint.companion = uimenu('Parent',graphmenu, ...
         'Label','Eigenvalues of Companion &Matrix', ...
         'Callback','rankgui companion', ...
         'Separator','on', ...
         'Enable','on', ...
         'Tag','MenuCompanion');

      %
      % Simulation menu
      %

      simulatemenu = uimenu('Parent',rankdlg, ...
         'Label','&Simulation', ...
         'Tag','SimulateMenu');

      coint.asymptotic = uimenu('Parent',simulatemenu, ...
         'Label','&Asymptotic', ...
         'Tag','AsymptoticMenu');

      coint.tracemenu = uimenu('Parent',coint.asymptotic, ...
         'Label','&Trace Distribution...', ...
         'Callback','rankgui tracetest', ...
         'Enable','on', ...
         'Tag','MenuTrace');

      if curr_ini.nyblom==1;

         coint.nyblommenu = uimenu('Parent',coint.asymptotic, ...
            'Label','&Nyblom Distribution...', ...
            'Callback','rankgui nyblomtest', ...
            'Enable','off', ...
            'Tag','MenuNyblom');

      end;

      coint.bootstrap = uimenu('Parent',simulatemenu, ...
         'Label','&Bootstrap', ...
         'Tag','BootstrapMenu');

      coint.boottracemenu = uimenu('Parent',coint.bootstrap, ...
         'Label','&Trace Distribution...', ...
         'Callback','rankgui boottracetest', ...
         'Enable','on', ...
         'Tag','MenuBootTrace');

     coint.bootcointtestmenu = uimenu('Parent',coint.bootstrap, ...
         'Label','&Cointegration Space Tests...', ...
         'Callback','rankgui bootcointtest', ...
         'Enable','off', ...
         'Tag','MenuBootCointTest');

     if curr_ini.nyblom==1;

         coint.bootnyblommenu = uimenu('Parent',coint.bootstrap, ...
         'Label','&Nyblom Distribution...', ...
         'Callback','rankgui bootnyblomtest', ...
         'Enable','off', ...
         'Tag','MenuBootNyblom');

      end;

      coint.booteigenmenu = uimenu('Parent',coint.bootstrap, ...
         'Label','&Eigenvalue Fluctuation Test...', ...
         'Callback','rankgui booteigen', ...
         'Enable',recursivestatus, ...
         'Tag','MenuBootEigen');

      coint.bootploberger = uimenu('Parent',coint.bootstrap, ...
         'Label','&Recursive Fluctuation Test...', ...
         'Callback','rankgui bootploberger', ...
         'Enable','on', ...
         'Tag','MenuBootPloberger');

      coint.boot_specification = uimenu('Parent',coint.bootstrap, ...
         'Label','&Specification Tests...', ...
         'Callback','rankgui boot_specification', ...
         'Enable','on', ...
         'Tag','MenuBootSpecification');

      coint.markov_switching = uimenu('Parent',coint.bootstrap, ...
         'Label','&Markov Switching Test...', ...
         'Callback','rankgui boot_markov', ...
         'Enable','on', ...
         'Tag','MenuBootMarkov');

      helpmenu = uimenu('Parent',rankdlg, ...
         'Label','&Help', ...
         'Tag','HelpMenu');

      coint.rank_help = uimenu('Parent',helpmenu, ...
            'Label','Cointegration &Rank Tests', ...
            'Callback','help_fcn(''CointegrationRankTests'');', ...
            'Accelerator','H', ...
            'Separator','off', ...
            'Enable','on', ...
            'Tag','MenuRankHelp');

      if isempty(showpdfdoc)==0;
         if strcmp(showpdfdoc.cc,'')==0;
            coint.pdf_cc = uimenu('Parent',helpmenu, ...
               'Label','&Common Cycles - PDF file', ...
               'Callback','show_pdf', ...
               'Separator','on', ...
               'UserData',showpdfdoc.cc, ...
               'Enable','on', ...
               'Tag','MenuDocCCEstimate');
            sep_str = 'off';
         else;
            sep_str = 'on';
         end;
         %
         if strcmp(showpdfdoc.gir,'')==0;
            coint.pdf_gir = uimenu('Parent',helpmenu, ...
               'Label','&Generalized Impulse Responses - PDF file', ...
               'Callback','show_pdf', ...
               'Separator',sep_str, ...
               'UserData',showpdfdoc.gir, ...
               'Enable','on', ...
               'Tag','MenuDocGIREstimate');
         end;
         %
      end;
      %

%      xline([1 scrsz(4)/2-3 (scrsz(3)/2)],[0.5 1]);

      xline([1 scrsz(4)/2+9+add_height (scrsz(3)/2)+100],[0.5 1]);

      %
      % Outer axis
      %

      axesbox([2 2 (scrsz(3)/2)+98 scrsz(4)/2-5+add_height],'Maximum Likelihood Results',135,[0.5 1]);

      %
      % Outer axis for cointegration rank controls
      %

      axesbox([322 276 276 67],'Rank Selection',75,[0.5 1]);

      %
      % Outer axis for companion matrix eigenvalue control
      %

      axesbox([322 193 276 67],'Companion Matrix',85,[0.5 1]);

      %
      % Outer axis for text model info control
      %

      axesbox([14 14 scrsz(3)/2+72 165],'Model Information',85,[0.5 1]);

      %
      % Text control with header for results
      %

      if isempty(cm.bartcorr)==1;
         coint.tracetext = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[12 345 300 20], ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'Style','text', ...
            'UserData','', ...
            'HorizontalAlignment','left', ...
            'String','       Rank                 LR trace                    Eigenvalue', ...
            'Tag','Text2');
      else;
         coint.tracetext = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[12 345 300 35], ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'Style','text', ...
            'UserData','                                (corrected)', ...
            'HorizontalAlignment','left', ...
            'String',strvcat('       Rank                 LR trace                    Eigenvalue','                                (corrected)'), ...
            'Tag','Text2');
      end;

      %
      % Listbox control with results
      %

      coint.traceresults = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[14 193 298 150], ...
         'FontSize',10, ...
         'FontName','FixedWidth', ...
         'Style','listbox', ...
         'Enable','inactive', ...
         'Max',2, ...
         'HorizontalAlignment','center', ...
         'String',cm.textlambda, ...
         'Tag','Text1',...
         'Value',[]);

      %
      % Cointegration rank order control
      %

      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[336 295 200 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'HorizontalAlignment','left', ...
         'String','Number of cointegration relations:', ...
         'Tag','ListBoxRankText');

      coint.mypopup = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[533 300 50 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Value',cm.r+1, ...
         'Callback','rankgui setrank', ...
         'UserData',thisexit, ...
         'String',ranks, ...
         'Tag','ListBoxRank');

      %
      % Companion matrix eigenvalue control
      %

      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[336 215 200 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'HorizontalAlignment','left', ...
         'String','Largest non-unity eigenvalue:', ...
         'Tag','EigenText');

      coint.eigenvalue = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[533 215 50 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'HorizontalAlignment','left', ...
         'UserData','working', ...
         'String',num2str(cm.evalue,'%0.4f'), ...
         'Tag','EigenTextBox');

      %
      % Text control listing info about model
      %

      coint.model_header = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[30 30 scrsz(3)/2+40 135], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'String',cm.model_info.header, ...
         'ForegroundColor',curr_ini.gui_foreground_color, ...
         'HorizontalAlignment','left', ...
         'Tag','ModelInfoHeaderText');

      head_ext = get(coint.model_header,'Extent');
      if head_ext(1,4)<=135;
         new_pos = [30 30+(135-head_ext(1,4))/2 head_ext(1,3:4)];
      else;
         new_pos = [30 30 head_ext(1,3) 135];
      end;
      set(coint.model_header,'Position',new_pos);

      coint.model_info = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[35+new_pos(1,3) new_pos(1,2) scrsz(3)/2+35-new_pos(1,3) new_pos(1,4)], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'String',cm.model_info.info, ...
         'ForegroundColor',curr_ini.gui_foreground_color, ...
         'HorizontalAlignment','left', ...
         'Tag','ModelInfoText');

      %
      % Setting up the toolbar
      %

      coint.toolbar = uitoolbar('Parent',rankdlg, ...
                        'HandleVisibility','off', ...
                        'Interruptible','on', ...
                        'Clipping','on');

      %
      % Quit button
      %

      coint.quit = uipushtool('Parent',coint.toolbar, ...
                         'TooltipString','Return', ...
                         'CData',button_images.return, ...
                         'ClickedCallback','rankgui quit', ...
                         'Separator','off', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable','on', ...
                         'Tag','Return');

      %
      %  continue button
      %

      coint.continue = uipushtool('Parent',coint.toolbar, ...
                         'TooltipString','Continue', ...
                         'CData',button_images.continue, ...
                         'ClickedCallback','rankgui continue', ...
                         'Separator','off', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'UserData','waiting', ...
                         'Enable','on', ...
                         'Tag','Continue');

      %
      % Graphics button
      %

      coint.graphs = uipushtool('Parent',coint.toolbar, ...
                         'TooltipString','Cointegration Relations', ...
                         'CData',button_images.graph, ...
                         'ClickedCallback','rankgui graphs', ...
                         'Separator','on', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable','on', ...
                         'Tag','Graphics');

      coint.permcomp = uipushtool('Parent',coint.toolbar, ...
                         'TooltipString','Permanent and Transitory Components', ...
                         'CData',button_images.permcomp, ...
                         'ClickedCallback','rankgui permcomp', ...
                         'Separator','off', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable',pcstatus, ...
                         'Tag','PermCompGraphics');

      coint.residgraph = uipushtool('Parent',coint.toolbar, ...
                         'TooltipString','Residuals', ...
                         'CData',button_images.histogram, ...
                         'ClickedCallback','rankgui residuals', ...
                         'Separator','off', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable','on', ...
                         'Tag','ResidGraphics');

      %
      % Forecasting button
      %

      coint.forecast_button = uipushtool('Parent',coint.toolbar, ...
                         'TooltipString','Forecasting', ...
                         'CData',button_images.forecast, ...
                         'ClickedCallback','rankgui forecast', ...
                         'Separator','on', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable','on', ...
                         'Tag','ForecastGraph');

      if cm.q1+cm.q0>0;
         set(coint.forecast_button,'Enable','off');
      end;

      coint.receigengraph = uipushtool('Parent',coint.toolbar, ...
                         'TooltipString','Recursive Eigenvalues', ...
                         'CData',button_images.eigen, ...
                         'ClickedCallback','rankgui recursiveeig', ...
                         'Separator','on', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable',recursivestatus, ...
                         'Tag','ReceigenGraphics');

%      if (cm.q1+cm.q0>0)|(cm.datad>0);
%         set(coint.menurecursive,'Enable','off');
%         set(coint.booteigenmenu,'Enable','off');
%         set(coint.receigengraph,'Enable','off');
%      end;

      coint.chow = uipushtool('Parent',coint.toolbar, ...
                         'TooltipString','Recursive Chow Tests', ...
                         'CData',button_images.chow, ...
                         'ClickedCallback','rankgui chow', ...
                         'Separator','off', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable','on', ...
                         'Tag','RecChowGraph');

      coint.ploberger = uipushtool('Parent',coint.toolbar, ...
                         'TooltipString','Recursive Fluctuation Test', ...
                         'CData',button_images.fluctest, ...
                         'ClickedCallback','rankgui ploberger', ...
                         'Separator','off', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable','on', ...
                         'Tag','RecPlobGraph');

      if ((cm.n<=12)&(cm.q0==0)&(cm.q1<=11))|((cm.q1==0)&(cm.q0>0));
         if cm.dummies==0;

            coint.dist = uipushtool('Parent',coint.toolbar, ...
                          'TooltipString',cvstr, ...
                          'CData',mypicture, ...
                          'ClickedCallback','rankgui dist', ...
                          'Separator','on', ...
                          'Interruptible','on', ...
                          'Clipping','on', ...
                          'Enable','on', ...
                          'Tag','Dist');

             coint.dist2 = uipushtool('Parent',coint.toolbar, ...
                          'TooltipString','Eigenvalues', ...
                          'CData',button_images.lambda, ...
                          'ClickedCallback','rankgui dist', ...
                          'Separator','off', ...
                          'Interruptible','on', ...
                          'Clipping','on', ...
                          'Enable','off', ...
                          'Tag','Dist2');

         end;
      end;

      set(rankdlg,'UserData',coint,...
         'HandleVisibility','callback');

   case 'distribution'
      if cm.running==0;
         cm.running = 1;
         set(rankdlg,'Visible','off');
         drawnow;
         %
         thisgraph = distdlg('init',cm.cbs);
         killguipid(thisgraph);
         %
         set(rankdlg,'Visible','on');
         drawnow;
         cm.running = 0;
      end;
   case 'booteigen'
      if cm.running==0;
         cm.running = 1;
         set(rankdlg,'Visible','off');
         drawnow;
         eigen_bootstrap('init',cm);
         drawnow;
         set(rankdlg,'Visible','on');
         drawnow;
         cm.running = 0;
      end;
   case 'boot_markov'
      if cm.running==0;
         cm.running = 1;
         set(rankdlg,'Visible','off');
         drawnow;
         markov_bootstrap('init',cm);
         drawnow;
         set(rankdlg,'Visible','on');
         drawnow;
         cm.running = 0;
      end;
   case 'bootploberger'
      if cm.running==0;
         cm.running = 1;
         set(rankdlg,'Visible','off');
         drawnow;
         pkk_bootstrap('init',cm);
         drawnow;
         set(rankdlg,'Visible','on');
         drawnow;
         cm.running = 0;
      end;
   case 'boot_specification'
      if cm.running==0;
         cm.running = 1;
         set(rankdlg,'Visible','off');
         drawnow;
         specification_bootstrap('init',cm);
         drawnow;
         set(rankdlg,'Visible','on');
         drawnow;
         cm.running = 0;
      end;
   case 'boottracetest'
      if cm.running==0;
         cm.running = 1;
         set(rankdlg,'Visible','off');
         drawnow;
         trace_bootstrap('init',cm);
         drawnow;
         set(rankdlg,'Visible','on');
         drawnow;
         cm.running = 0;
      end;
   case 'bootnyblomtest'
      if cm.running==0;
         cm.running = 1;
         set(rankdlg,'Visible','off');
         drawnow;
         nyblom_bootstrap('init',cm);
         drawnow;
         set(rankdlg,'Visible','on');
         drawnow;
         cm.running = 0;
      end;
   case 'bootcointtest'
      if cm.running==0;
         cm.running = 1;
         set(rankdlg,'Visible','off');
         drawnow;
         cointtest_bootstrap('init',cm);
         drawnow;
         set(rankdlg,'Visible','on');
         drawnow;
         cm.running = 0;
      end;
   case 'nyblomtest'
      if cm.running==0;
         cm.running = 1;
         set(rankdlg,'Visible','off');
         drawnow;
         nyblom_dist('init',cm);
         drawnow;
         set(rankdlg,'Visible','on');
         drawnow;
         cm.running = 0;
      end;
   case 'tracetest'
      if cm.running==0;
         cm.running = 1;
         set(rankdlg,'Visible','off');
         drawnow;
         trace_dist('init',cm);
         drawnow;
         set(rankdlg,'Visible','on');
         drawnow;
         cm.running = 0;
      end;
   case 'showbeta'
      if cm.running==0;
         cm.running = 1;
         set(rankdlg,'Visible','off');
         drawnow;
         %
         txt = showbeta(normbeta(cm.beta(:,1:cm.r)),cm.evars,strtrim([cm.xvars1 ' ' cm.restvec]),['%' num2str(8+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f']);
         textgui(txt,'Cointegration Vectors',[(realscrsz(3)-700)/2 (realscrsz(4)-500)/2 700 500],'Results',38);
         %
         set(rankdlg,'Visible','on');
         drawnow;
         cm.running = 0;
      end;
   case 'restconsttrend'
      if cm.running==0;
         cm.running = 1;
         set(rankdlg,'Visible','off');
         drawnow;
         %
         % test down, that is, use the current model as the alternative and a more restricted as the null
         %
         [test,df,pval] = rest_const_trend(cm.test_type,cm.epsilon,cm.r,cm.Z0,cm.Z1,cm.Z2,cm.df,curr_ini.sscorrect);
         if strcmp(cm.test_type,'uconst')==1;
            txt = ['TESTING UNRESTRICTED VS. RESTRICTED CONSTANT MODEL (for r=' num2str(cm.r,'%0.0f') ')'];
            my_txt_null = 'delta(0) = alpha*mu(0)';
            my_txt_alt = 'delta(0) not equal to alpha*mu(0)';
         elseif strcmp(cm.test_type,'rconst')==1;
            txt = ['TESTING RESTRICTED VS. ZERO CONSTANT MODEL (for r=' num2str(cm.r,'%0.0f') ')'];
            my_txt_null = 'mu(0) = 0';
            my_txt_alt = 'mu(0) not equal to 0';
         elseif strcmp(cm.test_type,'utrend')==1;
            txt = ['TESTING UNRESTRICTED VS. RESTRICTED LINEAR TREND MODEL (for r=' num2str(cm.r,'%0.0f') ')'];
            my_txt_null = 'delta(1) = alpha*mu(1)';
            my_txt_alt = 'delta(1) not equal to alpha*mu(1)';
         elseif strcmp(cm.test_type,'rtrend')==1;
            txt = ['TESTING RESTRICTED VS. ZERO LINEAR TREND MODEL (for r=' num2str(cm.r,'%0.0f') ')'];
            my_txt_null = 'mu(1) = 0';
            my_txt_alt = 'mu(1) not equal to 0';
         end;
         add_txt = '';
         for i=1:size(txt,2);
            add_txt = [add_txt '='];
         end;
         txt = strvcat(' ',txt,add_txt,' ','  LR-type test statistic','  ~~~~~~~~~~~~~~~~~~~~~~',' ');
         txt = strvcat(txt,['Null Hypothesis:        ' my_txt_null],['Alternative Hypothesis: ' my_txt_alt],' ');
         if curr_ini.sscorrect==0;
            txt = strvcat(txt,['   LR(' num2str(df,'%0.0f') ') = ' num2str(test,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])],[' p-value = ' num2str(pval,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])],' ');
         else;
            txt = strvcat(txt,[' F(' num2str(df(1,1),'%0.0f') ',' num2str(df(1,2),'%0.0f') ') = ' num2str(test,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])],[' p-value = ' num2str(pval,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])],' ');
         end;
         hdr = strrep(get(coint.restconsttrend,'Label'),'&','');
         hdr = hdr(1,1:size(hdr,2)-3);
         textgui(txt,hdr,[(realscrsz(3)-680)/2 (realscrsz(4)-400)/2 680 400],'Results',38);
         %
         set(rankdlg,'Visible','on');
         drawnow;
         cm.running = 0;
      end;
   case 'residanalysis'
      if cm.running==0;
         cm.running = 1;
         show_residual_analysis(rankdlg,cm,0);
         cm.running = 0;
      end;
   case 'rectrace';
      if cm.running==0;
         cm.running = 1;
         show_recursive_trace(rankdlg,cm,curr_ini);
         cm.running = 0;
      end;
   case 'fitted'
      if cm.running==0;
         cm.running = 1;
         set(rankdlg,'Visible','off');
         drawnow;
         thisgraph = fittedterms('init',cm,[cm.Psi cm.alpha],cm.beta(:,1:cm.r));
         fitted = get(thisgraph,'UserData');
         set(fitted.show,'UserData','done');
         killguipid(thisgraph);
         set(rankdlg,'Visible','on');
         drawnow;
         cm.running = 0;
      end;
   case 'companion'
      if cm.running==0;
         cm.running = 1;
         show_companion(cm.beta(:,1:cm.r),cm.alpha,cm.Psi,cm,curr_ini,0,1);
         cm.running = 0;
      end;
   case 'common_cycles'
      if cm.running==0;
         cm.running = 1;
         set(rankdlg,'Visible','off');
         drawnow;
         show_common_cycles(cm,curr_ini,cm.alpha,cm.Psi,cm.beta(:,1:cm.r));
         set(rankdlg,'Visible','on');
         drawnow;
         cm.running = 0;
      end;
   case 'dummyprop'
      if cm.running==0;
         cm.running = 1;
         set(rankdlg,'Visible','off');
         drawnow;
         proportionality_dummies_dlg('init',cm,curr_ini);
         set(rankdlg,'Visible','on');
         drawnow;
         cm.running = 0;
      end;
   case 'dummylongrun'
      if cm.running==0;
         cm.running = 1;
         show_longrun_dummies(rankdlg,cm,curr_ini);
         cm.running = 0;
      end;
   case 'dummyexclusion'
      if cm.running==0;
         cm.running = 1;
         show_exclude_dummies(rankdlg,cm,curr_ini);
         cm.running = 0;
      end;
   case 'dummyimpulse'
      if cm.running==0;
         cm.running = 1;
         set(rankdlg,'Visible','off');
         drawnow;
         %
         alpha = cm.alpha;
         beta = cm.beta(:,1:cm.r);
         Psi = cm.Psi;
         Omega = cm.Omega;
         Sigma_theta = [];
         %
         txt = 'Would you like to impose restrictions on the dummy variables?';
         if (cm.datad>1)|((cm.r<cm.n)&(cm.r>0));
            answer = query(txt,'question',120,'Structural VAR - Dummy Restrictions',300,'no');
         else;
            answer = 'No';
         end;
         if strcmp(answer,'Yes')==1;
            %
            % open a select restrictions dialog
            %
            tm = restrict_dummies_dlg('init',cm,curr_ini);
            if strcmp(tm.action,'cancel')==0;
               %
               % check if we should use new estimated
               %
               if (isfield(tm,'applied')==1)&(isempty(tm.applied)==0)&(ischar(tm.applied)==1)&(strcmp(tm.applied,'applied')==1);
                  if isfield(tm,'dm')==1;
                     txt = 'Are you sure you want to use the restricted estimates for the dummy impulse responses?';
                     answer = query(txt,'question',120,'Structural VAR - Dummy Restrictions',300,'yes');
                     if strcmp(answer,'Yes')==1;
                        alpha = tm.dm.alpha;
                        beta = tm.dm.beta;
                        Psi = tm.dm.Psi;
                        Omega = tm.dm.Omega;
                        Sigma_theta = tm.dm.Sigma_theta;
                     end;
                  end;
               end;
            else;
               %
               % no dummy impulses
               %
               set(rankdlg,'Visible','on');
               drawnow;
               return;
            end;
         end;
         %
         setlogtext(strvcat(['Computing impulse responses for dummies up to period ' num2str(cm.h)],['with asymptotic ' num2str(cm.c) ' % confidence bands...']));
         abort = '';
         [cm.duir,cm.duir_std,cm.buir,cm.buir_std,abort] = dummy_impulses_fcn(cm,alpha,beta,Psi,Omega,Sigma_theta,1);
         %
         if strcmp(abort,'cancel')==0;
            %
            % get the value from the normal distribution corresponding to the
            % chosen levels of significance c
            %
            c_val = norm_inv((100+cm.c)/200);
            for i=1:size(cm.duir,2);
               for j=1:cm.n*cm.datad;
                  if abs(cm.duir_std(j,i))<1.0e-008;
                     cm.duir_std(j,i) = 0;
                  end;
               end;
            end;
            cm.duir_upper = cm.duir+(c_val*cm.duir_std);
            cm.duir_lower = cm.duir-(c_val*cm.duir_std);
            %
            if isempty(cm.buir)==0;
               for i=1:size(cm.buir,2);
                  for j=1:cm.r*cm.datad;
                     if abs(cm.buir_std(j,i))<1.0e-008;
                        cm.buir_std(j,i) = 0;
                     end;
                  end;
               end;
               cm.buir_upper = cm.buir+(c_val*cm.buir_std);
               cm.buir_lower = cm.buir-(c_val*cm.buir_std);
            else;
               cm.buir_upper = [];
               cm.buir_lower = [];
            end;
            %
            thisgraph = duir_graphdlg('init',cm);
            ir_graph = get(thisgraph,'UserData');
            set(ir_graph.show,'UserData','done');
            killguipid(thisgraph);
         end;
         %
         set(rankdlg,'Visible','on');
         drawnow;
         cm.running = 0;
      end;
   case 'longrun_gir'
      if cm.running==0;
         cm.running = 1;
         set(rankdlg,'Visible','off');
         drawnow;
         %
         [lr_gir,lr_gir_std] = longrun_gir_fcn(cm.alpha,cm.beta(:,1:cm.r),cm.Psi,cm.Omega,[],cm.epsilon,cm.Z1,cm.Z2,cm.p,cm.d);
         ctext = strvcat(' ',['LONG RUN GENERALIZED IMPULSE RESPONSES (for rank=' num2str(cm.r,'%1.0f') ')']);
         numchar = size(ctext,2);
         addcorr = '';
         for i=1:numchar;
            addcorr = strcat(addcorr,'=');
         end;
         ctext = strvcat(ctext,addcorr,' ');
         ctext = strvcat(ctext,showc(lr_gir,cm.myvars),' ');
         ctext = strvcat(ctext,'Estimated asymptotic standard errors:',' ',showc(lr_gir_std,cm.myvars),' ','t-ratios:',' ',showc(inf2nan(lr_gir./lr_gir_std),cm.myvars),' ');
         drawnow;
         textgui(ctext,'Long Run GIRs',[(realscrsz(3)-700)/2 (realscrsz(4)-500)/2 700 500],'Results',38);
         %
         set(rankdlg,'Visible','on');
         drawnow;
         cm.running = 0;
      end;
   case 'genimpulse'
      if cm.running==0;
         cm.running = 1;
         set(rankdlg,'Visible','off');
         drawnow;
         setlogtext(strvcat(['Computing generalized impulse responses up to period ' num2str(cm.h)],['with asymptotic ' num2str(cm.c) ' % confidence bands...']));
         abort = '';
         [cm.gir,cm.gir_std,cm.bir,cm.bir_std,abort] = generalized_impulses_fcn(cm,cm.alpha,cm.beta(:,1:cm.r),cm.Psi,cm.Omega,[],1);
         if strcmp(abort,'cancel')==0;
            %
            % get the value from the normal distribution corresponding to the
            % chosen levels of significance c
            %
            c_val = norm_inv((100+cm.c)/200);
            for i=1:size(cm.gir,2);
               for j=1:cm.n*cm.n;
                  if abs(cm.gir_std(j,i))<1.0e-008;
                     cm.gir_std(j,i) = 0;
                  end;
               end;
            end;
            cm.gir_upper = cm.gir+(c_val*cm.gir_std);
            cm.gir_lower = cm.gir-(c_val*cm.gir_std);
            if isempty(cm.bir)==0;
               for i=1:size(cm.bir,2);
                  for j=1:cm.r*cm.n;
                     if abs(cm.bir_std(j,i))<1.0e-008;
                        cm.bir_std(j,i) = 0;
                     end;
                  end;
               end;
               cm.bir_upper = cm.bir+(c_val*cm.bir_std);
               cm.bir_lower = cm.bir-(c_val*cm.bir_std);
            else;
               cm.bir_upper = [];
               cm.bir_lower = [];
            end;
            thisgraph = gir_graphdlg('init',cm);
            ir_graph = get(thisgraph,'UserData');
            set(ir_graph.show,'UserData','done');
            killguipid(thisgraph);
         end;
         %
         set(rankdlg,'Visible','on');
         drawnow;
         cm.running = 0;
      end;
   case 'setrank';
      if cm.running==0;
         cm.running = 1;
         drawnow;
         curr_ini.images = button_images;
         curr_ini.model = cm;
         set(coint.viewdata,'UserData',curr_ini);
         cm.r = get(coint.mypopup,'Value')-1;
         setlogtext(strvcat(' ',['Setting cointegration rank to ' num2str(cm.r) '...']));
         set(coint.mypopup,'UserData',thisexit);
         if cm.r>0;
            set(coint.graphs,'Enable','on');
            set(coint.menugraph,'Enable','on');
            set(coint.savecoint,'Enable','on');
         else;
            set(coint.graphs,'Enable','off');
            set(coint.menugraph,'Enable','off');
            set(coint.savecoint,'Enable','off');
         end;
         dfc = round(((cm.n+cm.q1+cm.dcoint-cm.r)*cm.r)/cm.n);
         cm.df = cm.n*(cm.p-1)+cm.r+cm.q1*cm.pe+cm.q0*(cm.pe+1)+cm.d+dfc;
         setlogtext('Computing short-run dynamics...');
         if cm.r>0;
            cm.alpha = (cm.S_01*cm.beta(:,1:cm.r))/(cm.beta(:,1:cm.r)'*cm.S_11*cm.beta(:,1:cm.r));
            if isempty(cm.Z2)==0;
               cm.Psi = (cm.M_02/cm.M_22)-(cm.alpha*cm.beta(:,1:cm.r)'*(cm.M_12/cm.M_22));
               cm.epsilon = cm.Z0-(cm.alpha*cm.beta(:,1:cm.r)'*cm.Z1)-(cm.Psi*cm.Z2);
            else;
               cm.Psi = [];
               cm.epsilon = cm.Z0-(cm.alpha*cm.beta(:,1:cm.r)'*cm.Z1);
            end;
            mybeta = cm.beta(:,1:cm.r);
         else;
            cm.alpha = [];
            if isempty(cm.Z2)==0;
               cm.Psi = cm.M_02/cm.M_22;
               cm.epsilon = cm.Z0-(cm.Psi*cm.Z2);
            else;
               Psi = [];
               cm.epsilon = cm.Z0;
            end;
            mybeta = [];
         end;
         cm.Omega = (1/cm.T)*cm.epsilon*cm.epsilon';
         if (cm.r<cm.n)&(cm.r>0);
            set(coint.weakexo,'Enable','on');
            set(coint.space,'Enable','on');
            set(coint.showbeta,'Enable','on');
            set(coint.restconsttrend,'Enable','on');
            set(coint.bootcointtestmenu,'Enable','on');
%            if (curr_ini.nyblom==1)&(cm.q1+cm.q0==0);
            if (curr_ini.nyblom==1);
               set(coint.nyblommenu,'Enable','on');
               set(coint.bootnyblommenu,'Enable','on');
            end;
            if isfield(coint,'dummy')==1;
               set(coint.dummylongrun,'Enable','on');
            end;
         else;
            if cm.r>0;
               set(coint.showbeta,'Enable','on');
            else;
               set(coint.showbeta,'Enable','off');
            end;
            set(coint.weakexo,'Enable','off');
            set(coint.restconsttrend,'Enable','off');
            set(coint.bootcointtestmenu,'Enable','off');
            if (cm.r==cm.n)&(cm.q1>0);
               set(coint.space,'Enable','on');
            else;
               set(coint.space,'Enable','off');
            end;
            if curr_ini.nyblom==1;
               set(coint.nyblommenu,'Enable','off');
               set(coint.bootnyblommenu,'Enable','off');
            end;
            if isfield(coint,'dummy')==1;
               set(coint.dummylongrun,'Enable','off');
            end;
         end;
         if cm.p==1;
            if (cm.r+cm.d)==0;
               set(coint.constancytest,'Enable','off');
               set(coint.menuchow,'Enable','off');
               set(coint.chow,'Enable','off');
               set(coint.menuploberger,'Enable','off');
               set(coint.ploberger,'Enable','off');
            else;
               set(coint.constancytest,'Enable','on');
               set(coint.menuchow,'Enable','on');
               set(coint.chow,'Enable','on');
               set(coint.menuploberger,'Enable','on');
               set(coint.ploberger,'Enable','on');
            end;
         end;
         if (cm.p==1)&(cm.r==0);
            cm.evalue = 0;
         else;
            eigenvalues = companion(cm.Z0,cm.Z1,cm.Z2,cm.r,cm.p,cm.n,cm.q1,cm.q0,cm.d,cm.T);
            eigenvalues = abs(sort(eigenvalues));
            i = size(eigenvalues,1);
            while i>=1;
               cm.evalue = eigenvalues(i,1);
               if strcmp(num2str(cm.evalue,'%1.10f'),'1.0000000000')==1;
                  i = i-1;
               else;
                  i = 0;
               end;
            end;
         end;
         if cm.evalue>=1;
            set(coint.menurecursive,'Enable','off');
            set(coint.receigengraph,'Enable','off');
            set(coint.booteigenmenu,'Enable','off');
            set(coint.cmat,'Enable','off');
            set(coint.longrun_gir,'Enable','off');
            set(coint.menupermcomp,'Enable','off');
            set(coint.permcomp,'Enable','off');
            set(coint.savetc,'Enable','off');
         else;
%            if (cm.qsum>0)|(cm.datad>0);
%               set(coint.menurecursive,'Enable','off');
%               set(coint.booteigenmenu,'Enable','off');
%               set(coint.receigengraph,'Enable','off');
%            else;
%               set(coint.menurecursive,'Enable','on');
%               set(coint.booteigenmenu,'Enable','on');
%               set(coint.receigengraph,'Enable','on');
%            end;
            if cm.r<cm.n+cm.q1;
               set(coint.booteigenmenu,'Enable','on');
               set(coint.menurecursive,'Enable','on');
               set(coint.receigengraph,'Enable','on');
               if (cm.r==0)&(cm.p==1);
                  set(coint.cmat,'Enable','off');
                  set(coint.longrun_gir,'Enable','off');
                  set(coint.menupermcomp,'Enable','off');
                  set(coint.permcomp,'Enable','off');
                  set(coint.savetc,'Enable','off');
               else;
                  set(coint.cmat,'Enable','on');
                  set(coint.longrun_gir,'Enable','on');
                  set(coint.menupermcomp,'Enable','on');
                  set(coint.permcomp,'Enable','on');
                  set(coint.savetc,'Enable','on');
               end;
            else;
               set(coint.booteigenmenu,'Enable','off');
               set(coint.menurecursive,'Enable','off');
               set(coint.receigengraph,'Enable','off');
               set(coint.cmat,'Enable','off');
               set(coint.longrun_gir,'Enable','off');
               set(coint.menupermcomp,'Enable','off');
               set(coint.permcomp,'Enable','off');
               set(coint.savetc,'Enable','off');
            end;
         end;
         if cm.r==0;
            set(coint.menurecursive,'Enable','off');
            set(coint.booteigenmenu,'Enable','off');
            set(coint.receigengraph,'Enable','off');
         end;
         if ((cm.r==0)&(cm.p==1));
            set(coint.gctest,'Enable','off');
            if cm.n>2;
               set(coint.multigctest,'Enable','off');
            end;
         else;
            if (cm.n==1)&((cm.q1+cm.q0)==0);
               set(coint.gctest,'Enable','off');
            else;
               set(coint.gctest,'Enable','on');
               if cm.n>2;
                  set(coint.multigctest,'Enable','on');
               end;
            end;
         end;
         set(coint.eigenvalue,'String',num2str(cm.evalue,'%0.4f'));
         set(rankdlg,'UserData',coint);
         checkr = 1;
         for i=1:size(cm.rvec,2);
            if cm.r==cm.rvec(1,i);
               checkr = 0;
               break;
            end;
         end;
         [lnl,ldOmega] = loglike(cm.epsilon);
         cm.model_info.info = setmodelinfo(cm.model_info.info,cm.T,cm.df,lnl);
         set(coint.model_info,'String',cm.model_info.info);
         if cm.p>1;
            if cm.r<cm.n;
               set(coint.common_cycles,'Enable','on');
            else;
               set(coint.common_cycles,'Enable','off');
            end;
         end;
         if curr_ini.noprint==0;
            if checkr==1;
               if (curr_ini.shortdyn==1)&(curr_ini.noprint==0);
                  shortstr = shortrun(cm.alpha,cm.Psi,cm.Omega,mybeta,cm.Z1,cm.Z2,cm.p,cm.pe,cm.d,cm.deterselect,cm.q0,cm.q1,cm.evars,cm.xvars0,cm.xvars1,cm.deter,cm.restvec,1,cm.outputfile,0);
                  fout = fopen(cm.outputfile,'at');
                  if curr_ini.texoutputformat>=2;
                     fprintf(fout,'\\ruler\n\n%%==============================================================================\n\n');
                     if (cm.r<cm.n)&~((cm.p==1)&(cm.r==0));
                        C = cmat(cm.Psi,cm.alpha,mybeta,cm.epsilon,cm.Z1,cm.Z2,cm.p,cm.d,1);
                        myC = showc(C(:,1:cm.n),cm.myvars);
                        myCstd = showc(C(:,cm.n+1:2*cm.n),cm.myvars);
                        myCt = showc(inf2nan(C(:,1:cm.n)./C(:,cm.n+1:2*cm.n)),cm.myvars);
                        myC = text_latextable(myC);
                        myCstd = text_latextable(myCstd);
                        myCstd = myCstd(2:size(myCstd,1),:);
                        myCt = text_latextable(myCt);
                        myCt = myCt(2:size(myCt,1),:);
                        myC = merge_latextable(myC,myCstd,myCt);
                        r_str = 'r';
                        for i=1:cm.n;
                           r_str = [r_str 'r'];
                        end;
                        fprintf(fout,'\\subsection*{The $C$ matrix}\n\n\\header{For $r$=%0.0f}\n\n',cm.r);
                        fprintf(fout,['\\begin{tabular}{' r_str '}\n']);
                        for i=1:(size(myC,1));
                           fprintf(fout,'%s\n',myC(i,:));
                        end;
                        fprintf(fout,'\\end{tabular}\n\n');
                        fprintf(fout,'\\ruler\n\n%%==============================================================================\n\n');
                     end;
                  else;
                     fprintf(fout,'\n===============================================================================\n\n');
                     if (cm.r<cm.n)&~((cm.p==1)&(cm.r==0));
                        C = cmat(cm.Psi,cm.alpha,mybeta,cm.epsilon,cm.Z1,cm.Z2,cm.p,cm.d,1);
                        myC = showc(C(:,1:cm.n),cm.myvars);
                        myCstd = showc(C(:,cm.n+1:2*cm.n),cm.myvars);
                        myCt = showc(inf2nan(C(:,1:cm.n)./C(:,cm.n+1:2*cm.n)),cm.myvars);
                        fprintf(fout,'THE C-MATRIX (for rank=%1.0f)\n\n',cm.r);
                        for i=1:(size(myC,1));
                           fprintf(fout,'%s\n',myC(i,:));
                        end;
                        fprintf(fout,'\nEstimated asymptotic standard errors:\n\n');
                        for i=1:(size(myC,1));
                           fprintf(fout,'%s\n',myCstd(i,:));
                        end;
                        fprintf(fout,'\nt-ratios:\n\n');
                        for i=1:(size(myC,1));
                           fprintf(fout,'%s\n',myCt(i,:));
                        end;
                        fprintf(fout,'\n===============================================================================\n\n');
                     end;
                  end;
                  fclose(fout);
               end;
               fout = fopen(cm.outputfile,'at');
               if curr_ini.texoutputformat>=2;
                  fprintf(fout,'\\subsection*{Value of the maximized log-likelihood function:}\n\n');
                  fprintf(fout,'\\begin{tabular}{ll}\n');
                  fprintf(fout,[' & $\\ln L(\\mbox{\\rm lags}=%0.0f,r=%0.0f)$=%0.' num2str(curr_ini.decimals,'%0.0f') 'f \\\\\n'],cm.p,cm.r,lnl);
                  fprintf(fout,[' & $\\ln (\\det(\\Omega))$=%0.' num2str(curr_ini.decimals,'%0.0f') 'f \\\\\n'],ldOmega);
                  fprintf(fout,'\\end{tabular}\n\n\\ruler\n\n%%==============================================================================\n\n');
               else;
                  fprintf(fout,'Value of the maximized log-likelihood function:\n\n');
                  fprintf(fout,['   lnL(lags=%1.0f,rank=%1.0f)=%1.' num2str(curr_ini.decimals,'%0.0f') 'f\n\n'],cm.p,cm.r,lnl);
                  fprintf(fout,['   ln(det(Omega))=%0.' num2str(curr_ini.decimals,'%0.0f') 'f\n'],ldOmega);
                  fprintf(fout,'\n===============================================================================\n\n');
               end;
               fclose(fout);
               %
               % Calculate exclusion and stationarity tests
               %
               if (curr_ini.excludestat==1)&(cm.r>0);
                  setlogtext('Computing exclusion tests...');
                  print_exclusion(cm,curr_ini);
                  setlogtext('Computing stationarity tests...');
                  print_stationarity(cm,curr_ini);
               end;
               %
               % compute tests for additional deterministic variables
               %
               if (curr_ini.dummytests==1)&(cm.datad>0);
                  print_exclude_dummies(cm,curr_ini);
                  if cm.r>0;
                     print_longrun_dummies(cm,curr_ini);
                  end;
               end;
               %
               % Calculate lag-order test
               %
               if curr_ini.lagtest>0;
                  setlogtext('Computing lag order tests...');
                  print_lagordertest(cm,curr_ini,mybeta,cm.alpha,cm.Psi,cm.epsilon,[],0,0,cm.T-cm.df,0);
               end;
               %
               if ((cm.r>0)|(cm.p>1));
                  if curr_ini.gctest==1;
                     setlogtext('Computing Granger causality tests...');
                     print_gctest(cm,curr_ini,mybeta,cm.alpha,cm.Psi,cm.epsilon,[],0,0,cm.T-cm.df,0);
                     if cm.n>2;
                        setlogtext('Computing multi-step Granger causality tests...');
                        print_mgctest(cm,curr_ini,mybeta,cm.alpha,cm.Psi,cm.epsilon,[],0,0,0,0);
                     end;
                  end;
               end;
               %
               if curr_ini.excludediffs==1;
                  if ((cm.p>1)&(cm.n>2))|(cm.q0>0)|((cm.q1>0)&(cm.pe>0));
                     setlogtext('Computing exclusion tests for first differences...');
                     print_firstdiffstests(cm,curr_ini,mybeta,cm.alpha,cm.Psi,cm.epsilon,[],0,0,cm.df,0);
                  end;
               end;
               %
               if (cm.r<cm.n)&(cm.r>0);
                  if curr_ini.weakexo==1;
                     setlogtext('Computing weak exogeneity tests...');
                     print_weakexo(cm,curr_ini,mybeta,cm.alpha,cm.epsilon,[],0,0,cm.T-cm.df,0);
                  end;
               end;
               %
               if (cm.r<cm.n)&(cm.p>1);
                  if curr_ini.commoncycles==1;
                     setlogtext('Computing common cycle tests...');
                     print_commoncycles(cm,curr_ini,cm.alpha,cm.Psi,cm.beta(:,1:cm.r));
                  end;
               end;
               %
               % residual statistics
               %
               print_residual_analysis(cm,curr_ini,cm.epsilon,0,0,cm.df);
               %
               % specification tests
               %
               if cm.spectest(1,4)==1;
                  txt = strvcat(' ','Computing specification tests.','Please hold!');
                  mywait = waitdlg(txt,'information');
                  waitf = get(mywait,'UserData');
               end;
               if cm.spectest(1,1)==1;
                  if cm.r>0;
                     this_beta = cm.beta(:,1:cm.r);
                  else;
                     this_beta = [];
                  end;
                  setlogtext('Computing serial correlation tests...');
                  print_corrtest(cm,curr_ini,cm.epsilon,this_beta,0,0,cm.df);
               end;
               %
               if cm.spectest(1,2)==1;
                  setlogtext('Computing ARCH tests...');
                  print_archtest(cm,curr_ini,cm.epsilon,0,0,cm.df);
               end;
               %
               if cm.spectest(1,3)==1;
                  setlogtext('Computing normality tests...');
                  print_normalitytest(cm,curr_ini,cm.epsilon,0,0,cm.df);
               end;
               %
               if cm.spectest(1,4)==1;
                  if cm.r+cm.p+cm.d>1;
                     if cm.r>0;
                        Zb = cm.beta(:,1:cm.r)'*cm.Z1;
                     else;
                        Zb = 0;
                     end;
                     fout = fopen(cm.outputfile,'at');
                     if curr_ini.texoutputformat>=2;
                        fprintf(fout,['\\subsection*{Parameter constancy tests}\n\n\\header{For $r$=' num2str(cm.r) ', lags=' num2str(cm.p) ', \\#free $\\beta$ params=' num2str(cm.r*(cm.n-cm.r),'%0.0f') ', \\#free $\\alpha$ params=' num2str(cm.n*cm.r,'%0.0f') '}\n\n']);
                     else;
                        fprintf(fout,['PARAMETER CONSTANCY TESTS\n\n(for rank=' num2str(cm.r) ',lags=' num2str(cm.p) ',#free beta params=' num2str(cm.r*(cm.n-cm.r),'%0.0f') ',#free alpha params=' num2str(cm.n*cm.r,'%0.0f') ')\n\n']);
                     end;
                     fclose(fout);
                     if curr_ini.lstrtest==1;
                        setlogtext('Computing LSTR1 constancy tests...');
                        print_lstr1test(cm,curr_ini,cm.epsilon,Zb,cm.df);
                     end;
                     %
                     if (cm.r>0)&(cm.evalue<1)&(cm.q1+cm.q0==0);
                        setlogtext('Computing Hansen-Johansen constancy tests...');
                        if curr_ini.nyblom==1;
                           setlogtext('Computing Nyblom tests for beta constancy...');
                        end;
                     end;
                     print_jo_hansen(cm,curr_ini,cm.df);
                     %
                     if curr_ini.chow==1;
                        setlogtext('Computing Chow tests...');
                        print_chow(cm,curr_ini,mybeta,0);
                     end;
                     %
                     setlogtext('Computing fluctuation tests...');
                     print_ploberger(cm,curr_ini,mybeta,0);
                  end;
               end;
            end;
            if (cm.spectest(1,4)==1)&(checkr==1);
               set(waitf.text,'UserData','done');
               delete(mywait);
               drawnow;
            end;
         end;
         cm.rvec = [cm.rvec cm.r];
         cm.running = 0;
      end;
   case 'quit'
      if cm.running==0;
         cm.running = 1;
         if curr_ini.sillyq==0;
            txt = ['Are you sure you want to stop the estimation?'];
            answer = query(txt,'question',120,'Cointegration Rank Tests',300);
         else;
            answer = 'Yes';
         end;
         if strcmp(answer,'Yes');
            set(coint.continue,'UserData','done');
            set(coint.mypopup,'UserData',2);
            set(rankdlg,'UserData',coint);
         end;
         cm.running = 0;
      end;
   case 'graphs';
      if cm.running==0;
         cm.running = 1;
         set(coint.mypopup,'UserData',thisexit);
         set(rankdlg,'Visible','off');
         drawnow;
         cointrel = cm.bZ1t(1:cm.r,:);
         corrcointrel = cm.bR1t(1:cm.r,:);
         thisgraph = cointgraphdlg('init',cm,cointrel,corrcointrel,0);
         graph = get(thisgraph,'UserData');
         set(graph.show,'UserData','done');
         killguipid(thisgraph);
         set(rankdlg,'Visible','on');
         set(rankdlg,'UserData',coint);
         cm.running = 0;
      end;
   case 'permcomp'
      if cm.running==0;
         cm.running = 1;
         [y_t,perm_y,trans_y] = permcomp(cm.Psi,cm.alpha,cm.beta(:,1:cm.r),cm.epsilon,cm.x0,cm.x1,cm.x1_r,cm.x2,cm.d,cm.dcoint,cm.p,cm.pe,cm.q1,cm.q0);
         set(rankdlg,'Visible','off');
         drawnow;
         thisgraph = pctcdlg('init',cm,y_t,perm_y,trans_y,0);
         pctc = get(thisgraph,'UserData');
         set(pctc.show,'UserData','done');
         killguipid(thisgraph);
         set(rankdlg,'Visible','on');
         drawnow;
         cm.running = 0;
      end;
   case 'corrtest'
      if cm.running==0;
         cm.running = 1;
         show_corrtest(rankdlg,cm,curr_ini,0);
         cm.running = 0;
      end;
   case 'archtest'
      if cm.running==0;
         cm.running = 1;
         show_archtest(rankdlg,cm,curr_ini,0);
         cm.running = 0;
      end;
   case 'normalitytest'
      if cm.running==0;
         cm.running = 1;
         show_normalitytest(rankdlg,cm,curr_ini,0);
         cm.running = 0;
      end;
   case 'constancytest'
      if cm.running==0;
         cm.running = 1;
         show_constancytest(rankdlg,cm.beta(:,1:cm.r),cm,curr_ini,0,0,1);
         cm.running = 0;
      end;
   case 'lagorder'
      if cm.running==0;
         cm.running = 1;
         show_lagordertest(rankdlg,cm.beta(:,1:cm.r),cm.alpha,cm.Psi,[],cm,curr_ini,0,0);
         cm.running = 0;
      end;
   case 'firstdiffs'
      if cm.running==0;
         cm.running = 1;
         show_firstdiffstests(rankdlg,cm.beta(:,1:cm.r),cm.alpha,cm.Psi,[],cm,curr_ini,0,0);
         cm.running = 0;
      end;
   case 'gctest'
      if cm.running==0;
         cm.running = 1;
         show_gctest(rankdlg,cm.beta(:,1:cm.r),cm.alpha,cm.Psi,[],cm,curr_ini,0,0);
         cm.running = 0;
      end;
   case 'multigctest'
      if cm.running==0;
         cm.running = 1;
         set(rankdlg,'Visible','off');
         drawnow;
         this_graph = select_mgc('init',cm,cm.beta(:,1:cm.r),[],0,0,0);
         mgc = get(this_graph,'UserData');
         set(mgc.show,'UserData','done');
         killguipid(this_graph);
         set(rankdlg,'Visible','on');
         drawnow;
         cm.running = 0;
      end;
   case 'savetc'
      if cm.running==0;
         cm.running = 1;
         [y_t,perm_y,trans_y] = permcomp(cm.Psi,cm.alpha,cm.beta(:,1:cm.r),cm.epsilon,cm.x0,cm.x1,cm.x1_r,cm.x2,cm.d,cm.dcoint,cm.p,cm.pe,cm.q1,cm.q0);
         myfile = [cm.outputdir 'trans.comp-' num2str(cm.r,'%1.0f') '.data'];
         [savefile,savepath] = uiputfile(myfile,'Save As');
         drawnow;
         if isnumeric(savefile)==0;
            [myN myT] = size(trans_y);
            myt = '';
            for i=1:myT;
               myt = strvcat(myt,getdate(cm.samplebeg,cm.sampleend,cm.freq,i/myT));
            end;
            setlogtext(['Saving transitory components to ' savefile '...']);
            savefile = strcat(savepath,savefile);
            fid = fopen(savefile,'wt');
            myprintstr = '';
            firststr = ' DATE  ';
            prt_str = ['%' num2str(2*(curr_ini.exportdata+3),'%0.0f') '.' num2str(curr_ini.exportdata+3,'%0.0f') 'f'];
            for i=1:myN;
               myprintstr = [myprintstr '   ' prt_str];
               firststr = [firststr '              tc_' cm.myvars(i,:)];
            end;
            fprintf(fid,[firststr '\n']);
            for i=1:myT;
               fprintf(fid,['%s ' myprintstr '\n'],myt(i,:),trans_y(:,i)');
            end;
            fclose(fid);
         end;
         cm.running = 0;
      end;
   case 'savecoint'
      if cm.running==0;
         cm.running = 1;
         CR = normbeta(cm.beta(:,1:cm.r))'*cm.Z1t;
         myfile = [cm.outputdir 'coint-' num2str(cm.r,'%1.0f') '.data'];
         [savefile,savepath] = uiputfile(myfile,'Save As');
         drawnow;
         if isnumeric(savefile)==0;
            [myR myT] = size(CR);
            myt = '';
            for i=1:myT;
               myt = strvcat(myt,getdate(cm.samplebeg,cm.sampleend,cm.freq,i/myT));
            end;
            setlogtext(['Saving cointegration relations to ' savefile '...']);
            savefile = strcat(savepath,savefile);
            fid = fopen(savefile,'wt');
            myprintstr = '';
            firststr = ' DATE  ';
            prt_str = ['%' num2str(2*(curr_ini.exportdata+3),'%0.0f') '.' num2str(curr_ini.exportdata+3,'%0.0f') 'f'];
            for i=1:myR;
               myprintstr = [myprintstr '   ' prt_str];
               firststr = [firststr '               ci_' num2str(i,'%1.0f')];
            end;
            fprintf(fid,[firststr '\n']);
            for i=1:myT;
               fprintf(fid,['%s ' myprintstr '\n'],myt(i,:),CR(:,i)');
            end;
            fclose(fid);
         end;
         cm.running = 0;
      end;
   case 'saveresid'
      if cm.running==0;
         cm.running = 1;
         myfile = [cm.outputdir 'epsilon-' num2str(cm.r,'%1.0f') '.data'];
         [savefile,savepath] = uiputfile(myfile,'Save As');
         drawnow;
         if isnumeric(savefile)==0;
            [myN myT] = size(cm.epsilon);
            myt = '';
            for i=1:myT;
               myt = strvcat(myt,getdate(cm.samplebeg,cm.sampleend,cm.freq,i/myT));
            end;
            setlogtext(['Saving residuals to ' savefile '...']);
            savefile = strcat(savepath,savefile);
            fid = fopen(savefile,'wt');
            myprintstr = '';
            firststr = ' DATE  ';
            prt_str = ['%' num2str(2*(curr_ini.exportdata+3),'%0.0f') '.' num2str(curr_ini.exportdata+3,'%0.0f') 'f'];
            for i=1:myN;
               myprintstr = [myprintstr '   ' prt_str];
               firststr = [firststr '             eps_' cm.myvars(i,:)];
            end;
            fprintf(fid,[firststr '\n']);
            for i=1:myT;
               fprintf(fid,['%s ' myprintstr '\n'],myt(i,:),cm.epsilon(:,i)');
            end;
            fclose(fid);
         end;
         cm.running = 0;
      end;
   case 'viewdata'
      if cm.running==0;
         cm.running = 1;
         if matlabnumber>=6.0;
            myfile = {'*.txt;*.data;*.wk1;*.xls;*.mat;*.csv', 'Data Files (*.txt, *.data, *.wk1, *.xls, *.mat, *.csv)'; ...
                    '*.txt;*.data', 'Text Files (*.txt, *.data)'; ...
                    '*.mat', 'MatLab MAT Files (*.mat)'; ...
                    '*.wk1', 'Lotus 1-2-3 Spreadsheets (*.wk1)'; ...
                    '*.xls', 'Excel Spreadsheets (*.xls)'; ...
                    '*.csv', 'Comma Separated Value Files (*.csv)'; ...
                    '*.*', 'All Files (*.*)'};
         else;
            if (iscompiled==1)&(iswinnt==1)&(curr_ini.opendialog==1);
               fix_fig = findobj('Tag','StructuralVAR');
               model = get(fix_fig,'UserData');
               afile = get(model.endogenous,'String');
               basedir = getpath(strtrim(afile));
               file_fltr = 'Data Files (*.txt, *.data, *.wk1, *.mat, *.csv)|*.txt;*.data;*.wk1;*.mat;*.csv|Text Files (*.txt, *.data)|*.txt;*.data|MatLab MAT Files (*.mat)|*.mat|Lotus 1-2-3 Spreadsheets (*.wk1)|*.wk1|Comma Separated Value Files (*.csv)|*.csv|All Files (*.*)|*.*|';
               best_pos = 1;
               title_txt = 'Open';
            else;
               fix_fig = findobj('Tag','StructuralVAR');
               model = get(fix_fig,'UserData');
               afile = get(model.endogenous,'String');
               afile = strtrim(afile);
               if fileexist(afile)==1;
                  adir = getpath(afile);
                  if ispc==1;
                     if strcmp(adir(1,size(adir,2)),'\')==0;
                        adir = [adir '\'];
                     end;
                  else;
                     if strcmp(adir(1,size(adir,2)),'/')==0;
                        adir = [adir '/'];
                     end;
                  end;
               else;
                  adir = cm.outputdir;
               end;
               myfile = [adir '*.txt;*.data;*.wk1;*.mat;*.csv'];
            end;
         end;
         if (iscompiled==1)&(iswinnt==1)&(curr_ini.opendialog==1)&(matlabnumber<6.0);
            [openfile,openpath] = fileopen(basedir,file_fltr,best_pos,title_txt);
         else;
            if matlabnumber>=6;
               [openfile,openpath] = uigetfile(myfile,'Open',getpath(cm.endofile));
            else;
               [openfile,openpath] = uigetfile(myfile,'Open');
            end;
         end;
         drawnow;
         if isnumeric(openfile)==0;
            openfile = strcat(openpath,openfile);
            set(rankdlg,'Visible','off');
            drawnow;
            textgui(openfile,['View Data - ' openfile],[(realscrsz(3)-(realscrsz(4)-80))/2 1 realscrsz(4)-80 realscrsz(4)-54],'Data',25);
            set(rankdlg,'Visible','on');
            drawnow;
         end;
         cm.running = 0;
      end;
   case 'cmat'
      if cm.running==0;
         cm.running = 1;
         if cm.r<cm.n;
            C = cmat(cm.Psi,cm.alpha,cm.beta(:,1:cm.r),cm.epsilon,cm.Z1,cm.Z2,cm.p,cm.d,1);
         else;
            C = cmat_stat(cm.Psi,cm.alpha,cm.beta,cm.epsilon,cm.Z1,cm.Z2,cm.p,cm.d,1);
         end;
         ctext = strvcat(' ',['THE C-MATRIX (for rank=' num2str(cm.r,'%1.0f') ')']);
         numchar = size(ctext,2);
         addcorr = '';
         for i=1:numchar;
            addcorr = strcat(addcorr,'=');
         end;
         ctext = strvcat(ctext,addcorr,' ');
         ctext = strvcat(ctext,showc(C(:,1:cm.n),cm.myvars),' ');
         ctext = strvcat(ctext,'Estimated asymptotic standard errors:',' ',showc(C(:,cm.n+1:2*cm.n),cm.myvars),' ','t-ratios:',' ',showc(inf2nan(C(:,1:cm.n)./C(:,cm.n+1:2*cm.n)),cm.myvars),' ');
         set(rankdlg,'Visible','off');
         drawnow;
         textgui(ctext,'C-Matrix',[(realscrsz(3)-700)/2 (realscrsz(4)-500)/2 700 500],'Results',38);
         set(rankdlg,'Visible','on');
         drawnow;
         cm.running = 0;
      end;
   case 'exclusion'
      if cm.running==0;
         cm.running = 1;
         show_exclusion(rankdlg,cm,curr_ini);
         cm.running = 0;
      end;
   case 'stationarity'
      if cm.running==0;
         cm.running = 1;
         show_stationarity(rankdlg,cm,curr_ini);
         cm.running = 0;
      end;
   case 'weakexo'
      if cm.running==0;
         cm.running = 1;
         show_weakexo(rankdlg,cm.beta(:,1:cm.r),cm.alpha,[],cm,curr_ini,0,0);
         cm.running = 0;
      end;
   case 'shortdyn'
      if cm.running==0;
         cm.running = 1;
         if cm.r>0;
            mybeta = cm.beta(:,1:cm.r);
         else;
            mybeta = [];
         end;
         shortstr = shortrun(cm.alpha,cm.Psi,cm.Omega,mybeta,cm.Z1,cm.Z2,cm.p,cm.pe,cm.d,cm.deterselect,cm.q0,cm.q1,cm.evars,cm.xvars0,cm.xvars1,cm.deter,cm.restvec,1,cm.outputfile,1);
         set(rankdlg,'Visible','off');
         drawnow;
         textgui(shortstr,'Short Run Dynamics',[(realscrsz(3)-800)/2 (realscrsz(4)-500)/2 800 500],'Results',38);
         set(rankdlg,'Visible','on');
         drawnow;
         cm.running = 0;
      end;
   case 'forecast'
      if cm.running==0;
         cm.running = 1;
         set(rankdlg,'Visible','off');
         drawnow;
         thisgraph = forecastdlg('init',cm,[0 0]);
         f_cast = get(thisgraph,'UserData');
         set(f_cast.show,'UserData','done');
         killguipid(thisgraph);
         set(rankdlg,'Visible','on');
         drawnow;
         cm.running = 0;
      end;
   case 'varforecast'
      if cm.running==0;
         cm.running = 1;
         set(rankdlg,'Visible','off');
         drawnow;
         thisgraph = var_forecastdlg('init',cm,[0 0]);
         f_cast = get(thisgraph,'UserData');
         set(f_cast.show,'UserData','done');
         killguipid(thisgraph);
         set(rankdlg,'Visible','on');
         drawnow;
         cm.running = 0;
      end;
   case 'residuals'
      if cm.running==0;
         cm.running = 1;
         set(rankdlg,'Visible','off');
         drawnow;
         thisgraph = epsilondlg('init',cm,0);
         epsi = get(thisgraph,'UserData');
         set(epsi.show,'UserData','done');
         killguipid(thisgraph);
         set(rankdlg,'Visible','on');
         drawnow;
         cm.running = 0;
      end;
   case 'ploberger'
      if cm.running==0;
         cm.running = 1;
         show_ploberger(rankdlg,cm.beta(:,1:cm.r),cm,curr_ini,0,0);
         cm.running = 0;
      end;
   case 'chow'
      if cm.running==0;
         cm.running = 1;
         show_chow(rankdlg,cm.beta(:,1:cm.r),cm,curr_ini,0,0);
         cm.running = 0;
      end;
   case 'recursiveeig'
      if cm.running==0;
         cm.running = 1;
         show_recursiveeig(rankdlg,cm,curr_ini);
         cm.running = 0;
      end;
   case 'dist'
      if cm.running==0;
         cm.running = 1;
         if cm.showcritval==0;
            if cm.critvalnum==6;
               if isempty(cm.pvalues);
                  if (cm.q1+cm.q0)==0;
                     cm.pvalues = tracepval(cm.n,cm.trace,cm.deterselect);
                  elseif (cm.q1>0)&(cm.q1<12)&(cm.q0==0)&((cm.deterselect(1,2)==1)|(cm.deterselect(1,4)==1));
                     cm.pvalues = tracepval_exo(cm.n,cm.q1,cm.trace,cm.deterselect);
                  elseif (cm.q1==0)&(cm.q0>0);
                     cm.pvalues = tracepval_exoi0(cm.n,cm.p,cm.pe,cm.q0,cm.trace,cm.deterselect,cm.d,cm.beta,cm.S_01,cm.M_02,cm.M_12,cm.M_22,cm.Z0,cm.Z1,cm.Z2);
                  else;
                     cm.pvalues = NaN;
                     for j=2:cm.n;
                        cm.pvalues = [cm.pvalues;NaN];
                     end;
                  end;
               end;
               testtext = strvcat(['       Rank                 LR trace                     p-value'],get(coint.tracetext,'UserData'));
               set(coint.tracetext,'String',testtext);
%               set(coint.dist,'TooltipString','Eigenvalues','CData',button_images.lambda);
               set(coint.dist,'Enable','off');
               set(coint.dist2,'Enable','on');
               set(coint.distmenu,'Enable','off');
               set(coint.dist2menu,'Enable','on');
               h0 = (0:cm.n-1);
               prependstr = '   ';
               for i=2:cm.n;
                  prependstr = [prependstr;'   '];
               end;
               textcritval = [num2str(h0','%2.0f') prependstr prependstr num2str(cm.trace,'%12.4f') prependstr prependstr num2str(cm.pvalues,'%12.4f')];
               textcritval = [prependstr textcritval];
               textcritval = strvcat(' ',textcritval,' ');
               set(coint.traceresults,'String',textcritval);
               cm.showcritval = 1;
            else;
               if (cm.q1+cm.q0)==0;
                  mydist = tracedist(cm.n,cm.critvalnum,cm.deterselect);
               elseif (cm.q1>0)&(cm.q1<12)&(cm.q0==0)&((cm.deterselect(1,2)==1)|(cm.deterselect(1,4)==1));
                  mydist = trace_exo_dist(cm.n,cm.q1,cm.deterselect,cm.critvalnum);
               elseif (cm.q1==0)&(cm.q0>0);
                  mydist = trace_exoi0_dist(cm.n,cm.p,cm.pe,cm.q0,cm.critvalnum,cm.deterselect,cm.d,cm.beta,cm.S_01,cm.M_02,cm.M_12,cm.M_22,cm.Z0,cm.Z1,cm.Z2);
               else;
                  mydist = NaN;
                  for j=2:cm.n;
                     mydist = [mydist;NaN];
                  end;
               end;
               testtext = strvcat(['       Rank                 LR trace                    ' num2str(100-curr_ini.critval) '% quantile'],get(coint.tracetext,'UserData'));
               set(coint.tracetext,'String',testtext);
%               set(coint.dist,'TooltipString','Eigenvalues','CData',button_images.lambda);
               set(coint.dist,'Enable','off');
               set(coint.dist2,'Enable','on');
               set(coint.distmenu,'Enable','off');
               set(coint.dist2menu,'Enable','on');
               h0 = (0:cm.n-1);
               prependstr = '   ';
               for i=2:cm.n;
                  prependstr = [prependstr;'   '];
               end;
               textcritval = [num2str(h0','%2.0f') prependstr prependstr num2str(cm.trace,'%12.4f') prependstr prependstr num2str(mydist,'%12.3f')];
               textcritval = [prependstr textcritval];
               textcritval = strvcat(' ',textcritval,' ');
               set(coint.traceresults,'String',textcritval);
               cm.showcritval = 1;
            end;
         else;
            testtext = strvcat('       Rank                 LR trace                    Eigenvalue',get(coint.tracetext,'UserData'));
            set(coint.tracetext,'String',testtext);
%            if cm.critvalnum==6;
%               set(coint.dist,'TooltipString','p-values');
%               set(coint.dist,'CData',button_images.pvalue);
%            else;
%               set(coint.dist,'CData',button_images.cv);
%               set(coint.dist,'TooltipString','Critical Values');
%            end;
            set(coint.dist,'Enable','on');
            set(coint.dist2,'Enable','off');
            set(coint.distmenu,'Enable','on');
            set(coint.dist2menu,'Enable','off');
            set(coint.traceresults,'String',cm.textlambda);
            cm.showcritval = 0;
         end;
         set(rankdlg,'UserData',coint);
         cm.running = 0;
      end;
   case 'continue';
      if cm.running==0;
         cm.running = 1;
         if curr_ini.sillyq==0;
            txt = ['Are you sure you want to select a cointegration rank of ' num2str(cm.r) '?'];
            answer = query(txt,'question',120,'Cointegration Rank Tests',350);
         else;
            answer = 'Yes';
         end;
         if strcmp(answer,'Yes');
            set(coint.continue,'UserData','done');
            set(coint.mypopup,'UserData',thisexit);
            set(rankdlg,'UserData',coint);
         end;
         cm.running = 0;
      end;
   case 'wayout'
      if cm.running==0;
         cm.running = 1;
         if strcmp(get(coint.continue,'UserData'),'done')==0;
            if curr_ini.sillyq==0;
               txt = ['Are you sure you want to select a cointegration rank of ' num2str(cm.r) '?'];
               answer = query(txt,'question',120,'Cointegration Rank Tests',350);
            else;
               answer = 'Yes';
            end;
            if strcmp(answer,'Yes');
               set(coint.continue,'UserData','done');
               set(coint.mypopup,'UserData',thisexit);
            end;
         end;
%         if strcmp(get(coint.eigenvalue,'UserData'),'done')==1;
%            delete(rankdlg);
%         end;
         cm.running = 0;
      end;
end;

if strcmp(selector,'init')==1;
   if strcmp(cm.deterdel,'')==0;
      deterdelinfo = ['Due to linear dependence, the following deterministic variables were deleted: ' cm.deterdel '.'];
      set(coint.model_info,'TooltipString',deterdelinfo);
      set(coint.model_header,'TooltipString',deterdelinfo);
   end;
   if strcmp(corrstr,'')==0;
      set(coint.traceresults,'TooltipString',corrstr);
   end;
   set(rankdlg,'Visible','on');
end;

if nargout==1;
   h = rankdlg;
end;

curr_ini.images = button_images;
curr_ini.model = cm;
set(coint.viewdata,'UserData',curr_ini);

if thisexit==0;
   coint = get(rankdlg,'UserData');
   waitfor(coint.continue,'UserData','done');
end;

%
% end of rankgui.m
%
