%
% export: tauT xisumT xistdT
%

function [tauT,xisumT,xistdT,status,tT] = receigen(Z0,Z1,Z2,r,p,d,T0,np,deterselect,real_T)

curr_ini = find_inisettings;

[n T] = size(Z0);

if nargin<10;
   real_T = T;
end;

%
% Ensuring that all input variables are set
%

if nargin<7;
   T1 = round(2*real_T/3);
else;
   if T0<0;
      T1 = round(2*real_T/3);
   elseif T0>0.95;
      T1 = round(2*real_T/3);
   else;
      T1 = round(real_T*T0);
   end;
end;

if T1<=size(Z1,1)+size(Z2,1);
   T1 = size(Z1,1)+size(Z2,1)+1;
end;
%
% check if Z1 has a zero row
%
ZeroRows = [];
for i=1:size(Z1,1);
   if isequal(Z1(i,1:T1),zeros(1,T1))==1;
      ZeroRows = [ZeroRows i];
   end;
end;
%
% if a zero row is located, we replace it with 1-rowvalue
%
if isempty(ZeroRows)==0;
   Z1(ZeroRows,:) = ones(length(ZeroRows),T)-Z1(ZeroRows,:);
   if length(ZeroRows)>1;
      %
      % we need to try to move T1 up
      %
      for t=T1:T;
         if rank(Z1(:,1:t))==size(Z1,1);
            T1 = t;
            break;
         end;
      end;
   end;
end;
%
if nargin<8;
   np = r+round(r*(n-r)/n)+n*(p-1)+d;
end;

if nargin<9;
   deterselect = [1 0 0 0];
end;

tT = [];

if T1>T;
   status = 1;
   tauT = [];
   xisumT = [];
   xistdT = [];
   return;
end;

status = 0;

%
% compute full sample estimates
%

[S_00,S_01,S_10,S_11,M_02,M_22,M_12,beta,lambda,trace_test] = mlcointbasic(Z0,Z1,Z2,r);

lambdaT = lambda(1:r,1);
tauT = zeros(r,T-T1+1);
lambdaT0 = lambda(1:r,1);

alpha = S_01*beta*inverse(beta'*S_11*beta);
if isempty(Z2)==0;
   Psi = M_02*inverse(M_22)-(alpha*beta'*M_12*inverse(M_22));
   epsilon = Z0-(alpha*beta'*Z1)-(Psi*Z2);
else;
   Psi = [];
   epsilon = Z0-(alpha*beta'*Z1);
end;
Omega = (1/T)*epsilon*epsilon';

if isempty(Z2)==0;
   R0 = Z0-(M_02*inverse(M_22)*Z2);
   R1 = Z1-(M_12*inverse(M_22)*Z2);
else;
   R0 = Z0;
   R1 = Z1;
end;

beta = beta(1:n,1:r);

%
% computing the matrix A
%

if p>=2;
   Phi = Psi(:,d+1:d+n*(p-1));
end;

if p>=2;
   A = [[(beta'*alpha)+eye(r) beta'*Phi];[alpha Phi]];
   if p>=3;
      A = [A;[zeros((p-2)*n,r) eye((p-2)*n) zeros((p-2)*n,n)]];
   end;
else;
   A = [[(beta'*alpha)+eye(r) zeros(r,n)];[alpha zeros(n,n)]];
end;

OmegaTilde = [[beta'*Omega*beta beta'*Omega];[Omega*beta Omega]];

if p>=3;
   OmegaTilde = [[OmegaTilde zeros(r+n,n*(p-2))];zeros(n*(p-2),r+n*(p-1))];
end;

%
% Computing the covariance matrix SigmaTilde
%

q = size(A,1);
Ak = eye(q*q)-kron(A,A);
if min(abs(eig(Ak)))<=1.0e-010;
   status = 1;
   tauT = [];
   xisumT = [];
   xistdT = [];
   return;
end;

Akinv = Ak\eye(q*q);
sigmatilde = Akinv*vec(OmegaTilde);
SigmaTilde = vecinv(sigmatilde,q);
SigmaTildeInv = eye(q)/SigmaTilde;

%
% Computing asymptotic variances
%

Upsilon = kron(SigmaTildeInv,SigmaTildeInv)*Akinv;
Upsilon2 = Upsilon+Upsilon';

lambdastd = zeros(r,1);
sigmastd = zeros(r,1);
xistdT = 0;

for i=1:r;
   itilde = i+(i-1)*(r+n*(p-1));
   lambdai = (1-lambda(i,1))*lambda(i,1);
   lambdastd(i,1) = (2/T)*lambdai*lambdai*Upsilon2(itilde,itilde);
   sigmastd(i,1) = (2/T)*Upsilon2(itilde,itilde);
   for j=1:r;
      jtilde = j+(j-1)*(r+n*(p-1));
      xistdT = xistdT+(Upsilon2(itilde,jtilde));
   end;
end;

lambdastdT = lambdastd;
sigmastdT = sigmastd;

xistdT = (2/T)*xistdT*[zeros(1,T-T1) 1];

tT = [zeros(1,T-T1) 1];
t = T-1;
while t>=T1;
   R0t = R0(:,1:t);
   R1t = R1(:,1:t);
   S_00 = (1/t)*R0t*R0t';
   S_11 = (1/t)*R1t*R1t';
   S_01 = (1/t)*R0t*R1t';
   S_10 = (1/t)*R1t*R0t';
   %
   % Solving the eigenvalue problem
   %
   % Step 1: Diagonalize S_11
   %
   [W,rho] = eig(S_11);
   rho = diag(rho,0);
   [rho2,AscInd] = sort(abs(rho));
   nr = size(AscInd,1);
   DescInd = zeros(nr,1);
   for i=1:nr;
      DescInd(i)=AscInd(nr+1-i);
   end;
   %
   % Resort eigenvalues and eigenvectors
   % in descending order
   %
   rho = rho(DescInd);
   sqrho = sqrt(rho);
   rho = diag(rho,0);
   sqrho = diag(sqrho,0);
   W = W(:,DescInd);
   %
   % Step 2: Reformulating eigenvalue problem to
   %         calculating the eigenvalues for
   %
   %         adjS_11 = sqS_11*S_10*inverse(S_00)*S_01*sqS_11
   %
   sqS_11 = W*inverse(sqrho)*W';
   adjS_11 = sqS_11*S_10*inverse(S_00)*S_01*sqS_11;
   [U,lambda] = eig(adjS_11);
   lambda = diag(lambda,0);
   [lambda2,AscInd] = sort(abs(lambda));
   nr = size(AscInd,1);
   DescInd = zeros(nr,1);
   for i=1:nr;
      DescInd(i)=AscInd(nr+1-i);
   end;
   %
   % Resort eigenvalues and eigenvectors
   % in descending order
   %
   lambda = abs(lambda(DescInd));
   U = U(:,DescInd);
   %
   % Renormalize U such that V'S_11V=I
   %
   V = sqS_11*U;
   %
   beta = V(:,1:r);
   if curr_ini.transeig==1;
      tauTt = log((lambda(1:r,1)./(ones(size(lambdaT0,1),1)-lambda(1:r,1))))-log((lambdaT0./(ones(size(lambdaT0,1),1)-lambdaT0)));
   else;
      tauTt = lambda(1:r,1)-lambdaT0;
   end;
   if abs(max(lambda(1:r,1))-1)<1.0e-5;
      for i=1:r;
         if abs(lambda(i,1)-1)<1.0e-5;
            lambda(i,1) = 0.99999;
         end;
      end;
   end;
   lambdaT = [lambda(1:r,1) lambdaT];
   alpha = S_01*beta*inverse(beta'*S_11*beta);
   Omega = S_00-(alpha*beta'*S_11*beta*alpha');
   %
   %
   beta = beta(1:n,1:r);
   %
   % computing the matrix A
   %
   if p>=2;
      Phi = Psi(:,d+1:d+n*(p-1));
   end;
   if p>=2;
      A = [[(beta'*alpha)+eye(r) beta'*Phi];[alpha Phi]];
      if p>=3;
         A = [A;[zeros((p-2)*n,r) eye((p-2)*n) zeros((p-2)*n,n)]];
      end;
   else;
      A = [[(beta'*alpha)+eye(r) zeros(r,n)];[alpha zeros(n,n)]];
   end;
   %
   OmegaTilde = [[beta'*Omega*beta beta'*Omega];[Omega*beta Omega]];
   if p>=3;
      OmegaTilde = [[OmegaTilde zeros(r+n,n*(p-2))];zeros(n*(p-2),r+n*(p-1))];
   end;
   %
   % Computing the covariance matrix SigmaTilde
   %
   Ak = eye(q*q)-kron(A,A);
   %
%   if min(abs(eig(Ak)))<=1.0e-010;
   if rcond(Ak)<eps;
      status = 1;
      tauT = [];
      xisumT = [];
      xistdT = [];
      break;
      return;
   end;
   %
   Akinv = Ak\eye(q*q);
%   sigmatilde = Ak\vec(OmegaTilde);
   sigmatilde = Akinv*vec(OmegaTilde);
   SigmaTilde = vecinv(sigmatilde,q);
   SigmaTildeInv = eye(q)/SigmaTilde;
   %
   % Computing asymptotic variances
   %
%   Upsilon = kron(SigmaTildeInv,SigmaTildeInv)/Ak;
   Upsilon = kron(SigmaTildeInv,SigmaTildeInv)*Akinv;
   Upsilon2 = Upsilon+Upsilon';
   lambdastdt = zeros(r,1);
   sigmastdt = zeros(r,1);
   taut = zeros(r,1);
   xistdt = 0;
   for i=1:r;
      itilde = i+(i-1)*(r+n*(p-1));
      lambdai = (1-lambda(i,1))*lambda(i,1);
      lambdastdt(i,1) = (2/T)*lambdai*lambdai*Upsilon2(itilde,itilde);
      sigmastdt(i,1) = (2/T)*Upsilon2(itilde,itilde);
      if curr_ini.transeig==1;
         taut(i,1) = abs((t/T)*(tauTt(i,1)/sqrt(sigmastdT(i,1))));
      else;
         taut(i,1) = abs((t/T)*(tauTt(i,1)/sqrt(lambdastdT(i,1))));
      end;
      for j=1:r;
         jtilde = j+(j-1)*(r+n*(p-1));
         xistdt = xistdt+(Upsilon2(itilde,jtilde));
      end;
   end;
   xistdT(1,t-T1+1) = (2/T)*xistdt;
   tauT(:,t-T1+1) = taut;
   tT(1,t-T1+1) = (t/T);
   t = t-1;
end;

if r>1;
   xisumT = sum(log(lambdaT./(1-lambdaT)));
else;
   xisumT = log(lambdaT./(1-lambdaT));
end;

%
% End of function receigen.m
%
