/*
# runvar: written by Anders Warne anders.warne@texlips.org<10/21/2002>
#
# It starts up matlab with the structural var software using an opentional
# .var file for model input
#
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#define VAR_VERSION "0.1"
#define VAR_DATE    "2002-10-21"


#ifndef MATOPT
 #ifdef __WIN32__
  #define MATOPT "-minimize "
 #else
  #define MATOPT ""
 #endif
#endif

#ifndef SHOWMATOPT
 #ifdef __WIN32__
  #define SHOWMATOPT "minimize"
 #else
  #define SHOWMATOPT ""
 #endif
#endif

#ifndef START
 #ifdef __WIN32__
  #define START "start "
 #else
  #define START ""
 #endif
#endif

#ifndef ADDPATH
 #ifdef __WIN32__
  #define ADDPATH "\\"
 #else
  #define ADDPATH "/"
 #endif
#endif

static void usage(void)
{
	printf("\nUsage: runvar [options and/or inputfile]\n\n");
        printf("It is not necessary for the input file to have the extension '.var'.\n");
        printf("The extension is automatically appended if left out.\n\n");
        printf("Options:\n");
        printf("     --matlab-options=opt1,opt2,opt3    Comma separated list of command\n");
        printf("                                        line options for matlab, or\n");
        printf("                   -m opt1,opt2,opt3    as an alternative\n");
        printf("                                        (default is: %s)\n",SHOWMATOPT);
        printf("     --matlab-path=PATH                 Use PATH as the path to matlab.exe\n");
        printf("                -p PATH                 as an alternative\n");
        printf("                                        (default is no path, i.e. assumes\n");
        printf("                                        the matlab path is in your path\n");
        printf("                                        environment variable)\n");
        printf("     -s, --start                        Use start command under Windoze\n");
        printf("                                        (terminates var after starting matlab)\n");
        printf("     -h, --help                         Show this help screen\n");
        printf("     -v, --version                      Show version number\n\n");
        printf("NOTES:\n");
        printf("      (i) using the r option for matlab is not valid,\n");
        printf("     (ii) using -m model.var makes var assume that model.var is a matlab\n");
        printf("          option, while using -m -s model.var makes var assume that -m\n");
        printf("          includes no options,\n");
        printf("    (iii) using -p model.var does not work since model.var is not the path\n");
        printf("          to matlab.\n\n");
        printf("EXAMPLES:\n");
        printf("      runvar --matlab-options=nosplash\n");
        printf("      runvar -m nosplash,logfile=filename\n");
        printf("      runvar -m -s model.var\n");
}

static void version(void)
{
	printf("\nStructural VAR version %s\n\n",VAR_VERSION);
	printf("Copyright (c) Anders Warne 2001-2002\n");
        printf("anders.warne@texlips.org <%s>\n",VAR_DATE);
}

int main(int argc,char *argv[])
{
	FILE *in;
	char *infile=NULL,*matopt,*matlabopt,*checkext,*start,*matpath,*checkpath,*addpath;
        char helpopt[2000];
        char exten[4];
        char command[2000];
        int i,status,j,j0;

        matopt=MATOPT;
        start="";
        matpath="";
        addpath=ADDPATH;

	/******************************************************************

		Process command line options

	******************************************************************/

	for(i=1;i<argc;i++){

	  /* printf("i=%d  arg=>>%s<<\n",i,argv[i]); */

	  if(!strcmp(argv[i],"--help") || !strcmp(argv[i],"-h")){
	    usage();
	    status=0;
	    goto EXIT;
	  }

	  if(!strcmp(argv[i],"--version") || !strcmp(argv[i],"-v")){
	    version();
	    status=0;
	    goto EXIT;
	  }

	  if(argv[i][0]!='-'){
	     if(infile) printf("\nCan process only one input file\n");
	    else{
	     infile=malloc(strlen(argv[i])+1);
             strcpy(infile,argv[i]);
             for(j=1;j<=4;j++){
                j0=5-j;
                checkext=malloc(2);
                sprintf(checkext,"%c",infile[strlen(infile)-j0]);
                if(j==1){
                  sprintf(exten,"%s",checkext);
                }
                else{
                  sprintf(exten,"%s%s",exten,checkext);
                }
             }
             if(strcmp(exten,".var")){
                infile=malloc(strlen(argv[i])+5);
                strcpy(infile,argv[i]);
                strcat(infile,".var");
             }
	    }
	    continue;
	  }

	  if(!strcmp(argv[i],"--start") || !strcmp(argv[i],"-s")){
            start=malloc(7);
	    start=START;
	    continue;
	  }

          if(!strncmp(argv[i],"--matlab-path=",strlen("--matlab-path="))){
            matpath=malloc(strlen(argv[i])-strlen("--matlab-path=")+1);
	    strcpy(matpath, argv[i]+strlen("--matlab-path="));
            checkpath=malloc(2);
            sprintf(checkpath,"%c",matpath[strlen(matpath)-1]);
            if(strlen(matpath)>=1){
               if(strcmp(checkpath,addpath)){
                  sprintf(matpath,"%s%s",matpath,addpath);
               }
            }
            continue;
          }

          if(!strncmp(argv[i],"-p=",strlen("-p="))){
            matpath=malloc(strlen(argv[i])-strlen("-p=")+1);
	    strcpy(matpath, argv[i]+strlen("-p="));
            checkpath=malloc(2);
            sprintf(checkpath,"%c",matpath[strlen(matpath)-1]);
            if(strlen(matpath)>=1){
               if(strcmp(checkpath,addpath)){
                  sprintf(matpath,"%s%s",matpath,addpath);
               }
            }
            continue;
          }

          if(!strncmp(argv[i],"-p",strlen("-p"))){
            if(i+1<argc){
               matpath=malloc(strlen(argv[i+1])+1);
               strcat(matpath,argv[i+1]);
               checkpath=malloc(2);
               sprintf(checkpath,"%c",matpath[strlen(matpath)-1]);
               if(strlen(matpath)>=1){
                  if(strcmp(checkpath,addpath)){
                     sprintf(matpath,"%s%s",matpath,addpath);
                  }
               }
               if(strlen(matpath)>1){
                  checkext=malloc(2);
                  sprintf(checkext,"%c",matpath[0]);
                  if(!strcmp(checkext,"-")){
                     sprintf(matpath,"%s","");
                  }
                  else{
                     i++;
                  }
               }
            }
            continue;
          }

	  if(!strncmp(argv[i],"--matlab-options=",strlen("--matlab-options="))){
            matopt=malloc(strlen(argv[i])-strlen("--matlab-options=")+1);
	    strcpy(matopt, argv[i]+strlen("--matlab-options="));
            for(j=0;j<strlen(matopt);j++){
               if(matopt[j]!=','){
                 matlabopt=malloc(2);
                 if(matopt[j]!='='){
                    sprintf(matlabopt,"%c",matopt[j]);
                 }
                 else{
                    strcat(helpopt," ");
                 }
               }
               else{
                 matlabopt=malloc(3);
                 matlabopt=" -";
               }
               if(j>0){
                  sprintf(helpopt,"%s%s",helpopt,matlabopt);
               }
               else{
                  sprintf(helpopt,"-%s",matlabopt);
               }
            }

            /* check that -r is not included in command line */
            j0=-1;
            for(j=0;j<strlen(helpopt)-1;j++){
               matlabopt=malloc(3);
               sprintf(matlabopt,"%c%c",helpopt[j],helpopt[j+1]);
               if(!strcmp(matlabopt,"-r")){
                  j0=j;
                  j=strlen(helpopt);
               }
            }
            if(j0>=0){
               printf("\nYour matlab command line options, i.e. '%s',\n",helpopt);
               printf("includes the for runvar.exe illegal switch -r.\n");
               printf("Program execution has been aborted.\n");
               status=1;
               goto EXIT;
            }
            if(strlen(helpopt)>1){
               strcat(helpopt," ");
            }
            else{
               sprintf(helpopt,"%s","");
            }
            matopt=malloc(strlen(helpopt)+1);
            strcpy(matopt,helpopt);
	    continue;
	  }

	  if(!strncmp(argv[i],"-m=",strlen("-m="))){
            matopt=malloc(strlen(argv[i])-strlen("-m=")+1);
	    strcpy(matopt, argv[i]+strlen("-m="));
            for(j=0;j<strlen(matopt);j++){
               if(matopt[j]!=','){
                 matlabopt=malloc(2);
                 if(matopt[j]!='='){
                    sprintf(matlabopt,"%c",matopt[j]);
                 }
                 else{
                    strcat(helpopt," ");
                 }
               }
               else{
                 matlabopt=malloc(3);
                 matlabopt=" -";
               }
               if(j>0){
                  sprintf(helpopt,"%s%s",helpopt,matlabopt);
               }
               else{
                  sprintf(helpopt,"-%s",matlabopt);
               }
            }

            /* check that -r is not included in command line */
            j0=-1;
            for(j=0;j<strlen(helpopt)-1;j++){
               matlabopt=malloc(3);
               sprintf(matlabopt,"%c%c",helpopt[j],helpopt[j+1]);
               if(!strcmp(matlabopt,"-r")){
                  j0=j;
                  j=strlen(helpopt);
               }
            }
            if(j0>=0){
               printf("\nYour matlab command line options, i.e. '%s',\n",helpopt);
               printf("includes the for runvar.exe illegal switch -r.\n");
               printf("Program execution has been aborted.\n");
               status=1;
               goto EXIT;
            }
            if(strlen(helpopt)>1){
               strcat(helpopt," ");
            }
            else{
               sprintf(helpopt,"%s","");
            }
            matopt=malloc(strlen(helpopt)+1);
            strcpy(matopt,helpopt);
	    continue;
	  }


	  if(!strncmp(argv[i],"-m",strlen("-m"))){
            if(i+1<argc){
               matopt=malloc(strlen(argv[i+1])+1);
               strcpy(matopt, argv[i+1]);
               for(j=0;j<strlen(matopt);j++){
                  if(matopt[j]!=','){
                    matlabopt=malloc(2);
                    if(matopt[j]!='='){
                       sprintf(matlabopt,"%c",matopt[j]);
                    }
                    else{
                       strcat(helpopt," ");
                    }
                  }
                  else{
                    matlabopt=malloc(3);
                    matlabopt=" -";
                  }
                  if(j>0){
                     sprintf(helpopt,"%s%s",helpopt,matlabopt);
                  }
                  else{
                     sprintf(helpopt,"-%s",matlabopt);
                  }
               }

               /* check that -r is not included in command line */
               j0=-1;
               for(j=0;j<strlen(helpopt)-1;j++){
                  matlabopt=malloc(3);
                  sprintf(matlabopt,"%c%c",helpopt[j],helpopt[j+1]);
                  if(!strcmp(matlabopt,"-r")){
                     j0=j;
                     j=strlen(helpopt);
                  }
               }
               if(j0>=0){
                  printf("\nYour matlab command line options, i.e. '%s',\n",helpopt);
                  printf("includes the for runvar.exe illegal switch -r.\n");
                  printf("Program execution has been aborted.\n");
                  status=1;
                  goto EXIT;
               }
               if(strlen(helpopt)>1){
                  checkext=malloc(2);
                  sprintf(checkext,"%c%c",helpopt[0],helpopt[1]);
                  if(!strcmp(checkext,"--")){
                     sprintf(helpopt,"%s","");
                  }
                  else{
                     strcat(helpopt," ");
                     i++;
                  }
               }
               else{
                  sprintf(helpopt,"%s","");
               }
               matopt=malloc(strlen(helpopt)+1);
               strcpy(matopt,helpopt);
            }
	    continue;
	  }

	  usage();
	  fprintf(stderr,"\nunknown option <%s>\n",argv[i]);
	  status=1;
	  goto EXIT;
	}

        if(!infile){
               printf("\nExecuting the command:\n\n");
               printf("     %s%smatlab.exe %s-r var\n",start,matpath,matopt);
  	       sprintf(command,"%s%smatlab.exe %s-r var",start,matpath,matopt);
        }
        else{
               printf("\nExecuting the command:\n\n");
               printf("     %s%smatlab.exe %s-r runvar('%s')\n",start,matpath,matopt,infile);
               sprintf(command,"%s%smatlab.exe %s-r runvar('%s')",start,matpath,matopt,infile);
        }

        status=system(command);

        EXIT:

        free(infile);
        free(matopt);

        return status;

}
