function outvec = trace_exoi0_dist(n,p,pe,q0,critvalnum,deterselect,d,beta,S_01,M_02,M_12,M_22,Z0,Z1,Z2)

outvec = zeros(n,1);

if critvalnum==1;
   cval = 0.99;
elseif critvalnum==2;
   cval = 0.98;
elseif critvalnum==3;
   cval = 0.95;
elseif critvalnum==4;
   cval = 0.90;
elseif critvalnum==5;
   cval = 0.80;
elseif critvalnum>=50;
   cval = critvalnum/100;
end;

%
% compute critical values for trace test when there are exogenous I(0) variables based on the approach suggested
% by Boswijk and Doornik (2005) in Journal of Applied Econometrics
%
orig_beta = beta;
Z = Z2(d+(n*(p-1))+1:size(Z2,1),:);
T = size(Z,2);
%
% compute the long-run variance for
%
Z_t = Z(1:q0,:);
O_zz = (1/T)*Z_t*Z_t';

for i=1:round(0.9*T);
   G = (1/T)*Z_t(:,1:T-i)*Z_t(:,1+i:T)';
   ch = O_zz+(G+G');
   h = min(eig(ch));
   if h>=0;
      O_zz = ch;
   end;
end;

H = eye(q0);
for i=1:pe;
   H = [H;eye(q0)];
end;

for i=1:n;
   %
   % 1. Estimate the canonical correlations between the common trends and the common trends+accumulated exogenous I(0) variables
   % using Andrews kernel method
   %
   if i>1;
      beta = orig_beta(:,1:i-1);
   else;
      beta = [];
   end;
   %
   % determine the parameters of the VEC
   %
   if i>1;
      alpha = S_01*beta;
      alpha_orth = null(alpha');
      Psi = (M_02/M_22)-(alpha*beta'*(M_12/M_22));
      Phi = Psi(:,d+(n*(p-1))+1:size(Z2,1));
      epsilon = Z0-(Psi*Z2)-(alpha*beta'*Z1);
   else;
      alpha = [];
      alpha_orth = eye(n);
      Psi = (M_02/M_22);
      Phi = Psi(:,d+(n*(p-1))+1:size(Z2,1));
      epsilon = Z0-(Psi*Z2);
   end;
   %
   % and now compute the long-run variances
   %
   Omega = (1/T)*epsilon*epsilon';
   O_11 = alpha_orth'*Omega*alpha_orth;
   %
   D = Phi*H;
   %
   O_uz = zeros(n,q0);
   for j=1:round(0.9*T);
      G = (1/T)*epsilon(:,1:T-j)*Z_t(:,1+j:T)';
      ch = [Omega Omega+((O_uz+G)*D');Omega+(D*(O_uz+G)') Omega+((O_uz+G)*D')+(D*(O_uz+G)')+(D*O_zz*D')];
      if min(eig(ch))>0;
         O_uz = O_uz+G;
      end;
   end;
   O_uv = Omega+(O_uz*D');
   O_vv = Omega+(O_uz*D')+(D*O_uz')+(D*O_zz*D');
   O_12 = alpha_orth'*O_uv*alpha_orth;
   O_22 = alpha_orth'*O_vv*alpha_orth;
   %
   % compute the canonical correlations
   %
   O_adj = symm(O_11);
   O_f = inverse(O_adj)*O_12*inverse(O_22)*O_12'*inverse(O_adj);
   rho = eig(O_f);
   rho = reverse(sort(rho));
   a = (rho>1);
   %
   % check if a containts true
   %
   if max(a)==1;
      for j=1:size(a,1);
         if a(j,1)==1;
%            if rho(j,1)-1.0e-06<=1;
               rho(j,1) = 1;
%            end;
         else;
            break;
         end;
      end;
   end;
   if (max(rho)<=1)&(min(rho)>=0);
      %
      % we have obtained valid canonical correlations
      %
      if deterselect(1,1)==1;
         %
         % unrestricted constant
         %
         mom = [1 2;8.35 15.0;19.7 33.35;34.75 56.3;54.0 84.35;77.0 119.9;104.05 163.35;135.2 211.1;169.85 255.2;209.4 327.25;252.0 382.75;299.15 462.35];
         if (n-i+1)<=12;
            E_T = mom(n-i+1,1);
            V_T = mom(n-i+1,2);
         else;
            y = mom(2:12,:);
            x = [ones(1,11);[1 zeros(1,10)];(2:1:12);((2:1:12) .* (2:1:12))]';
            b = inverse(x'*x)*x'*y;
            res = [1 0 (n-i+1) (n-i+1)*(n-i+1)]*b;
            E_T = res(1,1);
            V_T = res(1,2);
         end;
         C_T = -1.3;
         q = (n-i+1);
      elseif deterselect(1,2)==1;
         %
         % restricted constant
         %
         E_T = (2*(n-i+1)*(n-i+1))+(2.01*(n-i+1));
         V_T = (3*(n-i+1)*(n-i+1))+(3.6*(n-i+1))+0.75;
         if (n-i+1)==1;
            E_T = E_T+0.06;
            V_T = V_T-0.4;
         elseif (n-i+1)==2;
            E_T = E_T+0.05;
            V_T = V_T-0.3;
         end;
         C_T = -1.066;
         q = (n-i+2);
      elseif deterselect(1,3)==1;
         %
         % unrestricted constant and linear trend
         %
         mom = [1 2;10.55 18.0;23.9 39.85;41.15 65.0;62.45 96.75;87.45 136.1;116.65 176.45;149.85 227.85;186.65 283.2;227.75 338.6;272.7 407.5;322.0 485.5];
         if (n-i+1)<=12;
            E_T = mom(n-i+1,1);
            V_T = mom(n-i+1,2);
         else;
            y = mom(2:12,:);
            x = [ones(1,11);[1 zeros(1,10)];(2:1:12);((2:1:12) .* (2:1:12))]';
            b = inverse(x'*x)*x'*y;
            res = [1 0 (n-i+1) (n-i+1)*(n-i+1)]*b;
            E_T = res(1,1);
            V_T = res(1,2);
         end;
         C_T = -1.3;
         q = (n-i+1);
      elseif deterselect(1,4)==1;
         %
         % constant and restricted linear trend
         %
         E_T = (2*(n-i+1)*(n-i+1))+(4.05*(n-i+1))+0.5;
         V_T = (3*(n-i+1)*(n-i+1))+(5.7*(n-i+1))+3.2;
         if (n-i+1)==1;
            E_T = E_T-0.23;
            V_T = V_T-1.3;
         elseif (n-i+1)==2;
            E_T = E_T-0.07;
            V_T = V_T-0.5;
         end;
         C_T = -1.35;
         q = n-i+2;
      end;
      V_Ti = (V_T/(n-i+1))-((n-i)*C_T);
      E_Q = ((1/(n-i+1))*sum(rho .* rho)*E_T)+((1-( (1/(n-i+1))*sum(rho .* rho) ))*(n-i+1)*q);
      %
      % and now the variance
      %
      v_1 = sum((rho .* rho .* rho .* rho))*V_Ti;
      v_2 = 2*q*sum( (1-(rho .* rho)) .* (1-(rho .* rho)) );
      v_3 = (4/(n-i+1))*E_T*sum( (rho .* rho) .* (1-(rho .* rho)) );
      v_4 = 0;
      if (n-i+1)>1;
         for i1=2:(n-i+1);
            for j=1:i1-1;
               v_j = sum( rho(1:j,1) .* rho(1:j,1) );
            end;
            v_4 = v_4+(rho(i1,1)*rho(i1,1)*v_j);
         end;
         v_4 = 2*v_4*C_T;
      end;
      V_Q = v_1+v_2+v_3+v_4;
      %
      % now we call the gamma distribution
      %
      outvec(i,1) = gamma_inv(cval,(E_Q*E_Q)/V_Q,V_Q/E_Q);
   end;
end;

%
% end of trace_exoi0_dist.m
%
