%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for bootstrapping the Nyblom test   %
%          on the constancy of the cointegration space           %
%                                                                %
%          Function: nyblom_bootstrap                            %
%                                                                %
%          Input:                                                %
%                       selector: case switch function           %
%                       cm: structure with model info            %
%                                                                %
%          Output:                                               %
%                                                                %
%          This version:        July 11, 2006                    %
%          Written by:          Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function nyblom_bootstrap(varargin)

%
% GUI for bootstrapping the Nyblom distributions
%

selector = varargin{1};
if (nargin==0)|(strcmp(selector,'init')==1);
   tm = varargin{2};
   if nargin>2;
      my_r_enable = 'off';
      tm.cointbeta = varargin{3};
   else;
      my_r_enable = 'on';
   end;
   if isfield(tm,'restrict')==0;
      tm.restrict = [0 0];
   end;
   if tm.restrict(1,1)==1;
      tm.restalpha = 'alpha-';
   else;
      tm.restalpha = '';
   end;
   if tm.restrict(1,2)==1;
      tm.restbeta = 'beta-';
   else;
      tm.restbeta = '';
   end;
   tm.usealtmodel = 0;
   %
   % toolbar images
   %
   button_images = read_images;
   %
   % more initialization
   %
   selector = 'init';
   my_exit = 1;
   tm.const_model = [0 0 0 0 0];
   if tm.deterselect(1)==1;
      tm.const_model(3) = 1;
   elseif tm.deterselect(2)==1
      tm.const_model(2) = 1;
   elseif tm.deterselect(3)==1;
      tm.const_model(5) = 1;
   else;
      tm.const_model(4) = 1;
   end;
   selector = 'init';
   %
   % Set screen size directly instead of using
   % get(0,'ScreenSize')!
   %
   tm.realscrsz = get(0,'ScreenSize');
   tm.nyblom_run = 0;
   %
   % read var.in
   %
   curr_ini = find_inisettings;
   if curr_ini.fullrec==1;
      tm.updating = 'fixed-';
   else;
      tm.updating = 'updated-';
   end;
   if curr_ini.taylor_nyblom==1;
      test_str = '(first-order Taylor expansion version)';
      tm.testtype = 'hj-';
   else;
      test_str = '(scores version)';
      tm.testtype = 's-';
   end;
   my_T = tm.T;
   rep = curr_ini.nRep;
   repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
   nRep_value = 1;
   for i=1:size(repvalues,2);
      if curr_ini.nRep==repvalues(1,i);
         nRep_value = i;
         break;
      end;
   end;
   if direxist(curr_ini.simulatedir)==0;
      mystatus = makedirs(curr_ini.simulatedir);
   else;
      mystatus = 2;
   end;
   if mystatus==0;
      curr_ini.simulatedir = pwd;
      if ispc==1;
         curr_ini.simulatedir = [curr_ini.simulatedir '\'];
      end;
   end;
   if isnumeric(curr_ini.external)==0;
      curr_ini.external = 0;
   end;
   %
   % check if an alternative model exists and if so load it
   %
   alt_mat = '';
   tm.altmodel = [];
   if tm.const_model(1)==1;
      alt_mat = [tm.outputdir  tm.modelfile '-nyblom-boot-alt-' num2str(tm.n) '-noconst.mat'];
   elseif tm.const_model(2)==1;
      alt_mat = [tm.outputdir  tm.modelfile '-nyblom-boot-alt-' num2str(tm.n) '-resconst.mat'];
   elseif tm.const_model(3)==1;
      alt_mat = [tm.outputdir  tm.modelfile '-nyblom-boot-alt-' num2str(tm.n) '-const.mat'];
   elseif tm.const_model(4)==1;
      alt_mat = [tm.outputdir  tm.modelfile '-nyblom-boot-alt-' num2str(tm.n) '-restrend.mat'];
   elseif tm.const_model(5)==1;
      alt_mat = [tm.outputdir  tm.modelfile '-nyblom-boot-alt-' num2str(tm.n) '-trend.mat'];
   end;
   if fileexist(alt_mat)==1;
      alt_info = load(alt_mat);
      if isfield(alt_info,'altmodel')==1;
         tm.altmodel = alt_info.altmodel;
         if isfield(tm.altmodel,'temprank')==0;
            tm.altmodel.temprank = 1;
            tm.altmodel.permrank = 1;
         else;
            if sum(tm.restrict)>0;
               tm.altmodel.temprank = 1;
               tm.altmodel.permrank = 1;
            end;
         end;
         if isfield(tm.altmodel,'tempcoidet')==0;
            tm.altmodel.tempcoidet = 0;
            tm.altmodel.permcoidet = 0;
         end;
         if isfield(tm.altmodel,'tempshortrun')==0;
            tm.altmodel.tempshortrun = 0;
            tm.altmodel.permshortrun = 0;
         else;
            if ((size(tm.restrict,2)>2)&(tm.restrict(1,3)==1))|((tm.p==1)&(tm.q1+tm.q0==0));
               tm.altmodel.tempshortrun = 0;
               tm.altmodel.permshortrun = 0;
            end;
         end;
         if isfield(tm.altmodel,'bootlr')==0;
            tm.altmodel.bootlr = 0;
         end;
      end;
   end;
   %
   if curr_ini.parametric==1;
      bootstyle = '';
   else;
      bootstyle = ['np' num2str(curr_ini.blocksize) '-'];
   end;
   full_mat = '';
   if tm.const_model(1)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
   elseif tm.const_model(2)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
   elseif tm.const_model(3)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
   elseif tm.const_model(4)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
   elseif tm.const_model(5)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
   end;
   if fileexist(full_mat)==1;
      full_enable = 'on';
      view_enable = 'on';
      if rep>=5000;
         this_text = strvcat(' ',['Collecting data from ' getfilename(full_mat) '...'],'Please hold!');
         mywait = waitdlg(this_text,'information');
         waitf = get(mywait,'UserData');
      end;
      nyblom_mat = load(full_mat);
      nyblom_data = [nyblom_mat.NyblomMax nyblom_mat.NyblomMean];
      if isfield(nyblom_mat,'boot_lr_test')==1;
         nyblom_data = [nyblom_data nyblom_mat.boot_lr_test];
         tm.lr_df = nyblom_mat.lr_df;
         tm.lr_test = nyblom_mat.lr_test;
      else;
         tm.lr_df = [];
      end;
      if rep>=5000;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
      end;
   else;
      view_enable = 'off';
      nyblom_data = [];
      full_mat = '';
      full_enable = 'off';
      tm.lr_df = [];
   end;
   summary_txt = '';
   if tm.const_model(1)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-summary-' bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.txt'];
      mod_type = 'noconst';
   elseif tm.const_model(2)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-summary-' bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
      mod_type = 'resconst';
   elseif tm.const_model(3)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-summary-' bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
      mod_type = 'const';
   elseif tm.const_model(4)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-summary-' bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
      mod_type = 'restrend';
   elseif tm.const_model(5)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-summary-' bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
      mod_type = 'trend';
   end;
%   if curr_ini.texoutputformat>=2;
%      summary_txt = strrep(summary_txt,'.txt','.ltx');
%   end;
   if fileexist(summary_txt)==1;
      summary_enable = 'on';
   else;
      summary_txt = '';
      summary_enable = 'off';
   end;
   %
   % check if file with bootstrapped residuals exists
   %
   epsfile = [curr_ini.simulatedir tm.modelfile '-' tm.restalpha tm.restbeta tm.updating tm.testtype 'epsilon-' num2str(tm.scale_endo,'%0.4f') '-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '-' num2str(rep) '-' mod_type '.mat'];
   testfile = strrep(epsfile,'.mat','-testdata.mat');
   if (strcmp(full_enable,'on')==1)&(fileexist(epsfile)==1)&(fileexist(testfile)==1);
      boot_enable = 'on';
   else;
      epsfile = '';
      testfile = '';
      boot_enable = 'off';
   end;
   %
   tm.interpolate = curr_ini.interpolate;
   if strcmp(tm.interpolate,'nearest')==1;
      tm.interpolate_value = 1;
   elseif strcmp(tm.interpolate,'linear')==1;
      tm.interpolate_value = 2;
   elseif strcmp(tm.interpolate,'spline')==1;
      tm.interpolate_value = 3;
   elseif strcmp(tm.interpolate,'cubic')==1;
      tm.interpolate_value = 4;
   elseif strcmp(tm.interpolate,'knorm')==1;
      tm.interpolate_value = 5;
   elseif strcmp(tm.interpolate,'kepan')==1;
      tm.interpolate_value = 6;
   elseif strcmp(tm.interpolate,'krect')==1;
      tm.interpolate_value = 7;
   elseif strcmp(tm.interpolate,'ktria')==1;
      tm.interpolate_value = 8;
   elseif strcmp(tm.interpolate,'kbiwe')==1;
      tm.interpolate_value = 9;
   elseif strcmp(tm.interpolate,'ktriw')==1;
      tm.interpolate_value = 10;
   elseif strcmp(tm.interpolate,'klapl')==1;
      tm.interpolate_value = 11;
   elseif strcmp(tm.interpolate,'klogi')==1;
      tm.interpolate_value = 12;
   end;
else;
   my_exit = 0;
   nyblom_boot_gui = findobj('Type','figure','Tag','NyblomBoot')';
   boot_nyblom = get(nyblom_boot_gui,'UserData');
   curr_ini = get(boot_nyblom.matfilebutton,'UserData');
   tm = curr_ini.models;
   button_images = curr_ini.images;
   if (get(boot_nyblom.experiments,'Value')>1)&(strcmp(selector,'simulate')==1);
      selector = 'montecarlo';
   end;
end;

switch selector
case 'init'
   nyblom_boot_gui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','nyblom_bootstrap.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(tm.realscrsz(3)-560)/2 (tm.realscrsz(4)-410)/2 560 410], ...
         'Tag','NyblomBoot', ...
         'Visible','off', ...
         'Resize','off', ...
         'Name','Bootstrap Distributions for Nyblom Tests', ...
         'NumberTitle','off', ...
         'CloseRequestFcn','nyblom_bootstrap done', ...
         'ToolBar','none');

   if matlabnumber>=7.0;
      set(nyblom_boot_gui,'DockControl','off');
   end;

   if strcmp(curr_ini.helpexe,'')==1;
      helpenable = 'off';
   else;
      helpenable = 'on';
   end;

   %
   % File menu
   %

   filemenu = uimenu('Parent',nyblom_boot_gui, ...
      'Label','&File', ...
      'Tag','FileMenu');

   boot_nyblom.simulatemenu = uimenu('Parent',filemenu, ...
         'Label','&Run Bootstrap', ...
         'Callback','nyblom_bootstrap simulate', ...
         'Enable','on', ...
         'Accelerator','R', ...
         'Tag','SimulateMenu');

   boot_nyblom.matfilemenu = uimenu('Parent',filemenu, ...
         'Label','Save to m&at-file', ...
         'Separator','on', ...
         'Accelerator','A', ...
         'Enable',full_enable, ...
         'Callback','nyblom_bootstrap matfile', ...
         'Tag','MatFileMenu');

   boot_nyblom.summarymenu = uimenu('Parent',filemenu, ...
         'Label','&Simulation Summary', ...
         'Separator','on', ...
         'Callback','nyblom_bootstrap summary', ...
         'UserData',summary_txt, ...
         'Accelerator','S', ...
         'Enable',summary_enable, ...
         'Tag','SummaryMenu');

   boot_nyblom.fullmenu = uimenu('Parent',filemenu, ...
         'Label','&Full Simulation', ...
         'Callback','nyblom_bootstrap full', ...
         'Accelerator','F', ...
         'UserData',full_mat, ...
         'Enable',full_enable, ...
         'Tag','FullMenu');

   if curr_ini.noprint==0;
      boot_nyblom.output = uimenu('Parent',filemenu, ...
            'Label','Append to &Output', ...
            'Separator','on', ...
            'Callback','nyblom_bootstrap output', ...
            'Accelerator','O', ...
            'Enable',summary_enable, ...
            'Tag','SummaryMenu');
   end;

   uimenu('Parent',filemenu, ...
         'Label','Center &Window', ...
         'Separator','on', ...
         'Accelerator','W', ...
         'Enable','on', ...
         'Callback','center_figure_fcn', ...
         'Tag','CenterMenu');

   boot_nyblom.returnmenu = uimenu('Parent',filemenu, ...
         'Label','R&eturn', ...
         'Separator','on', ...
         'Callback','nyblom_bootstrap done', ...
         'Enable','on', ...
         'Tag','MenuFileReturn');

   boot_nyblom.filemenu = filemenu;

   %
   % Tools Menu
   %

   toolsmenu = uimenu('Parent',nyblom_boot_gui, ...
      'Label','&Tools', ...
      'Tag','ToolsMenu');

   boot_nyblom.altmodelmenu = uimenu('Parent',toolsmenu, ...
         'Label','&Select Alternative Model', ...
         'Callback','nyblom_bootstrap altmodel', ...
         'Enable','on', ...
         'Tag','AltModelMenu');

   boot_nyblom.usealtmodelmenu = uimenu('Parent',toolsmenu, ...
         'Label','&Use Alternative &Model', ...
         'Callback','nyblom_bootstrap usealtmodel', ...
         'Enable','off', ...
         'Checked','off', ...
         'Tag','UseAltModelMenu');

   %
   % Graph Menu
   %

   graphmenu = uimenu('Parent',nyblom_boot_gui, ...
      'Label','&Graphics', ...
      'Tag','GraphMenu');

   boot_nyblom.bootstrapgraphmenu = uimenu('Parent',graphmenu, ...
         'Label','Graph &Bootstrap Sample', ...
         'Callback','nyblom_bootstrap display_bootstrap', ...
         'Accelerator','B', ...
         'UserData',testfile, ...
         'Enable',boot_enable, ...
         'Tag','BootstrapGraphMenu');

   boot_nyblom.displaymenu = uimenu('Parent',graphmenu, ...
         'Label','&Graph Distribution', ...
         'Callback','nyblom_bootstrap display', ...
         'Separator','on', ...
         'Accelerator','G', ...
         'UserData',tm.const_model, ...
         'Enable',view_enable, ...
         'Tag','DisplayMenu');

   boot_nyblom.histogrammenu = uimenu('Parent',graphmenu, ...
         'Label','&Histogram of Distribution', ...
         'Callback','nyblom_bootstrap display', ...
         'Accelerator','D', ...
         'Enable',view_enable, ...
         'Tag','HistogramMenu');

   %
   % Help Menu
   %

   helpmenu = uimenu('Parent',nyblom_boot_gui, ...
      'Label','&Help', ...
      'Tag','HelpMenu');

   boot_nyblom.helpmenu = uimenu('Parent',helpmenu, ...
         'Label','&Help Topics', ...
         'Callback','help_fcn(''bootstrapping'')', ...
         'Accelerator','H', ...
         'Enable',helpenable, ...
         'Tag','HelpMenu');

   %
   % The toolbar
   %

   boot_nyblom.toolbar = uitoolbar('Parent',nyblom_boot_gui, ...
                     'HandleVisibility','off', ...
                     'Interruptible','on', ...
                     'Clipping','on');

   if (iswinxp==0)|(matlabnumber<7);
      xline([1 409 560],[0.5 1]);
   end;

   boot_nyblom.simulate = uipushtool('Parent',boot_nyblom.toolbar, ...
                      'TooltipString','Run Bootstrap', ...
                      'CData',button_images.simulate, ...
                      'ClickedCallback','nyblom_bootstrap simulate', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable','on', ...
                      'UserData',0, ...
                      'Tag','Simulate');


   boot_nyblom.matfilebutton = uipushtool('Parent',boot_nyblom.toolbar, ...
                      'TooltipString','Save to mat-file', ...
                      'CData',button_images.matfile, ...
                      'ClickedCallback','nyblom_bootstrap matfile', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',full_enable, ...
                      'Tag','MatFileButton');

   boot_nyblom.summary = uipushtool('Parent',boot_nyblom.toolbar, ...
                      'TooltipString','View Simulation Summary', ...
                      'CData',button_images.sim_summary, ...
                      'ClickedCallback','nyblom_bootstrap summary', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',summary_enable, ...
                      'Tag','SummaryButton');

   boot_nyblom.full = uipushtool('Parent',boot_nyblom.toolbar, ...
                      'TooltipString','View Full Simulation', ...
                      'CData',button_images.sim_full, ...
                      'ClickedCallback','nyblom_bootstrap full', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',full_enable, ...
                      'Tag','FullButton');

   boot_nyblom.altmodel = uipushtool('Parent',boot_nyblom.toolbar, ...
                      'TooltipString','Select Alternative Model', ...
                      'CData',button_images.power, ...
                      'ClickedCallback','nyblom_bootstrap altmodel', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable','on', ...
                      'Tag','AltModel');

   boot_nyblom.usealtmodel = uitoggletool('Parent',boot_nyblom.toolbar, ...
                      'TooltipString','Use Alternative Model', ...
                      'CData',button_images.altmodel, ...
                      'ClickedCallback','nyblom_bootstrap usealtmodel', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'State','off', ...
                      'Clipping','on', ...
                      'Enable','off', ...
                      'Tag','UseAltModel');

   if (isfield(tm,'altmodel')==1)&(isempty(tm.altmodel)==0);
      if (tm.altmodel.tempdummy==1)|(tm.altmodel.permdummy==1);
         set(boot_nyblom.usealtmodel,'Enable','on');
         set(boot_nyblom.usealtmodelmenu,'Enable','on');
      end;
   end;

   boot_nyblom.bootstrapgraph = uipushtool('Parent',boot_nyblom.toolbar, ...
                      'TooltipString','Graph Bootstrap Sample', ...
                      'CData',button_images.bootstrapsmall, ...
                      'ClickedCallback','nyblom_bootstrap display_bootstrap', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'UserData',epsfile, ...
                      'Clipping','on', ...
                      'Enable',boot_enable, ...
                      'Tag','ViewBootstrapButton');

   boot_nyblom.display = uipushtool('Parent',boot_nyblom.toolbar, ...
                      'TooltipString','Graph Distribution', ...
                      'CData',button_images.viewdist, ...
                      'ClickedCallback','nyblom_bootstrap display', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'UserData',nyblom_data, ...
                      'Clipping','on', ...
                      'Enable',view_enable, ...
                      'Tag','ViewDistButton');

   boot_nyblom.histogram = uipushtool('Parent',boot_nyblom.toolbar, ...
                      'TooltipString','Histogram of Distribution', ...
                      'CData',button_images.bars, ...
                      'ClickedCallback','nyblom_bootstrap display', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',view_enable, ...
                      'Tag','HistogramButton');

   boot_nyblom.help = uipushtool('Parent',boot_nyblom.toolbar, ...
                      'TooltipString','Help Topics', ...
                      'CData',button_images.help, ...
                      'ClickedCallback','help_fcn(''bootstrapping'')', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',helpenable, ...
                      'Tag','HelpButton');

   boot_nyblom.done = uipushtool('Parent',boot_nyblom.toolbar, ...
                      'TooltipString','Return', ...
                      'CData',button_images.continue, ...
                      'ClickedCallback','nyblom_bootstrap done', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'UserData','waiting', ...
                      'Enable','on', ...
                      'Tag','Done');

   axesbox([2 2 558 395],'Nyblom Tests',70,[0.5 1]);

   %
   % GUI Header
   %

   header_txt = ['Bootstrap Nyblom Tests ' test_str];
   desc_txt = 'Select the type of bootstrap you wish to perform, the number of observations, replications, and experiments (Monte Carlo). Press the "Run Bootstrap" button when you''re satisfied with your choices and wait for the computations to finish.';
   dialog_header_fcn([16 311 530 70],button_images.bootstrap,header_txt,desc_txt);

   %
   % Options
   %

   axesbox([16 130 155 165],'Options',35,[0.5 1]);

   boot_nyblom.clock = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 257.5 130 20], ...
      'Value',1, ...
      'String','Show elapsed time', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','TimeCheck');

   boot_nyblom.progress = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 237.5 130 20], ...
      'Value',1, ...
      'String','Show progress dialog', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ProgressCheck');

   boot_nyblom.save = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 217.5 130 20], ...
      'Value',1, ...
      'String','Save full simulation', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','SaveCheck');

   boot_nyblom.parametric = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 197.5 130 20], ...
      'Value',curr_ini.parametric, ...
      'String','Parametric bootstrap', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'Callback','nyblom_bootstrap fixobscontrol', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ParametricCheck');


   boot_nyblom.blocktext = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[45 167.5 100 20], ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Style','text', ...
      'HorizontalAlignment','left', ...
      'String','Block size:', ...
      'Enable','off', ...
      'Tag','BlockText');

   boot_nyblom.block = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[105 172.5 50 20], ...
      'Value',1, ...
      'String','1|2|3|4|5|6|7|8|9|10|11|12', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Value',curr_ini.blocksize, ...
      'Enable','off', ...
      'Callback','nyblom_bootstrap check', ...
      'Tag','BlockPopup');
   
   if curr_ini.parametric==0;
      set(boot_nyblom.blocktext,'Enable','on');
      set(boot_nyblom.block,'Enable','on');
   end;

   boot_nyblom.bootstrap = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 147.5 130 20], ...
      'Value',curr_ini.reuse_bootstrap, ...
      'String','Reuse/save residuals', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ReuseBootstrapCheck');

   axesbox([185 130 361 165],'Parameters',55,[0.5 1]);

   %
   % number of observations per replication
   %

   boot_nyblom.obstext = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 254 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'HorizontalAlignment','left', ...
      'String','Number of observations:', ...
      'Tag','ObsText');

   boot_nyblom.obs = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 259 168 20], ...
      'Value',1, ...
      'String',[num2str(my_T) '|100|200|300|400|500|600|700|800|900|1000|1100|1200|1300|1400|1500|1600|1700|1800|1900|2000|2500|3000|4000|5000|6000|7000|8000|9000|10000'], ...
      'Style','popupmenu', ...
      'UserData',my_T, ...
      'Callback','nyblom_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'Tag','ObsPopup');

   if (tm.q1+tm.q0==0)&(isempty(tm.deterfile)==1);
      set(boot_nyblom.obstext,'Enable','on');
      set(boot_nyblom.obs,'Enable','on');
   end;

   %
   % number of replications
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 226.5 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Number of replications:', ...
      'Tag','SimulText');

   boot_nyblom.rep = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 231.5 168 20], ...
      'Value',nRep_value, ...
      'String','99|999|1,999|2,999|3,999|4,999|9,999|19,999|29,999|39,999|49,999|99,999|199,999|299,999|399,999|499,999|999,999', ...
      'Style','popupmenu', ...
      'Callback','nyblom_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'UserData',rep,...
      'Enable','on', ...
      'Tag','SimulPopup');

   %
   % number of experiments
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 199 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Number of experiments:', ...
      'Tag','ExpText');

   boot_nyblom.experiments = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 204 168 20], ...
      'Value',1, ...
      'String','1|100|200|300|400|500|600|700|800|900|1,000|1,500|2,000|2,500|3,000|3,500|4,000|4,00|5,000|10,000|15,000|20,000|25,000|50,000|75,000|100,000', ...
      'Style','popupmenu', ...
      'Callback','nyblom_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'UserData',[nRep_value 1],...
      'Enable','on', ...
      'Tag','ExpPopup');

   %
   % experiments by parts
   %

   boot_nyblom.runexperimentstext = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 171.5 250 20], ...
      'Style','text', ...
      'Enable','off', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Experiments selection:', ...
      'Tag','SelectExpText');

   boot_nyblom.runexperiments = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 176.5 168 20], ...
      'Value',1, ...
      'String','Run all experiments', ...
      'Style','popupmenu', ...
      'Callback','nyblom_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'Tag','SelectExpPopup');

   %
   % number of cointegration relations
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 144 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable',my_r_enable, ...
      'HorizontalAlignment','left', ...
      'String','Number of cointegration relations:', ...
      'Tag','CointText');

   r_str = '1';
   num_r = tm.n-1;
%   if size(tm.beta,1)>tm.n;
%      num_r = tm.n;
%   end;

   for i=2:num_r;
      r_str = [r_str '|' num2str(i)];
   end;

   boot_nyblom.my_r = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 149 168 20], ...
      'Value',tm.r, ...
      'String',r_str, ...
      'Style','popupmenu', ...
      'UserData',tm.r, ...
      'Callback','nyblom_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable',my_r_enable, ...
      'Tag','CointPopup');

   %
   % Select interpolation function
   %

   axesbox([16 16 530 100],'Graphics',45,[0.5 1]);

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 74 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Interpolation function:', ...
      'Tag','InterpolateText');

   boot_nyblom.interpolate = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 79 168 20], ...
      'Value',tm.interpolate_value, ...
      'String','Nearest neighborhood|Linear|Cubic spline|Cubic|Kernel density normal|Kernel density Epanechnikov|Kernel density rectangular|Kernel density triangular|Kernel density biweight|Kernel density triweight|Kernel density Laplace|Kernel density logistic', ...
      'Callback','nyblom_bootstrap interpolate', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','InterpolatePopup');

   %
   % Number of cells for graphing density functions
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 29 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Number of cells for histograms:', ...
      'Tag','CellText');

   boot_nyblom.cells = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 34 168 20], ...
      'Value',1, ...
      'String','20|25|30|35|40|45|50|55|60|65|70|75|80|85|90|95|100', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','CellPopup');

   boot_nyblom.cdf = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 84.5 140 20], ...
      'Value',0, ...
      'String','Cumulative distribution', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','cdfCheckbox');

   boot_nyblom.adaptive = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 64.5 140 20], ...
      'Value',0, ...
      'String','Adaptive KDE method', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'Tag','adaptiveCheckbox');

   if tm.interpolate_value>=5;
      set(boot_nyblom.adaptive,'Enable','on');
   end;


   boot_nyblom.bart = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 44.5 140 20], ...
      'Value',0, ...
      'String','Bartlett corr. bootstrap', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','BartlettCheckbox');

   boot_nyblom.pqplot = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 24.5 140 20], ...
      'Value',0, ...
      'String','P-value plots, etc.', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','PQPlotCheckbox');

   if tm.nyblom_asymp==0;
      set(boot_nyblom.bart,'Enable','off');
      set(boot_nyblom.pqplot,'Enable','off');
   end;

   set(nyblom_boot_gui,'UserData',boot_nyblom,...
         'HandleVisibility','callback');

case 'usealtmodel'
   if strcmp(get(boot_nyblom.usealtmodelmenu,'Checked'),'off')==1;
      set(boot_nyblom.usealtmodelmenu,'Checked','on');
      set(boot_nyblom.usealtmodel,'State','on');
   else;
      set(boot_nyblom.usealtmodelmenu,'Checked','off');
      set(boot_nyblom.usealtmodel,'State','off');
   end;
   nyblom_bootstrap('check');
case 'altmodel'
   set(nyblom_boot_gui,'Visible','off');
   drawnow;
   %
   tm.my_r = get(boot_nyblom.my_r,'UserData');
   alt_gui = alt_model_dlg('init',tm);
   altmod_controls = get(alt_gui,'UserData');
   t_m = get(altmod_controls.tempdummy,'UserData');
   if t_m.altmodel.changed==1;
      tm.altmodel = t_m.altmodel;
   end;
   killguipid(alt_gui);
   %
   if isempty(tm.altmodel)==0;
      if (tm.altmodel.tempdummy==1)|(tm.altmodel.permdummy==1);
         set(boot_nyblom.usealtmodel,'Enable','on');
         set(boot_nyblom.usealtmodelmenu,'Enable','on');
      else;
         set(boot_nyblom.usealtmodel,'Enable','off','State','off');
         set(boot_nyblom.usealtmodelmenu,'Enable','off','Checked','off');
      end;
   end;
   curr_ini.models = tm;
   set(boot_nyblom.matfilebutton,'UserData',curr_ini);
   %
   set(nyblom_boot_gui,'Visible','on');
   drawnow;
   nyblom_bootstrap('check');
case 'output'
   if curr_ini.texoutputformat>=2;
      file = strrep(lower(get(boot_nyblom.summarymenu,'UserData')),'.txt','.ltx');
      txt_str = readtext(file);
      fout = fopen(tm.outputfile,'at');
      fprintf(fout,'\\subsection*{Bootstrap Simulation of Nyblom Tests} \n\n');
      for i=1:size(txt_str,2);
         fprintf(fout,'%s\n',txt_str{i});
      end;
      fclose(fout);
   else;
      txt_str = readtext(lower(get(boot_nyblom.summarymenu,'UserData')));
      fout = fopen(tm.outputfile,'at');
      fprintf(fout,'                      Bootstrap Simulation of Nyblom Tests\n                      ------------------------------------\n');
      for i=5:size(txt_str,2)-4;
         fprintf(fout,'%s\n',txt_str{i});
      end;
      fprintf(fout,'\n===============================================================================\n\n');
      fclose(fout);
   end;
case 'display_bootstrap'
   rep = get(boot_nyblom.rep,'UserData');
   my_r = get(boot_nyblom.my_r,'UserData');
   tm.my_r = my_r;
   my_T = get(boot_nyblom.obs,'UserData');
   %
   if rep<4999;
      answer = 'Yes';
   else;
      check_txt = ['Your bootstrap setup includes ' num2str(rep) ' draws of the residuals. With ' num2str(tm.n) ' series and ' num2str(my_T) ' observations, this yields ' num2str(rep*tm.n*my_T) ' observations. Are you sure you want to load that much data into memory?'];
      answer = query(check_txt,'warning',120,'Exit',500,'no');
   end;
   if strcmp(answer,'Yes')==1;
      epsfile = get(boot_nyblom.bootstrapgraph,'UserData');
      testfile = get(boot_nyblom.bootstrapgraphmenu,'UserData');
      txt_str = strvcat('Nyblom Mean:','Nyblom Max:');
      if isempty(tm.lr_df)==0;
         %
         % need to check if boot_lr_test is stored in testfile, i.e. if test_data has 3 columns
         %
         check_mat = load(testfile);
         if size(check_mat.test_data,2)==3;
            txt_str = strvcat(txt_str,['LR(' num2str(tm.lr_df,'%0.0f') '):']);
         end;
         clear('check_mat');
      end;
      exp_str = get(boot_nyblom.experiments,'String');
      exp_val = get(boot_nyblom.experiments,'Value');
      num_exp = mystr2num(strrep(strtrim(exp_str(exp_val,:)),',',''));
      if strcmp(get(boot_nyblom.usealtmodel,'State'),'off')==1;
         tm.usealtmodel = 0;
      else;
         tm.usealtmodel = 1;
      end;
      %
      if strcmp(get(boot_nyblom.my_r,'Enable'),'on')==1;
         mybeta = tm.beta(:,1:my_r);
      else;
         mybeta = tm.beta;
      end;
      set(nyblom_boot_gui,'Visible','off');
      drawnow;
      if num_exp==1;
         thisgraph = bootgraphdlg('init',tm,epsfile,testfile,txt_str,mybeta,rep,my_T,my_r);
      else;
         thisgraph = bootgraphdlg('init',tm,epsfile,testfile,txt_str,mybeta,num_exp,my_T,my_r);
      end;
      bootgraph = get(thisgraph,'UserData');
      set(bootgraph.show,'UserData','done');
      killguipid(thisgraph);
      tm.usealtmodel = 0;
      set(nyblom_boot_gui,'Visible','on');
      drawnow;
   end;
case 'fixobscontrol'
   if get(boot_nyblom.parametric,'Value')==0;
      T_str = get(boot_nyblom.obs,'String');
      my_T = mystr2num(strtrim(T_str(get(boot_nyblom.obs,'Value'),:)));
      set(boot_nyblom.obs,'Value',1,'UserData',my_T,'Enable','off');
      set(boot_nyblom.obstext,'Enable','off');
   elseif (tm.q1+tm.q0==0)&(isempty(tm.deterfile)==1);
      set(boot_nyblom.obs,'Enable','on');
      set(boot_nyblom.obstext,'Enable','on');
   end;
   nyblom_bootstrap('check');
case 'interpolate'
   tm.interpolate_value = get(boot_nyblom.interpolate,'Value');
   interpol_vec = strvcat('nearest','linear','spline','cubic','knorm','kepan','krect','ktria','kbiwe','ktriw','klapl','klogi');
   tm.interpolate = strtrim(interpol_vec(tm.interpolate_value,:));
   if tm.interpolate_value>=5;
      set(boot_nyblom.adaptive,'Enable','on');
   else;
      set(boot_nyblom.adaptive,'Enable','off','Value',0);
   end;
case 'matfile'
   result = get(boot_nyblom.display,'UserData');
   NyblomMax = result(:,1);
   NyblomMean = result(:,2);
   if (isempty(tm.lr_df)==0)&(size(result,2)==3);
      boot_lr_test = result(:,3);
      lr_test = tm.lr_test;
      lr_df = tm.lr_df;
   end;
   rep = get(boot_nyblom.rep,'UserData');
   my_r = get(boot_nyblom.my_r,'UserData');
   my_T = get(boot_nyblom.obs,'UserData');
   %
   if strcmp(get(boot_nyblom.usealtmodel,'State'),'off')==1;
      usealt = '';
   else;
      usealt = 'alt-';
      if tm.altmodel.tempdummy==1;
         usealt = [usealt 't-'];
         if tm.altmodel.tempcorel==1;
            usealt = [usealt 'coi-'];
            if tm.altmodel.tempcoidet==1;
               usealt = [usealt 'det-'];
            end;
            if tm.altmodel.temprank==2;
               usealt = [usealt 'inc-'];
            elseif tm.altmodel.temprank==3;
               usealt = [usealt 'dec-'];
            end;
         elseif tm.altmodel.tempshortrun==1;
            usealt = [usealt 'sr-'];
         else;
            usealt = [usealt 'con-'];
         end;
         if tm.altmodel.tempacc==1;
            usealt = [usealt 'acc-'];
         end;
      else;
         usealt = [usealt 'p-'];
         if tm.altmodel.permcorel==1;
            usealt = [usealt 'coi-'];
            if tm.altmodel.permcoidet==1;
               usealt = [usealt 'det-'];
            end;
            if tm.altmodel.permrank==2;
               usealt = [usealt 'inc-'];
            elseif tm.altmodel.permrank==3;
               usealt = [usealt 'dec-'];
            end;
         elseif tm.altmodel.permshortrun==1;
            usealt = [usealt 'sr-'];
         else;
            usealt = [usealt 'con-'];
         end;
         if tm.altmodel.permacc==1;
            usealt = [usealt 'acc-'];
         end;
      end;
      if (tm.altmodel.relsample==1)&(my_T~=tm.T);
         usealt = [usealt 'rs-'];
      end;
   end;
   if get(boot_nyblom.parametric,'Value')==1;
      bootstyle = '';
   else;
      bootstyle = ['np' num2str(get(boot_nyblom.block,'Value')) '-'];
   end;
   %
   exp_str = get(boot_nyblom.experiments,'String');
   exp_val = get(boot_nyblom.experiments,'Value');
   num_exp = mystr2num(strrep(strtrim(exp_str(exp_val,:)),',',''));
   %
   my_const_model = get(boot_nyblom.displaymenu,'UserData');
   if num_exp==1;
      if my_const_model(1)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
      elseif my_const_model(2)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
      elseif my_const_model(3)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
      elseif my_const_model(4)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
      elseif my_const_model(5)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
      end;
      Number = (1:1:rep)';
   else;
      if tm.const_model(1)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '-' num2str(rep) '-noconst.mat'];
         mod_type = 'noconst';
      elseif tm.const_model(2)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '-' num2str(rep) '-resconst.mat'];
         mod_type = 'resconst';
      elseif tm.const_model(3)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '-' num2str(rep) '-const.mat'];
         mod_type = 'const';
      elseif tm.const_model(4)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '-' num2str(rep) '-restrend.mat'];
         mod_type = 'restrend';
      elseif tm.const_model(5)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '-' num2str(rep) '-trend.mat'];
         mod_type = 'trend';
      end;
      Number = (1:1:num_exp)';
      monte_carlo = get(boot_nyblom.altmodel,'UserData');
      max_mean = monte_carlo(:,1);
      mean_mean = monte_carlo(:,2);
   end;
   if fileexist(full_mat)==1;
      my_text = ['The file "' getfilename(full_mat) '" already exists. Are you sure you want to overwrite it?'];
      answer = query(my_text,'question',120,'Save to mat-file',500,'no');
   else;
      answer = 'Yes';
   end;
   if strcmp(answer,'Yes')==1;
      setlogtext('Savings results to mat-files...');
      if num_exp==1;
         if (isempty(tm.lr_df)==1)|(size(result,2)==2);
            save(full_mat,'Number','NyblomMax','NyblomMean');
         else;
            save(full_mat,'Number','NyblomMax','NyblomMean','boot_lr_test','lr_test','lr_df');
         end;
      else;
         save(full_mat,'Number','NyblomMax','NyblomMean','max_mean','mean_mean');
      end;
   end;
case 'check'
   T_str = get(boot_nyblom.obs,'String');
   my_T = mystr2num(strtrim(T_str(get(boot_nyblom.obs,'Value'),:)));
   repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
   rep_val = get(boot_nyblom.rep,'Value');
   rep = repvalues(rep_val);
   if strcmp(get(boot_nyblom.usealtmodel,'State'),'off')==1;
      usealt = '';
   else;
      usealt = 'alt-';
      if tm.altmodel.tempdummy==1;
         usealt = [usealt 't-'];
         if tm.altmodel.tempcorel==1;
            usealt = [usealt 'coi-'];
            if tm.altmodel.tempcoidet==1;
               usealt = [usealt 'det-'];
            end;
            if tm.altmodel.temprank==2;
               usealt = [usealt 'inc-'];
            elseif tm.altmodel.temprank==3;
               usealt = [usealt 'dec-'];
            end;
         elseif tm.altmodel.tempshortrun==1;
            usealt = [usealt 'sr-'];
         else;
            usealt = [usealt 'con-'];
         end;
         if tm.altmodel.tempacc==1;
            usealt = [usealt 'acc-'];
         end;
      else;
         usealt = [usealt 'p-'];
         if tm.altmodel.permcorel==1;
            usealt = [usealt 'coi-'];
            if tm.altmodel.permcoidet==1;
               usealt = [usealt 'det-'];
            end;
            if tm.altmodel.permrank==2;
               usealt = [usealt 'inc-'];
            elseif tm.altmodel.permrank==3;
               usealt = [usealt 'dec-'];
            end;
         elseif tm.altmodel.permshortrun==1;
            usealt = [usealt 'sr-'];
         else;
            usealt = [usealt 'con-'];
         end;
         if tm.altmodel.permacc==1;
            usealt = [usealt 'acc-'];
         end;
      end;
      if (tm.altmodel.relsample==1)&(my_T~=tm.T);
         usealt = [usealt 'rs-'];
      end;
   end;
   set(boot_nyblom.rep,'UserData',rep);
   my_r = get(boot_nyblom.my_r,'Value');
   set(boot_nyblom.obs,'UserData',my_T);
   set(boot_nyblom.my_r,'UserData',my_r);
   if strcmp(get(boot_nyblom.my_r,'Enable'),'on')==1;
      tm.alpha = tm.S_01*tm.beta(:,1:my_r)*inverse(tm.beta(:,1:my_r)'*tm.S_11*tm.beta(:,1:my_r));
      if isempty(tm.Z2)==0;
         tm.Psi = tm.M_02*inverse(tm.M_22)-(tm.alpha*tm.beta(:,1:my_r)'*tm.M_12*inverse(tm.M_22));
         tm.epsilon = tm.Z0-(tm.alpha*tm.beta(:,1:my_r)'*tm.Z1)-(tm.Psi*tm.Z2);
      else;
         tm.Psi = [];
         tm.epsilon = tm.Z0-(tm.alpha*tm.beta(:,1:my_r)'*tm.Z1);
      end;
      tm.Omega = (1/tm.T)*tm.epsilon*tm.epsilon';
   end;
   if get(boot_nyblom.parametric,'Value')==1;
      bootstyle = '';
      set(boot_nyblom.blocktext,'Enable','off');
      set(boot_nyblom.block,'Enable','off','Value',1);
   else;
      if strcmp(get(boot_nyblom.block,'Enable'),'off')==1;
         set(boot_nyblom.blocktext,'Enable','on');
         set(boot_nyblom.block,'Enable','on','Value',curr_ini.blocksize);
      end;
      bootstyle = ['np' num2str(get(boot_nyblom.block,'Value')) '-'];
   end;
   %
   exp_str = get(boot_nyblom.experiments,'String');
   exp_val = get(boot_nyblom.experiments,'Value');
   num_exp = mystr2num(strrep(strtrim(exp_str(exp_val,:)),',',''));
   %
   if num_exp>1;
      low_lim = 1;
      up_lim = 0.1*num_exp;
      add_lim = up_lim;
      this_str = 'Run all experiments';
      for i=1:10;
         if tm.const_model(1)==1;
            part_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(i) '-' num2str(rep) '-noconst.mat'];
         elseif tm.const_model(2)==1;
            part_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(i) '-' num2str(rep) '-resconst.mat'];
         elseif tm.const_model(3)==1;
            part_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(i) '-' num2str(rep) '-const.mat'];
         elseif tm.const_model(4)==1;
            part_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(i) '-' num2str(rep) '-restrend.mat'];
         elseif tm.const_model(5)==1;
            part_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(i) '-' num2str(rep) '-trend.mat'];
         end;
         %
         if fileexist(part_mat)==1;
            exp_exist_str = ' (done)';
         else;
            exp_exist_str = '';
         end;
         %
         this_str = [this_str '|Run expmnts ' num2str(low_lim) '-' num2str(up_lim) exp_exist_str];
         low_lim = low_lim+add_lim;
         up_lim = up_lim+add_lim;
      end;
      low_lim = 1;
      up_lim = 0.2*num_exp;
      add_lim = up_lim;
      for i=1:5;
         num = 2*(i-1);
         if tm.const_model(1)==1;
            part_mat_1 = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(1+num) '-' num2str(rep) '-noconst.mat'];
            part_mat_2 = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(2+num) '-' num2str(rep) '-noconst.mat'];
         elseif tm.const_model(2)==1;
            part_mat_1 = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(1+num) '-' num2str(rep) '-resconst.mat'];
            part_mat_2 = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(2+num) '-' num2str(rep) '-resconst.mat'];
         elseif tm.const_model(3)==1;
            part_mat_1 = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(1+num) '-' num2str(rep) '-const.mat'];
            part_mat_2 = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(2+num) '-' num2str(rep) '-const.mat'];
         elseif tm.const_model(4)==1;
            part_mat_1 = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(1+num) '-' num2str(rep) '-restrend.mat'];
            part_mat_2 = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(2+num) '-' num2str(rep) '-restrend.mat'];
         elseif tm.const_model(5)==1;
            part_mat_1 = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(1+num) '-' num2str(rep) '-trend.mat'];
            part_mat_2 = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(2+num) '-' num2str(rep) '-trend.mat'];
         end;
         %
         if (fileexist(part_mat_1)==1)&(fileexist(part_mat_2)==1);
            exp_exist_str = ' (done)';
         else;
            exp_exist_str = '';
         end;
         %
         this_str = [this_str '|Run expmnts ' num2str(low_lim) '-' num2str(up_lim) exp_exist_str];
         low_lim = low_lim+add_lim;
         up_lim = up_lim+add_lim;
      end;
      set(boot_nyblom.runexperiments,'Enable','on','String',this_str);
      set(boot_nyblom.runexperimentstext,'Enable','on');
   else;
      set(boot_nyblom.runexperiments,'Enable','off','String','Run all experiments','Value',1);
      set(boot_nyblom.runexperimentstext,'Enable','off');
   end;
   %
   % adjusting the view text buttons
   %
   if num_exp==1;
      full_mat = '';
      if tm.const_model(1)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
         mod_type = 'noconst';
      elseif tm.const_model(2)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
         mod_type = 'resconst';
      elseif tm.const_model(3)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
         mod_type = 'const';
      elseif tm.const_model(4)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
         mod_type = 'restrend';
      elseif tm.const_model(5)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
         mod_type = 'trend';
      end;
      if fileexist(full_mat)==1;
         full_enable = 'on';
         if rep>=5000;
            this_text = strvcat(' ',['Collecting data from ' getfilename(full_mat) '...'],'Please hold!');
            mywait = waitdlg(this_text,'information');
            waitf = get(mywait,'UserData');
         end;
         nyblom_mat = load(full_mat);
         nyblom_data = [nyblom_mat.NyblomMax nyblom_mat.NyblomMean];
         %
         if isfield(nyblom_mat,'boot_lr_test')==1;
            nyblom_data = [nyblom_data nyblom_mat.boot_lr_test];
            tm.lr_df = nyblom_mat.lr_df;
            tm.lr_test = nyblom_mat.lr_test;
         else;
            tm.lr_df = [];
         end;
         %
         if rep>=5000;
            set(waitf.text,'UserData','done');
            delete(mywait);
            drawnow;
         end;
         %
         % adjusting the Graph Distrbution button
         %
         set(boot_nyblom.display,'Enable','on','UserData',nyblom_data);
         set(boot_nyblom.displaymenu,'Enable','on','UserData',tm.const_model);
         set(boot_nyblom.histogram,'Enable','on');
         set(boot_nyblom.histogrammenu,'Enable','on');
         set(boot_nyblom.matfilebutton,'Enable','on');
         set(boot_nyblom.matfilemenu,'Enable','on');
      else;
         tm.lr_df = [];
         full_mat = '';
         full_enable = 'off';
         set(boot_nyblom.display,'Enable','off','UserData',[]);
         set(boot_nyblom.displaymenu,'Enable','off','UserData',tm.const_model);
         set(boot_nyblom.histogram,'Enable','off');
         set(boot_nyblom.histogrammenu,'Enable','off');
         set(boot_nyblom.matfilebutton,'Enable','off');
         set(boot_nyblom.matfilemenu,'Enable','off');
      end;
      %
      % Checking if residuals file exists
      %
      epsfile = [curr_ini.simulatedir tm.modelfile '-' usealt tm.restalpha tm.restbeta tm.updating tm.testtype 'epsilon-' num2str(tm.scale_endo,'%0.4f') '-' bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(rep) '-' mod_type '.mat'];
      testfile = strrep(epsfile,'.mat','-testdata.mat');
      if (strcmp(full_enable,'on')==1)&(fileexist(epsfile)==1)&(fileexist(testfile)==1);
         set(boot_nyblom.bootstrapgraph,'Enable','on','UserData',epsfile);
         set(boot_nyblom.bootstrapgraphmenu,'Enable','on','UserData',testfile);
      else;
         set(boot_nyblom.bootstrapgraph,'Enable','off','UserData',[]);
         set(boot_nyblom.bootstrapgraphmenu,'Enable','off','UserData','');
      end;
      %
      set(boot_nyblom.fullmenu,'Enable',full_enable,'UserData',full_mat);
      set(boot_nyblom.full,'Enable',full_enable);
      summary_txt = '';
      if tm.const_model(1)==1;
         summary_txt = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-summary-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-noconst.txt'];
      elseif tm.const_model(2)==1;
         summary_txt = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-summary-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
      elseif tm.const_model(3)==1;
         summary_txt = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-summary-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
      elseif tm.const_model(4)==1;
         summary_txt = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-summary-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
      elseif tm.const_model(5)==1;
         summary_txt = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-summary-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
      end;
%      if curr_ini.texoutputformat>=2;
%         summary_txt = strrep(summary_txt,'.txt','.ltx');
%      end;
      if fileexist(summary_txt)==1;
         summary_enable = 'on';
      else;
         summary_txt = '';
         summary_enable = 'off';
      end;
      if curr_ini.noprint==0;
         set(boot_nyblom.output,'Enable',summary_enable);
      end;
      set(boot_nyblom.altmodel,'UserData',[]);
      set(boot_nyblom.summarymenu,'Enable',summary_enable,'UserData',summary_txt);
      set(boot_nyblom.summary,'Enable',summary_enable);
      set(nyblom_boot_gui,'UserData',boot_nyblom);
   else;
      full_mat = '';
      if tm.const_model(1)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '-' num2str(rep) '-noconst.mat'];
         mod_type = 'noconst';
      elseif tm.const_model(2)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '-' num2str(rep) '-resconst.mat'];
         mod_type = 'resconst';
      elseif tm.const_model(3)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '-' num2str(rep) '-const.mat'];
         mod_type = 'const';
      elseif tm.const_model(4)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '-' num2str(rep) '-restrend.mat'];
         mod_type = 'restrend';
      elseif tm.const_model(5)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '-' num2str(rep) '-trend.mat'];
         mod_type = 'trend';
      end;
      if fileexist(full_mat)==1;
         full_enable = 'on';
         if num_exp>=5000;
            this_text = strvcat(' ',['Collecting data from ' getfilename(full_mat) '...'],'Please hold!');
            mywait = waitdlg(this_text,'information');
            waitf = get(mywait,'UserData');
         end;
         nyblom_mat = load(full_mat);
         nyblom_data = [nyblom_mat.NyblomMax nyblom_mat.NyblomMean];
         nyblom_mcdata = [nyblom_mat.max_mean nyblom_mat.mean_mean];
         %
         if isfield(nyblom_mat,'boot_lr_test')==1;
            nyblom_data = [nyblom_data nyblom_mat.boot_lr_test];
            if isfield(nyblom_mat,'lr_mean')==1;
               nyblom_mcdata = [nyblom_mcdata nyblom_mat.lr_mean];
            end;
            tm.lr_df = nyblom_mat.lr_df;
            tm.lr_test = nyblom_mat.lr_test;
         else;
            tm.lr_df = [];
         end;
         %
         if num_exp>=5000;
            set(waitf.text,'UserData','done');
            delete(mywait);
            drawnow;
         end;
         %
         % adjusting the Graph Distrbution button
         %
         set(boot_nyblom.display,'Enable','on','UserData',nyblom_data);
         set(boot_nyblom.altmodel,'UserData',nyblom_mcdata);
         set(boot_nyblom.displaymenu,'Enable','on','UserData',tm.const_model);
         set(boot_nyblom.histogram,'Enable','on');
         set(boot_nyblom.histogrammenu,'Enable','on');
         set(boot_nyblom.matfilebutton,'Enable','on');
         set(boot_nyblom.matfilemenu,'Enable','on');
      else;
         full_mat = '';
         full_enable = 'off';
         tm.lr_df = [];
         set(boot_nyblom.display,'Enable','off','UserData',[]);
         set(boot_nyblom.altmodel,'UserData',[]);
         set(boot_nyblom.displaymenu,'Enable','off','UserData',tm.const_model);
         set(boot_nyblom.histogram,'Enable','off');
         set(boot_nyblom.histogrammenu,'Enable','off');
         set(boot_nyblom.matfilebutton,'Enable','off');
         set(boot_nyblom.matfilemenu,'Enable','off');
      end;
      %
      % Checking if residuals file exists
      %
      epsfile = [curr_ini.simulatedir tm.modelfile '-' usealt tm.restalpha tm.restbeta tm.updating tm.testtype 'epsilon-' num2str(tm.scale_endo,'%0.4f') '-' bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '-' num2str(rep) '-' mod_type '.mat'];
      testfile = strrep(epsfile,'.mat','-testdata.mat');
      if (strcmp(full_enable,'on')==1)&(fileexist(epsfile)==1)&(fileexist(testfile)==1);
         set(boot_nyblom.bootstrapgraph,'Enable','on','UserData',epsfile);
         set(boot_nyblom.bootstrapgraphmenu,'Enable','on','UserData',testfile);
      else;
         set(boot_nyblom.bootstrapgraph,'Enable','off','UserData',[]);
         set(boot_nyblom.bootstrapgraphmenu,'Enable','off','UserData','');
      end;
      %
      set(boot_nyblom.fullmenu,'Enable',full_enable,'UserData',full_mat);
      set(boot_nyblom.full,'Enable',full_enable);
      summary_txt = '';
      if tm.const_model(1)==1;
         summary_txt = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-summary-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '-' num2str(rep) '-noconst.txt'];
      elseif tm.const_model(2)==1;
         summary_txt = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-summary-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '-' num2str(rep) '-resconst.txt'];
      elseif tm.const_model(3)==1;
         summary_txt = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-summary-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '-' num2str(rep) '-const.txt'];
      elseif tm.const_model(4)==1;
         summary_txt = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-summary-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '-' num2str(rep) '-restrend.txt'];
      elseif tm.const_model(5)==1;
         summary_txt = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-summary-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '-' num2str(rep) '-trend.txt'];
      end;
%      if curr_ini.texoutputformat>=2;
%         summary_txt = strrep(summary_txt,'.txt','.ltx');
%      end;
      if fileexist(summary_txt)==1;
         summary_enable = 'on';
      else;
         summary_txt = '';
         summary_enable = 'off';
      end;
      if curr_ini.noprint==0;
         set(boot_nyblom.output,'Enable',summary_enable);
      end;
      set(boot_nyblom.summarymenu,'Enable',summary_enable,'UserData',summary_txt);
      set(boot_nyblom.summary,'Enable',summary_enable);
      set(nyblom_boot_gui,'UserData',boot_nyblom);
   end;
case 'summary'
   set(nyblom_boot_gui,'Visible','off');
   drawnow;
   %
   exp_str = get(boot_nyblom.experiments,'String');
   exp_val = get(boot_nyblom.experiments,'Value');
   num_exp = mystr2num(strrep(strtrim(exp_str(exp_val,:)),',',''));
   %
   file = lower(get(boot_nyblom.summarymenu,'UserData'));
   if strcmp(lower(getext(file)),'.ltx')==1;
      newfile = [file(1:size(file,2)-4) '.txt'];
      if fileexist(newfile)==1;
         file = newfile;
      end;
   end;
   if num_exp==1;
      pos = [(tm.realscrsz(3)-700)/2 (tm.realscrsz(4)-500)/2 700 500];
   else;
      if tm.realscrsz(3)>=980;
         pos = [(tm.realscrsz(3)-980)/2 (tm.realscrsz(4)-600)/2 980 600];
      else;
         pos = [0 (tm.realscrsz(4)-550)/2 tm.realscrsz(3) 550]
      end;
   end;
   prtgui = printgui('init',file,'Structural VAR - Nyblom Tests Simulation Summary',pos,'Results',40);
   myprint = get(prtgui,'UserData');
   set(myprint.print,'UserData','done');
   killguipid(prtgui);
   set(nyblom_boot_gui,'Visible','on');
   drawnow;
   set(nyblom_boot_gui,'UserData',boot_nyblom);
case 'full'
   set(nyblom_boot_gui,'Visible','off');
   drawnow;
   rep = get(boot_nyblom.rep,'UserData');
   %
   exp_str = get(boot_nyblom.experiments,'String');
   exp_val = get(boot_nyblom.experiments,'Value');
   num_exp = mystr2num(strrep(strtrim(exp_str(exp_val,:)),',',''));
   %
   if num_exp==1;
      rep_times = rep;
   else;
      rep_times = num_exp;
   end;
   %
   full_mat = lower(get(boot_nyblom.fullmenu,'UserData'));
   abort = '';
   if rep_times>=5000;
      input_var.title = ['Progress for ' int2str(rep) ' replications'];
      input_var.facecolor = curr_ini.progress_facecolor;
      input_var.startfacecolor = curr_ini.progress_startfacecolor;
      input_var.edgecolor = curr_ini.progress_edgecolor;
      input_var.bgcolor = curr_ini.progress_bgcolor;
      input_var.label = 'Replication number:';
      input_var.stop = 0;
      input_var.clock = 1;
      input_var.name = ['Data in ' getname(full_mat)];
      mywait = progressdlg(0,input_var);
%      set(mywait,'Name',['Data in ' getname(full_mat)]);
      set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
      drawnow;
   end;
   nyblom_mat = load(full_mat);
   my_data = [nyblom_mat.Number nyblom_mat.NyblomMax nyblom_mat.NyblomMean];
   add_lr_test = 0;
   sp_str = spacestr(curr_ini.decimals-2);
   my_text = strvcat(' ',[' Number      Max-test  ' sp_str '  Mean-test'],' ');
   if isfield(nyblom_mat,'boot_lr_test')==1;
      my_data = [my_data nyblom_mat.boot_lr_test];
      add_lr_test = 1;
      my_text = strvcat(' ',[' Number      Max-test ' sp_str '   Mean-test ' sp_str '  LR-test'],' ');
   end;
   for i=1:size(my_data,1);
      if rep_times>=5000;
         abort = get(mywait,'UserData');
         if strcmp(abort,'cancel')==1;
            break;
         else;
            progressdlg([(i/rep_times) i]);
         end;
      end;
      first_str = '';
      for j=1:7-size(num2str(my_data(i,1),'%0.0f'),2);
         first_str = [first_str ' '];
      end;
      if add_lr_test==0;
         my_text = strvcat(my_text,sprintf(['%7.0f  %' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f    %' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'],my_data(i,1),my_data(i,2),my_data(i,3)));
      else;
         my_text = strvcat(my_text,sprintf(['%7.0f  %' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f    %' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f    %' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'],my_data(i,1),my_data(i,2),my_data(i,3),my_data(i,4)));
      end;
   end;
   my_text = strvcat(my_text,' ');
   if rep_times>=5000;
      set(mywait,'UserData','done');
      close(mywait);
      drawnow;
   end;
   if strcmp(abort,'cancel')==0;
      textgui(my_text,'Structural VAR - Nyblom Tests Simulation',[(tm.realscrsz(3)-700)/2 (tm.realscrsz(4)-500)/2 700 500],'Results',40);
   end;
   set(nyblom_boot_gui,'Visible','on');
   drawnow;
   set(nyblom_boot_gui,'UserData',boot_nyblom);
case 'display'
   result = get(boot_nyblom.display,'UserData');
   pos = [(tm.realscrsz(3)-600)/2 (tm.realscrsz(4)-400)/2];
   NyblomMax = result(:,1);
   NyblomMean = result(:,2);
   %
   if (isempty(tm.lr_df)==0)&(size(result,2)==3);
      boot_lr_test = result(:,3);
   end;
   %
   rep = get(boot_nyblom.rep,'UserData');
   my_r = get(boot_nyblom.my_r,'UserData');
   my_T = get(boot_nyblom.obs,'UserData');
   my_const_model = get(boot_nyblom.displaymenu,'UserData');
   %
   exp_str = get(boot_nyblom.experiments,'String');
   exp_val = get(boot_nyblom.experiments,'Value');
   num_exp = mystr2num(strrep(strtrim(exp_str(exp_val,:)),',',''));
   %
   % check if we should display mean distributions as well
   %
   if num_exp>1;
      monte_carlo = get(boot_nyblom.altmodel,'UserData');
      max_mean = monte_carlo(:,1);
      mean_mean = monte_carlo(:,2);
      if size(monte_carlo,2)==3;
         lr_mean = monte_carlo(:,3);
      else;
         lr_mean = [];
      end;
   else;
      max_mean = [];
      mean_mean = [];
      lr_mean = [];
   end;
   %
   if strcmp(get(boot_nyblom.usealtmodel,'State'),'off')==1;
      usealt = '';
   else;
      usealt = 'alt-';
      if tm.altmodel.tempdummy==1;
         usealt = [usealt 't-'];
         if tm.altmodel.tempcorel==1;
            usealt = [usealt 'coi-'];
            if tm.altmodel.tempcoidet==1;
               usealt = [usealt 'det-'];
            end;
            if tm.altmodel.temprank==2;
               usealt = [usealt 'inc-'];
            elseif tm.altmodel.temprank==3;
               usealt = [usealt 'dec-'];
            end;
         elseif tm.altmodel.tempshortrun==1;
            usealt = [usealt 'sr-'];
         else;
            usealt = [usealt 'con-'];
         end;
         if tm.altmodel.tempacc==1;
            usealt = [usealt 'acc-'];
         end;
      else;
         usealt = [usealt 'p-'];
         if tm.altmodel.permcorel==1;
            usealt = [usealt 'coi-'];
            if tm.altmodel.permcoidet==1;
               usealt = [usealt 'det-'];
            end;
            if tm.altmodel.permrank==2;
               usealt = [usealt 'inc-'];
            elseif tm.altmodel.permrank==3;
               usealt = [usealt 'dec-'];
            end;
         elseif tm.altmodel.permshortrun==1;
            usealt = [usealt 'sr-'];
         else;
            usealt = [usealt 'con-'];
         end;
         if tm.altmodel.permacc==1;
            usealt = [usealt 'acc-'];
         end;
      end;
      if (tm.altmodel.relsample==1)&(my_T~=tm.T);
         usealt = [usealt 'rs-'];
      end;
   end;
   %
   if my_const_model(1)==1;
      this_mod = '(no constant)';
   elseif my_const_model(2)==1;
      this_mod = '(restricted constant)';
   elseif my_const_model(3)==1;
      this_mod = '(constant)';
   elseif my_const_model(4)==1;
      this_mod = '(restricted trend)';
   elseif my_const_model(5)==1;
      this_mod = '(trend)';
   end;
   cell_value = get(boot_nyblom.cells,'Value');
   cell_vec = [20 25 30 35 40 45 50 55 60 65 70 75 80 85 90 95 100];
   numcells = cell_vec(cell_value);
   my_80 = floor(0.8*rep);
   my_90 = floor(0.9*rep);
   my_95 = floor(0.95*rep);
   my_975 = floor(0.98*rep);
   my_99 = floor(0.99*rep);
   %
   if num_exp>1;
      mc_80 = my_80;
      mc_90 = my_90;
      mc_95 = my_95;
      mc_975 = my_975;
      mc_99 = my_99;
      my_80 = floor(0.8*num_exp);
      my_90 = floor(0.9*num_exp);
      my_95 = floor(0.95*num_exp);
      my_975 = floor(0.98*num_exp);
      my_99 = floor(0.99*num_exp);
   end;
   %
   if curr_ini.colors==1;
      col.vec_1 = [0 0 1];
      col.vec_2 = [1 0 0];
      col.vec_3 = [0 0.75 0];
      col.vec_4 = [1 0.5 0];
      col.vec_5 = [0 0.75 0.75];
      col.vec_6 = [0 0 0];
      col.vec_7 = (1/255)*[255 28 28];
      col.vec_8 = [0 1 0];
   else;
      col.vec_1 = [0 0 0];
      col.vec_2 = [0.7 0.7 0.7];
      col.vec_3 = [0.6 0.6 0.6];
      col.vec_4 = [0.5 0.5 0.5];
      col.vec_5 = [0.4 0.4 0.4];
      col.vec_6 = [0.3 0.3 0.3];
      col.vec_7 = [0.8 0.8 0.8];
      col.vec_8 = [0.2 0.2 0.2];
   end;
   %
   % try to construct asymptotic distributions for max and mean test
   %
   max_series = [];
   mean_series = [];
   bart_max = [];
   bart_mean = [];
   max_pplot = [];
   mean_pplot = [];
   max_plot = [];
   mean_plot = [];
   lr_series = [];
   if (tm.nyblom_asymp==1)&((gcbo==boot_nyblom.display)|(gcbo==boot_nyblom.displaymenu));
      max_table = nyblom_table(tm.n,my_r,'max',tm.deterselect);
      mean_table = nyblom_table(tm.n,my_r,'mean',tm.deterselect);
      max_quant = quantiles_fcn;
      rand('state',sum(100*clock));
      %
      new_max = rand(10000+50,1);
      new_max = sort(new_max(51:10000+50,:));
      max_series = zeros(10000,1);
      for i=1:10000;
         for j=1:220;
            if new_max(i,1)<=max_quant(j,1);
               max_series(i,1) = max_table(j,1);
               break;
            elseif j==220;
               max_series(i,1) = max_table(221,1);
            end;
         end;
      end;
      %
      mean_series = zeros(10000,1);
      for i=1:10000;
         for j=1:220;
            if new_max(i,1)<=max_quant(j,1);
               mean_series(i,1) = mean_table(j,1);
               break;
            elseif j==220;
               mean_series(i,1) = mean_table(221,1);
            end;
         end;
      end;
      %
      mean_max_series = (1/10000)*sum(max_series);
      bart_max = (mean_max_series*size(NyblomMax,1)/sum(NyblomMax));
      mean_mean_series = (1/10000)*sum(mean_series);
      bart_mean = (mean_mean_series*size(NyblomMean,1)/sum(NyblomMean));
   end;
   if (isempty(tm.lr_df)==0)&(size(result,2)==3)&((gcbo==boot_nyblom.display)|(gcbo==boot_nyblom.displaymenu));
      [lr_series,lr_quant,lr_table] = asymp_series(tm.lr_df,0);
   end;
   %
   % now we try to make p-value plots etc. for max test
   %
   if ((gcbo==boot_nyblom.display)|(gcbo==boot_nyblom.displaymenu))&(get(boot_nyblom.pqplot,'Value')==1)&(isempty(max_series)==0);
      [p_series,pp_series,qq_series] = pq_nyblom_series(NyblomMax,max_quant,max_table,tm.n,my_r,'max',tm.deterselect);
      [pos,max_pplot] = pq_plot(pos,['nyblom-max-test-pqplot-' usealt],'P-value and Quantile Plots of Nyblom Max Test','P-value plot for sup Q_{T}^{(t)}','P-value discrepancy plot for sup Q_{T}^{(t)}','PP plot for sup Q_{T}^{(t)}','QQ plot for sup Q_{T}^{(t)}',tm,max_quant,max_table,p_series,pp_series,qq_series,col);
   end;
   %
   [pos,thisplot] = dist_plot(pos,['nyblom-max-' usealt],'Density for Nyblom Max Test',['Nyblom supremum test ' this_mod ' with ' num2str(tm.n) ' variables and ' num2str(my_r) ' cointegration vectors'],tm,curr_ini,boot_nyblom,NyblomMax,max_series,1,0,0,col,my_80,my_90,my_95,my_975,my_99,numcells,1,bart_max);
   if isempty(max_mean)==0;
      b_max = [];
      if (tm.nyblom_asymp==1)&((gcbo==boot_nyblom.display)|(gcbo==boot_nyblom.displaymenu));
         b_max = (mean_max_series*size(max_mean,1)/sum(max_mean));
      end;
      [pos,max_plot] = dist_plot(pos,['nyblom-max-exp-mean-' usealt],'Density for the Nyblom Max Test (experiment means)',['Nyblom supremum test ' this_mod ' with ' num2str(tm.n) ' variables and ' num2str(my_r) ' cointegration vectors'],tm,curr_ini,boot_nyblom,max_mean,max_series,1,0,0,col,mc_80,mc_90,mc_95,mc_975,mc_99,numcells,1,b_max,'Average ');
   end;
   %
   % mean test
   %
   if ((gcbo==boot_nyblom.display)|(gcbo==boot_nyblom.displaymenu))&(get(boot_nyblom.pqplot,'Value')==1)&(isempty(max_series)==0);
      [p_series,pp_series,qq_series] = pq_nyblom_series(NyblomMean,max_quant,mean_table,tm.n,my_r,'mean',tm.deterselect);
      [pos,mean_pplot] = pq_plot(pos,['nyblom-mean-test-pqplot-' usealt],'P-value and Quantile Plots of Nyblom Mean Test','P-value plot for mean Q_{T}^{(t)}','P-value discrepancy plot for mean Q_{T}^{(t)}','PP plot for mean Q_{T}^{(t)}','QQ plot for mean Q_{T}^{(t)}',tm,max_quant,mean_table,p_series,pp_series,qq_series,col);
   end;
   [pos,nextplot] = dist_plot(pos,['nyblom-mean-' usealt],'Density for Nyblom Mean Test',['Nyblom mean test ' this_mod ' with ' num2str(tm.n) ' variables and ' num2str(my_r) ' cointegration vectors'],tm,curr_ini,boot_nyblom,NyblomMean,mean_series,1,0,0,col,my_80,my_90,my_95,my_975,my_99,numcells,1,bart_mean);
   if isempty(mean_mean)==0;
      b_mean = [];
      if (tm.nyblom_asymp==1)&((gcbo==boot_nyblom.display)|(gcbo==boot_nyblom.displaymenu));
         b_mean = (mean_mean_series*size(mean_mean,1)/sum(mean_mean));
      end;
      [pos,mean_plot] = dist_plot(pos,['nyblom-mean-exp-mean-' usealt],'Density for Nyblom Mean Test (experiment means)',['Nyblom mean test ' this_mod ' with ' num2str(tm.n) ' variables and ' num2str(my_r) ' cointegration vectors'],tm,curr_ini,boot_nyblom,mean_mean,mean_series,1,0,0,col,mc_80,mc_90,mc_95,mc_975,mc_99,numcells,1,b_mean,'Average ');
   end;
   %
   % if LR-test has been bootstrapped
   %
   if (isempty(tm.lr_df)==0)&(size(result,2)==3);
      add_name = ['LR(' num2str(tm.lr_df,'%0.0f') ')'];
      lr_p_plot = [];
      if (isempty(lr_series)==0)&(get(boot_nyblom.pqplot,'Value')==1);
         [p_series,pp_series,qq_series] = pq_plot_series(boot_lr_test,lr_quant,lr_table,tm.lr_df,0);
         [pos,lr_p_plot] = pq_plot(pos,'lr-test-pqplot-',['P-value and Quantile Plots for ' add_name ' Test'],['P-value plot of ' add_name],['P-value discrepancy plot of ' add_name],['PP plot of ' add_name],['QQ plot of ' add_name],tm,lr_quant,lr_table,p_series,pp_series,qq_series,col);
      end;
      [pos,lr_plot] = dist_plot(pos,'lr-test-plot-',['Density for ' add_name ' Test'],[add_name ' test vs. alternative model ' this_mod ' with ' num2str(tm.n) ' variables and ' num2str(my_r) ' cointegration vectors'],tm,curr_ini,boot_nyblom,boot_lr_test,lr_series,1,0,0,col,my_80,my_90,my_95,my_975,my_99,numcells,tm.lr_df);
      if isempty(lr_mean)==0;
         [pos,lr_mean_plot] = dist_plot(pos,'lr-test-exp-mean-plot-',['Density for ' add_name ' Test (experiment means)'],[add_name ' test vs. alternative model ' this_mod ' with ' num2str(tm.n) ' variables and ' num2str(my_r) ' cointegration vectors'],tm,curr_ini,boot_nyblom,lr_mean,lr_series,1,0,0,col,my_80,my_90,my_95,my_975,my_99,numcells,tm.lr_df,[],'Average ');
      else;
         lr_mean_plot = [];
      end;
   end;
   %
   if curr_ini.external==0;
      if (isempty(max_pplot)==0)&(ishandle(max_pplot)==1);
         set(max_pplot,'Visible','on');
      end;
      set(thisplot,'Visible','on');
      if (isempty(max_plot)==0)&(ishandle(max_plot)==1);
         set(max_plot,'Visible','on');
      end;
      if (isempty(mean_pplot)==0)&(ishandle(mean_pplot)==1);
         set(mean_pplot,'Visible','on');
      end;
      set(nextplot,'Visible','on');
      if (isempty(mean_plot)==0)&(ishandle(mean_plot)==1);
         set(mean_plot,'Visible','on');
      end;
      %
      if (isempty(tm.lr_df)==0)&(size(result,2)==3);
         if isempty(lr_p_plot)==0;
            set(lr_p_plot,'Visible','on');
         end;
         set(lr_plot,'Visible','on');
         if isempty(lr_mean_plot)==0;
            set(lr_mean_plot,'Visible','on');
         end;
      end;
   else;
      this_mod = strrep(this_mod,'(','');
      this_mod = strrep(this_mod,')','');
      this_mod = strtrim(this_mod);
      this_mod = strrep(this_mod,' ','.');
      if (gcbo==boot_nyblom.histogram)|(gcbo==boot_nyblom.histogrammenu);
         file1 = [curr_ini.simulatedir 'nyblom-hist-max-' usealt tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(rep) '-' this_mod];
         file2 = [curr_ini.simulatedir 'nyblom-hist-mean-' usealt tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(rep) '-' this_mod];
         if (isempty(max_plot)==0)&(ishandle(max_plot)==1);
            file5 = [curr_ini.simulatedir 'nyblom-hist-max-exp-mean-' usealt tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(rep) '-' this_mod];
         end;
         if (isempty(mean_plot)==0)&(ishandle(mean_plot)==1);
            file6 = [curr_ini.simulatedir 'nyblom-hist-mean-exp-mean-' usealt tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(rep) '-' this_mod];
         end;
         if (isempty(tm.lr_df)==0)&(size(result,2)==3);
            file8 = [curr_ini.simulatedir 'lr-' num2str(tm.lr_df,'%0.0f') '-hist-' usealt tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(rep) '-' this_mod];
            if (isempty(lr_mean_plot)==0)&(ishandle(lr_mean_plot)==1);
               file9 = [curr_ini.simulatedir 'lr-exp-mean-' num2str(tm.lr_df,'%0.0f') '-hist-' usealt tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(rep) '-' this_mod];
            end;
         end;
      else;
         file1 = [curr_ini.simulatedir 'nyblom-max-' usealt tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(rep) '-' this_mod];
         file2 = [curr_ini.simulatedir 'nyblom-mean-' usealt tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(rep) '-' this_mod];
         if (isempty(max_pplot)==0)&(ishandle(max_pplot)==1);
            file3 = [curr_ini.simulatedir get(max_pplot,'Tag') tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(rep) '-' this_mod];
         end;
         if (isempty(mean_pplot)==0)&(ishandle(mean_pplot)==1);
            file4 = [curr_ini.simulatedir get(mean_pplot,'Tag') tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(rep) '-' this_mod];
         end;
         if (isempty(max_plot)==0)&(ishandle(max_plot)==1);
            file5 = [curr_ini.simulatedir 'nyblom-max-exp-mean-' usealt tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(rep) '-' this_mod];
         end;
         if (isempty(mean_plot)==0)&(ishandle(mean_plot)==1);
            file6 = [curr_ini.simulatedir 'nyblom-mean-exp-mean-' usealt tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(rep) '-' this_mod];
         end;
         if (isempty(tm.lr_df)==0)&(size(result,2)==3);
            file8 = [curr_ini.simulatedir 'lr-' num2str(tm.lr_df,'%0.0f') '-test-' usealt tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(rep) '-' this_mod];
            if (isempty(lr_p_plot)==0)&(ishandle(lr_p_plot)==1);
               file7 = [curr_ini.simulatedir 'lr-' num2str(tm.lr_df,'%0.0f') '-test-pqplot-' usealt tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(rep) '-' this_mod];
            end;
            if (isempty(lr_mean_plot)==0)&(ishandle(lr_mean_plot)==1);
               file9 = [curr_ini.simulatedir 'lr-exp-mean-' num2str(tm.lr_df,'%0.0f') '-test-' usealt tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(rep) '-' this_mod];
            end;
         end;
      end;
      if (isempty(max_pplot)==0)&(ishandle(max_pplot)==1);
         set(0,'CurrentFigure',max_pplot);
         mstat3 = autosavefigure(max_pplot,file3);
      else;
         mstat3 = 1;
      end;
      set(0,'CurrentFigure',thisplot);
      mstat1 = autosavefigure(thisplot,file1);
      if (isempty(max_plot)==0)&(ishandle(max_plot)==1);
         set(0,'CurrentFigure',max_plot);
         mstat5 = autosavefigure(max_plot,file5);
      else;
         mstat5 = 1;
      end;
      %
      if (isempty(mean_pplot)==0)&(ishandle(mean_pplot)==1);
         set(0,'CurrentFigure',mean_pplot);
         mstat4 = autosavefigure(mean_pplot,file4);
      else;
         mstat4 = 1;
      end;
      set(0,'CurrentFigure',nextplot);
      mstat2 = autosavefigure(nextplot,file2);
      if (isempty(mean_plot)==0)&(ishandle(mean_plot)==1);
         mstat6 = autosavefigure(mean_plot,file6);
      else;
         mstat6 = 1;
      end;
      if (isempty(tm.lr_df)==0)&(size(result,2)==3);
         set(0,'CurrentFigure',lr_plot);
         mstat8 = autosavefigure(lr_plot,file8);
         if (isempty(lr_p_plot)==0)&(ishandle(lr_p_plot)==1);
            set(0,'CurrentFigure',lr_p_plot);
            mstat7 = autosavefigure(lr_p_plot,file7);
         else;
            mstat7 = 1;
         end;
         if (isempty(lr_mean_plot)==0)&(ishandle(lr_mean_plot)==1);
            set(0,'CurrentFigure',lr_mean_plot);
            mstat9 = autosavefigure(lr_mean_plot,file9);
         else;
            mstat9 = 1;
         end;
      else;
         mstat7 = 1;
         mstat8 = 1;
         mstat9 = 1;
      end;
      %
      % display file-plots
      %
      if mstat3==0;
         autoshowfigure(file3);
      end;
      if mstat1==0;
         autoshowfigure(file1);
      end;
      if mstat5==0;
         autoshowfigure(file5);
      end;
      if mstat4==0;
         autoshowfigure(file4);
      end;
      if mstat2==0;
         autoshowfigure(file2);
      end;
      if mstat6==0;
         autoshowfigure(file6);
      end;
      if mstat7==0;
         autoshowfigure(file7);
      end;
      if mstat8==0;
         autoshowfigure(file8);
      end;
      if mstat9==0;
         autoshowfigure(file9);
      end;
   end;
   set(nyblom_boot_gui,'UserData',boot_nyblom);
case 'montecarlo'
   tm.nyblom_run = 1;
   set(nyblom_boot_gui,'Visible','off');
   drawnow;
   %
   % collect values
   %
   T_str = get(boot_nyblom.obs,'String');
   my_T = mystr2num(strtrim(T_str(get(boot_nyblom.obs,'Value'),:)));
   repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
   rep_val = get(boot_nyblom.rep,'Value');
   rep = repvalues(rep_val);
   set(boot_nyblom.simulate,'UserData',rep);
   blocksize = get(boot_nyblom.block,'Value');
   block_txt = '';
   if blocksize>1;
      block_txt = ['Applying block bootstrap with block length ' num2str(blocksize,'%0.0f') '...'];
   end;
   if get(boot_nyblom.parametric,'Value')==1;
      bootstyle = '';
   else;
      bootstyle = ['np' num2str(get(boot_nyblom.block,'Value')) '-'];
   end;
   my_r = get(boot_nyblom.my_r,'Value');
   if strcmp(get(boot_nyblom.my_r,'Enable'),'on')==1;
      mybeta = tm.beta(:,1:my_r);
   else;
      mybeta = tm.beta;
   end;
   alt_state = get(boot_nyblom.usealtmodel,'State');
   if strcmp(alt_state,'off')==1;
      usealt = '';
      test_lr = 0;
      if (isfield(tm,'altmodel')==1)&(isempty(tm.altmodel)==0);
         if (isfield(tm.altmodel,'bootlr')==1)&(tm.altmodel.tempdummy+tm.altmodel.permdummy>0);
            test_lr = tm.altmodel.bootlr;
         end;
      end;
   else;
      usealt = 'alt-';
      if tm.altmodel.tempdummy+tm.altmodel.permdummy>0;
         test_lr = tm.altmodel.bootlr;
      else;
         test_lr = 0;
      end;
      if tm.altmodel.tempdummy==1;
         usealt = [usealt 't-'];
         if tm.altmodel.tempcorel==1;
            usealt = [usealt 'coi-'];
            if tm.altmodel.tempcoidet==1;
               usealt = [usealt 'det-'];
            end;
            if tm.altmodel.temprank==2;
               usealt = [usealt 'inc-'];
               test_lr = 0;
            elseif tm.altmodel.temprank==3;
               usealt = [usealt 'dec-'];
               test_lr = 0;
            end;
         elseif tm.altmodel.tempshortrun==1;
            usealt = [usealt 'sr-'];
         else;
            usealt = [usealt 'con-'];
         end;
         if tm.altmodel.tempacc==1;
            usealt = [usealt 'acc-'];
         end;
      else;
         usealt = [usealt 'p-'];
         if tm.altmodel.permcorel==1;
            usealt = [usealt 'coi-'];
            if tm.altmodel.permcoidet==1;
               usealt = [usealt 'det-'];
            end;
            if tm.altmodel.permrank==2;
               usealt = [usealt 'inc-'];
               test_lr = 0;
            elseif tm.altmodel.permrank==3;
               usealt = [usealt 'dec-'];
               test_lr = 0;
            end;
         elseif tm.altmodel.permshortrun==1;
            usealt = [usealt 'sr-'];
         else;
            usealt = [usealt 'con-'];
         end;
         if tm.altmodel.permacc==1;
            usealt = [usealt 'acc-'];
         end;
      end;
      if (tm.altmodel.relsample==1)&(my_T~=tm.T);
         usealt = [usealt 'rs-'];
      end;
   end;
   tm.usealtmodel = 0;
   %
   % computing tests for the actual data
   %
   if tm.restrict(1,2)==0;
      %
      % Base case, no restrictions on the cointegration space
      %
      if curr_ini.fullrec==1;
         [nyblomT,nyblomcorr] = boot_nyblom_partial(tm.Z0,tm.Z1,tm.Z2,my_r,tm.p,tm.q1,tm.d,curr_ini.T0,tm.df,tm.T);
      else;
         [nyblomT,nyblomcorr] = boot_nyblom_full(tm.Z0,tm.Z1,tm.Z2,my_r,tm.p,tm.q1,tm.d,curr_ini.T0,tm.df,tm.deterselect,tm.T);
      end;
   else;
      %
      % restrictions on the cointegration space are possible
      %
      status = testident(tm.modelsdir,tm.modelfile,my_r,tm.n,tm.dcoint,tm.q1);
      if sum(status)==my_r;
         [nyblomT,nyblomcorr] = boot_nyblom_restbeta_fcn(tm,curr_ini,tm.cointbeta,tm.Z0,tm.Z1,tm.Z2,tm.T,my_r,tm.T);
      else;
         nyblomT = [];
      end;
   end;
   %
   % if we can compute the tests
   %
   if isempty(nyblomT)==0;
      tm.NyblomMean = (1/size(nyblomT,2))*sum(nyblomT);
      tm.NyblomMax = max(nyblomT);
      %
      if test_lr==1;
         if tm.r==my_r;
            lnL_orig = loglike(tm.epsilon);
         else;
            [S_00,S_01,S_10,S_11,M_02,M_22,M_12,beta_n,lambda,my_trace] = mlcointbasic(tm.Z0,tm.Z1,tm.Z2,my_r);
            alpha_n = (S_01*beta_n)*inverse(beta_n'*S_11*beta_n);
            if isempty(tm.Z2)==0;
               Psi_n = (M_02*inverse(M_22))-(alpha_n*beta_n'*M_12*inverse(M_22));
               epsilon_n = tm.Z0-(alpha_n*beta_n'*tm.Z1)-(Psi_n*tm.Z2);
            else;
               epsilon_n = tm.Z0-(alpha_n*beta_n'*tm.Z1);
            end;
            lnL_orig = loglike(epsilon_n);
         end;
      end;
      %
      exp_str = get(boot_nyblom.experiments,'String');
      exp_val = get(boot_nyblom.experiments,'Value');
      num_exp = mystr2num(strrep(strtrim(exp_str(exp_val,:)),',',''));
      %
      % check if we should run all experiments at once or by parts
      %
      rexp_value = get(boot_nyblom.runexperiments,'Value');
      if rexp_value==1;
         first_rexp = 1;
         last_rexp = num_exp;
      else;
         rexp_str = get(boot_nyblom.runexperiments,'String');
         rexp_str = strtrim(rexp_str(rexp_value,:));
         rexp_str = strrep(rexp_str,'Run expmnts ','');
         rexp_str = strtrim(strrep(rexp_str,'(done)',''));
         rexp_vec = mystr2num(strrep(rexp_str,'-',' '));
         first_rexp = rexp_vec(1,1);
         last_rexp = rexp_vec(1,2);
      end;
      %
      % check if we should use the original model or estimate an alternative model
      %
      if (strcmp(alt_state,'off')==1)&(test_lr==0);
         %
         % collect all the model information into am structure
         %
         am = tm;
         am.beta = mybeta;
         if tm.q0+tm.q1>0;
            am.exo = tm.Z2(tm.d+(tm.n*(tm.p-1))+1:size(tm.Z2,1),:);
         end;
         d_rank = 1;
      else;
         %
         % read the tm.altmodel structure
         %
         tempdummy = tm.altmodel.tempdummy;
         permdummy = tm.altmodel.permdummy;
         if tempdummy==1;
            d_begin = tm.altmodel.tempbegin;
            d_end = tm.altmodel.tempend;
            d_acc = tm.altmodel.tempacc;
            d_coint = tm.altmodel.tempcoint;
            d_corel = tm.altmodel.tempcorel;
            d_rank = tm.altmodel.temprank;
            d_shortrun = tm.altmodel.tempshortrun;
            d_coidet = tm.altmodel.tempcoidet;
         else;
            d_begin = tm.altmodel.permbegin;
            d_end = tm.T;
            d_acc = tm.altmodel.permacc;
            d_coint = tm.altmodel.permcoint;
            d_corel = tm.altmodel.permcorel;
            d_rank = tm.altmodel.permrank;
            d_shortrun = tm.altmodel.permshortrun;
            d_coidet = tm.altmodel.permcoidet;
         end;
         if (d_begin>1)&(d_end<tm.T);
            data_dummy = [zeros(d_begin-1,1);ones(d_end-d_begin+1,1);zeros(tm.T-d_end,1)];
         elseif d_begin==1;
            data_dummy = [ones(d_end,1);zeros(tm.T-d_end,1)];
         else;
            data_dummy = [zeros(d_begin-1,1);ones(tm.T-d_begin+1,1)];
         end;
         if d_acc==1;
            data_dummy = cumsum(data_dummy);
         end;
         if (d_corel==1)&(d_rank==3);
            data_dummy = 1-data_dummy;
         end;
         %
         % check rank of [tm.Z1;data_dummy';tm.Z2]
         %
         bad_dummy = 0;
         if d_corel==0;
            if d_shortrun==0;
               test_mat = [tm.Z1;data_dummy';tm.Z2];
               if size(test_mat,1)>rank(test_mat);
                  bad_dummy = 1;
               end;
            else;
               test_mat = tm.Z2(tm.d+1:size(tm.Z2,1),:);
               num_ones = sum((data_dummy>0));
               num_zeros = sum((data_dummy==0));
               if min(num_ones,num_zeros)<=size(test_mat,1);
                  bad_dummy = 4;
               end;
            end;
         else;
            num_ones = sum((data_dummy>0));
            num_zeros = sum((data_dummy==0));
            if min(num_ones,num_zeros)<=size(tm.Z1,1);
               bad_dummy = 2;
            end;
         end;
         ch_dummy = check_dummy(tm,my_T);
         if ch_dummy==0;
            bad_dummy = 3;
         end;
         if bad_dummy==0;
            %
            % we're now ready to estimate the alternative model
            %
            am = tm;
            if tm.q0+tm.q1>0;
               am.exo = tm.Z2(tm.d+(tm.n*(tm.p-1))+1:size(tm.Z2,1),:);
            end;
            if d_rank==1;
               am.usealtmodel = 1;
               if d_coint==0;
                  if d_corel==0;
                     am.Z1 = tm.Z1;
                     if d_shortrun==0;
                        am.Z2 = [data_dummy';tm.Z2];
                        am.d = am.d+1;
                     else;
                        am.Z2 = [];
                        if tm.d>0;
                           am.Z2 = tm.Z2(1:tm.d,:);
                        end;
                        am.Z2 = [am.Z2;test_mat .* (ones(size(test_mat,1),1)*(1-data_dummy'));test_mat .* (ones(size(test_mat,1),1)*data_dummy')];
                     end;
                  else;
                     am.Z2 = tm.Z2;
                     if d_coidet==0;
                        am.Z1 = [tm.Z1 .* (ones(size(tm.Z1,1),1)*(1-data_dummy'));tm.Z1 .* (ones(size(tm.Z1,1),1)*data_dummy')];
                     else;
                        am.Z1 = [tm.Z1(1:size(tm.Z1,1)-1,:) .* (ones(size(tm.Z1,1)-1,1)*(1-data_dummy'));tm.Z1(size(tm.Z1,1),:);tm.Z1(1:size(tm.Z1,1)-1,:) .* (ones(size(tm.Z1,1)-1,1)*data_dummy')];
                     end;
                  end;
               else;
                  am.Z1 = [tm.Z1;data_dummy'];
                  am.Z2 = tm.Z2;
               end;
               %
               % check that the dummy doesn't make am.Z1 or am.Z2 being singular
               %
               if rank(am.Z1)<size(am.Z1,1);
                  bad_dummy = 4;
               else;
                  if isempty(am.Z2)==0;
                     if rank(am.Z2)<size(am.Z2,1);
                        bad_dummy = 5;
                     end;
                  end;
               end;
               if bad_dummy==0;
                  [am.S_00,am.S_01,am.S_10,am.S_11,am.M_02,am.M_22,am.M_12,am.beta,am.lambda,am.trace] = mlcointbasic(am.Z0,am.Z1,am.Z2,my_r);
                  %
                  % need to run a routine which can have dcoint 1 and have a dummy in the cointegration space
                  %
                  lr_warn = 0;
                  if tm.restrict(1,2)==1;
                     [am.beta,am.dfbeta,const_rest] = beta_alt_estimate(am.S_00,am.S_11,am.S_01,am.S_10,am.beta,tm.T,tm.modelsdir,tm.modelfile,tm.dcoint,tm.q1,d_coint,d_corel,d_coidet);
                     if am.dfbeta==((size(am.beta,1)-size(am.beta,2))*size(am.beta,2))-const_rest;
                        lr_warn = 1;
                     end;
                  end;
                  %
                  if lr_warn==0;
                     am.alpha = (am.S_01*am.beta)/(am.beta'*am.S_11*am.beta);
                     if isempty(am.Z2)==0;
                        am.Psi = (am.M_02/am.M_22)-(am.alpha*am.beta'*(am.M_12/am.M_22));
                        am.Z = [am.Z2;am.beta'*am.Z1];
                     else;
                        am.Psi = [];
                        am.Z = am.beta'*am.Z1;
                     end;
                     Theta = [am.Psi am.alpha];
                     am.epsilon = am.Z0-(Theta*am.Z);
                     am.Omega = (1/tm.T)*am.epsilon*am.epsilon';
                     if tm.restrict(1,1)==1;
                        %
                        % estimate alpha under restrictions
                        %
                        file = strcat(tm.modelsdir,'G-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
                        G = loaddata(file);
                        [Rmat,rvec] = rmatrix(G,tm.n,tm.r);
                        am.dfalpha = size(G,1);
                        if isempty(am.Z2)==0;
                           Rmat = [zeros(am.dfalpha,size(am.Z2,1)*tm.n) Rmat];
                        end;
                        if curr_ini.reestbeta==0;
                           [theta,Sigma_theta,infomat,nabort] = linrest(am.Z0,am.Z,Theta,Rmat,rvec,0);
                        else;
                           %
                           % re-estimate beta under alpha restrictions
                           %
                           [theta,am.beta,am.Z] = alpha_beta_alt_estimate(am.Z0,am.Z1,am.Z2,am.Z,am.beta,Theta,Rmat,rvec,tm.dcoint,tm.q1,tm.modelsdir,tm.modelfile,d_coint,d_corel,d_coidet);
                        end;
                        g2 = size(theta,2);
                        am.alpha = theta(:,g2-tm.r+1:g2);
                        if g2>tm.r;
                           am.Psi = theta(:,1:g2-tm.r);
                        else;
                           am.Psi = [];
                        end;
                        am.epsilon = am.Z0-(theta*am.Z);
                        am.Omega = (1/tm.T)*am.epsilon*am.epsilon';
                        Theta = theta;
                     end;
                     %
                     % consider restrictions on C
                     %
                     if (size(tm.restrict,2)==3)&(tm.restrict(1,3)==1);
                        %
                        % collect restrictions on C
                        %
                        file = strcat(tm.modelsdir,'C-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
                        Cres = loaddata(file);
                        [Rmat_C,rvec_C] = rmatrix(Cres,tm.n,tm.n);
                        %
                        % Estimate under C restrictions
                        %
                        d_parm = tm.d;
                        if d_corel==0;
                           d_parm = tm.d+(1-d_coint);
                        end;
                        [theta,am.beta] = c_alt_restrict(am.Z0,am.Z1,am.Z2,tm.restrict,am.beta,Theta,Rmat_C,rvec_C,tm.p,tm.pe,d_parm,tm.dcoint,tm.q0,tm.q1,tm.modelsdir,tm.modelfile,curr_ini.reestbeta,d_coint,d_corel,d_coidet);
                        am.Z = [];
                        if tm.r>0;
                           am.Z = am.beta'*am.Z1;
                        end;
                        am.Z = [am.Z2;am.Z];
                        %
                        % fix all the other parameters
                        %
                        am.epsilon = am.Z0-(theta*am.Z);
                        am.Omega = (1/tm.T)*am.epsilon*am.epsilon';
                        g2 = size(theta,2);
                        if tm.r>0;
                           am.alpha = theta(:,g2-tm.r+1:g2);
                        else;
                           am.alpha = [];
                        end;
                        if g2>tm.r;
                           am.Psi = theta(:,1:g2-tm.r);
                        else;
                           am.Psi = [];
                        end;               
                        Theta = theta;
                     end;
                     %
                     if test_lr==1;
                        lnL_alt = loglike(am.epsilon);
                        lr_test = 2*(lnL_alt-lnL_orig);
                        %
                        % determine the number of degrees of freedom
                        %
                        if d_corel==1;
                           if d_coidet==0;
                              lr_df = (size(am.beta,1)/2)*size(am.beta,2);
                           else;
                              lr_df = (tm.n+tm.q1)*size(am.beta,2);
                           end;
                           if tm.restrict(1,2)==1;
                              lr_df = round((((size(am.beta,1)-size(am.beta,2))*size(am.beta,2))-am.dfbeta-const_rest)/2);
                           end;
                        else;
                           if d_coint==1;
                              lr_df = tm.r;
                           else;
                              if d_shortrun==0;
                                 lr_df = tm.n;
                              else;
                                 lr_df = size(test_mat,1)*tm.n;
                              end;
                           end;
                        end;
                     end;
                  else;
                     txt = 'The original and the alternative models are equivalent since the original cointegration space is assumed to be known exactly, i.e., there are no free parameters in the cointegration space that can vary across the 2 regimes. Please consider a different original or alternative model.';
                     about(txt,'information','Bad Alternative Model...',130,350);
                     tm.nyblom_run = 0;
                     set(nyblom_boot_gui,'Visible','on');
                     drawnow;
                     return;
                  end;
               else;
                  if bad_dummy==4;
                     txt = 'The dummy variable you have created makes some of the levels variables linearly dependent. It''s therefore impossible to extend that model with the new dummy variable. Please select another dummy!';
                     about(txt,'information','Bad Dummy...',130,350);
                  elseif bad_dummy==5;
                     txt = 'The dummy variable you have created makes some of the first difference, exogenous, and/or deterministic variables linearly dependent. It''s therefore impossible to extend that model with the new dummy variable. Please select another dummy!';
                     about(txt,'information','Bad Dummy...',130,350);
                  end;
                  tm.nyblom_run = 0;
                  set(nyblom_boot_gui,'Visible','on');
                  drawnow;
                  return;
               end;
            else;
               %
               % estimate alternative model under changes in rank
               %
               if d_rank==2;
                  r_0 = my_r;
                  r_1 = my_r+1;
                  alt_r = r_0;
               elseif d_rank==3;
                  r_0 = my_r;
                  r_1 = my_r-1;
                  alt_r = r_1;
               end;
               am.Z0 = tm.Z0;
               am.Z1 = tm.Z1;
               am.Z2 = tm.Z2;
               am.d = tm.d;
               am.n = tm.n;
               am.T = tm.T;
               am.freq = tm.freq;
               am.p = tm.p;
               am.q1 = tm.q1;
               am.q0 = tm.q0;
               am.altmodel = tm.altmodel;
               am.deterselect = tm.deterselect;
               %
               [am.beta_1,am.beta_2,am.alpha_1,am.alpha_2,am.Psi,am.Omega,am.epsilon] = varyrank(tm.Z0,tm.Z1,tm.Z2,data_dummy,alt_r,1);
            end;
            %
         else;
            if bad_dummy==1;
               txt = 'The dummy variable you have created is linearly dependent of some of the variables in your original model. It''s therefore not possible to extend that model with the new dummy variable. Please select another dummy!';
            elseif bad_dummy==2;
               txt = ['You have too few observations of the long-run relations in one of the regimes, i.e. ' num2str(min(num_ones,num_zeros),'%0.0f') '. You need at least ' num2str(size(tm.Z1,1)+1,'%0.0f') ' observations from each regime. Please select another regime dummy!'];
            elseif bad_dummy==3;
               txt = 'The dummy variable is equal to 0 for all observations under the sample size and the break set you have selected. Please select another dummy, change the sample size, or make sure that the dummy variable is active for a break set which is defined relative to the sample size.';
            elseif bad_dummy==4;
               txt = 'You have too few observations in one of the regimes to estimate all the short-run parameters for that regime. Please select another dummy!';
            end;
            about(txt,'information','Bad Dummy...',130,350);
            tm.nyblom_run = 0;
            set(nyblom_boot_gui,'Visible','on');
            drawnow;
            return;
         end;
      end;
      %
      if (strcmp(alt_state,'off')==1)&(test_lr==1);
         %
         % collect all the model information into am structure
         %
         am = tm;
         am.beta = mybeta;
         d_rank = 1;
      end;
      %
      if rexp_value==1;
         add_show_str = 'running all experiments';
      else;
         add_show_str = ['running experiments: ' num2str(first_rexp) '-' num2str(last_rexp)];
      end;
      %
      % check what type of dialog should be displayed
      %
      showprog = get(boot_nyblom.progress,'Value');
      if showprog==1;
         if rexp_value==1;
            input_var.title = ['Progress for ' int2str(num_exp) ' experiments and ' int2str(rep) ' replications'];
         elseif rexp_value<=11;
            input_var.title = ['Progress for ' num2str(0.1*num_exp) ' experiments and ' int2str(rep) ' replications'];
         else;
            input_var.title = ['Progress for ' num2str(0.2*num_exp) ' experiments and ' int2str(rep) ' replications'];
         end;
         input_var.facecolor = curr_ini.progress_facecolor;
         input_var.startfacecolor = curr_ini.progress_startfacecolor;
         input_var.edgecolor = curr_ini.progress_edgecolor;
         input_var.bgcolor = curr_ini.progress_bgcolor;
         input_var.clock = get(boot_nyblom.clock,'Value');
         input_var.label = 'Run number:';
         input_var.stop = 0;
         mywait = progressdlg(0,input_var);
         set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
      else;
         this_text = strvcat('Monte Carlo bootstraps. The art of pulling oneself up by the bootstraps. Attempt started at...',' ',['Time: ' datestr(now,14)],' ','Please hold!');
         mywait = waitdlg(this_text,'bootstrap','Nyblom Bootstrap Simulation');
         waitf = get(mywait,'UserData');
         tic;
      end;

      %
      if test_lr==0;
         test_lr_str = '';
         str_add = '...';
      else;
         test_lr_str = 'and LR-test vs. alternative model...';
         str_add = '';
      end;
      %
      if curr_ini.taylor_nyblom==0;
         test_str = 'Using the scores version of the Nyblom statistic';
      else;
         test_str = 'Using the 1st order Taylor verion of the Nyblom statistic';
      end;
      %
      if curr_ini.fullrec==1;
         test_str = strvcat(test_str,'with conditioning on full-sample estimates of delta and','Gamma_i parameters in recursion...');
      else;
         test_str = strvcat(test_str,'with updating of all parameters in recursion...');
      end;
      %
      if tm.const_model(2)==1;
         setlogtext(strvcat(' ',['Monte Carlo bootstraps for Nyblom tests' str_add],test_lr_str,test_str,block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Restricted constant',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(my_r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(num_exp) ' experiments'],['       (' add_show_str ')'],['       ' num2str(rep) ' replications']));
         if showprog==1;
            set(mywait,'Name',['Restricted constant model with ' num2str(my_T,'%0.0f') ' obs']);
            drawnow;
         end;
         mod_type = 'resconst';
      elseif tm.const_model(3)==1;
         setlogtext(strvcat(' ',['Monte Carlo bootstraps for Nyblom tests' str_add],test_lr_str,test_str,block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Unrestricted constant',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(my_r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(num_exp) ' experiments'],['       (' add_show_str ')'],['       ' num2str(rep) ' replications']));
         if showprog==1;
            set(mywait,'Name',['Constant model with ' num2str(my_T,'%0.0f') ' obs']);
            drawnow;
         end;
         mod_type = 'const';
      elseif tm.const_model(4)==1;
         setlogtext(strvcat(' ',['Monte Carlo bootstraps for Nyblom tests' str_add],test_lr_str,test_str,block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Restricted linear trend',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(my_r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(num_exp) ' experiments'],['       (' add_show_str ')'],['       ' num2str(rep) ' replications']));
         if showprog==1;
            set(mywait,'Name',['Restricted trend model with ' num2str(my_T,'%0.0f') ' obs']);
            drawnow;
         end;
         mod_type = 'restrend';
      elseif tm.const_model(5)==1;
         setlogtext(strvcat(' ',['Monte Carlo bootstraps for Nyblom tests' str_add],test_lr_str,test_str,block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Linear trend',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(my_r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(num_exp) ' experiments'],['       (' add_show_str ')'],['       ' num2str(rep) ' replications']));
         if showprog==1;
            set(mywait,'Name',['Linear trend model with ' num2str(my_T,'%0.0f') ' obs']);
            drawnow;
         end;
         mod_type = 'trend';
      end;
      %
      if strcmp(alt_state,'on')==1;
         %
         % we have an alternative model
         %
         log_str = strvcat('Using alternative model for DGP with properties:');
         if tempdummy==1;
            add_log_str = '     * Temporary dummy';
         else;
            add_log_str = '     * Permanent dummy';
         end;
         if d_acc==1;
            add_log_str = lower(add_log_str);
            add_log_str = strrep(add_log_str,'     * ','     * Accumulated');
         end;               
         if d_corel==1;
            if d_rank==1;
               if d_coidet==0;
                  add_log_str = strvcat([add_log_str ' applied to the'],'       cointegration relations');
               else;
                  if tm.deterselect(1,2)==1;
                     add_log_str = strvcat([add_log_str ' applied to the'],'       cointegration relations, but not to the','       restricted constant');
                  elseif tm.deterselect(1,4)==1;
                     add_log_str = strvcat([add_log_str ' applied to the'],'       cointegration relations, but not to the','       restricted linear trend');
                  end;
               end;
            else;
               add_log_str = strvcat([add_log_str ' applied to the'],'       cointegration relations and alpha with rank:',['       ' num2str(r_0) ' when dummy is 0'],['       ' num2str(r_1) ' when dummy is 1']);
            end;
         elseif d_coint==1;
            add_log_str = strvcat([add_log_str ' restricted to the'],'       cointegration space');
         elseif d_shortrun==1;
            add_log_str = strvcat([add_log_str ' applied to the'],'       short-run dynamics');
         end;
         if tm.altmodel.relsample==1;
            du_begin = round(d_begin*(my_T/tm.T));
            du_end = round(d_end*(my_T/tm.T));
         else;
            du_begin = d_begin;
            du_end = d_end;
            if (d_end==tm.T)&(permdummy==1);
               du_end = my_T;
            end;
         end;
         setlogtext(strvcat(log_str,add_log_str,['     * Dummy is active between period ' num2str(du_begin,'%0.0f') ' and ' num2str(du_end,'%0.0f')],' '));
      end;
      %
      if get(boot_nyblom.bootstrap,'Value')==1;
         %
         % epsilon-file
         %
         epsfile = [curr_ini.simulatedir tm.modelfile '-' usealt tm.restalpha tm.restbeta tm.updating tm.testtype 'epsilon-' num2str(tm.scale_endo,'%0.4f') '-' bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '-' num2str(rep) '-' mod_type '.mat'];
         if fileexist(epsfile)==1;
            load_eps = 1;
            %
            % load old epsilons
            %
            eps_data = load(epsfile);
            if isempty(eps_data.bootstrap(first_rexp).epsilon)==1;
               load_eps = 0;
            end;
            %
            % make sure that the bootstrap structure contains all previous draws of epsilon
            %
            for i=1:size(eps_data.bootstrap,2);
               if isempty(eps_data.bootstrap(i).epsilon)==0;
                  bootstrap(i).epsilon = eps_data.bootstrap(i).epsilon;
               end;
            end;
         else;
            load_eps = 0;
         end;
      else;
         load_eps = 0;
      end;
      %
      %
      % we're ready to start the experiments
      % the am structure holds the information for generating a bootstrap
      % draw of the tests in each experiment
      %
      max_orig_rej_prob = zeros(num_exp,1);
      mean_orig_rej_prob = zeros(num_exp,1);
      max_rej_prob = zeros(num_exp,1);
      mean_rej_prob = zeros(num_exp,1);
      max_tests = zeros(num_exp,1);
      mean_tests = zeros(num_exp,1);
      max_mean = zeros(rep,1);
      mean_mean = zeros(rep,1);
      if (tm.nyblom_asymp==1)&((sum(tm.restrict)==0)|((tm.restrict(1,2)==1)&(tm.dfbeta==0)&(sum(tm.restrict)==1)));
         max_asymp_rej_prob = zeros(num_exp,1);
         mean_asymp_rej_prob = zeros(num_exp,1);
      end;
      if test_lr==1;
         lr_tests = zeros(num_exp,1);
         lr_rej_prob = zeros(num_exp,1);
         lr_orig_rej_prob = zeros(num_exp,1);
         lr_asymp_rej_prob = zeros(num_exp,1);
         lr_mean = zeros(rep,1);
      end;
      abort = '';
      e_draw = first_rexp;
      num_draws = 1;
      half_point = 0;
      if rexp_value>1;
         num_draws = 1+((1+rep)*(rexp_value-2)*(0.1*num_exp));
         if rexp_value>11;
            num_draws = 1+((1+rep)*(rexp_value-12)*(0.2*num_exp));
            half_point = (last_rexp+e_draw-1)/2;
         end;
         %
         % check if there's old data to load
         %
         % attempt to recreate max_mean and mean_mean
         %
         for te_draw=1:num_exp;
            if tm.const_model(1)==1;
               temp_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(te_draw) '-' num2str(rep) '-noconst.mat'];
            elseif tm.const_model(2)==1;
               temp_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(te_draw) '-' num2str(rep) '-resconst.mat'];
            elseif tm.const_model(3)==1;
               temp_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(te_draw) '-' num2str(rep) '-const.mat'];
            elseif tm.const_model(4)==1;
               temp_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(te_draw) '-'  num2str(rep) '-restrend.mat'];
            elseif tm.const_model(5)==1;
               temp_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(te_draw) '-' num2str(rep) '-trend.mat'];
            end;
            if ((te_draw<first_rexp)|(te_draw>last_rexp))&(fileexist(temp_mat)==1);
               temp_data = load(temp_mat);
               max_mean = max_mean+temp_data.NyblomMax;
               mean_mean = mean_mean+temp_data.NyblomMean;
               if (isfield(temp_data,'LRtests')==1)&(isfield(temp_data,'altmodel')==1);
                  if check_altmodel_nyblom(tm.altmodel,temp_data.altmodel)==1;
                     lr_mean = lr_mean+temp_data.LRtests;
                  end;
               end;
               clear('temp_data');
            end;
         end;
         %
         % attempt to recreate max_orig_rej_prob, mean_orig_rej_prob, max_asymp_rej_prob, mean_asymp_rej_prob,etc
         %
         first_part = 1;
         last_part = 0.1*num_exp;
         add_part = last_part;
         for rexp_val=1:10;
            if tm.const_model(1)==1;
               part_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(rexp_val) '-' num2str(rep) '-noconst.mat'];
            elseif tm.const_model(2)==1;
               part_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(rexp_val) '-' num2str(rep) '-resconst.mat'];
            elseif tm.const_model(3)==1;
               part_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(rexp_val) '-' num2str(rep) '-const.mat'];
            elseif tm.const_model(4)==1;
               part_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(rexp_val) '-' num2str(rep) '-restrend.mat'];
            elseif tm.const_model(5)==1;
               part_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(rexp_val) '-' num2str(rep) '-trend.mat'];
            end;
            if rexp_val>1;
               first_part = first_part+add_part;
               last_part = last_part+add_part;
            end;
            if rexp_value<=11;
               if ((rexp_val<rexp_value-1)|(rexp_val>rexp_value-1))&(fileexist(part_mat)==1);
                  part_data = load(part_mat);
                  max_orig_rej_prob(first_part:last_part,1) = part_data.max_orig_rej_prob(first_part:last_part,1);
                  mean_orig_rej_prob(first_part:last_part,1) = part_data.mean_orig_rej_prob(first_part:last_part,1);
                  max_rej_prob(first_part:last_part,1) = part_data.max_rej_prob(first_part:last_part,1);
                  mean_rej_prob(first_part:last_part,1) = part_data.mean_rej_prob(first_part:last_part,1);
                  max_tests(first_part:last_part,1) = part_data.max_tests(first_part:last_part,1);
                  mean_tests(first_part:last_part,1) = part_data.mean_tests(first_part:last_part,1);
                  if isfield(part_data,'max_asymp_rej_prob')==1;
                     max_asymp_rej_prob(first_part:last_part,1) = part_data.max_asymp_rej_prob(first_part:last_part,1);
                     mean_asymp_rej_prob(first_part:last_part,1) = part_data.mean_asymp_rej_prob(first_part:last_part,1);
                  end;
                  if (isfield(part_data,'lr_tests')==1)&(isfield(part_data,'altmodel')==1);
                     if check_altmodel_nyblom(tm.altmodel,part_data.altmodel)==1;
                        lr_tests(first_part:last_part,1) = part_data.lr_tests(first_part:last_part,1);
                        lr_rej_prob(first_part:last_part,1) = part_data.lr_rej_prob(first_part:last_part,1);
                        lr_orig_rej_prob(first_part:last_part,1) = part_data.lr_orig_rej_prob(first_part:last_part,1);
                        lr_asymp_rej_prob(first_part:last_part,1) = part_data.lr_asymp_rej_prob(first_part:last_part,1);
                     end;
                  end;
                  clear('part_data');
               end;
            else;
               if (rexp_val~=(half_point*10/num_exp))&(rexp_val~=(last_rexp*10/num_exp))&(fileexist(part_mat)==1);
                  part_data = load(part_mat);
                  max_orig_rej_prob(first_part:last_part,1) = part_data.max_orig_rej_prob(first_part:last_part,1);
                  mean_orig_rej_prob(first_part:last_part,1) = part_data.mean_orig_rej_prob(first_part:last_part,1);
                  max_rej_prob(first_part:last_part,1) = part_data.max_rej_prob(first_part:last_part,1);
                  mean_rej_prob(first_part:last_part,1) = part_data.mean_rej_prob(first_part:last_part,1);
                  max_tests(first_part:last_part,1) = part_data.max_tests(first_part:last_part,1);
                  mean_tests(first_part:last_part,1) = part_data.mean_tests(first_part:last_part,1);
                  if isfield(part_data,'max_asymp_rej_prob')==1;
                     max_asymp_rej_prob(first_part:last_part,1) = part_data.max_asymp_rej_prob(first_part:last_part,1);
                     mean_asymp_rej_prob(first_part:last_part,1) = part_data.mean_asymp_rej_prob(first_part:last_part,1);
                  end;
                  if (isfield(part_data,'lr_tests')==1)&(isfield(part_data,'altmodel')==1);
                     if check_altmodel_nyblom(tm.altmodel,part_data.altmodel)==1;
                        lr_tests(first_part:last_part,1) = part_data.lr_tests(first_part:last_part,1);
                        lr_rej_prob(first_part:last_part,1) = part_data.lr_rej_prob(first_part:last_part,1);
                        lr_orig_rej_prob(first_part:last_part,1) = part_data.lr_orig_rej_prob(first_part:last_part,1);
                        lr_asymp_rej_prob(first_part:last_part,1) = part_data.lr_asymp_rej_prob(first_part:last_part,1);
                     end;
                  end;
                  clear('part_data');
               end;
            end;
         end;
      end;
      %
      first_draw = 1;
      while e_draw<=last_rexp; % should be last_rexp
         %
         % check for bootstrap style
         %
         if load_eps==0;
            if get(boot_nyblom.parametric,'Value')==1;
               %
               % reset the random number generator
               %
               if curr_ini.random_state==2;
                  randn('state',num_draws);
               elseif curr_ini.random_state==3;
                  randn('state',sum(100*clock));
               elseif curr_ini.random_state==4;
                  randn('state',sum(100*clock)+num_draws);
               end;
               %
               Epr = randn(tm.n,my_T+50);
               Epr = Epr(:,51:my_T+50);
               %
               % make sure draws in Epr have identity covariance matrix
               %
               Sig = (1/my_T)*Epr*Epr';
               P_sig = chol(Sig)';
               Epr = P_sig\Epr;
               if curr_ini.symmetric==0;
                  Epr = chol(am.Omega)'*Epr;
               else;
                  Epr = symm(am.Omega)*Epr;
               end;
            else;
               %
               % reset the random number generator
               %
               if curr_ini.random_state==2;
                  rand('state',num_draws);
               elseif curr_ini.random_state==3;
                  rand('state',sum(100*clock));
               elseif curr_ini.random_state==4;
                  rand('state',sum(100*clock)+num_draws);
               end;
               %
               % resample from estimated epsilons
               %
               uni_draws = rand([1 my_T+50]);
               uni_draws = uni_draws(1,51:my_T+50);
               Epr = boot_draw(uni_draws,am.epsilon,blocksize);
            end;
            if get(boot_nyblom.bootstrap,'Value')==1;
               bootstrap(e_draw).epsilon = Epr;
            end;
         else;
            Epr = eps_data.bootstrap(e_draw).epsilon;
         end;
         %
         % create the pseudo data based on the model estimated on the original data
         % and the created residuals
         %
         if d_rank==1;
            boot = bootstrap_sample(am,am.beta,Epr);
         else;
            %
            % where using a model with time varying cointegration rank
            %
            boot = bootstrap_varyrank(am,Epr);
         end;
         %
         % estimate the model based on this data and compute tests; e_parm contains estimates of alpha, beta, Psi, Omega and epsilon
         %
         if tm.restrict(1,2)==0;
            %
            % Base case, no restrictions on the cointegration space
            %
            if curr_ini.fullrec==1;
               [nyblomT,nyblomcorr,e_parm] = boot_nyblom_partial(boot.Z0,boot.Z1,boot.Z2,my_r,tm.p,tm.q1,tm.d,curr_ini.T0,tm.df,min(tm.T,my_T));
            else;
               [nyblomT,nyblomcorr,e_parm] = boot_nyblom_full(boot.Z0,boot.Z1,boot.Z2,my_r,tm.p,tm.q1,tm.d,curr_ini.T0,tm.df,tm.deterselect,min(tm.T,my_T));
            end;
         else;
            %
            % restrictions on the cointegration space are possible
            %
            [nyblomT,nyblomcorr,e_parm] = boot_nyblom_restbeta_fcn(tm,curr_ini,tm.cointbeta,boot.Z0,boot.Z1,boot.Z2,my_T,my_r,min(tm.T,my_T));
         end;
         %
         if test_lr==1;
            lnL_h0 = loglike(e_parm.epsilon);
            %
            % estimate under the alternative
            %
            if first_draw==1;
               %
               % create the data_dummy
               %
               if my_T==tm.T;
                  data_dummy_n = data_dummy;
               else;
                  if tm.altmodel.relsample==1;
                     d_begin = round(d_begin*(my_T/tm.T));
                     d_end = round(d_end*(my_T/tm.T));
                  else;
                     if (d_end==tm.T)&(permdummy==1);
                        d_end = my_T;
                     end;
                  end;
                  %
                  % create the dummy
                  %
                  if (d_begin>1)&(d_end<my_T);
                     data_dummy_n = [zeros(d_begin-1,1);ones(d_end-d_begin+1,1);zeros(my_T-d_end,1)];
                  elseif d_begin==1;
                     data_dummy_n = [ones(d_end,1);zeros(my_T-d_end,1)];
                  else;
                     data_dummy_n = [zeros(d_begin-1,1);ones(my_T-d_begin+1,1)];
                  end;
                  if d_acc==1;
                     data_dummy_n = cumsum(data_dummy_n);
                  end;
               end;
            end;
            %
            % create the data matrices
            %
            boot_n = bootdata_nyblomalt(boot,data_dummy_n,tm.d,d_coint,d_corel,d_shortrun,d_coidet);
            %
            % create restrictions matrices if any under both the null and the alternative
            %
            if first_draw==1;
               %
               % if there are alpha restrictions
               %
               if tm.restrict(1,1)==1;
                  %
                  % Collect alpha restrictions
                  %
                  file = strcat(tm.modelsdir,'G-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
                  G = loaddata(file);
                  dfalpha = size(G,1);
                  [Rmat_a,rvec_a] = rmatrix(G,tm.n,tm.r);
                  if isempty(boot_n.Z2)==0;
                     Rmat_a = [zeros(dfalpha,size(boot_n.Z2,1)*tm.n) Rmat_a];
                  end;
               else;
                  Rmat_a = [];
                  rvec_a = [];
               end;
               %
               % consider restrictions on C
               %
               if (size(tm.restrict,2)==3)&(tm.restrict(1,3)==1);
                  %
                  % collect restrictions on C
                  %
                  file = strcat(tm.modelsdir,'C-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
                  H = loaddata(file);
                  [Rmat_Ca,rvec_Ca] = rmatrix(H,tm.n,tm.n);
                  %
                  % Estimate under C restrictions
                  %
                  d_parm = tm.d;
                  if d_corel==0;
                     d_parm = tm.d+(1-d_coint);
                  end;
               else;
                  Rmat_Ca = [];
                  rvec_Ca = [];
                  d_parm = tm.d;
               end;
               first_draw = 0;
            end;
            %
            % Compute log-likelihood function under the alternative
            %
            lnL_hA = estimate_nyblomalt_alt(tm,boot_n,curr_ini,my_r,my_T,Rmat_a,rvec_a,Rmat_Ca,rvec_Ca,d_parm,d_coint,d_corel,d_coidet);
            %
            % compute the lr_test
            %
            lr_test_boot = 2*(lnL_hA-lnL_h0);
            lr_tests(e_draw,1) = lr_test_boot;
         end;
         %
         % compute the tests and collect the values
         %
         am.NyblomMean = (1/size(nyblomT,2))*sum(nyblomT);
         am.NyblomMax = max(nyblomT);
         max_tests(e_draw,1) = am.NyblomMax;
         mean_tests(e_draw,1) = am.NyblomMean;
         %
         % now we can do the bootstrap run within the experiment
         %
         if get(boot_nyblom.bootstrap,'Value')==1;
            %
            % epsilon-file
            %
            b_epsfile = [curr_ini.simulatedir tm.modelfile '-' usealt tm.restalpha tm.restbeta tm.updating tm.testtype 'epsilon-' num2str(tm.scale_endo,'%0.4f') '-' bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(e_draw) '-' num2str(rep) '-' mod_type '.mat'];
            if fileexist(b_epsfile)==1;
               load_booteps = 1;
               %
               % load old epsilons
               %
               boot_eps_data = load(b_epsfile);
            else;
               load_booteps = 0;
            end;
         else;
            load_booteps = 0;
         end;
         %
         em = tm;
         em.usealtmodel = 0;
         em.alpha = e_parm.alpha;
         em.beta = e_parm.beta;
         em.Psi = e_parm.Psi;
         em.epsilon = e_parm.epsilon;
         em.Omega = e_parm.Omega;
         draw = 1;
         NyblomMax = zeros(rep,1);
         NyblomMean = zeros(rep,1);
         if test_lr==1;
            LRtests = zeros(rep,1);
         end;
         num_draws = num_draws+1;
         while draw<=rep; % should be rep
            %
            % check for bootstrap style
            %
            if load_booteps==0;
               if get(boot_nyblom.parametric,'Value')==1;
                  if showprog==1;
                     abort = get(mywait,'UserData');
                     if strcmp(abort,'cancel')==1;
                        break;
                     else;
                        progressdlg([(draw+(rep*(e_draw-first_rexp)))/(rep*(last_rexp+1-first_rexp)) draw+(rep*(e_draw-1))]);
                     end;
                  end;
                  %
                  % reset the random number generator
                  %
                  if curr_ini.random_state==2;
                     randn('state',num_draws);
                  elseif curr_ini.random_state==3;
                     randn('state',sum(100*clock));
                  elseif curr_ini.random_state==4;
                     randn('state',sum(100*clock)+num_draws);
                  end;
                  %
                  Epr = randn(tm.n,my_T+50);
                  Epr = Epr(:,51:my_T+50);
                  %
                  % make sure draws in Epr have identity covariance matrix
                  %
                  Sig = (1/my_T)*Epr*Epr';
                  P_sig = chol(Sig)';
                  Epr = P_sig\Epr;
                  if curr_ini.symmetric==0;
                     Epr = chol(em.Omega)'*Epr;
                  else;
                     Epr = symm(em.Omega)*Epr;
                  end;
               else;
                  %
                  % reset the random number generator
                  %
                  if curr_ini.random_state==2;
                     rand('state',num_draws);
                  elseif curr_ini.random_state==3;
                     rand('state',sum(100*clock));
                  elseif curr_ini.random_state==4;
                     rand('state',sum(100*clock)+num_draws);
                  end;
                  %
                  % resample from estimated epsilons
                  %
                  uni_draws = rand([1 my_T+50]);
                  uni_draws = uni_draws(1,51:my_T+50);
                  Epr = boot_draw(uni_draws,em.epsilon,blocksize);
               end;
               if get(boot_nyblom.bootstrap,'Value')==1;
                  mc_bootstrap(draw).epsilon = Epr;
               end;
            else;
               Epr = boot_eps_data.mc_bootstrap(draw).epsilon;
            end;
            %
            % construct the bootstrap sample given the em structure
            % estimates
            %
            boot = bootstrap_sample(em,em.beta,Epr);
            %
            if tm.restrict(1,2)==0;
               %
               % Base case, no restrictions on the cointegration space
               %
               if curr_ini.fullrec==1;
                  [nyblomT,nyblomcorr,est_parm] = boot_nyblom_partial(boot.Z0,boot.Z1,boot.Z2,my_r,tm.p,tm.q1,tm.d,curr_ini.T0,tm.df,min(tm.T,my_T));
               else;
                  [nyblomT,nyblomcorr,est_parm] = boot_nyblom_full(boot.Z0,boot.Z1,boot.Z2,my_r,tm.p,tm.q1,tm.d,curr_ini.T0,tm.df,tm.deterselect,min(tm.T,my_T));
               end;
            else;
               %
               % restrictions on the cointegration space are possible
               %
               [nyblomT,nyblomcorr,est_parm] = boot_nyblom_restbeta_fcn(tm,curr_ini,tm.cointbeta,boot.Z0,boot.Z1,boot.Z2,my_T,my_r,min(tm.T,my_T));
            end;
            %
            if test_lr==1;
               %
               % compute the log-likelihood under the null hypothesis
               %
               lnL_h0 = loglike(est_parm.epsilon);
               %
               % fix the boot data to fit the alternative model
               %
               boot_n = bootdata_nyblomalt(boot,data_dummy_n,tm.d,d_coint,d_corel,d_shortrun,d_coidet);
               %
               % compute the log-likelihood under the alternative hypothesis
               %
               lnL_hA = estimate_nyblomalt_alt(tm,boot_n,curr_ini,my_r,my_T,Rmat_a,rvec_a,Rmat_Ca,rvec_Ca,d_parm,d_coint,d_corel,d_coidet);
               %
               % compute the LR-test
               %
               LRtests(draw,1) = 2*(lnL_hA-lnL_h0);
            end;
            %
            % Store bootstrap and max eigenvalue
            %
            NyblomMean(draw,1) = (1/size(nyblomT,2))*sum(nyblomT);
            NyblomMax(draw,1) = max(nyblomT);
            draw = draw+1;
            num_draws = num_draws+1;
         end;
         %
         if strcmp(abort,'cancel')==0;
            %
            % save the bootstrap residuals is requested to
            %
            if get(boot_nyblom.bootstrap,'Value')==1;
               if load_booteps==0;
                  save(b_epsfile,'mc_bootstrap');
               end;
               clear('mc_bootstrap');
            end;
            if test_lr==1;
               LRtests = sort(LRtests);
               lr_mean = lr_mean+LRtests;
               %
               % compare the lr_test_boot value to the bootstrapped LRtests distribution and the asymptotic
               % chi-square distribution
               %
               lr_rej_prob(e_draw,1) = size(LRtests(LRtests>lr_test_boot),1)/rep;
               lr_orig_rej_prob(e_draw,1) = size(LRtests(LRtests>lr_test),1)/rep;
               lr_asymp_rej_prob(e_draw,1) = 1-chis_cdf(lr_test_boot,lr_df);
            end;
            %
            % compare the am.NyblomMax and am.NyblomMean tests to the bootstrap distributions
            %
            NyblomMax = sort(NyblomMax);
            NyblomMean = sort(NyblomMean);
            max_mean = max_mean+NyblomMax;
            mean_mean = mean_mean+NyblomMean;
            %
            mean_rej_prob(e_draw,1) = size(NyblomMean(NyblomMean>am.NyblomMean),1)/rep;
            max_rej_prob(e_draw,1) = size(NyblomMax(NyblomMax>am.NyblomMax),1)/rep;
            %
            mean_orig_rej_prob(e_draw,1) = size(NyblomMean(NyblomMean>tm.NyblomMean),1)/rep;
            max_orig_rej_prob(e_draw,1) = size(NyblomMax(NyblomMax>tm.NyblomMax),1)/rep;
            %
            if (tm.nyblom_asymp==1)&((sum(tm.restrict)==0)|((tm.restrict(1,2)==1)&(tm.dfbeta==0)&(sum(tm.restrict)==1)));
               max_asymp_rej_prob(e_draw,1) = nyblom_pvalues(tm.n,my_r,am.NyblomMax,'max',tm.deterselect);
               mean_asymp_rej_prob(e_draw,1) = nyblom_pvalues(tm.n,my_r,am.NyblomMean,'mean',tm.deterselect);
            end;
            %
            % save the sorted Nyblom tests at least temporarily
            %
            if tm.const_model(1)==1;
               temp_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(e_draw) '-' num2str(rep) '-noconst.mat'];
            elseif tm.const_model(2)==1;
               temp_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(e_draw) '-' num2str(rep) '-resconst.mat'];
            elseif tm.const_model(3)==1;
               temp_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(e_draw) '-' num2str(rep) '-const.mat'];
            elseif tm.const_model(4)==1;
               temp_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(e_draw) '-'  num2str(rep) '-restrend.mat'];
            elseif tm.const_model(5)==1;
               temp_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(e_draw) '-' num2str(rep) '-trend.mat'];
            end;
            if test_lr==0;
               save(temp_mat,'NyblomMax','NyblomMean');
            else;
               altmodel = tm.altmodel;
               save(temp_mat,'NyblomMax','NyblomMean','LRtests','altmodel');
            end;
            if (half_point>0)&(e_draw==half_point);
               %
               % we need to save a part_mat file
               %
               if tm.const_model(1)==1;
                  part_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(half_point*10/num_exp) '-' num2str(rep) '-noconst.mat'];
               elseif tm.const_model(2)==1;
                  part_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(half_point*10/num_exp) '-' num2str(rep) '-resconst.mat'];
               elseif tm.const_model(3)==1;
                  part_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(half_point*10/num_exp) '-' num2str(rep) '-const.mat'];
               elseif tm.const_model(4)==1;
                  part_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(half_point*10/num_exp) '-' num2str(rep) '-restrend.mat'];
               elseif tm.const_model(5)==1;
                  part_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(half_point*10/num_exp) '-' num2str(rep) '-trend.mat'];
               end;
               if test_lr==0;
                  if (tm.nyblom_asymp==1)&((sum(tm.restrict)==0)|((tm.restrict(1,2)==1)&(tm.dfbeta==0)&(sum(tm.restrict)==1)));
                     save(part_mat,'max_orig_rej_prob','mean_orig_rej_prob','max_tests','mean_tests','max_rej_prob','mean_rej_prob','max_asymp_rej_prob','mean_asymp_rej_prob');
                  else;
                     save(part_mat,'max_orig_rej_prob','mean_orig_rej_prob','max_tests','mean_tests','max_rej_prob','mean_rej_prob');
                  end;
               else;
                  altmodel = tm.altmodel;
                  if (tm.nyblom_asymp==1)&((sum(tm.restrict)==0)|((tm.restrict(1,2)==1)&(tm.dfbeta==0)&(sum(tm.restrict)==1)));
                     save(part_mat,'max_orig_rej_prob','mean_orig_rej_prob','max_tests','mean_tests','max_rej_prob','mean_rej_prob','lr_tests','lr_rej_prob','lr_orig_rej_prob','lr_asymp_rej_prob','altmodel','max_asymp_rej_prob','mean_asymp_rej_prob');
                  else;
                     save(part_mat,'max_orig_rej_prob','mean_orig_rej_prob','max_tests','mean_tests','max_rej_prob','mean_rej_prob','lr_tests','lr_rej_prob','lr_orig_rej_prob','lr_asymp_rej_prob','altmodel');
                  end;
               end;
            end;
         else;
            break;
         end;
         %
         e_draw = e_draw+1;
      end;
      %
      % done with the experiments
      % check if the user cancelled
      %
      if showprog==1;
         set(mywait,'UserData','done');
         close(mywait);
         drawnow;
      else;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
         new_time = toc;
         my_hrs = '00';
         my_min = '00';
         my_sec = num2str(new_time,'%0.2f');
         if new_time>=60;
            ch_min = floor(new_time/60);
            my_sec = num2str(new_time-(ch_min*60),'%0.2f');
            my_min = num2str(ch_min,'%0.0f');
            if ch_min>=60;
               ch_hrs = floor(ch_min/60);
               my_min = num2str(ch_min-(ch_hrs*60),'%0.0f');
               my_hrs = num2str(ch_hrs,'%0.0f');
            end;
         end;
         if size(my_sec,2)==4;
            my_sec = ['0' my_sec];
         end;
         if size(my_min,2)==1;
            my_min = ['0' my_min];
         end;
         if size(my_hrs,2)==1;
            my_hrs = ['0' my_hrs];
         end;
         clock_str = [my_hrs ':' my_min ':' my_sec];
         this_text = strvcat(' ','The Monte Carlo bootstrap process took:',' ',['    ' clock_str ' (hrs:min:sec)']);
         about(this_text,'bootstrap','Monte Carlo Simulation Time',120,350);
      end;
      %
      % check is user cancelled
      %
      if strcmp(abort,'cancel')==0;
         %
         % check if we should save certain additional variables to disk to allow partial runs of experiments
         % without loss of data
         %
         if rexp_value>1;
            if half_point>0;
               file_number = last_rexp*10/num_exp;
            else;
               file_number = rexp_value-1;
            end;
            if tm.const_model(1)==1;
               part_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(file_number) '-' num2str(rep) '-noconst.mat'];
            elseif tm.const_model(2)==1;
               part_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(file_number) '-' num2str(rep) '-resconst.mat'];
            elseif tm.const_model(3)==1;
               part_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(file_number) '-' num2str(rep) '-const.mat'];
            elseif tm.const_model(4)==1;
               part_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(file_number) '-' num2str(rep) '-restrend.mat'];
            elseif tm.const_model(5)==1;
               part_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(file_number) '-' num2str(rep) '-trend.mat'];
            end;
            if test_lr==0;
               if (tm.nyblom_asymp==1)&((sum(tm.restrict)==0)|((tm.restrict(1,2)==1)&(tm.dfbeta==0)&(sum(tm.restrict)==1)));
                  save(part_mat,'max_orig_rej_prob','mean_orig_rej_prob','max_tests','mean_tests','max_rej_prob','mean_rej_prob','max_asymp_rej_prob','mean_asymp_rej_prob');
               else;
                  save(part_mat,'max_orig_rej_prob','mean_orig_rej_prob','max_tests','mean_tests','max_rej_prob','mean_rej_prob');
               end;
            else;
               altmodel = tm.altmodel;
               if (tm.nyblom_asymp==1)&((sum(tm.restrict)==0)|((tm.restrict(1,2)==1)&(tm.dfbeta==0)&(sum(tm.restrict)==1)));
                  save(part_mat,'max_orig_rej_prob','mean_orig_rej_prob','max_tests','mean_tests','max_rej_prob','mean_rej_prob','lr_tests','lr_rej_prob','lr_orig_rej_prob','lr_asymp_rej_prob','altmodel','max_asymp_rej_prob','mean_asymp_rej_prob');
               else;
                  save(part_mat,'max_orig_rej_prob','mean_orig_rej_prob','max_tests','mean_tests','max_rej_prob','mean_rej_prob','lr_tests','lr_rej_prob','lr_orig_rej_prob','lr_asymp_rej_prob','altmodel');
               end;
            end;
            %
            % fix the string property of the boot_nyblom.runexperiments object
            %
            low_lim = 1;
            up_lim = 0.1*num_exp;
            add_lim = up_lim;
            this_str = 'Run all experiments';
            for i=1:10;
               if tm.const_model(1)==1;
                  npart_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(i) '-' num2str(rep) '-noconst.mat'];
               elseif tm.const_model(2)==1;
                  npart_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(i) '-' num2str(rep) '-resconst.mat'];
               elseif tm.const_model(3)==1;
                  npart_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(i) '-' num2str(rep) '-const.mat'];
               elseif tm.const_model(4)==1;
                  npart_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(i) '-' num2str(rep) '-restrend.mat'];
               elseif tm.const_model(5)==1;
                  npart_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(i) '-' num2str(rep) '-trend.mat'];
               end;
               %
               if fileexist(npart_mat)==1;
                  exp_exist_str = ' (done)';
               else;
                  exp_exist_str = '';
               end;
               %
               this_str = [this_str '|Run expmnts ' num2str(low_lim) '-' num2str(up_lim) exp_exist_str];
               low_lim = low_lim+add_lim;
               up_lim = up_lim+add_lim;
            end;
            %
            low_lim = 1;
            up_lim = 0.2*num_exp;
            add_lim = up_lim;
            for i=1:5;
               num = 2*(i-1);
               if tm.const_model(1)==1;
                  part_mat_1 = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(1+num) '-' num2str(rep) '-noconst.mat'];
                  part_mat_2 = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(2+num) '-' num2str(rep) '-noconst.mat'];
               elseif tm.const_model(2)==1;
                  part_mat_1 = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(1+num) '-' num2str(rep) '-resconst.mat'];
                  part_mat_2 = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(2+num) '-' num2str(rep) '-resconst.mat'];
               elseif tm.const_model(3)==1;
                  part_mat_1 = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(1+num) '-' num2str(rep) '-const.mat'];
                  part_mat_2 = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(2+num) '-' num2str(rep) '-const.mat'];
               elseif tm.const_model(4)==1;
                  part_mat_1 = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(1+num) '-' num2str(rep) '-restrend.mat'];
                  part_mat_2 = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(2+num) '-' num2str(rep) '-restrend.mat'];
               elseif tm.const_model(5)==1;
                  part_mat_1 = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(1+num) '-' num2str(rep) '-trend.mat'];
                  part_mat_2 = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.part-' num2str(2+num) '-' num2str(rep) '-trend.mat'];
               end;
               %
               if (fileexist(part_mat_1)==1)&(fileexist(part_mat_2)==1);
                  exp_exist_str = ' (done)';
               else;
                  exp_exist_str = '';
               end;
               %
               this_str = [this_str '|Run expmnts ' num2str(low_lim) '-' num2str(up_lim) exp_exist_str];
               low_lim = low_lim+add_lim;
               up_lim = up_lim+add_lim;
            end;
            %
            set(boot_nyblom.runexperiments,'String',this_str);
            %
            check_full = ( max_tests==0 );
            if max(check_full)==1;
               %
               % we haven't run all the experiments yet
               %
               tm.nyblom_run = 0;
               set(nyblom_boot_gui,'Visible','on');
               drawnow;
               clear('max_orig_rej_prob','mean_orig_rej_prob','max_tests','mean_tests','max_rej_prob','mean_rej_prob');
               if (tm.nyblom_asymp==1)&((sum(tm.restrict)==0)|((tm.restrict(1,2)==1)&(tm.dfbeta==0)&(sum(tm.restrict)==1)));
                  clear('max_asymp_rej_prob','mean_asymp_rej_prob');
               end;
               if (get(boot_nyblom.bootstrap,'Value')==1)&(load_eps==0);
                  save(epsfile,'bootstrap');
               end;
               if test_lr==1;
                  clear('lr_tests','lr_rej_prob','lr_orig_rej_prob','lr_asymp_rej_prob');
               end;
               setlogtext(['Experiments ' num2str(first_rexp,'%0.0f') '-' num2str(last_rexp,'%0.0f') ' completed at: ' datestr(now,14) '!']);
               return;
            end;
         end;
         %
         % save epsilon's and unsorted tests to disk if asked to do so
         %
         NyblomMax = max_tests;
         NyblomMean = mean_tests;
         clear('max_tests','mean_tests');
         %
         this_text = strvcat(' ','Saving Monte Carlo bootstrap results to disk...','Please hold!');
         mywait = waitdlg(this_text,'bootstrap','Nyblom Tests Bootstrap Simulation');
         waitf = get(mywait,'UserData');
         if get(boot_nyblom.bootstrap,'Value')==1;
            if load_eps==0;
               save(epsfile,'bootstrap');
            end;
            clear('bootstrap');
            if test_lr==0;
               test_data = [NyblomMean NyblomMax];
            else;
               ch_lr = sum(lr_tests>0);
               if ch_lr==size(lr_tests,1);
                  test_data = [NyblomMean NyblomMax lr_tests];
               else;
                  test_data = [NyblomMean NyblomMax];
               end;
            end;
            testfile = strrep(epsfile,'.mat','-testdata.mat');
            save(testfile,'test_data');
            clear('test_data');
            set(boot_nyblom.bootstrapgraph,'Enable','on','UserData',epsfile);
            set(boot_nyblom.bootstrapgraphmenu,'Enable','on','UserData',testfile);
         end;
         setlogtext(['Monte Carlo bootstraps completed at: ' datestr(now,14) '!']);
         NyblomMean = sort(NyblomMean);
         NyblomMax = sort(NyblomMax);
         set(boot_nyblom.rep,'UserData',rep);
         set(boot_nyblom.obs,'UserData',my_T);
         set(boot_nyblom.my_r,'UserData',my_r);
         set(boot_nyblom.displaymenu,'Enable','on','UserData',tm.const_model);
         if tm.const_model(2)==1;
            my_mod = 'Restricted constant';
         elseif tm.const_model(3)==1;
            my_mod = 'Constant';
         elseif tm.const_model(4)==1;
            my_mod = 'Restricted linear trend';
         elseif tm.const_model(5)==1;
            my_mod = 'Linear trend';
         end;
         %
         % compute the means of the quantiles across experiments
         %
         max_mean = (1/num_exp)*max_mean;
         mean_mean = (1/num_exp)*mean_mean;
         %
         %
         %
         if test_lr==1;
            ch_lr = sum(lr_tests>0);
            if ch_lr==size(lr_tests,1);
               lr_tests = sort(lr_tests);
               lr_mean = (1/num_exp)*lr_mean;
            end;
         end;
         %
         % save the full simulation
         %
         if get(boot_nyblom.save,'Value')==1;
            this_text = strvcat(' ','Saving Monte Carlo bootstrapped Nyblom tests to disk...','Please hold!');
            set(waitf.text,'String',this_text);
            setlogtext('Saving results to mat-files...');
            if tm.const_model(1)==1;
               full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '-' num2str(rep) '-noconst.mat'];
            elseif tm.const_model(2)==1;
               full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '-' num2str(rep) '-resconst.mat'];
            elseif tm.const_model(3)==1;
               full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '-' num2str(rep) '-const.mat'];
            elseif tm.const_model(4)==1;
               full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '-' num2str(rep) '-restrend.mat'];
            elseif tm.const_model(5)==1;
               full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '-' num2str(rep) '-trend.mat'];
            end;
            Number = (1:1:num_exp)';
            if test_lr==0;
               save(full_mat,'Number','NyblomMax','NyblomMean','max_mean','mean_mean');
            else;
               if ch_lr==size(lr_tests,1);
                  boot_lr_test = lr_tests;
                  save(full_mat,'Number','NyblomMax','NyblomMean','max_mean','mean_mean','boot_lr_test','lr_test','lr_df','lr_mean');
               else;
                  save(full_mat,'Number','NyblomMax','NyblomMean','max_mean','mean_mean');
               end;
            end;
            set(boot_nyblom.fullmenu,'Enable','on','UserData',full_mat);
            set(boot_nyblom.full,'Enable','on');
         end;
         setlogtext('Saving Monte Carlo simulation summary to text file...');
         %
         max_orig_rej_prob = sort(max_orig_rej_prob);
         mean_orig_rej_prob = sort(mean_orig_rej_prob);
         %
         % collect results
         %
         boot_rej_prob = zeros(6,2);
         boot_rej_prob(1,1) = size(max_rej_prob(max_rej_prob<=0.01),1);
         boot_rej_prob(2,1) = size(max_rej_prob(max_rej_prob<=0.02),1);
         boot_rej_prob(3,1) = size(max_rej_prob(max_rej_prob<=0.05),1);
         boot_rej_prob(4,1) = size(max_rej_prob(max_rej_prob<=0.10),1);
         boot_rej_prob(5,1) = size(max_rej_prob(max_rej_prob<=0.20),1);
         boot_rej_prob(6,1) = size(max_rej_prob(max_rej_prob<=0.50),1);
         %
         boot_rej_prob(1,2) = size(mean_rej_prob(mean_rej_prob<=0.01),1);
         boot_rej_prob(2,2) = size(mean_rej_prob(mean_rej_prob<=0.02),1);
         boot_rej_prob(3,2) = size(mean_rej_prob(mean_rej_prob<=0.05),1);
         boot_rej_prob(4,2) = size(mean_rej_prob(mean_rej_prob<=0.10),1);
         boot_rej_prob(5,2) = size(mean_rej_prob(mean_rej_prob<=0.20),1);
         boot_rej_prob(6,2) = size(mean_rej_prob(mean_rej_prob<=0.50),1);
         %
         boot_rej_prob = (1/num_exp)*boot_rej_prob;
         %
         asymp_rej_prob = [];
         if (tm.nyblom_asymp==1)&((sum(tm.restrict)==0)|((tm.restrict(1,2)==1)&(tm.dfbeta==0)&(sum(tm.restrict)==1)));
            asymp_rej_prob = zeros(6,2);
            asymp_rej_prob(1,1) = size(max_asymp_rej_prob(max_asymp_rej_prob<=0.01),1);
            asymp_rej_prob(2,1) = size(max_asymp_rej_prob(max_asymp_rej_prob<=0.02),1);
            asymp_rej_prob(3,1) = size(max_asymp_rej_prob(max_asymp_rej_prob<=0.05),1);
            asymp_rej_prob(4,1) = size(max_asymp_rej_prob(max_asymp_rej_prob<=0.10),1);
            asymp_rej_prob(5,1) = size(max_asymp_rej_prob(max_asymp_rej_prob<=0.20),1);
            asymp_rej_prob(6,1) = size(max_asymp_rej_prob(max_asymp_rej_prob<=0.50),1);
            %
            asymp_rej_prob(1,2) = size(mean_asymp_rej_prob(mean_asymp_rej_prob<=0.01),1);
            asymp_rej_prob(2,2) = size(mean_asymp_rej_prob(mean_asymp_rej_prob<=0.02),1);
            asymp_rej_prob(3,2) = size(mean_asymp_rej_prob(mean_asymp_rej_prob<=0.05),1);
            asymp_rej_prob(4,2) = size(mean_asymp_rej_prob(mean_asymp_rej_prob<=0.10),1);
            asymp_rej_prob(5,2) = size(mean_asymp_rej_prob(mean_asymp_rej_prob<=0.20),1);
            asymp_rej_prob(6,2) = size(mean_asymp_rej_prob(mean_asymp_rej_prob<=0.50),1);
            %
            asymp_rej_prob = (1/num_exp)*asymp_rej_prob;
         end;
         %
         boot_lr_rej_prob = [];
         asymp_lr_rej_prob = [];
         if test_lr==1;
            if ch_lr==size(lr_tests,1);
               lr_orig_rej_prob = sort(lr_orig_rej_prob);
               boot_lr_rej_prob = zeros(6,1);
               boot_lr_rej_prob(1,1) = size(lr_rej_prob(lr_rej_prob<=0.01),1);
               boot_lr_rej_prob(2,1) = size(lr_rej_prob(lr_rej_prob<=0.02),1);
               boot_lr_rej_prob(3,1) = size(lr_rej_prob(lr_rej_prob<=0.05),1);
               boot_lr_rej_prob(4,1) = size(lr_rej_prob(lr_rej_prob<=0.10),1);
               boot_lr_rej_prob(5,1) = size(lr_rej_prob(lr_rej_prob<=0.20),1);
               boot_lr_rej_prob(6,1) = size(lr_rej_prob(lr_rej_prob<=0.50),1);
               %
               boot_lr_rej_prob = (1/num_exp)*boot_lr_rej_prob;
               %
               asymp_lr_rej_prob = zeros(6,1);
               asymp_lr_rej_prob(1,1) = size(lr_asymp_rej_prob(lr_asymp_rej_prob<=0.01),1);
               asymp_lr_rej_prob(2,1) = size(lr_asymp_rej_prob(lr_asymp_rej_prob<=0.02),1);
               asymp_lr_rej_prob(3,1) = size(lr_asymp_rej_prob(lr_asymp_rej_prob<=0.05),1);
               asymp_lr_rej_prob(4,1) = size(lr_asymp_rej_prob(lr_asymp_rej_prob<=0.10),1);
               asymp_lr_rej_prob(5,1) = size(lr_asymp_rej_prob(lr_asymp_rej_prob<=0.20),1);
               asymp_lr_rej_prob(6,1) = size(lr_asymp_rej_prob(lr_asymp_rej_prob<=0.50),1);
               %
               asymp_lr_rej_prob = (1/num_exp)*asymp_lr_rej_prob;
            end;
         end;
         %
         my_50 = floor(0.5*rep);
         my_80 = floor(0.8*rep);
         my_90 = floor(0.9*rep);
         my_95 = floor(0.95*rep);
         my_975 = floor(0.98*rep);
         my_99 = floor(0.99*rep);
         aw_lower_upper = [ceil(0.005*num_exp) ceil(0.01*num_exp) ceil(0.025*num_exp) ceil(0.05*num_exp) ceil(0.1*num_exp) ceil(0.25*num_exp);ceil(0.995*num_exp) ceil(0.99*num_exp) ceil(0.975*num_exp) ceil(0.95*num_exp) ceil(0.9*num_exp) ceil(0.75*num_exp)];
         %
         % reopen all temporary files to determine the mean and the standard deviations of the quantiles across experiments
         %
         max_std = zeros(rep,1);
         mean_std = zeros(rep,1);
         dist_max = zeros(num_exp,6);
         dist_mean = zeros(num_exp,6);
         lr_std = [];
         dist_lr = [];
         lr_exist = 0;
         if test_lr==1;
            if ch_lr==size(lr_tests,1);
               lr_std = zeros(rep,1);
               dist_lr = zeros(num_exp,6);
               lr_exist = 1;
            end;
         end;
         for e_draw=1:num_exp;
            if tm.const_model(1)==1;
               temp_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(e_draw) '-' num2str(rep) '-noconst.mat'];
            elseif tm.const_model(2)==1;
               temp_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(e_draw) '-' num2str(rep) '-resconst.mat'];
            elseif tm.const_model(3)==1;
               temp_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(e_draw) '-' num2str(rep) '-const.mat'];
            elseif tm.const_model(4)==1;
               temp_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(e_draw) '-'  num2str(rep) '-restrend.mat'];
            elseif tm.const_model(5)==1;
               temp_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '.' num2str(e_draw) '-' num2str(rep) '-trend.mat'];
            end;
            if fileexist(temp_mat)==1;
               temp_data = load(temp_mat);
               max_std = max_std+((temp_data.NyblomMax-max_mean).*(temp_data.NyblomMax-max_mean));
               mean_std = mean_std+((temp_data.NyblomMean-mean_mean).*(temp_data.NyblomMean-mean_mean));
               dist_max(e_draw,:) = [temp_data.NyblomMax(my_99,1) temp_data.NyblomMax(my_975,1) temp_data.NyblomMax(my_95,1) temp_data.NyblomMax(my_90,1) temp_data.NyblomMax(my_80,1) temp_data.NyblomMax(my_50,1)];
               dist_mean(e_draw,:) = [temp_data.NyblomMean(my_99,1) temp_data.NyblomMean(my_975,1) temp_data.NyblomMean(my_95,1) temp_data.NyblomMean(my_90,1) temp_data.NyblomMean(my_80,1) temp_data.NyblomMean(my_50,1)];
               %
               if (isempty(lr_std)==0)&(isfield(temp_data,'LRtests')==1)&(isfield(temp_data,'altmodel')==1);
                  if check_altmodel_nyblom(tm.altmodel,temp_data.altmodel)==1;
                     lr_std = lr_std+((temp_data.LRtests-lr_mean).*(temp_data.LRtests-lr_mean));
                     dist_lr(e_draw,:) = [temp_data.LRtests(my_99,1) temp_data.LRtests(my_975,1) temp_data.LRtests(my_95,1) temp_data.LRtests(my_90,1) temp_data.LRtests(my_80,1) temp_data.LRtests(my_50,1)];
                  else;
                     lr_exist = 0;
                  end;
               else;
                  lr_exist = 0;
               end;
               clear('temp_data');
               %
               % now delete the file unless the user has requested to save mat files
               %
               if get(boot_nyblom.save,'Value')==0;
                  delete_file_fcn(temp_mat);
               end;
            end;
         end;
         for i=1:6;
            dist_max(:,i) = sort(dist_max(:,i));
            dist_mean(:,i) = sort(dist_mean(:,i));
            if lr_exist==1;
               dist_lr(:,i) = sort(dist_lr(:,i));
            end;
         end;
         max_std = sqrt((1/num_exp)*max_std);
         mean_std = sqrt((1/num_exp)*mean_std);
         if lr_exist==1;
            lr_std = sqrt((1/num_exp)*lr_std);
         end;
         %
         % write summary to file
         %
         res_str = strvcat(' ','**************************************************************','*                          Results                           *');
         res_str = strvcat(res_str,'**************************************************************',' ',['  Model:                   ' my_mod],['  Endogenous variables:    ' num2str(tm.n,'%0.0f')],['  Cointegration relations: ' num2str(my_r,'%0.0f')],['  Experiments:             ' num2str(num_exp,'%0.0f')],['  Replications:            ' num2str(rep,'%0.0f')],['  Draws per replication:   ' num2str(my_T,'%0.0f')]);
         if blocksize>1;
            res_str = strvcat(res_str,' ',strrep(block_txt,'.',''),' ');
         end;
         if curr_ini.taylor_nyblom==0;
            res_str = strvcat(res_str,'  Method:                  Scores version');
         else;
            res_str = strvcat(res_str,'  Method:                  First-order Taylor expansion version');
         end;
         if curr_ini.fullrec==0;
            res_str = strvcat(res_str,'                           updating all parameters in recursion',' ');
         else;
            res_str = strvcat(res_str,'                           conditional on full-sample estimates of delta','                           and Gamma_i parameters in recursion',' ');
         end;
         if strcmp(alt_state,'on')==1;
            %
            % we have an alternative model
            %
            res_str = strvcat(res_str,'  Using alternative model for DGP with properties:',' ');
            if tempdummy==1;
               add_res_str = '       Temporary dummy';
            else;
               add_res_str = '       Permanent dummy';
            end;
            if d_acc==1;
               add_res_str = lower(add_res_str);
               add_res_str = strrep(add_res_str,'       ','       Accumulated');
            end;               
            if d_corel==1;
               if d_rank==1;
                  if d_coidet==0;
                     add_res_str = [add_res_str ' applied to the cointegration relations'];
                  else;
                     if tm.deterselect(1,2)==1;
                        add_res_str = strvcat([add_res_str ' applied to the cointegration relations, but not to the'],'       restricted constant');
                     elseif tm.deterselect(1,4)==1;
                        add_res_str = strvcat([add_res_str ' applied to the cointegration relations, but not to the'],'       restricted linear trend');
                     end;
                  end;
               else;
                  add_res_str = strvcat([add_res_str ' applied to the cointegration relations'],'       and alpha with rank:',['          ' num2str(r_0) ' when dummy is 0'],['          ' num2str(r_1) ' when dummy is 1']);
               end;
            elseif d_shortrun==1;
               add_res_str = [add_res_str ' applied to the short-run dynamics'];
            elseif d_coint==1;
               add_res_str = [add_res_str ' restricted to the cointegration space'];
            end;
            if tm.altmodel.relsample==1;
               du_begin = round(d_begin*(my_T/tm.T));
               du_end = round(d_end*(my_T/tm.T));
            else;
               du_begin = d_begin;
               du_end = d_end;
               if (d_end==tm.T)&(permdummy==1);
                  du_end = my_T;
               end;
            end;
            res_str = strvcat(res_str,add_res_str,['       Dummy is active between period ' num2str(du_begin,'%0.0f') ' and ' num2str(du_end,'%0.0f')],' ');
         end;
         %
         sp_str = spacestr(curr_ini.decimals-2);
         prt_val = ['%' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
         res_str = strvcat(res_str,'                           Supremum test','                           -------------',' ','        Rejection rates at bootstrap size','  50%     20%     10%      5%      2%      1%');
         res_str = strvcat(res_str,sprintf('%6.2f  %6.2f  %6.2f  %6.2f  %6.2f  %6.2f',100*boot_rej_prob(6,1),100*boot_rej_prob(5,1),100*boot_rej_prob(4,1),100*boot_rej_prob(3,1),100*boot_rej_prob(2,1),100*boot_rej_prob(1,1)));
         if (tm.nyblom_asymp==1)&((sum(tm.restrict)==0)|((tm.restrict(1,2)==1)&(tm.dfbeta==0)&(sum(tm.restrict)==1)));
            res_str = strvcat(res_str,' ','        Rejection rates at asymptotic size');
            res_str = strvcat(res_str,sprintf('%6.2f  %6.2f  %6.2f  %6.2f  %6.2f  %6.2f',100*asymp_rej_prob(6,1),100*asymp_rej_prob(5,1),100*asymp_rej_prob(4,1),100*asymp_rej_prob(3,1),100*asymp_rej_prob(2,1),100*asymp_rej_prob(1,1)));
         end;
         res_str = strvcat(res_str,' ','      Quantile moments for bootstrap distributions',['moment        50%    ' sp_str '    80%    ' sp_str '    90%    ' sp_str '    95%    ' sp_str '    98%   ' sp_str '     99%']);
         res_str = strvcat(res_str,sprintf(['mean      ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],max_mean(my_50,1),max_mean(my_80,1),max_mean(my_90,1),max_mean(my_95,1),max_mean(my_975,1),max_mean(my_99,1)));
         res_str = strvcat(res_str,sprintf(['st. dev.  ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],max_std(my_50,1),max_std(my_80,1),max_std(my_90,1),max_std(my_95,1),max_std(my_975,1),max_std(my_99,1)),' ');
         %
         % display confidence bands
         %
         res_str = strvcat(res_str,'      Confidence bands for quantiles',['size\\quantile          50%         ' sp_str sp_str '          80%         ' sp_str sp_str '          90%         ' sp_str sp_str '          95%        ' sp_str sp_str '           98%        ' sp_str sp_str '           99%']);
         res_str = strvcat(res_str,sprintf(['[  50%         [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],dist_max(aw_lower_upper(1,6),6),dist_max(aw_lower_upper(2,6),6),dist_max(aw_lower_upper(1,6),5),dist_max(aw_lower_upper(2,6),5),dist_max(aw_lower_upper(1,6),4),dist_max(aw_lower_upper(2,6),4),dist_max(aw_lower_upper(1,6),3),dist_max(aw_lower_upper(2,6),3),dist_max(aw_lower_upper(1,6),2),dist_max(aw_lower_upper(2,6),2),dist_max(aw_lower_upper(1,6),1),dist_max(aw_lower_upper(2,6),1)));
         res_str = strvcat(res_str,sprintf(['[  80%         [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],dist_max(aw_lower_upper(1,5),6),dist_max(aw_lower_upper(2,5),6),dist_max(aw_lower_upper(1,5),5),dist_max(aw_lower_upper(2,5),5),dist_max(aw_lower_upper(1,5),4),dist_max(aw_lower_upper(2,5),4),dist_max(aw_lower_upper(1,5),3),dist_max(aw_lower_upper(2,5),3),dist_max(aw_lower_upper(1,5),2),dist_max(aw_lower_upper(2,5),2),dist_max(aw_lower_upper(1,5),1),dist_max(aw_lower_upper(2,5),1)));
         res_str = strvcat(res_str,sprintf(['[  90%         [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],dist_max(aw_lower_upper(1,4),6),dist_max(aw_lower_upper(2,4),6),dist_max(aw_lower_upper(1,4),5),dist_max(aw_lower_upper(2,4),5),dist_max(aw_lower_upper(1,4),4),dist_max(aw_lower_upper(2,4),4),dist_max(aw_lower_upper(1,4),3),dist_max(aw_lower_upper(2,4),3),dist_max(aw_lower_upper(1,4),2),dist_max(aw_lower_upper(2,4),2),dist_max(aw_lower_upper(1,4),1),dist_max(aw_lower_upper(2,4),1)));
         res_str = strvcat(res_str,sprintf(['[  95%         [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],dist_max(aw_lower_upper(1,3),6),dist_max(aw_lower_upper(2,3),6),dist_max(aw_lower_upper(1,3),5),dist_max(aw_lower_upper(2,3),5),dist_max(aw_lower_upper(1,3),4),dist_max(aw_lower_upper(2,3),4),dist_max(aw_lower_upper(1,3),3),dist_max(aw_lower_upper(2,3),3),dist_max(aw_lower_upper(1,3),2),dist_max(aw_lower_upper(2,3),2),dist_max(aw_lower_upper(1,3),1),dist_max(aw_lower_upper(2,3),1)));
         res_str = strvcat(res_str,sprintf(['[  98%         [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],dist_max(aw_lower_upper(1,2),6),dist_max(aw_lower_upper(2,2),6),dist_max(aw_lower_upper(1,2),5),dist_max(aw_lower_upper(2,2),5),dist_max(aw_lower_upper(1,2),4),dist_max(aw_lower_upper(2,2),4),dist_max(aw_lower_upper(1,2),3),dist_max(aw_lower_upper(2,2),3),dist_max(aw_lower_upper(1,2),2),dist_max(aw_lower_upper(2,2),2),dist_max(aw_lower_upper(1,2),1),dist_max(aw_lower_upper(2,2),1)));
         res_str = strvcat(res_str,sprintf(['[  99%         [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],dist_max(aw_lower_upper(1,1),6),dist_max(aw_lower_upper(2,1),6),dist_max(aw_lower_upper(1,1),5),dist_max(aw_lower_upper(2,1),5),dist_max(aw_lower_upper(1,1),4),dist_max(aw_lower_upper(2,1),4),dist_max(aw_lower_upper(1,1),3),dist_max(aw_lower_upper(2,1),3),dist_max(aw_lower_upper(1,1),2),dist_max(aw_lower_upper(2,1),2),dist_max(aw_lower_upper(1,1),1),dist_max(aw_lower_upper(2,1),1)),' ');
         %
         % p-value information
         %
         res_str = strvcat(res_str,'      Original test value and p-value properties',' ',['sup Q(t|T) = ' num2str(tm.NyblomMax,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])]);
         max_pval_mean = (1/num_exp)*sum(max_orig_rej_prob);
         max_pval_std = sqrt((1/num_exp)*sum( (max_orig_rej_prob-max_pval_mean).*(max_orig_rej_prob-max_pval_mean) ));
         res_str = strvcat(res_str,['mean p-value =     ' num2str(max_pval_mean,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])]);
         res_str = strvcat(res_str,['st. dev. p-value = ' num2str(max_pval_std,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])],' ');
         res_str = strvcat(res_str,'      Confidence bands for p-values');
         res_str = strvcat(res_str,['  50%         [' num2str(max_orig_rej_prob(aw_lower_upper(1,6),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ',' num2str(max_orig_rej_prob(aw_lower_upper(2,6),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ']']);
         res_str = strvcat(res_str,['  80%         [' num2str(max_orig_rej_prob(aw_lower_upper(1,5),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ',' num2str(max_orig_rej_prob(aw_lower_upper(2,5),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ']']);
         res_str = strvcat(res_str,['  90%         [' num2str(max_orig_rej_prob(aw_lower_upper(1,4),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ',' num2str(max_orig_rej_prob(aw_lower_upper(2,4),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ']']);
         res_str = strvcat(res_str,['  95%         [' num2str(max_orig_rej_prob(aw_lower_upper(1,3),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ',' num2str(max_orig_rej_prob(aw_lower_upper(2,3),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ']']);
         res_str = strvcat(res_str,['  98%         [' num2str(max_orig_rej_prob(aw_lower_upper(1,2),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ',' num2str(max_orig_rej_prob(aw_lower_upper(2,2),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ']']);
         res_str = strvcat(res_str,['  99%         [' num2str(max_orig_rej_prob(aw_lower_upper(1,1),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ',' num2str(max_orig_rej_prob(aw_lower_upper(2,1),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ']'],' ');
         %
         res_str = strvcat(res_str,'                           Mean test','                           ---------',' ','        Rejection rates at bootstrap size','  50%     20%     10%      5%      2%      1%');
         res_str = strvcat(res_str,sprintf('%6.2f  %6.2f  %6.2f  %6.2f  %6.2f  %6.2f',100*boot_rej_prob(6,2),100*boot_rej_prob(5,2),100*boot_rej_prob(4,2),100*boot_rej_prob(3,2),100*boot_rej_prob(2,2),100*boot_rej_prob(1,2)));
         if (tm.nyblom_asymp==1)&((sum(tm.restrict)==0)|((tm.restrict(1,2)==1)&(tm.dfbeta==0)&(sum(tm.restrict)==1)));
            res_str = strvcat(res_str,' ','        Rejection rates at asymptotic size');
            res_str = strvcat(res_str,sprintf('%6.2f  %6.2f  %6.2f  %6.2f  %6.2f  %6.2f',100*asymp_rej_prob(6,2),100*asymp_rej_prob(5,2),100*asymp_rej_prob(4,2),100*asymp_rej_prob(3,2),100*asymp_rej_prob(2,2),100*asymp_rej_prob(1,2)));
         end;
         res_str = strvcat(res_str,' ','      Quantile moments for bootstrap distributions',['moment        50%    ' sp_str '    80%    ' sp_str '    90%    ' sp_str '    95%    ' sp_str '    98%   ' sp_str '     99%']);
         res_str = strvcat(res_str,sprintf(['mean      ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],mean_mean(my_50,1),mean_mean(my_80,1),mean_mean(my_90,1),mean_mean(my_95,1),mean_mean(my_975,1),mean_mean(my_99,1)));
         res_str = strvcat(res_str,sprintf(['st. dev.  ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],mean_std(my_50,1),mean_std(my_80,1),mean_std(my_90,1),mean_std(my_95,1),mean_std(my_975,1),mean_std(my_99,1)),' ');
         %
         % display confidence bands
         %
         res_str = strvcat(res_str,'      Confidence bands for quantiles',['size\\quantile          50%         ' sp_str sp_str '          80%         ' sp_str sp_str '          90%         ' sp_str sp_str '          95%        ' sp_str sp_str '           98%        ' sp_str sp_str '           99%']);
         res_str = strvcat(res_str,sprintf(['[  50%         [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],dist_mean(aw_lower_upper(1,6),6),dist_mean(aw_lower_upper(2,6),6),dist_mean(aw_lower_upper(1,6),5),dist_mean(aw_lower_upper(2,6),5),dist_mean(aw_lower_upper(1,6),4),dist_mean(aw_lower_upper(2,6),4),dist_mean(aw_lower_upper(1,6),3),dist_mean(aw_lower_upper(2,6),3),dist_mean(aw_lower_upper(1,6),2),dist_mean(aw_lower_upper(2,6),2),dist_mean(aw_lower_upper(1,6),1),dist_mean(aw_lower_upper(2,6),1)));
         res_str = strvcat(res_str,sprintf(['[  80%         [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],dist_mean(aw_lower_upper(1,5),6),dist_mean(aw_lower_upper(2,5),6),dist_mean(aw_lower_upper(1,5),5),dist_mean(aw_lower_upper(2,5),5),dist_mean(aw_lower_upper(1,5),4),dist_mean(aw_lower_upper(2,5),4),dist_mean(aw_lower_upper(1,5),3),dist_mean(aw_lower_upper(2,5),3),dist_mean(aw_lower_upper(1,5),2),dist_mean(aw_lower_upper(2,5),2),dist_mean(aw_lower_upper(1,5),1),dist_mean(aw_lower_upper(2,5),1)));
         res_str = strvcat(res_str,sprintf(['[  90%         [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],dist_mean(aw_lower_upper(1,4),6),dist_mean(aw_lower_upper(2,4),6),dist_mean(aw_lower_upper(1,4),5),dist_mean(aw_lower_upper(2,4),5),dist_mean(aw_lower_upper(1,4),4),dist_mean(aw_lower_upper(2,4),4),dist_mean(aw_lower_upper(1,4),3),dist_mean(aw_lower_upper(2,4),3),dist_mean(aw_lower_upper(1,4),2),dist_mean(aw_lower_upper(2,4),2),dist_mean(aw_lower_upper(1,4),1),dist_mean(aw_lower_upper(2,4),1)));
         res_str = strvcat(res_str,sprintf(['[  95%         [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],dist_mean(aw_lower_upper(1,3),6),dist_mean(aw_lower_upper(2,3),6),dist_mean(aw_lower_upper(1,3),5),dist_mean(aw_lower_upper(2,3),5),dist_mean(aw_lower_upper(1,3),4),dist_mean(aw_lower_upper(2,3),4),dist_mean(aw_lower_upper(1,3),3),dist_mean(aw_lower_upper(2,3),3),dist_mean(aw_lower_upper(1,3),2),dist_mean(aw_lower_upper(2,3),2),dist_mean(aw_lower_upper(1,3),1),dist_mean(aw_lower_upper(2,3),1)));
         res_str = strvcat(res_str,sprintf(['[  98%         [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],dist_mean(aw_lower_upper(1,2),6),dist_mean(aw_lower_upper(2,2),6),dist_mean(aw_lower_upper(1,2),5),dist_mean(aw_lower_upper(2,2),5),dist_mean(aw_lower_upper(1,2),4),dist_mean(aw_lower_upper(2,2),4),dist_mean(aw_lower_upper(1,2),3),dist_mean(aw_lower_upper(2,2),3),dist_mean(aw_lower_upper(1,2),2),dist_mean(aw_lower_upper(2,2),2),dist_mean(aw_lower_upper(1,2),1),dist_mean(aw_lower_upper(2,2),1)));
         res_str = strvcat(res_str,sprintf(['[  99%         [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],dist_mean(aw_lower_upper(1,1),6),dist_mean(aw_lower_upper(2,1),6),dist_mean(aw_lower_upper(1,1),5),dist_mean(aw_lower_upper(2,1),5),dist_mean(aw_lower_upper(1,1),4),dist_mean(aw_lower_upper(2,1),4),dist_mean(aw_lower_upper(1,1),3),dist_mean(aw_lower_upper(2,1),3),dist_mean(aw_lower_upper(1,1),2),dist_mean(aw_lower_upper(2,1),2),dist_mean(aw_lower_upper(1,1),1),dist_mean(aw_lower_upper(2,1),1)),' ');
         %
         % p-value information
         %
         res_str = strvcat(res_str,'      Original test value and p-value properties',' ',['mean Q(t|T) = ' num2str(tm.NyblomMean,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])]);
         mean_pval_mean = (1/num_exp)*sum(mean_orig_rej_prob);
         mean_pval_std = sqrt((1/num_exp)*sum( (mean_orig_rej_prob-mean_pval_mean).*(mean_orig_rej_prob-mean_pval_mean) ));
         res_str = strvcat(res_str,['mean p-value =     ' num2str(mean_pval_mean,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])]);
         res_str = strvcat(res_str,['st. dev. p-value = ' num2str(mean_pval_std,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])],' ');
         res_str = strvcat(res_str,'      Confidence bands for p-values');
         res_str = strvcat(res_str,['  50%         [' num2str(mean_orig_rej_prob(aw_lower_upper(1,6),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ',' num2str(mean_orig_rej_prob(aw_lower_upper(2,6),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ']']);
         res_str = strvcat(res_str,['  80%         [' num2str(mean_orig_rej_prob(aw_lower_upper(1,5),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ',' num2str(mean_orig_rej_prob(aw_lower_upper(2,5),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ']']);
         res_str = strvcat(res_str,['  90%         [' num2str(mean_orig_rej_prob(aw_lower_upper(1,4),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ',' num2str(mean_orig_rej_prob(aw_lower_upper(2,4),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ']']);
         res_str = strvcat(res_str,['  95%         [' num2str(mean_orig_rej_prob(aw_lower_upper(1,3),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ',' num2str(mean_orig_rej_prob(aw_lower_upper(2,3),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ']']);
         res_str = strvcat(res_str,['  98%         [' num2str(mean_orig_rej_prob(aw_lower_upper(1,2),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ',' num2str(mean_orig_rej_prob(aw_lower_upper(2,2),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ']']);
         res_str = strvcat(res_str,['  99%         [' num2str(mean_orig_rej_prob(aw_lower_upper(1,1),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ',' num2str(mean_orig_rej_prob(aw_lower_upper(2,1),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ']'],' ');
         %
         % and now the LR-test
         %
         if lr_exist==1;
            res_str = strvcat(res_str,'--------------------------------------------------------------',' ');
            res_str = strvcat(res_str,'                           LR-test','                           -------',' ','        Rejection rates at bootstrap size','  50%     20%     10%      5%      2%      1%');
            res_str = strvcat(res_str,sprintf('%6.2f  %6.2f  %6.2f  %6.2f  %6.2f  %6.2f',100*boot_lr_rej_prob(6,1),100*boot_lr_rej_prob(5,1),100*boot_lr_rej_prob(4,1),100*boot_lr_rej_prob(3,1),100*boot_lr_rej_prob(2,1),100*boot_lr_rej_prob(1,1)));
            res_str = strvcat(res_str,' ','        Rejection rates at asymptotic size');
            res_str = strvcat(res_str,sprintf('%6.2f  %6.2f  %6.2f  %6.2f  %6.2f  %6.2f',100*asymp_lr_rej_prob(6,1),100*asymp_lr_rej_prob(5,1),100*asymp_lr_rej_prob(4,1),100*asymp_lr_rej_prob(3,1),100*asymp_lr_rej_prob(2,1),100*asymp_lr_rej_prob(1,1)));
            res_str = strvcat(res_str,' ','      Quantile moments for bootstrap distributions',['moment        50%    ' sp_str '    80%    ' sp_str '    90%    ' sp_str '    95%    ' sp_str '    98%   ' sp_str '     99%']);
            res_str = strvcat(res_str,sprintf(['mean      ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],lr_mean(my_50,1),lr_mean(my_80,1),lr_mean(my_90,1),lr_mean(my_95,1),lr_mean(my_975,1),lr_mean(my_99,1)));
            res_str = strvcat(res_str,sprintf(['st. dev.  ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val '   ' prt_val],lr_std(my_50,1),lr_std(my_80,1),lr_std(my_90,1),lr_std(my_95,1),lr_std(my_975,1),lr_std(my_99,1)),' ');
            %
            % display confidence bands
            %
            res_str = strvcat(res_str,'      Confidence bands for quantiles',['size\\quantile          50%         ' sp_str sp_str '          80%         ' sp_str sp_str '          90%         ' sp_str sp_str '          95%        ' sp_str sp_str '           98%        ' sp_str sp_str '           99%']);
            res_str = strvcat(res_str,sprintf(['[  50%         [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],dist_lr(aw_lower_upper(1,6),6),dist_lr(aw_lower_upper(2,6),6),dist_lr(aw_lower_upper(1,6),5),dist_lr(aw_lower_upper(2,6),5),dist_lr(aw_lower_upper(1,6),4),dist_lr(aw_lower_upper(2,6),4),dist_lr(aw_lower_upper(1,6),3),dist_lr(aw_lower_upper(2,6),3),dist_lr(aw_lower_upper(1,6),2),dist_lr(aw_lower_upper(2,6),2),dist_lr(aw_lower_upper(1,6),1),dist_lr(aw_lower_upper(2,6),1)));
            res_str = strvcat(res_str,sprintf(['[  80%         [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],dist_lr(aw_lower_upper(1,5),6),dist_lr(aw_lower_upper(2,5),6),dist_lr(aw_lower_upper(1,5),5),dist_lr(aw_lower_upper(2,5),5),dist_lr(aw_lower_upper(1,5),4),dist_lr(aw_lower_upper(2,5),4),dist_lr(aw_lower_upper(1,5),3),dist_lr(aw_lower_upper(2,5),3),dist_lr(aw_lower_upper(1,5),2),dist_lr(aw_lower_upper(2,5),2),dist_lr(aw_lower_upper(1,5),1),dist_lr(aw_lower_upper(2,5),1)));
            res_str = strvcat(res_str,sprintf(['[  90%         [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],dist_lr(aw_lower_upper(1,4),6),dist_lr(aw_lower_upper(2,4),6),dist_lr(aw_lower_upper(1,4),5),dist_lr(aw_lower_upper(2,4),5),dist_lr(aw_lower_upper(1,4),4),dist_lr(aw_lower_upper(2,4),4),dist_lr(aw_lower_upper(1,4),3),dist_lr(aw_lower_upper(2,4),3),dist_lr(aw_lower_upper(1,4),2),dist_lr(aw_lower_upper(2,4),2),dist_lr(aw_lower_upper(1,4),1),dist_lr(aw_lower_upper(2,4),1)));
            res_str = strvcat(res_str,sprintf(['[  95%         [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],dist_lr(aw_lower_upper(1,3),6),dist_lr(aw_lower_upper(2,3),6),dist_lr(aw_lower_upper(1,3),5),dist_lr(aw_lower_upper(2,3),5),dist_lr(aw_lower_upper(1,3),4),dist_lr(aw_lower_upper(2,3),4),dist_lr(aw_lower_upper(1,3),3),dist_lr(aw_lower_upper(2,3),3),dist_lr(aw_lower_upper(1,3),2),dist_lr(aw_lower_upper(2,3),2),dist_lr(aw_lower_upper(1,3),1),dist_lr(aw_lower_upper(2,3),1)));
            res_str = strvcat(res_str,sprintf(['[  98%         [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],dist_lr(aw_lower_upper(1,2),6),dist_lr(aw_lower_upper(2,2),6),dist_lr(aw_lower_upper(1,2),5),dist_lr(aw_lower_upper(2,2),5),dist_lr(aw_lower_upper(1,2),4),dist_lr(aw_lower_upper(2,2),4),dist_lr(aw_lower_upper(1,2),3),dist_lr(aw_lower_upper(2,2),3),dist_lr(aw_lower_upper(1,2),2),dist_lr(aw_lower_upper(2,2),2),dist_lr(aw_lower_upper(1,2),1),dist_lr(aw_lower_upper(2,2),1)));
            res_str = strvcat(res_str,sprintf(['[  99%         [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']   [' prt_val ',' prt_val ']'],dist_lr(aw_lower_upper(1,1),6),dist_lr(aw_lower_upper(2,1),6),dist_lr(aw_lower_upper(1,1),5),dist_lr(aw_lower_upper(2,1),5),dist_lr(aw_lower_upper(1,1),4),dist_lr(aw_lower_upper(2,1),4),dist_lr(aw_lower_upper(1,1),3),dist_lr(aw_lower_upper(2,1),3),dist_lr(aw_lower_upper(1,1),2),dist_lr(aw_lower_upper(2,1),2),dist_lr(aw_lower_upper(1,1),1),dist_lr(aw_lower_upper(2,1),1)),' ');
            %
            % p-value information
            %
            res_str = strvcat(res_str,'      Original test value and p-value properties',' ',['     LR(' num2str(lr_df,'%0.0f') ') = ' num2str(lr_test,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])]);
            lr_pval_mean = (1/num_exp)*sum(lr_orig_rej_prob);
            lr_pval_std = sqrt((1/num_exp)*sum( (lr_orig_rej_prob-lr_pval_mean).*(lr_orig_rej_prob-lr_pval_mean) ));
            res_str = strvcat(res_str,['mean p-value =     ' num2str(lr_pval_mean,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])]);
            res_str = strvcat(res_str,['st. dev. p-value = ' num2str(lr_pval_std,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])],' ');
            res_str = strvcat(res_str,'      Confidence bands for p-values');
            res_str = strvcat(res_str,['  50%         [' num2str(lr_orig_rej_prob(aw_lower_upper(1,6),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ',' num2str(lr_orig_rej_prob(aw_lower_upper(2,6),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ']']);
            res_str = strvcat(res_str,['  80%         [' num2str(lr_orig_rej_prob(aw_lower_upper(1,5),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ',' num2str(lr_orig_rej_prob(aw_lower_upper(2,5),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ']']);
            res_str = strvcat(res_str,['  90%         [' num2str(lr_orig_rej_prob(aw_lower_upper(1,4),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ',' num2str(lr_orig_rej_prob(aw_lower_upper(2,4),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ']']);
            res_str = strvcat(res_str,['  95%         [' num2str(lr_orig_rej_prob(aw_lower_upper(1,3),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ',' num2str(lr_orig_rej_prob(aw_lower_upper(2,3),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ']']);
            res_str = strvcat(res_str,['  98%         [' num2str(lr_orig_rej_prob(aw_lower_upper(1,2),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ',' num2str(lr_orig_rej_prob(aw_lower_upper(2,2),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ']']);
            res_str = strvcat(res_str,['  99%         [' num2str(lr_orig_rej_prob(aw_lower_upper(1,1),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ',' num2str(lr_orig_rej_prob(aw_lower_upper(2,1),1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f']) ']'],' ');
         end;
         %
         res_str = strvcat(res_str,'**************************************************************',' ');
         if tm.const_model(1)==1;
            file_txt = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-summary-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '-' num2str(rep) '-noconst.txt'];
         elseif tm.const_model(2)==1;
            file_txt = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-summary-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '-' num2str(rep) '-resconst.txt'];
         elseif tm.const_model(3)==1;
            file_txt = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-summary-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '-' num2str(rep) '-const.txt'];
         elseif tm.const_model(4)==1;
            file_txt = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-summary-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '-' num2str(rep) '-restrend.txt'];
         elseif tm.const_model(5)==1;
            file_txt = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-summary-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(num_exp) '-' num2str(rep) '-trend.txt'];
         end;
         fid_txt = fopen(file_txt,'wt');
         for i=1:size(res_str,1);
            fprintf(fid_txt,[strrep(res_str(i,:),'%','%%') '\n']);
         end;
         fprintf(fid_txt,['Output created on: ' datestr(now,0) '\n']);
         fclose(fid_txt);
         %
         % write to tex file
         %
         prt_val = ['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'];
         file_tex = strrep(file_txt,'.txt','.ltx');
         f_id = fopen(file_tex,'wt');
         fprintf(f_id,'\\begin{tabular}{ll}\n');
         fprintf(f_id,['Model: & ' my_mod ' \\\\\n']);
         fprintf(f_id,['\\#Endogenous variables: & ' num2str(tm.n,'%0.0f') ' \\\\\n']);
         fprintf(f_id,['\\#Cointegration relations: & ' num2str(my_r,'%0.0f') ' \\\\\n']);
         fprintf(f_id,['\\#Experiments: & ' num2str(num_exp,'%0.0f') ' \\\\\n']);
         fprintf(f_id,['\\#Replications: & ' num2str(rep,'%0.0f') ' \\\\\n']);
         fprintf(f_id,['\\#Draws per replication: & ' num2str(my_T,'%0.0f') ' \\\\\n']);
         if blocksize>1;
            fprintf(f_id,['Block size length: & ' num2str(blocksize,'%0.0f') ' \\\\\n']);
         end;
         if curr_ini.taylor_nyblom==0;
            fprintf(f_id,'Method: & Scores version \\\\\n');
         else;
            fprintf(f_id,'Method: & First-order Taylor expansion version \\\\\n');
         end;
         if curr_ini.fullrec==0;
            fprintf(f_id,' & updating all parameters in recursion \\\\\n');
         else;
            fprintf(f_id,' & conditional on full-sample estimates of $\\delta$ \\\\\n & and $\\Gamma_i$ parameters in recursion \\\\\n');
         end;
         if strcmp(alt_state,'on')==1;
            fprintf(f_id,'\\multicolumn{2}{c}{ } \\\\\n');
            for i=1:size(add_res_str,1);
               fprintf(f_id,' & %s \\\\\n',strtrim(add_res_str(i,:)));
            end;
            fprintf(f_id,' & Dummy is active between period %0.0f and %0.0f \\\\\n',du_begin,du_end);
         end;
         fprintf(f_id,'\\end{tabular}\n\n');
         fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrr}\n');
         fprintf(f_id,'\\multicolumn{6}{c}{Supremum test} \\\\\n');
         fprintf(f_id,'\\multicolumn{6}{c}{Rejection rates at bootstrap size} \\\\\n');
         fprintf(f_id,'50\\%% & 20\\%% & 10\\%% & 5\\%% & 2\\%% & 1\\%% \\\\\n');
         fprintf(f_id,'%0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% \\\\\n',100*boot_rej_prob(6,1),100*boot_rej_prob(5,1),100*boot_rej_prob(4,1),100*boot_rej_prob(3,1),100*boot_rej_prob(2,1),100*boot_rej_prob(1,1));
         if (tm.nyblom_asymp==1)&((sum(tm.restrict)==0)|((tm.restrict(1,2)==1)&(tm.dfbeta==0)&(sum(tm.restrict)==1)));
            fprintf(f_id,'\\multicolumn{6}{c}{ } \\\\\n');
            fprintf(f_id,'\\multicolumn{6}{c}{Rejection rates at asymptotic size} \\\\\n');
            fprintf(f_id,'%0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% \\\\\n',100*asymp_rej_prob(6,1),100*asymp_rej_prob(5,1),100*asymp_rej_prob(4,1),100*asymp_rej_prob(3,1),100*asymp_rej_prob(2,1),100*asymp_rej_prob(1,1));
         end;
         fprintf(f_id,'\\end{tabular}\n\n');
         fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrr}\n');
         fprintf(f_id,'\\multicolumn{7}{c}{Quantile moments for bootstrap distributions} \\\\\n');
         fprintf(f_id,'moment     &  50\\%%  &  80\\%%  &  90\\%%  &  95\\%%  &  98\\%%  &  99\\%% \\\\\n');
         fprintf(f_id,['mean       & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' \\\\ \n'],max_mean(my_50,1),max_mean(my_80,1),max_mean(my_90,1),max_mean(my_95,1),max_mean(my_975,1),max_mean(my_99,1));
         fprintf(f_id,['st. dev    & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' \\\\ \n'],max_std(my_50,1),max_std(my_80,1),max_std(my_90,1),max_std(my_95,1),max_std(my_975,1),max_std(my_99,1));
         fprintf(f_id,'\\end{tabular}\n\n');
         %
         % confidence bands
         %
         fprintf(f_id,'\\vspace*{3mm}\n\n{\\small\n\\begin{tabular}{ccccccc}\n');
         fprintf(f_id,'\\multicolumn{7}{c}{Confidence bands for quantiles} \\\\\n');
         fprintf(f_id,'size$\\backslash$quantile & 50\\%% & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% \\\\\n');
         fprintf(f_id,['  50\\%% & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] \\\\ \n'],dist_max(aw_lower_upper(1,6),6),dist_max(aw_lower_upper(2,6),6),dist_max(aw_lower_upper(1,6),5),dist_max(aw_lower_upper(2,6),5),dist_max(aw_lower_upper(1,6),4),dist_max(aw_lower_upper(2,6),4),dist_max(aw_lower_upper(1,6),3),dist_max(aw_lower_upper(2,6),3),dist_max(aw_lower_upper(1,6),2),dist_max(aw_lower_upper(2,6),2),dist_max(aw_lower_upper(1,6),1),dist_max(aw_lower_upper(1,6),1));
         fprintf(f_id,['  80\\%% & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] \\\\ \n'],dist_max(aw_lower_upper(1,5),6),dist_max(aw_lower_upper(2,5),6),dist_max(aw_lower_upper(1,5),5),dist_max(aw_lower_upper(2,5),5),dist_max(aw_lower_upper(1,5),4),dist_max(aw_lower_upper(2,5),4),dist_max(aw_lower_upper(1,5),3),dist_max(aw_lower_upper(2,5),3),dist_max(aw_lower_upper(1,5),2),dist_max(aw_lower_upper(2,5),2),dist_max(aw_lower_upper(1,5),1),dist_max(aw_lower_upper(1,5),1));
         fprintf(f_id,['  90\\%% & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] \\\\ \n'],dist_max(aw_lower_upper(1,4),6),dist_max(aw_lower_upper(2,4),6),dist_max(aw_lower_upper(1,4),5),dist_max(aw_lower_upper(2,4),5),dist_max(aw_lower_upper(1,4),4),dist_max(aw_lower_upper(2,4),4),dist_max(aw_lower_upper(1,4),3),dist_max(aw_lower_upper(2,4),3),dist_max(aw_lower_upper(1,4),2),dist_max(aw_lower_upper(2,4),2),dist_max(aw_lower_upper(1,4),1),dist_max(aw_lower_upper(1,4),1));
         fprintf(f_id,['  95\\%% & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] \\\\ \n'],dist_max(aw_lower_upper(1,3),6),dist_max(aw_lower_upper(2,3),6),dist_max(aw_lower_upper(1,3),5),dist_max(aw_lower_upper(2,3),5),dist_max(aw_lower_upper(1,3),4),dist_max(aw_lower_upper(2,3),4),dist_max(aw_lower_upper(1,3),3),dist_max(aw_lower_upper(2,3),3),dist_max(aw_lower_upper(1,3),2),dist_max(aw_lower_upper(2,3),2),dist_max(aw_lower_upper(1,3),1),dist_max(aw_lower_upper(1,3),1));
         fprintf(f_id,['  98\\%% & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] \\\\ \n'],dist_max(aw_lower_upper(1,2),6),dist_max(aw_lower_upper(2,2),6),dist_max(aw_lower_upper(1,2),5),dist_max(aw_lower_upper(2,2),5),dist_max(aw_lower_upper(1,2),4),dist_max(aw_lower_upper(2,2),4),dist_max(aw_lower_upper(1,2),3),dist_max(aw_lower_upper(2,2),3),dist_max(aw_lower_upper(1,2),2),dist_max(aw_lower_upper(2,2),2),dist_max(aw_lower_upper(1,2),1),dist_max(aw_lower_upper(1,2),1));
         fprintf(f_id,['  99\\%% & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] \\\\ \n'],dist_max(aw_lower_upper(1,1),6),dist_max(aw_lower_upper(2,1),6),dist_max(aw_lower_upper(1,1),5),dist_max(aw_lower_upper(2,1),5),dist_max(aw_lower_upper(1,1),4),dist_max(aw_lower_upper(2,1),4),dist_max(aw_lower_upper(1,1),3),dist_max(aw_lower_upper(2,1),3),dist_max(aw_lower_upper(1,1),2),dist_max(aw_lower_upper(2,1),2),dist_max(aw_lower_upper(1,1),1),dist_max(aw_lower_upper(1,1),1));
         fprintf(f_id,'\\end{tabular}\n}\n\n');
         %
         % dealing with p-value
         %
         fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rl}\n');
         fprintf(f_id,'\\multicolumn{2}{c}{Original test value and $p$-value properties} \\\\\n');
         fprintf(f_id,[' & $\\sup Q_{t|T}$ = ' prt_val ' \\\\ \n'],tm.NyblomMax);
         fprintf(f_id,[' & mean $p$-value = ' prt_val ' \\\\ \n'],max_pval_mean);
         fprintf(f_id,[' & st. dev. $p$-value = ' prt_val ' \\\\ \n'],max_pval_std);
         fprintf(f_id,'\\multicolumn{2}{c}{ } \\\\\n');
         fprintf(f_id,'\\multicolumn{2}{c}{Confidence bands for $p$-values} \\\\\n');
         fprintf(f_id,[' 50\\%% & [' prt_val ',' prt_val '] \\\\ \n'],max_orig_rej_prob(aw_lower_upper(1,6),1),max_orig_rej_prob(aw_lower_upper(2,6),1));
         fprintf(f_id,[' 80\\%% & [' prt_val ',' prt_val '] \\\\ \n'],max_orig_rej_prob(aw_lower_upper(1,5),1),max_orig_rej_prob(aw_lower_upper(2,5),1));
         fprintf(f_id,[' 90\\%% & [' prt_val ',' prt_val '] \\\\ \n'],max_orig_rej_prob(aw_lower_upper(1,4),1),max_orig_rej_prob(aw_lower_upper(2,4),1));
         fprintf(f_id,[' 95\\%% & [' prt_val ',' prt_val '] \\\\ \n'],max_orig_rej_prob(aw_lower_upper(1,3),1),max_orig_rej_prob(aw_lower_upper(2,3),1));
         fprintf(f_id,[' 98\\%% & [' prt_val ',' prt_val '] \\\\ \n'],max_orig_rej_prob(aw_lower_upper(1,2),1),max_orig_rej_prob(aw_lower_upper(2,2),1));
         fprintf(f_id,[' 99\\%% & [' prt_val ',' prt_val '] \\\\ \n'],max_orig_rej_prob(aw_lower_upper(1,1),1),max_orig_rej_prob(aw_lower_upper(2,1),1));
         fprintf(f_id,'\\end{tabular}\n\n');
         %
         % mean test
         %
         fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrr}\n');
         fprintf(f_id,'\\multicolumn{6}{c}{Mean test} \\\\\n');
         fprintf(f_id,'\\multicolumn{6}{c}{Rejection rates at bootstrap size} \\\\\n');
         fprintf(f_id,'50\\%% & 20\\%% & 10\\%% & 5\\%% & 2\\%% & 1\\%% \\\\\n');
         fprintf(f_id,'%0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% \\\\\n',100*boot_rej_prob(6,2),100*boot_rej_prob(5,2),100*boot_rej_prob(4,2),100*boot_rej_prob(3,2),100*boot_rej_prob(2,2),100*boot_rej_prob(1,2));
         if (tm.nyblom_asymp==1)&((sum(tm.restrict)==0)|((tm.restrict(1,2)==1)&(tm.dfbeta==0)&(sum(tm.restrict)==1)));
            fprintf(f_id,'\\multicolumn{6}{c}{ } \\\\\n');
            fprintf(f_id,'\\multicolumn{6}{c}{Rejection rates at asymptotic size} \\\\\n');
            fprintf(f_id,'%0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% \\\\\n',100*asymp_rej_prob(6,2),100*asymp_rej_prob(5,2),100*asymp_rej_prob(4,2),100*asymp_rej_prob(3,2),100*asymp_rej_prob(2,2),100*asymp_rej_prob(1,2));
         end;
         fprintf(f_id,'\\end{tabular}\n\n');
         fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrr}\n');
         fprintf(f_id,'\\multicolumn{7}{c}{Quantile moments for bootstrap distributions} \\\\\n');
         fprintf(f_id,'moment     &  50\\%%  &  80\\%%  &  90\\%%  &  95\\%%  &  98\\%%  &  99\\%% \\\\\n');
         fprintf(f_id,['mean       & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' \\\\ \n'],mean_mean(my_50,1),mean_mean(my_80,1),mean_mean(my_90,1),mean_mean(my_95,1),mean_mean(my_975,1),mean_mean(my_99,1));
         fprintf(f_id,['st. dev    & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' \\\\ \n'],mean_std(my_50,1),mean_std(my_80,1),mean_std(my_90,1),mean_std(my_95,1),mean_std(my_975,1),mean_std(my_99,1));
         fprintf(f_id,'\\end{tabular}\n\n');
         %
         % confidence bands
         %
         fprintf(f_id,'\\vspace*{3mm}\n\n{\\small\n\\begin{tabular}{ccccccc}\n');
         fprintf(f_id,'\\multicolumn{7}{c}{Confidence bands for quantiles} \\\\\n');
         fprintf(f_id,'size$\\backslash$quantile & 50\\%% & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% \\\\\n');
         fprintf(f_id,['  50\\%% & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] \\\\ \n'],dist_mean(aw_lower_upper(1,6),6),dist_mean(aw_lower_upper(2,6),6),dist_mean(aw_lower_upper(1,6),5),dist_mean(aw_lower_upper(2,6),5),dist_mean(aw_lower_upper(1,6),4),dist_mean(aw_lower_upper(2,6),4),dist_mean(aw_lower_upper(1,6),3),dist_mean(aw_lower_upper(2,6),3),dist_mean(aw_lower_upper(1,6),2),dist_mean(aw_lower_upper(2,6),2),dist_mean(aw_lower_upper(1,6),1),dist_mean(aw_lower_upper(1,6),1));
         fprintf(f_id,['  80\\%% & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] \\\\ \n'],dist_mean(aw_lower_upper(1,5),6),dist_mean(aw_lower_upper(2,5),6),dist_mean(aw_lower_upper(1,5),5),dist_mean(aw_lower_upper(2,5),5),dist_mean(aw_lower_upper(1,5),4),dist_mean(aw_lower_upper(2,5),4),dist_mean(aw_lower_upper(1,5),3),dist_mean(aw_lower_upper(2,5),3),dist_mean(aw_lower_upper(1,5),2),dist_mean(aw_lower_upper(2,5),2),dist_mean(aw_lower_upper(1,5),1),dist_mean(aw_lower_upper(1,5),1));
         fprintf(f_id,['  90\\%% & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] \\\\ \n'],dist_mean(aw_lower_upper(1,4),6),dist_mean(aw_lower_upper(2,4),6),dist_mean(aw_lower_upper(1,4),5),dist_mean(aw_lower_upper(2,4),5),dist_mean(aw_lower_upper(1,4),4),dist_mean(aw_lower_upper(2,4),4),dist_mean(aw_lower_upper(1,4),3),dist_mean(aw_lower_upper(2,4),3),dist_mean(aw_lower_upper(1,4),2),dist_mean(aw_lower_upper(2,4),2),dist_mean(aw_lower_upper(1,4),1),dist_mean(aw_lower_upper(1,4),1));
         fprintf(f_id,['  95\\%% & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] \\\\ \n'],dist_mean(aw_lower_upper(1,3),6),dist_mean(aw_lower_upper(2,3),6),dist_mean(aw_lower_upper(1,3),5),dist_mean(aw_lower_upper(2,3),5),dist_mean(aw_lower_upper(1,3),4),dist_mean(aw_lower_upper(2,3),4),dist_mean(aw_lower_upper(1,3),3),dist_mean(aw_lower_upper(2,3),3),dist_mean(aw_lower_upper(1,3),2),dist_mean(aw_lower_upper(2,3),2),dist_mean(aw_lower_upper(1,3),1),dist_mean(aw_lower_upper(1,3),1));
         fprintf(f_id,['  98\\%% & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] \\\\ \n'],dist_mean(aw_lower_upper(1,2),6),dist_mean(aw_lower_upper(2,2),6),dist_mean(aw_lower_upper(1,2),5),dist_mean(aw_lower_upper(2,2),5),dist_mean(aw_lower_upper(1,2),4),dist_mean(aw_lower_upper(2,2),4),dist_mean(aw_lower_upper(1,2),3),dist_mean(aw_lower_upper(2,2),3),dist_mean(aw_lower_upper(1,2),2),dist_mean(aw_lower_upper(2,2),2),dist_mean(aw_lower_upper(1,2),1),dist_mean(aw_lower_upper(1,2),1));
         fprintf(f_id,['  99\\%% & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] \\\\ \n'],dist_mean(aw_lower_upper(1,1),6),dist_mean(aw_lower_upper(2,1),6),dist_mean(aw_lower_upper(1,1),5),dist_mean(aw_lower_upper(2,1),5),dist_mean(aw_lower_upper(1,1),4),dist_mean(aw_lower_upper(2,1),4),dist_mean(aw_lower_upper(1,1),3),dist_mean(aw_lower_upper(2,1),3),dist_mean(aw_lower_upper(1,1),2),dist_mean(aw_lower_upper(2,1),2),dist_mean(aw_lower_upper(1,1),1),dist_mean(aw_lower_upper(1,1),1));
         fprintf(f_id,'\\end{tabular}\n}\n\n');
         %
         % dealing with p-value
         %
         fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rl}\n');
         fprintf(f_id,'\\multicolumn{2}{c}{Original test value and $p$-value properties} \\\\\n');
         fprintf(f_id,[' & $\\mean Q_{t|T}$ = ' prt_val ' \\\\ \n'],tm.NyblomMean);
         fprintf(f_id,[' & mean $p$-value = ' prt_val ' \\\\ \n'],mean_pval_mean);
         fprintf(f_id,[' & st. dev. $p$-value = ' prt_val ' \\\\ \n'],mean_pval_std);
         fprintf(f_id,'\\multicolumn{2}{c}{ } \\\\\n');
         fprintf(f_id,'\\multicolumn{2}{c}{Confidence bands for $p$-values} \\\\\n');
         fprintf(f_id,[' 50\\%% & [' prt_val ',' prt_val '] \\\\ \n'],mean_orig_rej_prob(aw_lower_upper(1,6),1),mean_orig_rej_prob(aw_lower_upper(2,6),1));
         fprintf(f_id,[' 80\\%% & [' prt_val ',' prt_val '] \\\\ \n'],mean_orig_rej_prob(aw_lower_upper(1,5),1),mean_orig_rej_prob(aw_lower_upper(2,5),1));
         fprintf(f_id,[' 90\\%% & [' prt_val ',' prt_val '] \\\\ \n'],mean_orig_rej_prob(aw_lower_upper(1,4),1),mean_orig_rej_prob(aw_lower_upper(2,4),1));
         fprintf(f_id,[' 95\\%% & [' prt_val ',' prt_val '] \\\\ \n'],mean_orig_rej_prob(aw_lower_upper(1,3),1),mean_orig_rej_prob(aw_lower_upper(2,3),1));
         fprintf(f_id,[' 98\\%% & [' prt_val ',' prt_val '] \\\\ \n'],mean_orig_rej_prob(aw_lower_upper(1,2),1),mean_orig_rej_prob(aw_lower_upper(2,2),1));
         fprintf(f_id,[' 99\\%% & [' prt_val ',' prt_val '] \\\\ \n'],mean_orig_rej_prob(aw_lower_upper(1,1),1),mean_orig_rej_prob(aw_lower_upper(2,1),1));
         fprintf(f_id,'\\end{tabular}\n\n');
         %
         % and the LR-test
         %
         if lr_exist==1;
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrr}\n');
            fprintf(f_id,'\\multicolumn{6}{c}{LR-test} \\\\\n');
            fprintf(f_id,'\\multicolumn{6}{c}{Rejection rates at bootstrap size} \\\\\n');
            fprintf(f_id,'50\\%% & 20\\%% & 10\\%% & 5\\%% & 2\\%% & 1\\%% \\\\\n');
            fprintf(f_id,'%0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% \\\\\n',100*boot_lr_rej_prob(6,1),100*boot_lr_rej_prob(5,1),100*boot_lr_rej_prob(4,1),100*boot_lr_rej_prob(3,1),100*boot_lr_rej_prob(2,1),100*boot_lr_rej_prob(1,1));
            fprintf(f_id,'\\multicolumn{6}{c}{Rejection rates at asymptotic size} \\\\\n');
            fprintf(f_id,'%0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% \\\\\n',100*asymp_lr_rej_prob(6,1),100*asymp_lr_rej_prob(5,1),100*asymp_lr_rej_prob(4,1),100*asymp_lr_rej_prob(3,1),100*asymp_lr_rej_prob(2,1),100*asymp_lr_rej_prob(1,1));
            fprintf(f_id,'\\end{tabular}\n\n');
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrr}\n');
            fprintf(f_id,'\\multicolumn{7}{c}{Quantile moments for bootstrap distributions} \\\\\n');
            fprintf(f_id,'moment     &  50\\%%  &  80\\%%  &  90\\%%  &  95\\%%  &  98\\%%  &  99\\%% \\\\\n');
            fprintf(f_id,['mean       & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' \\\\ \n'],lr_mean(my_50,1),lr_mean(my_80,1),lr_mean(my_90,1),lr_mean(my_95,1),lr_mean(my_975,1),lr_mean(my_99,1));
            fprintf(f_id,['st. dev    & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' \\\\ \n'],lr_std(my_50,1),lr_std(my_80,1),lr_std(my_90,1),lr_std(my_95,1),lr_std(my_975,1),lr_std(my_99,1));
            fprintf(f_id,'\\end{tabular}\n\n');
            %
            % confidence bands
            %
            fprintf(f_id,'\\vspace*{3mm}\n\n{\\small\n\\begin{tabular}{ccccccc}\n');
            fprintf(f_id,'\\multicolumn{7}{c}{Confidence bands for quantiles} \\\\\n');
            fprintf(f_id,'size$\\backslash$quantile & 50\\%% & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% \\\\\n');
            fprintf(f_id,['  50\\%% & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] \\\\ \n'],dist_lr(aw_lower_upper(1,6),6),dist_lr(aw_lower_upper(2,6),6),dist_lr(aw_lower_upper(1,6),5),dist_lr(aw_lower_upper(2,6),5),dist_lr(aw_lower_upper(1,6),4),dist_lr(aw_lower_upper(2,6),4),dist_lr(aw_lower_upper(1,6),3),dist_lr(aw_lower_upper(2,6),3),dist_lr(aw_lower_upper(1,6),2),dist_lr(aw_lower_upper(2,6),2),dist_lr(aw_lower_upper(1,6),1),dist_lr(aw_lower_upper(1,6),1));
            fprintf(f_id,['  80\\%% & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] \\\\ \n'],dist_lr(aw_lower_upper(1,5),6),dist_lr(aw_lower_upper(2,5),6),dist_lr(aw_lower_upper(1,5),5),dist_lr(aw_lower_upper(2,5),5),dist_lr(aw_lower_upper(1,5),4),dist_lr(aw_lower_upper(2,5),4),dist_lr(aw_lower_upper(1,5),3),dist_lr(aw_lower_upper(2,5),3),dist_lr(aw_lower_upper(1,5),2),dist_lr(aw_lower_upper(2,5),2),dist_lr(aw_lower_upper(1,5),1),dist_lr(aw_lower_upper(1,5),1));
            fprintf(f_id,['  90\\%% & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] \\\\ \n'],dist_lr(aw_lower_upper(1,4),6),dist_lr(aw_lower_upper(2,4),6),dist_lr(aw_lower_upper(1,4),5),dist_lr(aw_lower_upper(2,4),5),dist_lr(aw_lower_upper(1,4),4),dist_lr(aw_lower_upper(2,4),4),dist_lr(aw_lower_upper(1,4),3),dist_lr(aw_lower_upper(2,4),3),dist_lr(aw_lower_upper(1,4),2),dist_lr(aw_lower_upper(2,4),2),dist_lr(aw_lower_upper(1,4),1),dist_lr(aw_lower_upper(1,4),1));
            fprintf(f_id,['  95\\%% & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] \\\\ \n'],dist_lr(aw_lower_upper(1,3),6),dist_lr(aw_lower_upper(2,3),6),dist_lr(aw_lower_upper(1,3),5),dist_lr(aw_lower_upper(2,3),5),dist_lr(aw_lower_upper(1,3),4),dist_lr(aw_lower_upper(2,3),4),dist_lr(aw_lower_upper(1,3),3),dist_lr(aw_lower_upper(2,3),3),dist_lr(aw_lower_upper(1,3),2),dist_lr(aw_lower_upper(2,3),2),dist_lr(aw_lower_upper(1,3),1),dist_lr(aw_lower_upper(1,3),1));
            fprintf(f_id,['  98\\%% & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] \\\\ \n'],dist_lr(aw_lower_upper(1,2),6),dist_lr(aw_lower_upper(2,2),6),dist_lr(aw_lower_upper(1,2),5),dist_lr(aw_lower_upper(2,2),5),dist_lr(aw_lower_upper(1,2),4),dist_lr(aw_lower_upper(2,2),4),dist_lr(aw_lower_upper(1,2),3),dist_lr(aw_lower_upper(2,2),3),dist_lr(aw_lower_upper(1,2),2),dist_lr(aw_lower_upper(2,2),2),dist_lr(aw_lower_upper(1,2),1),dist_lr(aw_lower_upper(1,2),1));
            fprintf(f_id,['  99\\%% & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] & [' prt_val ',' prt_val '] \\\\ \n'],dist_lr(aw_lower_upper(1,1),6),dist_lr(aw_lower_upper(2,1),6),dist_lr(aw_lower_upper(1,1),5),dist_lr(aw_lower_upper(2,1),5),dist_lr(aw_lower_upper(1,1),4),dist_lr(aw_lower_upper(2,1),4),dist_lr(aw_lower_upper(1,1),3),dist_lr(aw_lower_upper(2,1),3),dist_lr(aw_lower_upper(1,1),2),dist_lr(aw_lower_upper(2,1),2),dist_lr(aw_lower_upper(1,1),1),dist_lr(aw_lower_upper(1,1),1));
            fprintf(f_id,'\\end{tabular}\n}\n\n');
            %
            % dealing with p-value
            %
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rl}\n');
            fprintf(f_id,'\\multicolumn{2}{c}{Original test value and $p$-value properties} \\\\\n');
            fprintf(f_id,[' & $LR(%s)$ = ' prt_val ' \\\\ \n'],lr_df,lr_test);
            fprintf(f_id,[' & mean $p$-value = ' prt_val ' \\\\ \n'],lr_pval_mean);
            fprintf(f_id,[' & st. dev. $p$-value = ' prt_val ' \\\\ \n'],lr_pval_std);
            fprintf(f_id,'\\multicolumn{2}{c}{ } \\\\\n');
            fprintf(f_id,'\\multicolumn{2}{c}{Confidence bands for $p$-values} \\\\\n');
            fprintf(f_id,[' 50\\%% & [' prt_val ',' prt_val '] \\\\ \n'],lr_orig_rej_prob(aw_lower_upper(1,6),1),lr_orig_rej_prob(aw_lower_upper(2,6),1));
            fprintf(f_id,[' 80\\%% & [' prt_val ',' prt_val '] \\\\ \n'],lr_orig_rej_prob(aw_lower_upper(1,5),1),lr_orig_rej_prob(aw_lower_upper(2,5),1));
            fprintf(f_id,[' 90\\%% & [' prt_val ',' prt_val '] \\\\ \n'],lr_orig_rej_prob(aw_lower_upper(1,4),1),lr_orig_rej_prob(aw_lower_upper(2,4),1));
            fprintf(f_id,[' 95\\%% & [' prt_val ',' prt_val '] \\\\ \n'],lr_orig_rej_prob(aw_lower_upper(1,3),1),lr_orig_rej_prob(aw_lower_upper(2,3),1));
            fprintf(f_id,[' 98\\%% & [' prt_val ',' prt_val '] \\\\ \n'],lr_orig_rej_prob(aw_lower_upper(1,2),1),lr_orig_rej_prob(aw_lower_upper(2,2),1));
            fprintf(f_id,[' 99\\%% & [' prt_val ',' prt_val '] \\\\ \n'],lr_orig_rej_prob(aw_lower_upper(1,1),1),lr_orig_rej_prob(aw_lower_upper(2,1),1));
            fprintf(f_id,'\\end{tabular}\n\n');
         end;
         %
         fprintf(f_id,'\\ruler\n\n%%*************************************************************\n');
         fclose(f_id);
         if curr_ini.noprint==0;
            set(boot_nyblom.output,'Enable','on');
         end;
         %
         set(boot_nyblom.summarymenu,'Enable','on','UserData',file_txt);
         set(boot_nyblom.summary,'Enable','on');
         %
         % saving the mean distributions for the Max and Mean tests as well as the sorted tests
         %
         if lr_exist==0;
            set(boot_nyblom.display,'Enable','on','UserData',[NyblomMax NyblomMean]);
            set(boot_nyblom.altmodel,'UserData',[max_mean mean_mean]);
            clear('NyblomMax','NyblomMean','max_mean','mean_mean');
         else;
            set(boot_nyblom.display,'Enable','on','UserData',[NyblomMax NyblomMean lr_tests]);
            set(boot_nyblom.altmodel,'UserData',[max_mean mean_mean lr_mean]);
            clear('NyblomMax','NyblomMean','max_mean','mean_mean','lr_tests','boot_lr_test','lr_mean');
            tm.lr_df = lr_df;
            tm.lr_test = lr_test;
         end;
         set(boot_nyblom.histogram,'Enable','on');
         set(boot_nyblom.histogrammenu,'Enable','on');
         set(boot_nyblom.matfilebutton,'Enable','on');
         set(boot_nyblom.matfilemenu,'Enable','on');
         %
         % close down the wait dialog
         %
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
      else;
         setlogtext('Cancelled...');
      end;
   else;
      unident = '';
      for i=1:my_r;
         if status(i,1)==0;
            if strcmp(unident,'')==1;
               unident = ['beta(' num2str(i) ')'];
               thisres = 'restriction';
               thisfail = 'fails';
            else;
               unident = [unident ', beta(' num2str(i) ')'];
               thisres = 'restrictions';
               thisfail = 'fail';
            end;
         end;
      end;
      txt = ['The restrictions you have selected for beta are not identifying. In particular, the ' thisres ' on ' unident ' ' thisfail ' the identification test.'];
      about(txt,'warning','Identification Test Failure',120,350);
   end;
   tm.nyblom_run = 0;
   set(nyblom_boot_gui,'Visible','on');
   drawnow;
   %
   % case simulate
   %
case 'simulate'
   tm.nyblom_run = 1;
   set(nyblom_boot_gui,'Visible','off');
   drawnow;
   %
   % collect values
   %
   T_str = get(boot_nyblom.obs,'String');
   my_T = mystr2num(strtrim(T_str(get(boot_nyblom.obs,'Value'),:)));
   repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
   rep_val = get(boot_nyblom.rep,'Value');
   rep = repvalues(rep_val);
   set(boot_nyblom.simulate,'UserData',rep);
   blocksize = get(boot_nyblom.block,'Value');
   block_txt = '';
   if blocksize>1;
      block_txt = ['Applying block bootstrap with block length ' num2str(blocksize,'%0.0f') '...'];
   end;
   if get(boot_nyblom.parametric,'Value')==1;
      bootstyle = '';
   else;
      bootstyle = ['np' num2str(get(boot_nyblom.block,'Value')) '-'];
   end;
   %
   my_r = get(boot_nyblom.my_r,'Value');
   if strcmp(get(boot_nyblom.my_r,'Enable'),'on')==1;
      mybeta = tm.beta(:,1:my_r);
   else;
      mybeta = tm.beta;
   end;
   alt_state = get(boot_nyblom.usealtmodel,'State');
   if strcmp(alt_state,'off')==1;
      usealt = '';
      test_lr = 0;
      if (isfield(tm,'altmodel')==1)&(isempty(tm.altmodel)==0);
         if (isfield(tm.altmodel,'bootlr')==1)&(tm.altmodel.tempdummy+tm.altmodel.permdummy>0);
            test_lr = tm.altmodel.bootlr;
         end;
      end;
   else;
      usealt = 'alt-';
      if tm.altmodel.tempdummy+tm.altmodel.permdummy>0;
         test_lr = tm.altmodel.bootlr;
      else;
         test_lr = 0;
      end;
      if tm.altmodel.tempdummy==1;
         usealt = [usealt 't-'];
         if tm.altmodel.tempcorel==1;
            usealt = [usealt 'coi-'];
            if tm.altmodel.tempcoidet==1;
               usealt = [usealt 'det-'];
            end;
            if tm.altmodel.temprank==2;
               usealt = [usealt 'inc-'];
               test_lr = 0;
            elseif tm.altmodel.temprank==3;
               usealt = [usealt 'dec-'];
               test_lr = 0;
            end;
         elseif tm.altmodel.tempshortrun==1;
            usealt = [usealt 'sr-'];
         else;
            usealt = [usealt 'con-'];
         end;
         if tm.altmodel.tempacc==1;
            usealt = [usealt 'acc-'];
         end;
      else;
         usealt = [usealt 'p-'];
         if tm.altmodel.permcorel==1;
            usealt = [usealt 'coi-'];
            if tm.altmodel.permcoidet==1;
               usealt = [usealt 'det-'];
            end;
            if tm.altmodel.permrank==2;
               usealt = [usealt 'inc-'];
               test_lr = 0;
            elseif tm.altmodel.permrank==3;
               usealt = [usealt 'dec-'];
               test_lr = 0;
            end;
         elseif tm.altmodel.permshortrun==1;
            usealt = [usealt 'sr-'];
         else;
            usealt = [usealt 'con-'];
         end;
         if tm.altmodel.permacc==1;
            usealt = [usealt 'acc-'];
         end;
      end;
      if (tm.altmodel.relsample==1)&(my_T~=tm.T);
         usealt = [usealt 'rs-'];
      end;
   end;
   tm.usealtmodel = 0;
   if tm.n>=my_r;
      abort = '';
      %
      % initialize
      %
      if tm.restrict(1,2)==0;
         %
         % Base case, no restrictions on the cointegration space
         %
         if curr_ini.fullrec==1;
            [nyblomT,nyblomcorr] = boot_nyblom_partial(tm.Z0,tm.Z1,tm.Z2,my_r,tm.p,tm.q1,tm.d,curr_ini.T0,tm.df,tm.T);
         else;
            [nyblomT,nyblomcorr] = boot_nyblom_full(tm.Z0,tm.Z1,tm.Z2,my_r,tm.p,tm.q1,tm.d,curr_ini.T0,tm.df,tm.deterselect,tm.T);
         end;
      else;
         %
         % restrictions on the cointegration space are possible
         %
         status = testident(tm.modelsdir,tm.modelfile,my_r,tm.n,tm.dcoint,tm.q1);
         if sum(status)==my_r;
            [nyblomT,nyblomcorr] = boot_nyblom_restbeta_fcn(tm,curr_ini,tm.cointbeta,tm.Z0,tm.Z1,tm.Z2,tm.T,my_r,tm.T);
         else;
            unident = '';
            for i=1:my_r;
               if status(i,1)==0;
                  if strcmp(unident,'')==1;
                     unident = ['beta(' num2str(i) ')'];
                     thisres = 'restriction';
                     thisfail = 'fails';
                  else;
                     unident = [unident ', beta(' num2str(i) ')'];
                     thisres = 'restrictions';
                     thisfail = 'fail';
                  end;
               end;
            end;
            txt = ['The restrictions you have selected for beta are not identifying. In particular, the ' thisres ' on ' unident ' ' thisfail ' the identification test.'];
            about(txt,'warning','Identification Test Failure',120,350);
            abort = 'cancel';
         end;
      end;
      if test_lr==1;
         if tm.r==my_r;
            lnL_orig = loglike(tm.epsilon);
         else;
            [S_00,S_01,S_10,S_11,M_02,M_22,M_12,beta_n,lambda,my_trace] = mlcointbasic(tm.Z0,tm.Z1,tm.Z2,my_r);
            alpha_n = (S_01*beta_n)*inverse(beta_n'*S_11*beta_n);
            if isempty(tm.Z2)==0;
               Psi_n = (M_02*inverse(M_22))-(alpha_n*beta_n'*M_12*inverse(M_22));
               epsilon_n = tm.Z0-(alpha_n*beta_n'*tm.Z1)-(Psi_n*tm.Z2);
            else;
               epsilon_n = tm.Z0-(alpha_n*beta_n'*tm.Z1);
            end;
            lnL_orig = loglike(epsilon_n);
         end;
      end;
      if strcmp(abort,'cancel')==0;
         %
         % check if we should estimate an alternative model
         %
         if (strcmp(alt_state,'on')==1)|(test_lr==1);
            %
            % read the tm.altmodel structure
            %
            tempdummy = tm.altmodel.tempdummy;
            permdummy = tm.altmodel.permdummy;
            if tempdummy==1;
               d_begin = tm.altmodel.tempbegin;
               d_end = tm.altmodel.tempend;
               d_acc = tm.altmodel.tempacc;
               d_coint = tm.altmodel.tempcoint;
               d_corel = tm.altmodel.tempcorel;
               d_rank = tm.altmodel.temprank;
               d_shortrun = tm.altmodel.tempshortrun;
               d_coidet = tm.altmodel.tempcoidet;
            else;
               d_begin = tm.altmodel.permbegin;
               d_end = tm.T;
               d_acc = tm.altmodel.permacc;
               d_coint = tm.altmodel.permcoint;
               d_corel = tm.altmodel.permcorel;
               d_rank = tm.altmodel.permrank;
               d_shortrun = tm.altmodel.permshortrun;
               d_coidet = tm.altmodel.permcoidet;
            end;
            if (d_begin>1)&(d_end<tm.T);
               data_dummy = [zeros(d_begin-1,1);ones(d_end-d_begin+1,1);zeros(tm.T-d_end,1)];
            elseif d_begin==1;
               data_dummy = [ones(d_end,1);zeros(tm.T-d_end,1)];
            else;
               data_dummy = [zeros(d_begin-1,1);ones(tm.T-d_begin+1,1)];
            end;
            if d_acc==1;
               data_dummy = cumsum(data_dummy);
            end;
            if (d_corel==1)&(d_rank==3);
               data_dummy = 1-data_dummy;
            end;
            %
            % check rank of [tm.Z1;data_dummy';tm.Z2]
            %
            bad_dummy = 0;
            if d_corel==0;
               if d_shortrun==0;
                  test_mat = [tm.Z1;data_dummy';tm.Z2];
                  if size(test_mat,1)>rank(test_mat);
                     bad_dummy = 1;
                  end;
               else;
                  test_mat = tm.Z2(tm.d+1:size(tm.Z2,1),:);
                  num_ones = sum((data_dummy>0));
                  num_zeros = sum((data_dummy==0));
                  if min(num_ones,num_zeros)<=size(test_mat,1);
                     bad_dummy = 4;
                  end;
               end;
            else;
               num_ones = sum((data_dummy>0));
               num_zeros = sum((data_dummy==0));
               if min(num_ones,num_zeros)<=size(tm.Z1,1);
                  bad_dummy = 2;
               end;
            end;
            ch_dummy = check_dummy(tm,my_T);
            if ch_dummy==0;
               bad_dummy = 3;
            end;
            %
            if bad_dummy==0;
               %
               % we're now ready to estimate the alternative model
               %
               if d_rank==1;
                  am.Z0 = tm.Z0;
                  am.d = tm.d;
                  am.n = tm.n;
                  am.T = tm.T;
                  am.freq = tm.freq;
                  am.p = tm.p;
                  am.q1 = tm.q1;
                  am.q0 = tm.q0;
                  am.altmodel = tm.altmodel;
                  am.usealtmodel = 1;
                  am.delete_d = 0;
                  if tm.q0+tm.q1>0;
                     am.exo = tm.Z2(tm.d+(tm.n*(tm.p-1))+1:size(tm.Z2,1),:);
                  end;
                  am.deterselect = tm.deterselect;
                  if d_coint==0;
                     if d_corel==0;
                        am.Z1 = tm.Z1;
                        if d_shortrun==0;
                           am.Z2 = [data_dummy';tm.Z2];
                           am.d = am.d+1;
                           am.delete_d = 1;
                        else;
                           am.Z2 = [];
                           if tm.d>0;
                              am.Z2 = tm.Z2(1:tm.d,:);
                           end;
                           am.Z2 = [am.Z2;test_mat .* (ones(size(test_mat,1),1)*(1-data_dummy'));test_mat .* (ones(size(test_mat,1),1)*data_dummy')];
                        end;
                     else;
                        am.Z2 = tm.Z2;
                        if d_coidet==0;
                           am.Z1 = [tm.Z1 .* (ones(size(tm.Z1,1),1)*(1-data_dummy'));tm.Z1 .* (ones(size(tm.Z1,1),1)*data_dummy')];
                        else;
                           am.Z1 = [tm.Z1(1:size(tm.Z1,1)-1,:) .* (ones(size(tm.Z1,1)-1,1)*(1-data_dummy'));tm.Z1(size(tm.Z1,1),:);tm.Z1(1:size(tm.Z1,1)-1,:) .* (ones(size(tm.Z1,1)-1,1)*data_dummy')];
                        end;
                     end;
                  else;
                     am.Z1 = [tm.Z1;data_dummy'];
                     am.Z2 = tm.Z2;
                  end;
                  %
                  % check that the dummy doesn't make am.Z1 or am.Z2 being singular
                  %
                  if rank(am.Z1)<size(am.Z1,1);
                     bad_dummy = 4;
                  else;
                     if isempty(am.Z2)==0;
                        if rank(am.Z2)<size(am.Z2,1);
                           bad_dummy = 5;
                        end;
                     end;
                  end;
                  if bad_dummy==0;
                     [am.S_00,am.S_01,am.S_10,am.S_11,am.M_02,am.M_22,am.M_12,am.beta,am.lambda,am.trace] = mlcointbasic(am.Z0,am.Z1,am.Z2,my_r);
                     %
                     % need to run a routine which can have dcoint 1 and have a dummy in the cointegration space
                     %
                     lr_warn = 0;
                     if tm.restrict(1,2)==1;
                        [am.beta,am.dfbeta,const_rest] = beta_alt_estimate(am.S_00,am.S_11,am.S_01,am.S_10,am.beta,tm.T,tm.modelsdir,tm.modelfile,tm.dcoint,tm.q1,d_coint,d_corel,d_coidet);
                        if am.dfbeta==((size(am.beta,1)-size(am.beta,2))*size(am.beta,2))-const_rest;
                           lr_warn = 1;
                        end;
                     end;
                     %
                     if lr_warn==0;
                        am.alpha = (am.S_01*am.beta)/(am.beta'*am.S_11*am.beta);
                        if isempty(am.Z2)==0;
                           am.Psi = (am.M_02/am.M_22)-(am.alpha*am.beta'*(am.M_12/am.M_22));
                           am.Z = [am.Z2;am.beta'*am.Z1];
                        else;
                           am.Psi = [];
                           am.Z = am.beta'*am.Z1;
                        end;
                        Theta = [am.Psi am.alpha];
                        am.epsilon = am.Z0-(Theta*am.Z);
                        am.Omega = (1/tm.T)*am.epsilon*am.epsilon';
                        if tm.restrict(1,1)==1;
                           %
                           % estimate alpha under restrictions
                           %
                           file = strcat(tm.modelsdir,'G-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
                           G = loaddata(file);
                           [Rmat,rvec] = rmatrix(G,tm.n,tm.r);
                           am.dfalpha = size(G,1);
                           if isempty(am.Z2)==0;
                              Rmat = [zeros(am.dfalpha,size(am.Z2,1)*tm.n) Rmat];
                           end;
                           if curr_ini.reestbeta==0;
                              [theta,Sigma_theta,infomat,nabort] = linrest(am.Z0,am.Z,Theta,Rmat,rvec,0);
                           else;
                              %
                              % re-estimate beta under alpha restrictions
                              %
                              [theta,am.beta,am.Z] = alpha_beta_alt_estimate(am.Z0,am.Z1,am.Z2,am.Z,am.beta,Theta,Rmat,rvec,tm.dcoint,tm.q1,tm.modelsdir,tm.modelfile,d_coint,d_corel,d_coidet);
                           end;
                           g2 = size(theta,2);
                           am.alpha = theta(:,g2-tm.r+1:g2);
                           if g2>tm.r;
                              am.Psi = theta(:,1:g2-tm.r);
                           else;
                              am.Psi = [];
                           end;
                           am.epsilon = am.Z0-(theta*am.Z);
                           am.Omega = (1/tm.T)*am.epsilon*am.epsilon';
                           Theta = theta;
                        end;
                        %
                        % consider restrictions on C
                        %
                        if (size(tm.restrict,2)==3)&(tm.restrict(1,3)==1);
                           %
                           % collect restrictions on C
                           %
                           file = strcat(tm.modelsdir,'C-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
                           Cres = loaddata(file);
                           [Rmat_C,rvec_C] = rmatrix(Cres,tm.n,tm.n);
                           %
                           % Estimate under C restrictions
                           %
                           d_parm = tm.d;
                           if d_corel==0;
                              d_parm = tm.d+(1-d_coint);
                           end;
                           [theta,am.beta] = c_alt_restrict(am.Z0,am.Z1,am.Z2,tm.restrict,am.beta,Theta,Rmat_C,rvec_C,tm.p,tm.pe,d_parm,tm.dcoint,tm.q0,tm.q1,tm.modelsdir,tm.modelfile,curr_ini.reestbeta,d_coint,d_corel,d_coidet);
                           am.Z = [];
                           if tm.r>0;
                              am.Z = am.beta'*am.Z1;
                           end;
                           am.Z = [am.Z2;am.Z];
                           %
                           % fix all the other parameters
                           %
                           am.epsilon = am.Z0-(theta*am.Z);
                           am.Omega = (1/tm.T)*am.epsilon*am.epsilon';
                           g2 = size(theta,2);
                           if tm.r>0;
                              am.alpha = theta(:,g2-tm.r+1:g2);
                           else;
                              am.alpha = [];
                           end;
                           if g2>tm.r;
                              am.Psi = theta(:,1:g2-tm.r);
                           else;
                              am.Psi = [];
                           end;               
                           Theta = theta;
                        end;
                        if test_lr==1;
                           lnL_new = loglike(am.epsilon);
                           lr_test = 2*(lnL_new-lnL_orig);
                           %
                           % determine the number of degrees of freedom
                           %
                           if d_corel==1;
                              if d_coidet==0;
                                 lr_df = (size(am.beta,1)/2)*size(am.beta,2);
                              else;
                                 lr_df = (tm.n+tm.q1)*size(am.beta,2);
                              end;
                              if tm.restrict(1,2)==1;
                                 lr_df = round((((size(am.beta,1)-size(am.beta,2))*size(am.beta,2))-am.dfbeta-const_rest)/2);
                              end;
                           else;
                              if d_coint==1;
                                 lr_df = tm.r;
                              else;
                                 if d_shortrun==0;
                                    lr_df = tm.n;
                                 else;
                                    lr_df = size(test_mat,1)*tm.n;
                                 end;
                              end;
                           end;
                        end;
                     else;
                        if strcmp(alt_state,'on')==1;
                           txt = 'The original and the alternative models are equivalent since the original cointegration space is assumed to be known exactly, i.e., there are no free parameters in the cointegration space that can vary across the 2 regimes. Please consider a different original or alternative model.';
                           about(txt,'information','Bad Alternative Model...',130,350);
                           tm.nyblom_run = 0;
                           set(nyblom_boot_gui,'Visible','on');
                           drawnow;
                           return;
                        else;
                           test_lr = 0;
                        end;
                     end;
                  else;
                     if bad_dummy==4;
                        txt = 'The dummy variable you have created makes some of the levels variables linearly dependent. It''s therefore impossible to extend that model with the new dummy variable. Please select another dummy!';
                        about(txt,'information','Bad Dummy...',130,350);
                     elseif bad_dummy==5;
                        txt = 'The dummy variable you have created makes some of the first difference, exogenous, and/or deterministic variables linearly dependent. It''s therefore impossible to extend that model with the new dummy variable. Please select another dummy!';
                        about(txt,'information','Bad Dummy...',130,350);
                     end;
                     tm.nyblom_run = 0;
                     set(nyblom_boot_gui,'Visible','on');
                     drawnow;
                     return;
                  end;
               else;
                  %
                  % estimate alternative model under changes in rank
                  %
                  if d_rank==2;
                     r_0 = my_r;
                     r_1 = my_r+1;
                     alt_r = r_0;
                  elseif d_rank==3;
                     r_0 = my_r;
                     r_1 = my_r-1;
                     alt_r = r_1;
                  end;
                  am.Z0 = tm.Z0;
                  am.Z1 = tm.Z1;
                  am.Z2 = tm.Z2;
                  am.d = tm.d;
                  am.n = tm.n;
                  am.T = tm.T;
                  am.freq = tm.freq;
                  am.p = tm.p;
                  am.q1 = tm.q1;
                  am.q0 = tm.q0;
                  am.altmodel = tm.altmodel;
                  am.deterselect = tm.deterselect;
                  %
                  [am.beta_1,am.beta_2,am.alpha_1,am.alpha_2,am.Psi,am.Omega,am.epsilon] = varyrank(tm.Z0,tm.Z1,tm.Z2,data_dummy,alt_r,1);
               end;
               %
            else;
               if strcmp(alt_state,'on')==1;
                  if bad_dummy==1;
                     txt = 'The dummy variable you have created is linearly dependent of some of the variables in your original model. It''s therefore not possible to extend that model with the new dummy variable. Please select another dummy!';
                  elseif bad_dummy==2;
                     txt = ['You have too few observations of the long-run relations in one of the regimes, i.e. ' num2str(min(num_ones,num_zeros),'%0.0f') '. You need at least ' num2str(size(tm.Z1,1)+1,'%0.0f') ' observations from each regime. Please select another regime dummy!'];
                  elseif bad_dummy==3;
                     txt = 'The dummy variable is equal to 0 for all observations under the sample size and the break set you have selected. Please select another dummy, change the sample size, or make sure that the dummy variable is active for a break set which is defined relative to the sample size.';
                  elseif bad_dummy==4;
                     txt = 'You have too few observations in one of the regimes to estimate all the short-run parameters for that regime. Please select another dummy!';
                  end;
                  about(txt,'information','Bad Dummy...',130,350);
                  tm.nyblom_run = 0;
                  set(nyblom_boot_gui,'Visible','on');
                  drawnow;
                  return;
               else;
                  test_lr = 0;
               end;
            end;
         end;
         %
         tm.NyblomMean = (1/size(nyblomT,2))*sum(nyblomT);
         tm.NyblomMax = max(nyblomT);
         n_r = tm.n-my_r;
         NyblomMean = zeros(rep,1);
         NyblomMax = zeros(rep,1);
         if test_lr==1;
            boot_lr_test = zeros(rep,1);
         end;
         %
         % choice of Omega depends on model
         %
         if strcmp(alt_state,'off')==1;
            if curr_ini.symmetric==0;
               Omega_sig = chol(tm.Omega)';
            else;
               Omega_sig = symm(tm.Omega);
            end;
         else;
            if curr_ini.symmetric==0;
               Omega_sig = chol(am.Omega)';
            else;
               Omega_sig = symm(am.Omega);
            end;
         end;
         abort = '';
         draw = 1;
         showprog = get(boot_nyblom.progress,'Value');
         if showprog==1;
            input_var.title = ['Progress for ' int2str(rep) ' replications'];
            input_var.facecolor = curr_ini.progress_facecolor;
            input_var.startfacecolor = curr_ini.progress_startfacecolor;
            input_var.edgecolor = curr_ini.progress_edgecolor;
            input_var.bgcolor = curr_ini.progress_bgcolor;
            input_var.clock = get(boot_nyblom.clock,'Value');
            input_var.label = 'Replication number:';
            input_var.stop = 0;
            mywait = progressdlg(0,input_var);
            set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
         else;
            this_text = strvcat('Bootstrapping. The art of pulling oneself up by the bootstraps. Attempt started at...',' ',['Time: ' datestr(now,14)],' ','Please hold!');
            mywait = waitdlg(this_text,'bootstrap','Nyblom Bootstrap Simulation');
            waitf = get(mywait,'UserData');
            tic;
         end;
         %
         if test_lr==0;
            test_lr_str = '';
            str_add = '...';
         else;
            test_lr_str = 'and LR-test vs. alternative model...';
            str_add = '';
         end;
         %
         if curr_ini.taylor_nyblom==0;
            test_str = 'Using the scores version of the Nyblom statistic';
         else;
            test_str = 'Using the 1st order Taylor verion of the Nyblom statistic';
         end;
         %
         if curr_ini.fullrec==1;
            test_str = strvcat(test_str,'with conditioning on full-sample estimates of delta and','Gamma_i parameters in recursion...');
         else;
            test_str = strvcat(test_str,'with updating of all parameters in recursion...');
         end;
         %
         if tm.const_model(2)==1;
            setlogtext(strvcat(' ',['Bootstrapping distribution for Nyblom tests' str_add],test_lr_str,test_str,block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Restricted constant',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(my_r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
            if showprog==1;
               set(mywait,'Name',['Restricted constant model with ' num2str(my_T,'%0.0f') ' obs']);
               drawnow;
            end;
            mod_type = 'resconst';
         elseif tm.const_model(3)==1;
            setlogtext(strvcat(' ',['Bootstrapping distribution for Nyblom tests' str_add],test_lr_str,test_str,block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Unrestricted constant',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(my_r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
            if showprog==1;
               set(mywait,'Name',['Constant model with ' num2str(my_T,'%0.0f') ' obs']);
               drawnow;
            end;
            mod_type = 'const';
         elseif tm.const_model(4)==1;
            setlogtext(strvcat(' ',['Bootstrapping distribution for Nyblom tests' str_add],test_lr_str,test_str,block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Restricted linear trend',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(my_r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
            if showprog==1;
               set(mywait,'Name',['Restricted trend model with ' num2str(my_T,'%0.0f') ' obs']);
               drawnow;
            end;
            mod_type = 'restrend';
         elseif tm.const_model(5)==1;
            setlogtext(strvcat(' ',['Bootstrapping distribution for Nyblom tests' str_add],test_lr_str,test_str,block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Linear trend',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(my_r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
            if showprog==1;
               set(mywait,'Name',['Linear trend model with ' num2str(my_T,'%0.0f') ' obs']);
               drawnow;
            end;
            mod_type = 'trend';
         end;
         %
         if strcmp(alt_state,'on')==1;
            %
            % we have an alternative model
            %
            log_str = strvcat('Using alternative model for DGP with properties:');
            if tempdummy==1;
               add_log_str = '     * Temporary dummy';
            else;
               add_log_str = '     * Permanent dummy';
            end;
            if d_acc==1;
               add_log_str = lower(add_log_str);
               add_log_str = strrep(add_log_str,'     * ','     * Accumulated');
            end;               
            if d_corel==1;
               if d_rank==1;
                  if d_coidet==0;
                     add_log_str = strvcat([add_log_str ' applied to the'],'       cointegration relations');
                  else;
                     if tm.deterselect(1,2)==1;
                        add_log_str = strvcat([add_log_str ' applied to the'],'       cointegration relations, but not to the','       restricted constant');
                     elseif tm.deterselect(1,4)==1;
                        add_log_str = strvcat([add_log_str ' applied to the'],'       cointegration relations, but not to the','       restricted linear trend');
                     end;
                  end;
               else;
                  add_log_str = strvcat([add_log_str ' applied to the'],'       cointegration relations and alpha with rank:',['       ' num2str(r_0) ' when dummy is 0'],['       ' num2str(r_1) ' when dummy is 1']);
               end;
            elseif d_coint==1;
               add_log_str = strvcat([add_log_str ' restricted to the'],'       cointegration space');
            elseif d_shortrun==1;
               add_log_str = strvcat([add_log_str ' applied to the'],'       short-run dynamics');
            end;
            if tm.altmodel.relsample==1;
               du_begin = round(d_begin*(my_T/tm.T));
               du_end = round(d_end*(my_T/tm.T));
            else;
               du_begin = d_begin;
               du_end = d_end;
               if (d_end==tm.T)&(permdummy==1);
                  du_end = my_T;
               end;
            end;
            setlogtext(strvcat(log_str,add_log_str,['     * Dummy is active between period ' num2str(du_begin,'%0.0f') ' and ' num2str(du_end,'%0.0f')],' '));
         end;
         %
         if get(boot_nyblom.bootstrap,'Value')==1;
            %
            % epsilon-file
            %
            epsfile = [curr_ini.simulatedir tm.modelfile '-' usealt tm.restalpha tm.restbeta tm.updating tm.testtype 'epsilon-' num2str(tm.scale_endo,'%0.4f') '-' bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(rep) '-' mod_type '.mat'];
            if fileexist(epsfile)==1;
               load_eps = 1;
               %
               % load old epsilons
               %
               eps_data = load(epsfile);
            else;
               load_eps = 0;
            end;
         else;
            load_eps = 0;
         end;
         %
         % replicating
         %
         while (draw<=rep);  % should be until rep
            if showprog==1;
               abort = get(mywait,'UserData');
               if strcmp(abort,'cancel')==1;
                  break;
               else;
                  progressdlg([(draw/rep) draw]);
               end;
            end;
            %
            % check for bootstrap style
            %
            if load_eps==0;
               if get(boot_nyblom.parametric,'Value')==1;
                  %
                  % reset the random number generator
                  %
                  if curr_ini.random_state==2;
                     randn('state',draw);
                  elseif curr_ini.random_state==3;
                     randn('state',sum(100*clock));
                  elseif curr_ini.random_state==4;
                     randn('state',sum(100*clock)+draw);
                  end;
                  %
                  Epr = randn(tm.n,my_T+50);
                  Epr = Epr(:,51:my_T+50);
                  %
                  % make sure draws in Epr have identity covariance matrix
                  %
                  Sig = (1/my_T)*Epr*Epr';
                  P_sig = chol(Sig)';
                  Epr = P_sig\Epr;
                  Epr = Omega_sig*Epr;
               else;
                  %
                  % reset the random number generator
                  %
                  if curr_ini.random_state==2;
                     rand('state',draw);
                  elseif curr_ini.random_state==3;
                     rand('state',sum(100*clock));
                  elseif curr_ini.random_state==4;
                     rand('state',sum(100*clock)+draw);
                  end;
                  %
                  % resample from estimated epsilons
                  %
                  uni_draws = rand([1 my_T+50]);
                  uni_draws = uni_draws(1,51:my_T+50);
                  Epr = boot_draw(uni_draws,tm.epsilon,blocksize);
               end;
               if get(boot_nyblom.bootstrap,'Value')==1;
                  bootstrap(draw).epsilon = Epr;
               end;
            else;
               Epr = eps_data.bootstrap(draw).epsilon;
            end;
            %
            % create new sample
            %
            if strcmp(alt_state,'off')==1;
               boot = bootstrap_sample(tm,mybeta,Epr);
            else;
               if d_rank==1;
                  boot = bootstrap_sample(am,am.beta,Epr);
               else;
                  boot = bootstrap_varyrank(am,Epr);
               end;
            end;
            %
            % Computing tests
            %
            if tm.restrict(1,2)==0;
               %
               % Base case, no restrictions on the cointegration space
               %
               if curr_ini.fullrec==1;
                  [nyblomT,nyblomcorr] = boot_nyblom_partial(boot.Z0,boot.Z1,boot.Z2,my_r,tm.p,tm.q1,tm.d,curr_ini.T0,tm.df,min(tm.T,my_T));
               else;
                  [nyblomT,nyblomcorr] = boot_nyblom_full(boot.Z0,boot.Z1,boot.Z2,my_r,tm.p,tm.q1,tm.d,curr_ini.T0,tm.df,tm.deterselect,min(tm.T,my_T));
               end;
            else;
               %
               % restrictions on the cointegration space are possible
               %
               [nyblomT,nyblomcorr] = boot_nyblom_restbeta_fcn(tm,curr_ini,tm.cointbeta,boot.Z0,boot.Z1,boot.Z2,my_T,my_r,min(tm.T,my_T));
            end;
            %
            % compute LR-test against alternative model
            %
            if test_lr==1;
               %
               % STEP 1: estimate under the null hypothesis
               %
               if tm.restrict(1,1)==1;
                  if draw==1;
                     file = strcat(tm.modelsdir,'G-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
                     G = loaddata(file);
                     [Rmat,rvec] = rmatrix(G,tm.n,tm.r);
                     dfalpha = size(G,1);
                     if isempty(boot.Z2)==0;
                        Rmat = [zeros(dfalpha,size(boot.Z2,1)*tm.n) Rmat];
                     end;
                  end;
               else;
                  Rmat = [];
                  rvec = [];
               end;
               %
               % if restricted C matrix
               %
               if (size(tm.restrict,2)==3)&(tm.restrict(1,3)==1);
                  if draw==1;
                     file = strcat(tm.modelsdir,'C-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
                     H = loaddata(file);
                     [Rmat_C,rvec_C] = rmatrix(H,tm.n,tm.n);
                  end;
               else;
                  Rmat_C = [];
                  rvec_C = [];
               end;
               %
               % now we compute the log-likelihood under the null hypothesis
               %
               lnL_h0 = estimate_nyblomalt_null(tm,boot,curr_ini,my_r,my_T,Rmat,rvec,Rmat_C,rvec_C);
               %
               % STEP 2: estimate under the alternative hypothesis
               %
               if draw==1;
                  %
                  % check if we need to recreate the data_dummy
                  %
                  if my_T==tm.T;
                     data_dummy_n = data_dummy;
                  else;
                     %
                     % we need to create a new data_dummy series
                     %
                     if tm.altmodel.relsample==1;
                        d_begin = round(d_begin*(my_T/tm.T));
                        d_end = round(d_end*(my_T/tm.T));
                     else;
                        if (d_end==tm.T)&(permdummy==1);
                           d_end = my_T;
                        end;
                     end;
                     %
                     % create the dummy
                     %
                     if (d_begin>1)&(d_end<my_T);
                        data_dummy_n = [zeros(d_begin-1,1);ones(d_end-d_begin+1,1);zeros(my_T-d_end,1)];
                     elseif d_begin==1;
                        data_dummy_n = [ones(d_end,1);zeros(my_T-d_end,1)];
                     else;
                        data_dummy_n = [zeros(d_begin-1,1);ones(my_T-d_begin+1,1)];
                     end;
                     if d_acc==1;
                        data_dummy_n = cumsum(data_dummy_n);
                     end;
                  end;
               end;
               %
               % create the data matrices
               %
               boot_n = bootdata_nyblomalt(boot,data_dummy_n,tm.d,d_coint,d_corel,d_shortrun,d_coidet);
               %
               % if there are alpha restrictions
               %
               if tm.restrict(1,1)==1;
                  %
                  % Collect alpha restrictions
                  %
                  if draw==1;
                     file = strcat(tm.modelsdir,'G-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
                     G = loaddata(file);
                     [Rmat_a,rvec_a] = rmatrix(G,tm.n,tm.r);
                     dfalpha = size(G,1);
                     if isempty(boot_n.Z2)==0;
                        Rmat_a = [zeros(dfalpha,size(boot_n.Z2,1)*tm.n) Rmat_a];
                     end;
                  end;
               else;
                  Rmat_a = [];
                  rvec_a = [];
               end;
               %
               % consider restrictions on C
               %
               if (size(tm.restrict,2)==3)&(tm.restrict(1,3)==1);
                  %
                  % collect restrictions on C
                  %
                  if draw==1;
                     file = strcat(tm.modelsdir,'C-',int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
                     Cres = loaddata(file);
                     [Rmat_Ca,rvec_Ca] = rmatrix(Cres,tm.n,tm.n);
                     %
                     % Estimate under C restrictions
                     %
                     d_parm = tm.d;
                     if d_corel==0;
                        d_parm = tm.d+(1-d_coint);
                     end;
                  end;
               else;
                  Rmat_Ca = [];
                  rvec_Ca = [];
                  d_parm = tm.d;
               end;
               %
               % Compute log-likelihood function under the alternative
               %
               lnL_hA = estimate_nyblomalt_alt(tm,boot_n,curr_ini,my_r,my_T,Rmat_a,rvec_a,Rmat_Ca,rvec_Ca,d_parm,d_coint,d_corel,d_coidet);
               %
               % Compute the LR-test
               %
               boot_lr_test(draw,1) = 2*(lnL_hA-lnL_h0);
            end;
            %
            % Store bootstrap and max eigenvalue
            %
            NyblomMean(draw,1) = (1/size(nyblomT,2))*sum(nyblomT);
            NyblomMax(draw,1) = max(nyblomT);
            draw = draw+1;
         end;
         %
         % bootstrap has finished
         %
         if showprog==1;
            set(mywait,'UserData','done');
            close(mywait);
            drawnow;
         else;
            set(waitf.text,'UserData','done');
            delete(mywait);
            drawnow;
            new_time = toc;
            my_hrs = '00';
            my_min = '00';
            my_sec = num2str(new_time,'%0.2f');
            if new_time>=60;
               ch_min = floor(new_time/60);
               my_sec = num2str(new_time-(ch_min*60),'%0.2f');
               my_min = num2str(ch_min,'%0.0f');
               if ch_min>=60;
                  ch_hrs = floor(ch_min/60);
                  my_min = num2str(ch_min-(ch_hrs*60),'%0.0f');
                  my_hrs = num2str(ch_hrs,'%0.0f');
               end;
            end;
            if size(my_sec,2)==4;
               my_sec = ['0' my_sec];
            end;
            if size(my_min,2)==1;
               my_min = ['0' my_min];
            end;
            if size(my_hrs,2)==1;
               my_hrs = ['0' my_hrs];
            end;
            clock_str = [my_hrs ':' my_min ':' my_sec];
            this_text = strvcat('The bootstrapping process took:',' ',['    ' clock_str ' (hrs:min:sec)']);
            about(this_text,'bootstrap','Simulation Time',120,350);
         end;
         %
         % if we don't cancel
         %
         if (strcmp(abort,'cancel')==0)&(isempty(NyblomMax)==0);
            this_text = strvcat(' ','Saving bootstrap results to disk...','Please hold!');
            mywait = waitdlg(this_text,'bootstrap','Nyblom Tests Bootstrap Simulation');
            waitf = get(mywait,'UserData');
            if get(boot_nyblom.bootstrap,'Value')==1;
               if load_eps==0;
                  save(epsfile,'bootstrap');
               end;
               clear('bootstrap');
               test_data = [NyblomMean NyblomMax];
               testfile = strrep(epsfile,'.mat','-testdata.mat');
               if test_lr==1;
                  test_data = [test_data boot_lr_test];
               end;
               save(testfile,'test_data');
               clear('test_data');
               set(boot_nyblom.bootstrapgraph,'Enable','on','UserData',epsfile);
               set(boot_nyblom.bootstrapgraphmenu,'Enable','on','UserData',testfile);
            end;
            setlogtext(['Bootstrap simulation completed at: ' datestr(now,14) '!']);
            NyblomMean = sort(NyblomMean);
            NyblomMax = sort(NyblomMax);
            if test_lr==1;
               boot_lr_test = sort(boot_lr_test);
            end;
            new_quantiles = ceil(rep*quantiles_fcn);
            cv_mean = NyblomMean(new_quantiles);
            cv_max = NyblomMax(new_quantiles);
            quantiles = [];
            for i=50:99;
               quantiles = [quantiles;ceil((i/100)*rep)];
            end;
            quant_mean = NyblomMean(quantiles);
            quant_max = NyblomMax(quantiles);
            set(boot_nyblom.rep,'UserData',rep);
            set(boot_nyblom.obs,'UserData',my_T);
            set(boot_nyblom.my_r,'UserData',my_r);
            set(boot_nyblom.displaymenu,'Enable','on','UserData',tm.const_model);
            if tm.const_model(2)==1;
               my_mod = 'Restricted constant';
            elseif tm.const_model(3)==1;
               my_mod = 'Constant';
            elseif tm.const_model(4)==1;
               my_mod = 'Restricted linear trend';
            elseif tm.const_model(5)==1;
               my_mod = 'Linear trend';
            end;
            %
            % save full simulations
            %
            if get(boot_nyblom.save,'Value')==1;
               this_text = strvcat(' ','Saving bootstrapped Nyblom tests to disk...','Please hold!');
               set(waitf.text,'String',this_text);
               setlogtext('Saving results to mat-files...');
               if tm.const_model(1)==1;
                  full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
               elseif tm.const_model(2)==1;
                  full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
               elseif tm.const_model(3)==1;
                  full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
               elseif tm.const_model(4)==1;
                  full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
               elseif tm.const_model(5)==1;
                  full_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
               end;
               Number = (1:1:rep)';
               if test_lr==0;
                  save(full_mat,'Number','NyblomMax','NyblomMean');
               else;
                  save(full_mat,'Number','NyblomMax','NyblomMean','boot_lr_test','lr_test','lr_df');
               end;
               set(boot_nyblom.fullmenu,'Enable','on','UserData',full_mat);
               set(boot_nyblom.full,'Enable','on');
            end;
            setlogtext('Saving simulation summary to text file...');
            %
            % dealing with the size of the test
            %
            boot_size = [];
            if (tm.nyblom_asymp==1)&((sum(tm.restrict)==0)|((tm.restrict(1,2)==1)&(tm.dfbeta==0)&(sum(tm.restrict)==1)));
               this_text = strvcat(' ','Determining the empirical size of the Nyblom max and mean tests...','Please hold!');
               set(waitf.text,'String',this_text);
               my_cv = [nyblom_quantile(tm.n,my_r,[99;98;95;90;80;50],'max',tm.deterselect) nyblom_quantile(tm.n,my_r,[99;98;95;90;80;50],'mean',tm.deterselect)];
               boot_size = zeros(6,2);
               for i=1:2;
                  for j=1:6;
                     for i1=1:rep;
                        if i==1;
                           test_val = NyblomMax(rep+1-i1,1);
                        else;
                           test_val = NyblomMean(rep+1-i1,1);
                        end;
                        if my_cv(j,i)>=test_val;
                           boot_size(j,i) = (rep+1-i1)/rep;
                           break;
                        end;
                     end;
                  end;
               end;
            end;
            %
            % dealing with the size of the LR-test against the alternative
            %
            boot_lr_size = [];
            boot_lr_pval = [];
            if test_lr==1;
               this_text = strvcat(' ','Determining the empirical size of the LR-test against specific alternative...','Please hold!');
               set(waitf.text,'String',this_text);
               my_cv_lr = chisq_inv([0.99;0.98;0.95;0.9;0.8;0.5],lr_df*ones(6,1));
               %
               for i=1:6;
                  for j=1:rep;
                     if my_cv_lr(i,1)>=boot_lr_test(rep+1-j,1);
                        break;
                     end;
                  end;
                  if (j<rep)|(my_cv_lr(i,1)>=boot_lr_test(1,1));
                     boot_lr_size = [boot_lr_size;(rep+1-j)/rep];
                  else;
                     boot_lr_size = [boot_lr_size;0];
                  end;
               end;
               %
               % determining the empirical p-value of the LR-test
               %
               if tm.T==my_T;
                  this_text = strvcat(' ','Determining the empirical p-value of the LR-test against specific alternative...','Please hold!');
                  set(waitf.text,'String',this_text);
                  for j=1:rep;
                     if lr_test>=boot_lr_test(rep+1-j);
                        break;
                     end;
                  end;
                  if j>1;
                     boot_lr_pval = j/rep;
                  else;
                     boot_lr_pval = 0;
                  end;
               end;
            end;
            %
            my_50 = floor(0.5*rep);
            my_80 = floor(0.8*rep);
            my_90 = floor(0.9*rep);
            my_95 = floor(0.95*rep);
            my_975 = floor(0.98*rep);
            my_99 = floor(0.99*rep);
            %
            p_size = [];
            lr_p_size = [];
            if strcmp(alt_state,'on')==1;
               %
               % check if we have a bootstrap results under the null
               %
               if tm.const_model(1)==1;
                  null_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
               elseif tm.const_model(2)==1;
                  null_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
               elseif tm.const_model(3)==1;
                  null_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
               elseif tm.const_model(4)==1;
                  null_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
               elseif tm.const_model(5)==1;
                  null_mat = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-full-' bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
               end;
               %
               if fileexist(null_mat)==1;
                  this_text = strvcat(' ','Determining the bootstrap rejection probabilities of the Nyblom max and mean tests...','Please hold!');
                  set(waitf.text,'String',this_text);
                  nyblom_mat = load(null_mat);
                  p_size = zeros(6,2);
                  my_h0 = [nyblom_mat.NyblomMax([my_99;my_975;my_95;my_90;my_80;my_50],:) nyblom_mat.NyblomMean([my_99;my_975;my_95;my_90;my_80;my_50],:)];
                  for i=1:2;
                     for j=1:6;
                        for i1=1:rep;
                           if i==1;
                              test_val = NyblomMax(rep+1-i1,1);
                           else;
                              test_val = NyblomMean(rep+1-i1,1);
                           end;
                           if my_h0(j,i)>=test_val;
                              p_size(j,i) = (rep+1-i1)/rep;
                              break;
                           end;
                        end;
                     end;
                  end;
                  %
                  % do the same for the LR-test
                  %
                  if (test_lr==1)&(isfield(nyblom_mat,'boot_lr_test')==1);
                     this_text = strvcat(' ','Determining the bootstrap rejection probabilities of the LR-test against specific alternative...','Please hold!');
                     set(waitf.text,'String',this_text);
                     my_h0_lr = nyblom_mat.boot_lr_test([my_99;my_975;my_95;my_90;my_80;my_50],1);
                     lr_p_size = zeros(6,1);
                     for j=1:6;
                        for i=1:rep;
                           if my_h0_lr(j,1)>=boot_lr_test(rep+1-i,1);
                              lr_p_size(j,1) = (rep+1-i)/rep;
                              break;
                           end;
                        end;
                     end;
                  end;
               end;
            end;
            %
            % computing empirical p-values
            %
            boot_pval = [];
            if my_T==tm.T;
               this_text = strvcat(' ','Determining the empirical p-value of the Nyblom tests...','Please hold!');
               set(waitf.text,'String',this_text);
               for j=1:rep;
                  if tm.NyblomMean>=NyblomMean(rep+1-j,1);
                     break;
                  end;
               end;
               if j>1;
                  boot_pval = j/rep;
               else;
                  boot_pval = 0;
               end;
               for j=1:rep;
                  if tm.NyblomMax>=NyblomMax(rep+1-j,1);
                     break;
                  end;
               end;
               if j>1;
                  boot_pval = [boot_pval j/rep];
               else;
                  boot_pval = [boot_pval 0];
               end;
            end;
            %
            % write summary to file
            %
            this_text = strvcat(' ','Writing bootstrap summary information to disk...','Please hold!');
            set(waitf.text,'String',this_text);
            res_str = strvcat(' ','**************************************************************','*                          Results                           *');
            res_str = strvcat(res_str,'**************************************************************',' ',['  Model:                   ' my_mod],['  Endogenous variables:    ' num2str(tm.n,'%0.0f')],['  Cointegration relations: ' num2str(my_r,'%0.0f')],['  Replications:            ' num2str(rep,'%0.0f')],['  Draws per replication:   ' num2str(my_T,'%0.0f')]);
            if blocksize>1;
               res_str = strvcat(res_str,' ',strrep(block_txt,'.',''),' ');
            end;
            if curr_ini.taylor_nyblom==0;
               res_str = strvcat(res_str,'  Method:                  Scores version');
            else;
               res_str = strvcat(res_str,'  Method:                  First-order Taylor expansion version');
            end;
            if curr_ini.fullrec==0;
               res_str = strvcat(res_str,'                           updating all parameters in recursion',' ');
            else;
               res_str = strvcat(res_str,'                           conditional on full-sample estimates of delta','                           and Gamma_i parameters in recursion',' ');
            end;
            if strcmp(alt_state,'on')==1;
               %
               % we have an alternative model
               %
               res_str = strvcat(res_str,'  Using alternative model for DGP with properties:',' ');
               if tempdummy==1;
                  add_res_str = '       Temporary dummy';
               else;
                  add_res_str = '       Permanent dummy';
               end;
               if d_acc==1;
                  add_res_str = lower(add_res_str);
                  add_res_str = strrep(add_res_str,'       ','       Accumulated');
               end;               
               if d_corel==1;
                  if d_rank==1;
                     if d_coidet==0;
                        add_res_str = [add_res_str ' applied to the cointegration relations'];
                     else;
                        if tm.deterselect(1,2)==1;
                           add_res_str = strvcat([add_res_str ' applied to the cointegration relations, but not to the'],'       restricted constant');
                        elseif tm.deterselect(1,4)==1;
                           add_res_str = strvcat([add_res_str ' applied to the cointegration relations, but not to the'],'       restricted linear trend');
                        end;
                     end;
                  else;
                     add_res_str = strvcat([add_res_str ' applied to the cointegration relations'],'       and alpha with rank:',['          ' num2str(r_0) ' when dummy is 0'],['          ' num2str(r_1) ' when dummy is 1']);
                  end;
               elseif d_shortrun==1;
                  add_res_str = [add_res_str ' applied to the short-run dynamics'];
               elseif d_coint==1;
                  add_res_str = [add_res_str ' restricted to the cointegration space'];
               end;
               if tm.altmodel.relsample==1;
                  du_begin = round(d_begin*(my_T/tm.T));
                  du_end = round(d_end*(my_T/tm.T));
               else;
                  du_begin = d_begin;
                  du_end = d_end;
                  if (d_end==tm.T)&(permdummy==1);
                     du_end = my_T;
                  end;
               end;
               res_str = strvcat(res_str,add_res_str,['       Dummy is active between period ' num2str(du_begin,'%0.0f') ' and ' num2str(du_end,'%0.0f')],' ');
            end;
            sp_str = spacestr(curr_ini.decimals-2);
            prt_val = ['%' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
            res_str = strvcat(res_str,'                           Supremum test','                           -------------',' ',['     50%   ' sp_str '   80%   ' sp_str '   90%   ' sp_str '   95%   ' sp_str '   98%   ' sp_str '   99%  ' sp_str '    Mean  ' sp_str '  Std. Dev.']);
            max_std = sqrt( (1/rep)*sum( ( NyblomMax - ( (1/rep)*sum(NyblomMax) ) ).*( NyblomMax - ( (1/rep)*sum(NyblomMax) ) ) ) );
            res_str = strvcat(res_str,sprintf([prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val],NyblomMax(my_50),NyblomMax(my_80),NyblomMax(my_90),NyblomMax(my_95),NyblomMax(my_975),NyblomMax(my_99),(1/rep)*sum(NyblomMax),max_std),' ');
            if (tm.nyblom_asymp==1)&((sum(tm.restrict)==0)|((tm.restrict(1,2)==1)&(tm.dfbeta==0)&(sum(tm.restrict)==1)));
               max_mom = nyblom_moments(tm.n,my_r,'max',tm.deterselect);
               res_str = strvcat(res_str,'From the asymptotic distribution we have the following quantile values:',' ',sprintf([prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val],my_cv(6,1),my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),max_mom(1,1),max_mom(1,2)),' ');
            end;
            res_str = strvcat(res_str,' ','                           Mean test','                           ---------',' ',['     50%   ' sp_str '   80%   ' sp_str '   90%   ' sp_str '   95%   ' sp_str '   98%   ' sp_str '   99%   ' sp_str '   Mean  ' sp_str '  Std. Dev.']);
            mean_std = sqrt( (1/rep)*sum( ( NyblomMean - ( (1/rep)*sum(NyblomMean) ) ).*( NyblomMean - ( (1/rep)*sum(NyblomMean) ) ) ) );
            res_str = strvcat(res_str,sprintf([prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val],NyblomMean(my_50),NyblomMean(my_80),NyblomMean(my_90),NyblomMean(my_95),NyblomMean(my_975),NyblomMean(my_99),(1/rep)*sum(NyblomMean),mean_std),' ');
            if (tm.nyblom_asymp==1)&((sum(tm.restrict)==0)|((tm.restrict(1,2)==1)&(tm.dfbeta==0)&(sum(tm.restrict)==1)));
               mean_mom = nyblom_moments(tm.n,my_r,'mean',tm.deterselect);
               res_str = strvcat(res_str,'From the asymptotic distribution we have the following quantile values:',' ',sprintf([prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val],my_cv(6,2),my_cv(5,2),my_cv(4,2),my_cv(3,2),my_cv(2,2),my_cv(1,2),mean_mom(1,1),mean_mom(1,2)),' ');
            end;
            if isempty(boot_size)==0;
               if strcmp(alt_state,'on')==1;
                  res_str = strvcat(res_str,'          Rejection probabilities (wrt asymptotic null)','          ---------------------------------------------',' ','    Test       50%     20%     10%      5%      2%      1%');
               else;
                  res_str = strvcat(res_str,'                      Empirical size','                      --------------',' ','    Test       50%     20%     10%      5%      2%      1%');
               end;
               res_str = strvcat(res_str,sprintf(' sup Q(t|T)  %6.2f  %6.2f  %6.2f  %6.2f  %6.2f  %6.2f',100*(1-boot_size(6,1)),100*(1-boot_size(5,1)),100*(1-boot_size(4,1)),100*(1-boot_size(3,1)),100*(1-boot_size(2,1)),100*(1-boot_size(1,1))));
               res_str = strvcat(res_str,sprintf('mean Q(t|T)  %6.2f  %6.2f  %6.2f  %6.2f  %6.2f  %6.2f',100*(1-boot_size(6,2)),100*(1-boot_size(5,2)),100*(1-boot_size(4,2)),100*(1-boot_size(3,2)),100*(1-boot_size(2,2)),100*(1-boot_size(1,2))),' ');
            end;
            if isempty(p_size)==0;
               res_str = strvcat(res_str,'          Rejection probabilities (wrt bootstrap null)','          --------------------------------------------',' ','    Test       50%     20%     10%      5%      2%      1%');
               res_str = strvcat(res_str,sprintf(' sup Q(t|T)  %6.2f  %6.2f  %6.2f  %6.2f  %6.2f  %6.2f',100*(1-p_size(6,1)),100*(1-p_size(5,1)),100*(1-p_size(4,1)),100*(1-p_size(3,1)),100*(1-p_size(2,1)),100*(1-p_size(1,1))));
               res_str = strvcat(res_str,sprintf('mean Q(t|T)  %6.2f  %6.2f  %6.2f  %6.2f  %6.2f  %6.2f',100*(1-p_size(6,2)),100*(1-p_size(5,2)),100*(1-p_size(4,2)),100*(1-p_size(3,2)),100*(1-p_size(2,2)),100*(1-p_size(1,2))),' ');
            end;
            if isempty(boot_pval)==0;
               res_str = strvcat(res_str,'                      Empirical p-values','                      ------------------',' ');
               res_str = strvcat(res_str,sprintf([' sup Q(t|T) = ' prt_val '    p-value = ' prt_val],tm.NyblomMax,boot_pval(1,2)));
               res_str = strvcat(res_str,sprintf(['mean Q(t|T) = ' prt_val '    p-value = ' prt_val],tm.NyblomMean,boot_pval(1,1)),' ');
            end;
            %
            % if we have bootstrapped the LR-test against a specific alternative
            %
            if test_lr==1;
               res_str = strvcat(res_str,'--------------------------------------------------------------',' ');
               res_str = strvcat(res_str,'                           LR-test','                           -------',' ',['     50%   ' sp_str '   80%   ' sp_str '   90%   ' sp_str '   95%   ' sp_str '   98%   ' sp_str '   99%   ' sp_str '   Mean  ' sp_str '  Std. Dev.']);
               lr_std = sqrt( (1/rep)*sum( ( boot_lr_test - ( (1/rep)*sum(boot_lr_test) ) ).*( boot_lr_test - ( (1/rep)*sum(boot_lr_test) ) ) ) );
               res_str = strvcat(res_str,sprintf([prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val],boot_lr_test(my_50,1),boot_lr_test(my_80,1),boot_lr_test(my_90,1),boot_lr_test(my_95,1),boot_lr_test(my_975,1),boot_lr_test(my_99,1),(1/rep)*sum(boot_lr_test,1),lr_std),' ');
               res_str = strvcat(res_str,'From the asymptotic distribution we have the following quantile values:',' ',sprintf([prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val ' ' prt_val],my_cv_lr(6,1),my_cv_lr(5,1),my_cv_lr(4,1),my_cv_lr(3,1),my_cv_lr(2,1),my_cv_lr(1,1),lr_df,sqrt(2*lr_df)),' ');
               if isempty(boot_lr_size)==0;
                  if strcmp(alt_state,'on')==1;
                     res_str = strvcat(res_str,'          Rejection probabilities (wrt asymptotic null)','          ---------------------------------------------',' ','    Test       50%     20%     10%      5%      2%      1%');
                  else;
                     res_str = strvcat(res_str,'                      Empirical size','                      --------------',' ','    Test       50%     20%     10%      5%      2%      1%');
                  end;
                  res_str = strvcat(res_str,sprintf('     LR      %6.2f  %6.2f  %6.2f  %6.2f  %6.2f  %6.2f',100*(1-boot_lr_size(6,1)),100*(1-boot_lr_size(5,1)),100*(1-boot_lr_size(4,1)),100*(1-boot_lr_size(3,1)),100*(1-boot_lr_size(2,1)),100*(1-boot_lr_size(1,1))),' ');
               end;
               if isempty(lr_p_size)==0;
                  res_str = strvcat(res_str,'          Rejection probabilities (wrt bootstrap null)','          --------------------------------------------',' ','    Test       50%     20%     10%      5%      2%      1%');
                  res_str = strvcat(res_str,sprintf('     LR      %6.2f  %6.2f  %6.2f  %6.2f  %6.2f  %6.2f',100*(1-lr_p_size(6,1)),100*(1-lr_p_size(5,1)),100*(1-lr_p_size(4,1)),100*(1-lr_p_size(3,1)),100*(1-lr_p_size(2,1)),100*(1-lr_p_size(1,1))),' ');
               end;
               if isempty(boot_lr_pval)==0;
                  res_str = strvcat(res_str,'                      Empirical p-value','                      -----------------',' ');
                  res_str = strvcat(res_str,sprintf(['     LR(%0.0f) = ' prt_val '    p-value = ' prt_val],lr_df,lr_test,boot_lr_pval),' ');
               end;
            end;
            res_str = strvcat(res_str,'**************************************************************',' ');
            if tm.const_model(1)==1;
               file_txt = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-summary-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-noconst.txt'];
            elseif tm.const_model(2)==1;
               file_txt = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-summary-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
            elseif tm.const_model(3)==1;
               file_txt = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-summary-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
            elseif tm.const_model(4)==1;
               file_txt = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-summary-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
            elseif tm.const_model(5)==1;
               file_txt = [curr_ini.simulatedir  tm.modelfile '-nyblom-boot-summary-' usealt bootstyle tm.restalpha tm.restbeta tm.updating tm.testtype num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
            end;
            fid_txt = fopen(file_txt,'wt');
            for i=1:size(res_str,1);
               fprintf(fid_txt,[strrep(res_str(i,:),'%','%%') '\n']);
            end;
            fprintf(fid_txt,['Output created on: ' datestr(now,0) '\n']);
            fclose(fid_txt);
            %
            % write to tex file
            %
            file_tex = strrep(file_txt,'.txt','.ltx');
            f_id = fopen(file_tex,'wt');
            fprintf(f_id,'\\begin{tabular}{ll}\n');
            fprintf(f_id,['Model: & ' my_mod ' \\\\\n']);
            fprintf(f_id,['\\#Endogenous variables: & ' num2str(tm.n,'%0.0f') ' \\\\\n']);
            fprintf(f_id,['\\#Cointegration relations: & ' num2str(my_r,'%0.0f') ' \\\\\n']);
            fprintf(f_id,['\\#Replications: & ' num2str(rep,'%0.0f') ' \\\\\n']);
            fprintf(f_id,['\\#Draws per replication: & ' num2str(my_T,'%0.0f') ' \\\\\n']);
            if blocksize>1;
               fprintf(f_id,['Block size length: & ' num2str(blocksize,'%0.0f') ' \\\\\n']);
            end;
            if curr_ini.taylor_nyblom==0;
               fprintf(f_id,'Method: & Scores version \\\\\n');
            else;
               fprintf(f_id,'Method: & First-order Taylor expansion version \\\\\n');
            end;
            if curr_ini.fullrec==0;
               fprintf(f_id,' & updating all parameters in recursion \\\\\n');
            else;
               fprintf(f_id,' & conditional on full-sample estimates of $\\delta$ \\\\\n & and $\\Gamma_i$ parameters in recursion \\\\\n');
            end;
            if strcmp(alt_state,'on')==1;
               fprintf(f_id,'\\multicolumn{2}{c}{ } \\\\\n');
               for i=1:size(add_res_str,1);
                  fprintf(f_id,' & %s \\\\\n',strtrim(add_res_str(i,:)));
               end;
               fprintf(f_id,' & Dummy is active between period %0.0f and %0.0f \\\\\n',du_begin,du_end);
            end;
            prt_val = ['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'];
            fprintf(f_id,'\\end{tabular}\n\n');
            fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrrr}\n');
            fprintf(f_id,'\\multicolumn{8}{c}{Supremum test} \\\\\n');
            fprintf(f_id,'50\\%% & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% & Mean & Std. Dev. \\\\\n');
            fprintf(f_id,[prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' \\\\ \n'],NyblomMax(my_50),NyblomMax(my_80),NyblomMax(my_90),NyblomMax(my_95),NyblomMax(my_975),NyblomMax(my_99),(1/rep)*sum(NyblomMax),max_std);
            if (tm.nyblom_asymp==1)&((sum(tm.restrict)==0)|((tm.restrict(1,2)==1)&(tm.dfbeta==0)&(sum(tm.restrict)==1)));
               fprintf(f_id,'\\multicolumn{8}{c}{ } \\\\\n');
               fprintf(f_id,'\\multicolumn{8}{c}{From the asymptotic distribution we have:} \\\\\n');
               fprintf(f_id,[prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' \\\\ \n'],my_cv(6,1),my_cv(5,1),my_cv(4,1),my_cv(3,1),my_cv(2,1),my_cv(1,1),max_mom(1,1),max_mom(1,2));
            end;
            fprintf(f_id,'\\multicolumn{8}{c}{ } \\\\\n');
            fprintf(f_id,'\\multicolumn{8}{c}{Mean test} \\\\\n');
            fprintf(f_id,[prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' \\\\ \n'],NyblomMean(my_50),NyblomMean(my_80),NyblomMean(my_90),NyblomMean(my_95),NyblomMean(my_975),NyblomMean(my_99),(1/rep)*sum(NyblomMean),mean_std);
            if (tm.nyblom_asymp==1)&((sum(tm.restrict)==0)|((tm.restrict(1,2)==1)&(tm.dfbeta==0)&(sum(tm.restrict)==1)));
               fprintf(f_id,'\\multicolumn{8}{c}{ } \\\\\n');
               fprintf(f_id,'\\multicolumn{8}{c}{From the asymptotic distribution we have:} \\\\\n');
               fprintf(f_id,[prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' \\\\ \n'],my_cv(6,2),my_cv(5,2),my_cv(4,2),my_cv(3,2),my_cv(2,2),my_cv(1,2),mean_mom(1,1),mean_mom(1,2));
            end;
            fprintf(f_id,'\\end{tabular}\n\n');
            %
            if isempty(boot_size)==0;
               fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrr}\n');
               if strcmp(alt_state,'on')==1;
                  fprintf(f_id,'\\multicolumn{7}{c}{Rejection probabilities (wrt asymptotic null)} \\\\\n');
               else;
                  fprintf(f_id,'\\multicolumn{7}{c}{Empirical size} \\\\\n');
               end;
               fprintf(f_id,'Test & 50\\%% & 20\\%% & 10\\%% & 5\\%% & 2\\%% & 1\\%% \\\\\n');
               fprintf(f_id,'$\\sup Q_{t|T}$ & %0.2f & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% \\\\\n',100*(1-boot_size(6,1)),100*(1-boot_size(5,1)),100*(1-boot_size(4,1)),100*(1-boot_size(3,1)),100*(1-boot_size(2,1)),100*(1-boot_size(1,1)));
               fprintf(f_id,'$\\mean Q_{t|T}$ & %0.2f & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% \\\\\n',100*(1-boot_size(6,2)),100*(1-boot_size(5,2)),100*(1-boot_size(4,2)),100*(1-boot_size(3,2)),100*(1-boot_size(2,2)),100*(1-boot_size(1,2)));
               fprintf(f_id,'\\end{tabular}\n\n');
            end;
            %
            if isempty(p_size)==0;
               fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrr}\n');
               fprintf(f_id,'\\multicolumn{7}{c}{Rejection probabilities (wrt bootstrap null)} \\\\\n');
               fprintf(f_id,'Test & 50\\%% & 20\\%% & 10\\%% & 5\\%% & 2\\%% & 1\\%% \\\\\n');
               fprintf(f_id,'$\\sup Q_{t|T}$ & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% \\\\\n',100*(1-p_size(6,1)),100*(1-p_size(5,1)),100*(1-p_size(4,1)),100*(1-p_size(3,1)),100*(1-p_size(2,1)),100*(1-p_size(1,1)));
               fprintf(f_id,'$\\mean Q_{t|T}$ & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% \\\\\n',100*(1-p_size(6,2)),100*(1-p_size(5,2)),100*(1-p_size(4,2)),100*(1-p_size(3,2)),100*(1-p_size(2,2)),100*(1-p_size(1,2)));
               fprintf(f_id,'\\end{tabular}\n\n');
            end;
            %
            if isempty(boot_pval)==0;
               fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{ll}\n');
               fprintf(f_id,'\\multicolumn{2}{c}{Empirical $p$-values} \\\\\n');
               fprintf(f_id,[' & $\\sup Q_{t|T}$ = ' prt_val ' \\\\ \n'],tm.NyblomMax);
               fprintf(f_id,[' & $p$-value = ' prt_val ' \\\\ \n'],boot_pval(1,2));
               fprintf(f_id,[' & $\\mean Q_{t|T}$ = ' prt_val ' \\\\ \n'],tm.NyblomMean);
               fprintf(f_id,[' & $p$-value = ' prt_val ' \\\\ \n'],boot_pval(1,1));
               fprintf(f_id,'\\end{tabular}\n\n');
            end;
            %
            % if we have bootstrapped the LR-test against a specific alternative
            %
            if test_lr==1;
               fprintf(f_id,'\\halfruler\n\n');
               fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrrr}\n');
               fprintf(f_id,'\\multicolumn{8}{c}{LR-test} \\\\\n');
               fprintf(f_id,'50\\%% & 80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% & Mean & Std. Dev. \\\\\n');
               fprintf(f_id,[prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' \\\\ \n'],boot_lr_test(my_50,1),boot_lr_test(my_80,1),boot_lr_test(my_90,1),boot_lr_test(my_95,1),boot_lr_test(my_975,1),boot_lr_test(my_99,1),(1/rep)*sum(boot_lr_test),lr_std);
               fprintf(f_id,'\\multicolumn{8}{c}{ } \\\\\n');
               fprintf(f_id,'\\multicolumn{8}{c}{From the asymptotic distribution we have:} \\\\\n');
               fprintf(f_id,[prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' \\\\ \n'],my_cv_lr(6,1),my_cv_lr(5,1),my_cv_lr(4,1),my_cv_lr(3,1),my_cv_lr(2,1),my_cv_lr(1,1),lr_df,sqrt(2*lr_df));
               fprintf(f_id,'\\end{tabular}\n\n');
               %
               if isempty(boot_lr_size)==0;
                  fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrr}\n');
                  if strcmp(alt_state,'on')==1;
                     fprintf(f_id,'\\multicolumn{7}{c}{Rejection probabilities (wrt asymptotic null)} \\\\\n');
                  else;
                     fprintf(f_id,'\\multicolumn{7}{c}{Empirical size} \\\\\n');
                  end;
                  fprintf(f_id,'Test & 50\\%% & 20\\%% & 10\\%% & 5\\%% & 2\\%% & 1\\%% \\\\\n');
                  fprintf(f_id,'$LR$ & %0.2f & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% \\\\\n',100*(1-boot_lr_size(6,1)),100*(1-boot_lr_size(5,1)),100*(1-boot_lr_size(4,1)),100*(1-boot_lr_size(3,1)),100*(1-boot_lr_size(2,1)),100*(1-boot_lr_size(1,1)));
                  fprintf(f_id,'\\end{tabular}\n\n');
               end;
               %
               if isempty(lr_p_size)==0;
                  fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{rrrrrrr}\n');
                  fprintf(f_id,'\\multicolumn{7}{c}{Rejection probabilities (wrt bootstrap null)} \\\\\n');
                  fprintf(f_id,'Test & 50\\%% & 20\\%% & 10\\%% & 5\\%% & 2\\%% & 1\\%% \\\\\n');
                  fprintf(f_id,'$LR$ & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% & %0.2f\\%% \\\\\n',100*(1-lr_p_size(6,1)),100*(1-lr_p_size(5,1)),100*(1-lr_p_size(4,1)),100*(1-lr_p_size(3,1)),100*(1-lr_p_size(2,1)),100*(1-lr_p_size(1,1)));
                  fprintf(f_id,'\\end{tabular}\n\n');
               end;
               %
               if isempty(boot_lr_pval)==0;
                  fprintf(f_id,'\\vspace*{3mm}\n\n\\begin{tabular}{ll}\n');
                  fprintf(f_id,'\\multicolumn{2}{c}{Empirical $p$-value} \\\\\n');
                  fprintf(f_id,[' & $LR(%0.0f)$ = ' prt_val ' \\\\ \n'],lr_df,lr_test);
                  fprintf(f_id,[' & $p$-value = ' prt_val ' \\\\ \n'],boot_lr_pval);
                  fprintf(f_id,'\\end{tabular}\n\n');
               end;
            end;
            fprintf(f_id,'\\ruler\n\n%%*************************************************************\n');
            fclose(f_id);
            if curr_ini.noprint==0;
               set(boot_nyblom.output,'Enable','on');
            end;
            set(boot_nyblom.summarymenu,'Enable','on','UserData',file_txt);
            set(boot_nyblom.summary,'Enable','on');
            if test_lr==0;
               set(boot_nyblom.display,'Enable','on','UserData',[NyblomMax NyblomMean]);
               tm.lr_df = [];
            else;
               set(boot_nyblom.display,'Enable','on','UserData',[NyblomMax NyblomMean boot_lr_test]);
               tm.lr_df = lr_df;
               tm.lr_test = lr_test;
               clear('boot_lr_test');
            end;
            set(boot_nyblom.altmodel,'UserData',[]);
            clear('NyblomMax','NyblomMean');
            set(boot_nyblom.histogram,'Enable','on');
            set(boot_nyblom.histogrammenu,'Enable','on');
            set(boot_nyblom.matfilebutton,'Enable','on');
            set(boot_nyblom.matfilemenu,'Enable','on');
            set(waitf.text,'UserData','done');
            delete(mywait);
            drawnow;
         else;
            setlogtext('Cancelled...');
         end;
      end;
   end;
   tm.nyblom_run = 0;
   set(nyblom_boot_gui,'Visible','on');
   drawnow;
case 'done'
   if tm.nyblom_run==0;
      set(boot_nyblom.done,'UserData','done');
      pid = get(boot_nyblom.filemenu,'UserData');
      if isempty(pid)==1;
         delete(nyblom_boot_gui);
      else;
         close(nyblom_boot_gui);
      end;
   end;
end;

if strcmp(selector,'init')==1;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(nyblom_boot_gui,'Name') ' ' fix_filepath([pwd '\icons\bootstrap.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(boot_nyblom.filemenu,'UserData',pid);
         set(nyblom_boot_gui,'CloseRequestFcn','killwinpid');
      end;
   end;
   set(nyblom_boot_gui,'Visible','on');
end;

if strcmp(selector,'done')==0;
   curr_ini.models = tm;
   curr_ini.images = button_images;
   set(boot_nyblom.matfilebutton,'UserData',curr_ini);
end;

if my_exit==1;
   waitfor(boot_nyblom.done,'UserData','done');
end;

%
% end of nyblom_bootstrap.m
%
