%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for tabbed options dialogs          %
%                                                                %
%          Function: options                                     %
%                                                                %
%          Input:                                                %
%                       selector: case switch function           %
%                       lvar_ini: structure of ini-data          %
%                                                                %
%          Output:                                               %
%                       written to var.ini                       %
%                                                                %
%          This version:        June 16, 2006                    %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function optionsdlg(selector,lvar_ini)

if nargin==0;
   selector = 'init';
end;

if strcmp(selector,'init')==1;
   var_ini = lvar_ini;
   var_ini.new_font = 0;
   var_ini.oldfont.fontname = var_ini.gui_fontname;
   var_ini.oldfont.fontsize = var_ini.gui_fontsize;
   var_ini.oldfont.fontweight = var_ini.gui_fontweight;;
   var_ini.oldfont.fontangle = var_ini.gui_fontangle;
   var_ini.previous.gui_light_color = var_ini.gui_light_color;
   var_ini.previous.gui_shade_color = var_ini.gui_shade_color;
   var_ini.previous.gui_dark_color = var_ini.gui_dark_color;
   var_ini.previous.frame_light_color = var_ini.frame_light_color;
   var_ini.previous.frame_shade_color = var_ini.frame_shade_color;
   var_ini.previous.frame_dark_color = var_ini.frame_dark_color;
   h = findobj('Type','figure','Tag','StructuralVAR');
   var_ini.position = get(h,'Position');
   var_ini.position = var_ini.position(1,1:2);
   fixed = 0;
   if matlabnumber>=6.0;
      fixed = 1;
   end;
   thisexit = 0;
   %
   % additional initialization
   %
   if var_ini.landscape==1;
      orientstr = 'landscape';
   else;
      orientstr = 'portrait';
   end;
   if var_ini.reestbeta==0;
      method1str = '''3-step'' Classical Gaussian ML (beta, reduced form, B matrix)';
      method2str = '''2-step'' Classical Gaussian ML (beta, reduced form and B matrix)';
   else;
      method1str = '''2-step'' Classical Gaussian ML (beta and reduced form, B matrix)';
      method2str = 'Full Information Classical Gaussian ML';
   end;
   if var_ini.uselastfile==0;
      var_ini.startrun = 0;
      startrunenable = 'off';
   else;
      startrunenable = 'on';
   end;
   if strcmp(var_ini.interpolate,'nearest')==1;
      var_ini.interpolate_value = 1;
   elseif strcmp(var_ini.interpolate,'linear')==1;
      var_ini.interpolate_value = 2;
   elseif strcmp(var_ini.interpolate,'spline')==1;
      var_ini.interpolate_value = 3;
   elseif strcmp(var_ini.interpolate,'cubic')==1;
      var_ini.interpolate_value = 4;
   elseif strcmp(var_ini.interpolate,'knorm')==1;
      var_ini.interpolate_value = 5;
   elseif strcmp(var_ini.interpolate,'kepan')==1;
      var_ini.interpolate_value = 6;
   elseif strcmp(var_ini.interpolate,'krect')==1;
      var_ini.interpolate_value = 7;
   elseif strcmp(var_ini.interpolate,'ktria')==1;
      var_ini.interpolate_value = 8;
   elseif strcmp(var_ini.interpolate,'kbiwe')==1;
      var_ini.interpolate_value = 9;
   elseif strcmp(var_ini.interpolate,'ktriw')==1;
      var_ini.interpolate_value = 10;
   elseif strcmp(var_ini.interpolate,'klapl')==1;
      var_ini.interpolate_value = 11;
   elseif strcmp(var_ini.interpolate,'klogi')==1;
      var_ini.interpolate_value = 12;
   end;
   if var_ini.edit_context==1;
      add_edit_context = 3;
   else;
      add_edit_context = 0;
   end;
   if var_ini.invert_hardcopy==1;
      inv_hardcopy = 'on';
   else;
      inv_hardcopy = 'off';
   end;
   repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
   var_ini.nRep_value = 1;
   for i=1:size(repvalues,2);
      if var_ini.nRep==repvalues(1,i);
         var_ini.nRep_value = i;
         break;
      end;
   end;
   if var_ini.geometry==[0 0];
      var_ini.geometryvalue = 0;
   else;
      var_ini.geometryvalue = 1;
   end;
   maxitv = 18;
   var_ini.maxitvec = [100 200 300 400 500 600 700 800 900 1000 1500 2000 2500 3000 3500 4000 4500 5000 5500 6000 6500 7000 7500 8000 8500 9000 9500 10000];
   for i = 1:size(var_ini.maxitvec,2);
      if var_ini.maxit==var_ini.maxitvec(1,i);
         maxitv = i;
         break;
      end;
   end;
   var_ini.maxitstring = '100|200|300|400|500|600|700|800|900|1000|1500|2000|2500|3000|3500|4000|4500|5000|5500|6000|6500|7000|7500|8000|8500|9000|9500|10000';
   var_ini.critvalstr = '99 percent|98 percent|95 percent|90 percent|80 percent|p-value';
   if var_ini.critval==1;
      var_ini.critvalnum = 1;
   elseif var_ini.critval==2;
      var_ini.critvalnum = 2;
   elseif var_ini.critval==5;
      var_ini.critvalnum = 3;
   elseif var_ini.critval==10;
      var_ini.critvalnum = 4;
   elseif var_ini.critval==20;
      var_ini.critvalnum = 5;
   else;
      var_ini.critvalnum = 6;
   end;
   graphicsstr = 'Encapsulated PostScript (*.eps)';
   graphicsstr = strvcat(graphicsstr,'Adobe Illustrator (*.ai)');
   graphicsstr = strvcat(graphicsstr,'Bitmap (*.bmp)');
   if iscompiled==0;
      graphicsstr = strvcat(graphicsstr,'JPEG (*.jpg)');
      graphicsstr = strvcat(graphicsstr,'Tagged Image Format (*.tif)');
      graphicsstr = strvcat(graphicsstr,'Portable Network Graphics (*.png)');
      graphicsstr = strvcat(graphicsstr,'Paintbrush 24-bit (*.pcx)');
      graphicsstr = strvcat(graphicsstr,'Portable Bitmap (*.pbm)');
      graphicsstr = strvcat(graphicsstr,'Portable Graymap (*.pgm)');
      graphicsstr = strvcat(graphicsstr,'Portable Pixmap (*.ppm)');
      graphicsstr = strvcat(graphicsstr,'Enhanced metafile (*.emf)');
      fmtchk = [0 0];
   else;
      if isgs==1;
         graphicsstr = strvcat(graphicsstr,'JPEG (*.jpg)');
         graphicsstr = strvcat(graphicsstr,'Tagged Image Format (*.tif)');
         graphicsstr = strvcat(graphicsstr,'Portable Network Graphics (*.png)');
         graphicsstr = strvcat(graphicsstr,'Paintbrush 24-bit (*.pcx)');
         graphicsstr = strvcat(graphicsstr,'Portable Bitmap (*.pbm)');
         graphicsstr = strvcat(graphicsstr,'Portable Graymap (*.pgm)');
         graphicsstr = strvcat(graphicsstr,'Portable Pixmap (*.ppm)');
         fmtchk = [0 1];
         if ispstoedit==1;
            graphicsstr = strvcat(graphicsstr,'Enhanced metafile (*.emf)');
            fmtchk = [0 0];
         end;
      else;
         fmtchk = [1 1];
      end;
   end;
   var_ini.graphicsstr = strvcat(graphicsstr,'MatLab Figure (*.fig)');
   if strcmp(var_ini.graphicsfmt,'eps')==1;
      var_ini.graphicsvalue = 1;
   elseif strcmp(var_ini.graphicsfmt,'ai')==1;
      var_ini.graphicsvalue = 2;
   elseif strcmp(var_ini.graphicsfmt,'bmp')==1;
      var_ini.graphicsvalue = 3;
   elseif strcmp(var_ini.graphicsfmt,'jpg')==1;
      var_ini.graphicsvalue = 4;
   elseif strcmp(var_ini.graphicsfmt,'tif')==1;
      var_ini.graphicsvalue = 5;
   elseif strcmp(var_ini.graphicsfmt,'png')==1;
      var_ini.graphicsvalue = 6;
   elseif strcmp(var_ini.graphicsfmt,'pcx')==1;
      var_ini.graphicsvalue = 7;
   elseif strcmp(var_ini.graphicsfmt,'pbm')==1;
      var_ini.graphicsvalue = 8;
   elseif strcmp(var_ini.graphicsfmt,'pgm')==1;
      var_ini.graphicsvalue = 9;
   elseif strcmp(var_ini.graphicsfmt,'ppm')==1;
      var_ini.graphicsvalue = 10;
   elseif strcmp(var_ini.graphicsfmt,'emf')==1;
      var_ini.graphicsvalue = 11;
   elseif strcmp(var_ini.graphicsfmt,'fig')==1;
      var_ini.graphicsvalue = 12;
   end;
   if sum(fmtchk)>0;
      if var_ini.graphicsvalue>10;
         var_ini.graphicsvalue = 1;
         var_ini.graphicsfmt = 'eps';
      else;
         if fmtchk(1,1)==1;
            var_ini.graphicsvalue = 1;
            var_ini.graphicsfmt = 'eps';
         end;
      end;
   end;
   if var_ini.external==1;
      myext = 'on';
   else;
      myext = 'off';
   end;
   if var_ini.noprint==1;
      noprintenable = 'off';
   else;
      noprintenable = 'on';
   end;
   oldvar_ini = var_ini;
else;
   thisexit = 1;
%   optionsgui = get(0,'CurrentFigure');
   optionsgui = findobj('Type','figure','Tag','Preferences')';
   controls = get(optionsgui,'UserData');
   var_ini = get(controls.cancel,'UserData');
   oldvar_ini = var_ini.oldvar;
end;

%
% Set screen size directly instead of using
% get(0,'ScreenSize')!
%

scrsz = get(0,'ScreenSize');

position = [(scrsz(3)-398)/2 (scrsz(4)-465)/2 398 465];
figname = 'Preferences';

switch selector;
   case 'init';
      optionsgui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','optionsdlg.m', ...
         'MenuBar','none', ...
         'PaperUnits',var_ini.paperunits, ...
         'PaperType',var_ini.papertype, ...
         'PaperPositionMode',var_ini.paperposmode, ...
         'PaperOrientation',orientstr, ...
         'InvertHardcopy',inv_hardcopy, ...
         'Units','pixels', ...
         'Position',position, ...
         'Tag',figname, ...
         'Resize','off', ...
         'Name',figname, ...
         'WindowStyle','modal', ...
         'Visible','off', ...
         'CloseRequestFcn','optionsdlg ok', ...
         'BusyAction','cancel', ...
         'NumberTitle','off', ...
         'ToolBar','none');

      if var_ini.edit_context==1;
         set(optionsgui,'DoubleBuffer','on');
      end;

      if matlabnumber>=7.0;
         set(optionsgui,'DockControl','off');
      end;

      %
      % Setting up the tabbed dialog
      %

      input_var.fldnames = {'tab1' 'tab2' 'tab3' 'tab4' 'tab5' 'middle1' 'middle2' 'middle3' 'middle4' 'middle5' 'upper1' 'upper2' 'upper3' 'upper4' 'upper5'};
      input_var.tags = {'tab1' 'tab2' 'tab3' 'tab4' 'tab5' 'tab6' 'tab7' 'tab8' 'tab9' 'tab10' 'tab11' 'tab12' 'tab13' 'tab14' 'tab15'};
      input_var.strings = {'General' 'Estimation' 'Statistics' 'Viewers' 'Bayesian' 'Graphics' 'Cointegration' 'Recursion' 'Utilities' 'Simulation' 'Forecasting' 'TeX' 'TeX Preamble' 'Output Control' 'Miscellaneous'};
      input_var.visible = {'on' 'on' 'on' 'on' 'on' 'on' 'on' 'on' 'on' 'on' 'on' 'on' 'on' 'on' 'on'};
      input_var.callbackstr = {'optionsdlg tab' 'optionsdlg tab' 'optionsdlg tab' 'optionsdlg tab' 'optionsdlg tab' 'optionsdlg tab' 'optionsdlg tab' 'optionsdlg tab' 'optionsdlg tab' 'optionsdlg tab' 'optionsdlg tab' 'optionsdlg tab' 'optionsdlg tab' 'optionsdlg tab' 'optionsdlg tab'};
      controls = tabbed_dialog([],var_ini,[10 40 378 350],15,input_var);

      controls.current = 'General';

      %
      % Axes on tab dialog General (common with Graphics, Cointegration,
      % Recursion, and Miscellaneous)
      %

      lightvec = [0.9 0.9 0.9];
      darkvec = [0.5 0.5 0.5];
      left = 24;
      bottom = 55;
      width = 350;
      height = 319;
      titlewidth = 50;
      title = 'Properties';

      hvec = axesbox([left bottom width height],title,titlewidth,[0.5 1],'on');
      controls.tab1axes11 = hvec(1,1);
      controls.tab1axes12 = hvec(1,2);
      controls.tab1axes13 = hvec(1,3);
      controls.tab1axes14 = hvec(1,4);
      controls.tab1axes15 = hvec(1,5);
      controls.tab1axes16 = hvec(1,6);
      controls.tab1axes17 = hvec(1,7);
      controls.tab1axes18 = hvec(1,8);
      if matlabnumber>=6.0;
         controls.tab1axes19 = hvec(1,9);
         controls.tab1axes110 = hvec(1,10);
         controls.tab1axes1text = hvec(1,11);
      else;
         controls.tab1axes1text = hvec(1,9);
      end;

      %
      % Axes on tab dialog Estimation
      %

      left = 24;
      bottom = 314;
      width = 350;
      height = 60;
      titlewidth = 50;
      title = 'Lag Order';

      hvec = axesbox([left bottom width height],title,titlewidth,[0.5 1],'off');
      controls.tab2axes11 = hvec(1,1);
      controls.tab2axes12 = hvec(1,2);
      controls.tab2axes13 = hvec(1,3);
      controls.tab2axes14 = hvec(1,4);
      controls.tab2axes15 = hvec(1,5);
      controls.tab2axes16 = hvec(1,6);
      controls.tab2axes17 = hvec(1,7);
      controls.tab2axes18 = hvec(1,8);
      if matlabnumber>=6.0;
         controls.tab2axes19 = hvec(1,9);
         controls.tab2axes110 = hvec(1,10);
         controls.tab2axes1text = hvec(1,11);
      else;
         controls.tab2axes1text = hvec(1,9);
      end;

      %
      % next axes box
      %

      left = 24;
      bottom = 200;
      width = 350;
      height = 100;
      titlewidth = 46;
      title = 'Iterations';

      hvec = axesbox([left bottom width height],title,titlewidth,[0.5 1],'off');
      controls.tab2axes21 = hvec(1,1);
      controls.tab2axes22 = hvec(1,2);
      controls.tab2axes23 = hvec(1,3);
      controls.tab2axes24 = hvec(1,4);
      controls.tab2axes25 = hvec(1,5);
      controls.tab2axes26 = hvec(1,6);
      controls.tab2axes27 = hvec(1,7);
      controls.tab2axes28 = hvec(1,8);
      if matlabnumber>=6.0;
         controls.tab2axes29 = hvec(1,9);
         controls.tab2axes210 = hvec(1,10);
         controls.tab2axes2text = hvec(1,11);
      else;
         controls.tab2axes2text = hvec(1,9);
      end;

      %
      % next axesbox
      %

      left = 24;
      bottom = 55;
      width = 350;
      height = 130;
      titlewidth = 38;
      title = 'Method';

      hvec = axesbox([left bottom width height],title,titlewidth,[0.5 1],'off');
      controls.tab2axes31 = hvec(1,1);
      controls.tab2axes32 = hvec(1,2);
      controls.tab2axes33 = hvec(1,3);
      controls.tab2axes34 = hvec(1,4);
      controls.tab2axes35 = hvec(1,5);
      controls.tab2axes36 = hvec(1,6);
      controls.tab2axes37 = hvec(1,7);
      controls.tab2axes38 = hvec(1,8);
      if matlabnumber>=6.0;
         controls.tab2axes39 = hvec(1,9);
         controls.tab2axes310 = hvec(1,10);
         controls.tab2axes3text = hvec(1,11);
      else;
         controls.tab2axes3text = hvec(1,9);
      end;

      %
      % Axes on tab dialog Statistics
      %

      left = 24;
      bottom = 55;
      width = 350;
      height = 319;
      titlewidth = 50;
      title = 'Properties';

      hvec = axesbox([left bottom width height],title,titlewidth,[0.5 1],'off');
      controls.tab3axes11 = hvec(1,1);
      controls.tab3axes12 = hvec(1,2);
      controls.tab3axes13 = hvec(1,3);
      controls.tab3axes14 = hvec(1,4);
      controls.tab3axes15 = hvec(1,5);
      controls.tab3axes16 = hvec(1,6);
      controls.tab3axes17 = hvec(1,7);
      controls.tab3axes18 = hvec(1,8);
      if matlabnumber>=6.0;
         controls.tab3axes19 = hvec(1,9);
         controls.tab3axes110 = hvec(1,10);
         controls.tab3axes1text = hvec(1,11);
      else;
         controls.tab3axes1text = hvec(1,9);
      end;

      %
      % Axes on tab dialog Viewers
      %

      left = 24;
      bottom = 190;
      width = 350;
      height = 184;
      titlewidth = 85;
      title = 'Graphics Viewers';

      hvec = axesbox([left bottom width height],title,titlewidth,[0.5 1],'off');
      controls.tab4axes11 = hvec(1,1);
      controls.tab4axes12 = hvec(1,2);
      controls.tab4axes13 = hvec(1,3);
      controls.tab4axes14 = hvec(1,4);
      controls.tab4axes15 = hvec(1,5);
      controls.tab4axes16 = hvec(1,6);
      controls.tab4axes17 = hvec(1,7);
      controls.tab4axes18 = hvec(1,8);
      if matlabnumber>=6.0;
         controls.tab4axes19 = hvec(1,9);
         controls.tab4axes110 = hvec(1,10);
         controls.tab4axes1text = hvec(1,11);
      else;
         controls.tab4axes1text = hvec(1,9);
      end;

      left = 24;
      bottom = 55;
      width = 350;
      height = 120;
      titlewidth = 88;
      title = 'Other applications';

      hvec = axesbox([left bottom width height],title,titlewidth,[0.5 1],'off');
      controls.tab4axes21 = hvec(1,1);
      controls.tab4axes22 = hvec(1,2);
      controls.tab4axes23 = hvec(1,3);
      controls.tab4axes24 = hvec(1,4);
      controls.tab4axes25 = hvec(1,5);
      controls.tab4axes26 = hvec(1,6);
      controls.tab4axes27 = hvec(1,7);
      controls.tab4axes28 = hvec(1,8);
      if matlabnumber>=6.0;
         controls.tab4axes29 = hvec(1,9);
         controls.tab4axes210 = hvec(1,10);
         controls.tab4axes2text = hvec(1,11);
      else;
         controls.tab4axes2text = hvec(1,9);
      end;

      %
      % Axes on tab dialog Bayesian
      %
      
      controls.bayes_prior = axesbox([24 200 350 174],'Prior Distributions',85,[0.5 1],'off');
      
      controls.bayes_mcmc = axesbox([24 55 350 130],'MCMC Sampler',75,[0.5 1],'off');

      %
      % Axes on tab dialog Utilities
      %

      left = 24;
      bottom = 55;
      width = 350;
      height = 319;
      titlewidth = 60;
      title = 'Applications';

      hvec = axesbox([left bottom width height],title,titlewidth,[0.5 1],'off');
      controls.tab9axes11 = hvec(1,1);
      controls.tab9axes12 = hvec(1,2);
      controls.tab9axes13 = hvec(1,3);
      controls.tab9axes14 = hvec(1,4);
      controls.tab9axes15 = hvec(1,5);
      controls.tab9axes16 = hvec(1,6);
      controls.tab9axes17 = hvec(1,7);
      controls.tab9axes18 = hvec(1,8);
      if matlabnumber>=6.0;
         controls.tab9axes19 = hvec(1,9);
         controls.tab9axes110 = hvec(1,10);
         controls.tab9axes1text = hvec(1,11);
      else;
         controls.tab9axes1text = hvec(1,9);
      end;

      %
      % Axes on tab dialog Miscellaneous
      %


      %
      % Controls on tab dialog General
      %

      if iscompiled==0;
         controls.openvar = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[40 340 250 20], ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Style','checkbox', ...
            'Value',var_ini.openvar, ...
            'Enable','on', ...
            'Visible','on', ...
            'Callback','optionsdlg openvar', ...
            'HorizontalAlignment','left', ...
            'String','Close Matlab when exiting ''Structural VAR''', ...
            'Tag','CheckOpenVar');
      else;
         controls.openvar = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[40 340 250 20], ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Style','checkbox', ...
            'Value',var_ini.openvar, ...
            'Enable','on', ...
            'Visible','on', ...
            'Callback','optionsdlg openvar', ...
            'HorizontalAlignment','left', ...
            'String','Don''t show a splash screen', ...
            'Tag','CheckOpenVar');
      end;

      controls.dirstructure = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 320 300 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.dirstructure, ...
         'Enable','on', ...
         'Visible','on', ...
         'Callback','optionsdlg dirstructure', ...
         'HorizontalAlignment','left', ...
         'String','Disable Structural VAR''s default directory structure', ...
         'Tag','CheckDirStructure');

      controls.geometry = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 300 300 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.geometryvalue, ...
         'Enable','on', ...
         'Visible','on', ...
         'Callback','optionsdlg geometry', ...
         'HorizontalAlignment','left', ...
         'String',['Remember position of main program window (l,b=' num2str(var_ini.position(1,1)) ',' num2str(var_ini.position(1,2)) ')'], ...
         'Tag','CheckGeometry');

      controls.uselastfile = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 280 300 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.uselastfile, ...
         'Enable','on', ...
         'Visible','on', ...
         'Callback','optionsdlg uselastfile', ...
         'HorizontalAlignment','left', ...
         'String','Open ''Structural VAR'' with the latest opened model', ...
         'Tag','CheckUseLastFile');

      controls.startrun = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 260 300 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.startrun, ...
         'Enable',startrunenable, ...
         'Visible','on', ...
         'Callback','optionsdlg startrun', ...
         'HorizontalAlignment','left', ...
         'String','Estimate opened model on start-up', ...
         'Tag','CheckStartRun');

      controls.logtab = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 240 300 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.logtab, ...
         'Enable','on', ...
         'Visible','on', ...
         'Callback','optionsdlg logtab', ...
         'HorizontalAlignment','left', ...
         'String','Show output tab when starting estimation', ...
         'Tag','CheckLogTab');

      controls.clearlog = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 220 300 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.clearlog, ...
         'Enable','on', ...
         'Visible','on', ...
         'Callback','optionsdlg clearlog', ...
         'HorizontalAlignment','left', ...
         'String','Don''t clear estimation log', ...
         'Tag','ClearLogTab');

      controls.sillyq = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 200 300 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.sillyq, ...
         'Enable','on', ...
         'Visible','on', ...
         'Callback','optionsdlg sillyq', ...
         'HorizontalAlignment','left', ...
         'String','Don''t ask ''silly questions''', ...
         'Tag','CheckSillyQuestions');

      controls.editcontext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 180 300 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.edit_context, ...
         'Enable','on', ...
         'Visible','on', ...
         'Callback','optionsdlg editcontext', ...
         'HorizontalAlignment','left', ...
         'String','Add context menu to file and directory edit controls', ...
         'Tag','CheckEditContext');

      controls.toolbar_bgcolor = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 160 300 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.use_toolbar_bgcolor, ...
         'Enable','on', ...
         'Visible','on', ...
         'Callback','optionsdlg toolbar_bgcolor', ...
         'HorizontalAlignment','left', ...
         'String','Fix image background color', ...
         'Tag','CheckToolbarBGColor');

      controls.gui_font = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 140 300 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.gui_font, ...
         'Enable','on', ...
         'Visible','on', ...
         'Callback','optionsdlg gui_font', ...
         'HorizontalAlignment','left', ...
         'String','Use system fonts for GUI and text controls', ...
         'Tag','CheckGUIFont');










      controls.gui_colors = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 95 102.667 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','on', ...
         'Callback','optionsdlg guicolors', ...
         'HorizontalAlignment','center', ...
         'String','GUI Colors...', ...
         'Tag','GUIColorsButton');

      controls.text_colors = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[147.667 95 102.667 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','on', ...
         'Callback','optionsdlg textcolors', ...
         'HorizontalAlignment','center', ...
         'String','Text Colors...', ...
         'Tag','TextColorsButton');

      controls.frame_colors = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[255.333 95 102.667 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','on', ...
         'Callback','optionsdlg framecolors', ...
         'HorizontalAlignment','center', ...
         'String','Frame Colors...', ...
         'Tag','FrameColorsButton');

      controls.gui_fontbutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 70 102.667 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','on', ...
         'Callback','optionsdlg gui_fontbutton', ...
         'HorizontalAlignment','center', ...
         'String','GUI Font...', ...
         'Tag','GUIFontButton');

      controls.fonttext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[147.667 70 102.667 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','on', ...
         'Callback','optionsdlg fonttext', ...
         'HorizontalAlignment','center', ...
         'String','Text Font...', ...
         'Tag','TextFontButton');

      if var_ini.gui_font==1;
         set(controls.gui_fontbutton,'Enable','off');
         set(controls.fonttext,'Enable','off');
      else;
         set(controls.gui_fontbutton,'Enable','on');
         set(controls.fonttext,'Enable','on');
      end;

      controls.default_colors = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[255.333 70 102.667 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','on', ...
         'Callback','optionsdlg defaultcolors', ...
         'HorizontalAlignment','center', ...
         'String','Default Colors', ...
         'Tag','DefaultColorsButton');

      %
      % Controls on tab dialog Estimation
      %

      controls.maxlagtext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 330 230 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Maximum Number of Lags for Lag Order Control:', ...
         'Tag','MaxLagText');

      controls.maxlag = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[285 335 70 20], ...
         'Style','edit', ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','optionsdlg maxlag', ...
         'String',num2str(var_ini.maxlag), ...
         'Tag','MaxLagEdit');

      controls.maxittext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 255 230 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Maximum Number of Iterations for Estimators:', ...
         'Tag','MaxitText');

      controls.maxit = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[285 260 70 20], ...
         'Style','popupmenu', ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'Value',maxitv, ...
         'Callback','optionsdlg maxit', ...
         'String',var_ini.maxitstring, ...
         'Tag','MaxitPopup');

      controls.convcrittext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 215 200 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Value for Convergence Criterion:', ...
         'Tag','ConvcritText');

      controls.convcrit = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[285 220 70 20], ...
         'Style','popupmenu', ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'Value',var_ini.convcrit, ...
         'Callback','optionsdlg convcrit', ...
         'String','1.0e-001|1.0e-002|1.0e-003|1.0e-004|1.0e-005|1.0e-006|1.0e-007|1.0e-008|1.0e-009|1.0e-010', ...
         'Tag','MaxitPopup');

      controls.method1 = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 150 330 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','radiobutton', ...
         'Value',var_ini.method(1,1), ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg method', ...
         'Max',1, ...
         'HorizontalAlignment','left', ...
         'String',method1str, ...
         'Tag','MethodRadio1');

      controls.method2 = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 130 330 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','radiobutton', ...
         'Value',var_ini.method(1,2), ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg method', ...
         'Max',1, ...
         'HorizontalAlignment','left', ...
         'String',method2str, ...
         'Tag','MethodRadio2');

      controls.method3 = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 110 330 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','radiobutton', ...
         'Value',var_ini.method(1,3), ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg method', ...
         'Max',1, ...
         'HorizontalAlignment','left', ...
         'String','Bayesian MCMC with Gaussian residuals', ...
         'Tag','MethodRadio3');

      controls.identifytext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 70 100 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Default identification:', ...
         'Tag','IdentifyText');

      controls.identify = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[150 75 205 20], ...
         'Style','popupmenu', ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'Value',var_ini.identify, ...
         'Callback','optionsdlg identify', ...
         'String','Contemporaneous|Long-run|Contemporaneous & long-run', ...
         'Tag','identifyPopup');

      %
      % Controls on tab dialog Statistics
      %

      controls.sscorrect = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 340 300 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.sscorrect, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg sscorrect', ...
         'HorizontalAlignment','left', ...
         'String','Apply F-type ''small-sample correction'' to chi-square tests', ...
         'Tag','CheckCorrection');

      controls.bartserial = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 320 300 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.bartserial, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg bartserial', ...
         'HorizontalAlignment','left', ...
         'String','''Bartlett correct'' lag order tests', ...
         'Tag','Portmanteau');

      controls.portmanteau = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 300 300 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.portmanteau, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg portmanteau', ...
         'HorizontalAlignment','left', ...
         'String','Compute Ljung-Box type Portmanteau statistic', ...
         'Tag','Portmanteau');

      controls.lbcorrect = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 280 300 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.lbcorrect, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg lbcorrect', ...
         'HorizontalAlignment','left', ...
         'String','Correct Ljung-Box type Portmanteau statistic', ...
         'Tag','CorrectPortmanteau');

      controls.omnibus = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 260 320 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.omnibus, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg omnibus', ...
         'HorizontalAlignment','left', ...
         'String','Compute Shenton-Bowman/Doornik-Hansen normality statistic', ...
         'Tag','Omnibus');

      controls.akaike = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 240 320 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.akaike, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg akaike', ...
         'HorizontalAlignment','left', ...
         'String','Compute Information Criteria', ...
         'Tag','InfoCriteria');

      controls.restat = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 220 320 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.restat, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg restat', ...
         'HorizontalAlignment','left', ...
         'String','Compute residual statistics', ...
         'Tag','ResidStats');

      controls.dummytests = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 200 320 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.dummytests, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg dummytests', ...
         'HorizontalAlignment','left', ...
         'String','Compute tests for additional deterministic variables', ...
         'Tag','DummyTests');

      controls.rest_march = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 180 320 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.rest_march, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg rest_march', ...
         'HorizontalAlignment','left', ...
         'String','Use restricted multivariate ARCH model for ARCH test', ...
         'Tag','RestrictedMARCHTests');

      controls.ms_maxlagtext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 130 230 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Maximum lag order for Model Selection:', ...
         'Tag','MSMaxLagText');

      controls.ms_maxlag = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[245 135 110 20], ...
         'Style','edit', ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','optionsdlg ms_maxlag', ...
         'String',num2str(var_ini.ms_maxlag,'%0.0f'), ...
         'Tag','MSMaxLagEdit');

      controls.noise_parmtxt = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 100 230 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Noise parameter for certain Wald tests:', ...
         'Tag','NoiseParmText');

      controls.noise_parm = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[245 105 110 20], ...
         'Style','edit', ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','optionsdlg noise_parm', ...
         'String',num2str(var_ini.noise_parm,'%0.8f'), ...
         'Tag','NoiseParameterEdit');

      controls.lagtesttext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 70 230 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Maximum lag order test horizon:', ...
         'Tag','LagTestText');

      controls.lagtest = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[245 75 110 20], ...
         'Style','popupmenu', ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'Value',var_ini.lagtest+1, ...
         'Callback','optionsdlg lagtest', ...
         'String','No lag order test|+/-1 lag|+/-2 lags|+/-3 lags|+/-4 lags|+/-5 lags|+/-6 lags|+/-7 lags|+/-8 lags|+/-9 lags|+/-10 lags', ...
         'Tag','LagTestPopup');

      %
      % Controls on tab dialog External
      %

      controls.aiviewertext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 330+add_edit_context 230 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Adobe Illustrator viewer:', ...
         'Tag','AiViewerText');

      if var_ini.edit_context==0;
         controls.aivieweredit = uicontrol('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[40 310 260 22], ...
            'Style','edit', ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'String',var_ini.aiviewer, ...
            'Callback','optionsdlg checkaiviewer', ...
            'Tag','AiViewerEdit');
      else;
         controls.aivieweredit = editbox('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[40 310 260 22], ...
            'FontName',get(controls.aiviewertext,'FontName'), ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'String',var_ini.aiviewer, ...
            'Callback','optionsdlg checkaiviewer', ...
            'Tag','AiViewerEdit');
      end;

      controls.aiviewerbutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[305 310 50 22], ...
         'TooltipString','Browse', ...
         'CData',var_ini.images.browse, ...
         'Visible','off', ...
         'Enable','on', ...
         'Callback','optionsdlg aiviewer', ...
         'Tag','AiViewerButton');

      controls.epsviewertext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 280+add_edit_context 230 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Encapsulated PostScript viewer:', ...
         'Tag','EpsViewerText');

      if var_ini.edit_context==0;
         controls.epsvieweredit = uicontrol('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[40 260 260 22], ...
            'Style','edit', ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'String',var_ini.epsviewer, ...
            'Callback','optionsdlg checkepsviewer', ...
            'Tag','EpsViewerEdit');
      else;
         controls.epsvieweredit = editbox('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[40 260 260 22], ...
            'FontName',get(controls.epsviewertext,'FontName'), ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'String',var_ini.epsviewer, ...
            'Callback','optionsdlg checkepsviewer', ...
            'Tag','EpsViewerEdit');
      end;

      controls.epsviewerbutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[305 260 50 22], ...
         'TooltipString','Browse', ...
         'CData',var_ini.images.browse, ...
         'Visible','off', ...
         'Enable','on', ...
         'Callback','optionsdlg epsviewer', ...
         'Tag','EpsViewerButton');

      controls.bitmapviewertext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 230+add_edit_context 270 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Other viewer (bmp, emf, png, jpg, tif, pcx etc. but not fig):', ...
         'Tag','BitmapViewerText');

      if var_ini.edit_context==0;
         controls.bitmapvieweredit = uicontrol('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[40 210 260 22], ...
            'Style','edit', ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'String',var_ini.bitmapviewer, ...
            'Callback','optionsdlg checkbitmapviewer', ...
            'Tag','BitmapViewerEdit');
      else;
         controls.bitmapvieweredit = editbox('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[40 210 260 22], ...
            'FontName',get(controls.bitmapviewertext,'FontName'), ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'String',var_ini.bitmapviewer, ...
            'Callback','optionsdlg checkbitmapviewer', ...
            'Tag','BitmapViewerEdit');
      end;

      controls.bitmapviewerbutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[305 210 50 22], ...
         'TooltipString','Browse', ...
         'CData',var_ini.images.browse, ...
         'Visible','off', ...
         'Enable','on', ...
         'Callback','optionsdlg bitmapviewer', ...
         'Tag','BitmapViewerButton');

      controls.editortext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 145+add_edit_context 270 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Editor:', ...
         'Tag','EditorText');

      if var_ini.edit_context==0;
         controls.editoredit = uicontrol('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[40 125 260 22], ...
            'Style','edit', ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'String',var_ini.editor, ...
            'Callback','optionsdlg checkeditor', ...
            'Tag','EditorEdit');
      else;
         controls.editoredit = editbox('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[40 125 260 22], ...
            'FontName',get(controls.editortext,'FontName'), ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'String',var_ini.editor, ...
            'Callback','optionsdlg checkeditor', ...
            'Tag','EditorEdit');
      end;

      controls.editorbutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[305 125 50 22], ...
         'TooltipString','Browse', ...
         'CData',var_ini.images.browse, ...
         'Visible','off', ...
         'Enable','on', ...
         'Callback','optionsdlg editor', ...
         'Tag','EditorButton');

      controls.helpexetext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 95+add_edit_context 270 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Help File Launcher:', ...
         'Tag','HelpExeText');

      if ispc==1;
         controls.helpexeedit = uicontrol('Units','pixels', ...
               'BackgroundColor',[1 1 1], ...
               'Position',[40 75 315 22], ...
               'Style','popup', ...
               'FontSize',var_ini.gui_fontsize, ...
               'FontName',var_ini.gui_fontname, ...
               'FontWeight',var_ini.gui_fontweight, ...
               'FontAngle',var_ini.gui_fontangle, ...
               'Visible','off', ...
               'HorizontalAlignment','left', ...
               'Value',1, ...
               'String','Help Format (winhlp32.exe)|HTML Help Format (hh.exe)|HTML Format (default browser)', ...
               'Callback','optionsdlg winhelpexe', ...
               'Tag','HelpExeEdit');

         if strcmp(lower(getfilename(var_ini.helpexe)),'winhlp32.exe')==1;
            set(controls.helpexeedit,'Value',1);
         elseif strcmp(lower(getfilename(var_ini.helpexe)),'hh.exe')==1;
            set(controls.helpexeedit,'Value',2);
         else;
            set(controls.helpexeedit,'Value',3);
         end;

      else;

         if var_ini.edit_context==0;
            controls.helpexeedit = uicontrol('Units','pixels', ...
               'BackgroundColor',[1 1 1], ...
               'Position',[40 75 260 22], ...
               'Style','edit', ...
               'FontSize',var_ini.gui_fontsize, ...
               'FontName',var_ini.gui_fontname, ...
               'FontWeight',var_ini.gui_fontweight, ...
               'FontAngle',var_ini.gui_fontangle, ...
               'Visible','off', ...
               'HorizontalAlignment','left', ...
               'String',var_ini.helpexe, ...
               'Callback','optionsdlg checkhelpexe', ...
               'Tag','HelpExeEdit');
         else;
            controls.helpexeedit = editbox('Units','pixels', ...
               'BackgroundColor',[1 1 1], ...
               'Position',[40 75 260 22], ...
               'FontName',get(controls.helpexetext,'FontName'), ...
               'FontSize',var_ini.gui_fontsize, ...
               'FontName',var_ini.gui_fontname, ...
               'FontWeight',var_ini.gui_fontweight, ...
               'FontAngle',var_ini.gui_fontangle, ...
               'Visible','off', ...
               'HorizontalAlignment','left', ...
               'String',var_ini.helpexe, ...
               'Callback','optionsdlg checkhelpexe', ...
               'Tag','HelpExeEdit');
         end;

         controls.helpexebutton = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[305 75 50 22], ...
            'TooltipString','Browse', ...
            'CData',var_ini.images.browse, ...
            'Visible','off', ...
            'Enable','on', ...
            'Callback','optionsdlg helpexe', ...
            'Tag','HelpExeButton');

      end;

      %
      % Controls on tab dialog Bayesian
      %

      controls.lambda_paramtext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 325 100 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Short-run dynamics:', ...
         'Tag','LambdaParamText');

      controls.lambda_inf_shortrun = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[145 325 100 25], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','popupmenu', ...
         'Visible','off', ...
         'Value',var_ini.prior_inf_shortrun, ...
         'Callback','optionsdlg lambda_inf_shortrun', ...
         'HorizontalAlignment','left', ...
         'String','Informative|Non-informative', ...
         'Tag','LambdaParamPopup');

      controls.lambda_param = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[255 330 100 25], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','optionsdlg lambda_param', ...
         'String','Hyperparameters...', ...
         'Tag','LambdaParamButton');

      if var_ini.prior_inf_shortrun==1;
         set(controls.lambda_param,'Enable','on');
      else;
         set(controls.lambda_param,'Enable','off');
      end;

      controls.lambda_dtext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 295 120 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Deterministics:', ...
         'Tag','LambdaDeterText');

      controls.lambda_inf_deter = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[145 295 100 25], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','popupmenu', ...
         'Visible','off', ...
         'Value',var_ini.prior_inf_deter, ...
         'Callback','optionsdlg lambda_inf_deter', ...
         'HorizontalAlignment','left', ...
         'String','Informative|Non-informative', ...
         'Tag','LambdaDeterPopup');

      controls.lambda_d = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[255 300 100 25], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','optionsdlg lambda_deter', ...
         'String','Hyperparameters...', ...
         'Tag','LambdaDeterButton');

      if var_ini.prior_inf_deter==1;
         set(controls.lambda_d,'Enable','on');
      else;
         set(controls.lambda_d,'Enable','off');
      end;

      controls.lambda_alphatext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 265 120 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Alpha:', ...
         'Tag','LambdaAlphaText');

      controls.lambda_inf_alpha = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[145 265 100 25], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','popupmenu', ...
         'Visible','off', ...
         'Value',var_ini.prior_inf_alpha, ...
         'Callback','optionsdlg lambda_inf_alpha', ...
         'HorizontalAlignment','left', ...
         'String','Informative|Non-informative', ...
         'Tag','LambdaAlphaPopup');

      controls.lambda_alpha = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[255 270 100 25], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','optionsdlg lambda_alpha', ...
         'String','Hyperparameter...', ...
         'Tag','LambdaAlphaButton');

      if var_ini.prior_inf_alpha==1;
         set(controls.lambda_alpha,'Enable','on');
      else;
         set(controls.lambda_alpha,'Enable','off');
      end;
      
      controls.lambda_omegatext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 235 120 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Omega:', ...
         'Tag','LambdaOmegaText');

      controls.lambda_inf_omega = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[145 235 100 25], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','popupmenu', ...
         'Visible','off', ...
         'Value',var_ini.prior_inf_omega, ...
         'Callback','optionsdlg lambda_inf_omega', ...
         'HorizontalAlignment','left', ...
         'String','Informative|Non-informative', ...
         'Tag','LambdaOmegaPopup');

      controls.lambda_omega = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[255 240 100 25], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','optionsdlg lambda_omega', ...
         'String','Hyperparameters...', ...
         'Tag','LambdaOmegaButton');
      
      if var_ini.prior_inf_omega==1;
         set(controls.lambda_omega,'Enable','on');
      else;
         set(controls.lambda_omega,'Enable','off');
      end;

      controls.burn_intext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 140 230 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Number of burn-in draws:', ...
         'Tag','BurnInDrawsText');

      controls.burn_in = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[245 145 110 20], ...
         'Style','popupmenu', ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'Value',1, ...
         'Callback','optionsdlg burn_in', ...
         'String','0|100|200|300|400|500|600|700|800|900|1,000|1,500|2,000|2,500|3,000|3,500|4,000|4,500|5,000|6,000|7,000|8,000|9,000|10,000|15,000|20,000|25,000|30,000|35,000|40,000|45,000|50,000', ...
         'Tag','BurnInDrawsPopup');

      b_str = get(controls.burn_in,'String');
      for i=1:size(b_str,1);
         bs_val = mystr2num(strtrim(strrep(b_str(i,:),',','')));
         if bs_val==var_ini.burn_in;
            b_val = i;
            break;
         end;
      end;

      set(controls.burn_in,'Value',b_val);

      controls.save_drawstext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 115 230 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Number of draws to save:', ...
         'Tag','SaveDrawsText');

      controls.save_draws = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[245 120 110 20], ...
         'Style','popupmenu', ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'Value',1, ...
         'Callback','optionsdlg save_draws', ...
         'String','100|200|300|400|500|600|700|800|900|1,000|1,500|2,000|2,500|3,000|3,500|4,000|4,500|5,000|6,000|7,000|8,000|9,000|10,000|15,000|20,000|25,000|30,000|35,000|40,000|45,000|50,000|60,000|70,000|80,000|90,000|100,000|200,000|300,000|400,000|500,000', ...
         'Tag','SaveDrawsPopup');

      s_str = get(controls.save_draws,'String');
      for i=1:size(s_str,1);
         ss_val = mystr2num(strtrim(strrep(s_str(i,:),',','')));
         if ss_val==var_ini.save_draws;
            s_val = i;
            break;
         end;
      end;
      set(controls.save_draws,'Value',s_val);

      controls.save_freqtext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 90 230 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Draw saving frequency:', ...
         'Tag','SaveFreqText');

      controls.save_freq = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[245 95 110 20], ...
         'Style','popupmenu', ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'Value',var_ini.save_freq, ...
         'Callback','optionsdlg save_freq', ...
         'String','1 in 1 (100%)|1 in 2 (50%)| 1 in 3 (33%)|1 in 4 (25%)|1 in 5 (20%)|1 in 6 (16.7%)|1 in 7 (14.3%)|1 in 8 (12.5%)|1 in 9 (11.1%)|1 in 10 (10%))|1 in 11 (9.1%)|1 in 12 (8.3%)|1 in 13 (7.7%)|1 in 14 (7.1%)|1 in 15 (6.7%)|1 in 16 (6.2%)|1 in 17 (5.9%)|1 in 18 (5.6%)|1 in 19 (5.3%)|1 in 20 (5%)', ...
         'Tag','SaveFreqPopup');

      controls.discard_explosive = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 70 230 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.discard_explosive, ...
         'Visible','off', ...
         'Callback','optionsdlg discard_explosive', ...
         'HorizontalAlignment','left', ...
         'String','Discard explosive processes', ...
         'Tag','DiscardExplosiveCheck');

      controls.bad_draws = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[245 70 110 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.bad_draws, ...
         'Visible','off', ...
         'Callback','optionsdlg bad_draws', ...
         'HorizontalAlignment','left', ...
         'String','Skip bad draws', ...
         'Tag','SkipBadDrawsCheck');

      %
      % Controls on tab dialog Graphics
      %

      controls.external = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 340 300 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.external, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg external', ...
         'HorizontalAlignment','left', ...
         'String','Use external graphics viewers + save graphics', ...
         'Tag','CheckExternal');

      controls.xgrid = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 320 300 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.xgrid, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg xgrid', ...
         'HorizontalAlignment','left', ...
         'String','Display vertical grid lines in graphs (perpendicular to X axis)', ...
         'Tag','CheckXGrid');

      controls.ygrid = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 300 310 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.ygrid, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg ygrid', ...
         'HorizontalAlignment','left', ...
         'String','Display horizontal grid lines in graphs (perpendicular to Y axis)', ...
         'Tag','CheckYGrid');

      controls.zgrid = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 280 300 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.zgrid, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg zgrid', ...
         'HorizontalAlignment','left', ...
         'String','Display depth grid lines in graphs (perpendicular to Z axis)', ...
         'Tag','CheckZGrid');

      controls.box = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 260 300 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.box, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg box', ...
         'HorizontalAlignment','left', ...
         'String','Toggle axes plot box on in graphs', ...
         'Tag','CheckBox');

      controls.colors = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 240 300 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.colors, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg colors', ...
         'HorizontalAlignment','left', ...
         'String','Use colors in graphs', ...
         'Tag','CheckColors');

      controls.zbuffer = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 220 300 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.z_buffer, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg zbuffer', ...
         'HorizontalAlignment','left', ...
         'String','Use ''zbuffer'' as default graph renderer', ...
         'Tag','CheckZBuffer');

      controls.ytick = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 200 300 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.ytick, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg ytick', ...
         'HorizontalAlignment','left', ...
         'String','Fix labels on Y axis to match data units', ...
         'Tag','CheckYTick');

      controls.xtick = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 180 300 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.xtick, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg xtick', ...
         'HorizontalAlignment','left', ...
         'String','Fix labels on X axis to match data units', ...
         'Tag','CheckXTick');

      controls.pagesetup = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 150 102.667 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Enable','on', ...
         'Visible','off', ...
         'HorizontalAlignment','center', ...
         'Callback','optionsdlg pagesetup', ...
         'String','Page Setup...', ...
         'Tag','PageSetypButton');

      controls.graphicsfmttext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 120 230 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Enable',myext, ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Default graphics format:', ...
         'Tag','GraphicsFmtText');

      controls.graphicsfmt = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[165 125 193 20], ...
         'Style','popupmenu', ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'Enable',myext, ...
         'Value',var_ini.graphicsvalue, ...
         'Callback','optionsdlg graphicsfmt', ...
         'String',var_ini.graphicsstr, ...
         'Tag','GraphicsFmtPopup');

      controls.axesfont = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 95 102.667 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'Callback','optionsdlg axesfont', ...
         'HorizontalAlignment','center', ...
         'String','Axes Font...', ...
         'Tag','AxesFontButton');

      controls.titlefont = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[147.667 95 102.667 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'Callback','optionsdlg titlefont', ...
         'HorizontalAlignment','center', ...
         'String','Title Font...', ...
         'Tag','TitleFontButton');

      controls.labelfont = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[255.333 95 102.667 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'Callback','optionsdlg labelfont', ...
         'HorizontalAlignment','center', ...
         'String','Label Font...', ...
         'Tag','LabelFontButton');

      controls.axescolor = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 70 102.667 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'Callback','optionsdlg axescolor', ...
         'HorizontalAlignment','center', ...
         'String','Axes Color...', ...
         'Tag','AxesColorButton');

      controls.titlecolor = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[147.667 70 102.667 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'Callback','optionsdlg titlecolor', ...
         'HorizontalAlignment','center', ...
         'String','Title Color...', ...
         'Tag','TitleColorButton');

      controls.labelcolor = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[255.333 70 102.667 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'Callback','optionsdlg labelcolor', ...
         'HorizontalAlignment','center', ...
         'String','Label Color...', ...
         'Tag','LabelColorButton');

      %
      % Controls on tab dialog Cointegration
      %

      controls.tracebart = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 340 250 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.tracebart, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg tracebart', ...
         'HorizontalAlignment','left', ...
         'String','Enable Bartlett correction of trace test', ...
         'Tag','TraceBartlett');

      controls.betagrad = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 320 250 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.betagrad, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg betagrad', ...
         'HorizontalAlignment','left', ...
         'String','Use gradient for restricted beta convergence', ...
         'Tag','BetaGradient');

      controls.rahbek = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 300 320 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.rahbek, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg rahbek', ...
         'HorizontalAlignment','left', ...
         'String','Use Rahbek-Mosconi fix to trace test (exogenous I(0) variables)', ...
         'Tag','RahbekMosconi');

      controls.reestbeta = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 280 330 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.reestbeta, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg reestbeta', ...
         'HorizontalAlignment','left', ...
         'String','Re-estimate beta when estimating alpha, C or B under restrictions', ...
         'Tag','ReEstimateBeta');

      controls.normbeta = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 260 330 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.normbeta, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg normbeta', ...
         'HorizontalAlignment','left', ...
         'String','Normalize unrestricted beta', ...
         'Tag','NormalizeBeta');

      controls.decompose_det = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 240 330 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.decompose_det, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg decompose_det', ...
         'HorizontalAlignment','left', ...
         'String','Decompose estimated unrestricted constant and trend parameter', ...
         'Tag','DecomposeDeterministics');

      controls.weakexo = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 220 320 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.weakexo, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg weakexo', ...
         'HorizontalAlignment','left', ...
         'String','Write weak exogeneity tests to output file', ...
         'Tag','WeakExogeneity');

      controls.commoncycles = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 200 320 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.commoncycles, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg commoncycles', ...
         'HorizontalAlignment','left', ...
         'String','Write common cycle tests to output file', ...
         'Tag','CommonCycles');

      controls.excludestat = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 180 320 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.excludestat, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg excludestat', ...
         'HorizontalAlignment','left', ...
         'String','Write cointegration exclusion and stationarity tests to output file', ...
         'Tag','ExclusionStationarity');

      controls.critvaltext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 70 230 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Trace test critical value or p-value:', ...
         'Tag','CritValText');

      controls.critval = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[245 75 110 20], ...
         'Style','popupmenu', ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'Value',var_ini.critvalnum, ...
         'Callback','optionsdlg critval', ...
         'String',var_ini.critvalstr, ...
         'Tag','CritValPopup');

      %
      % Controls on tab dialog Recursion
      %

      controls.transeig = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 340 320 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.transeig, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg transeig', ...
         'HorizontalAlignment','left', ...
         'String','Use transformed non-zero eigenvalue [ln(eig/(1-eig))]', ...
         'Tag','TransEig');

      controls.fluctest = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 320 320 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.fluctest, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg fluctest', ...
         'HorizontalAlignment','left', ...
         'String','Compute Hansen-Johansen fluctuation test', ...
         'Tag','FlucTest');

      controls.nyblom = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 300 320 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.nyblom, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg nyblom', ...
         'HorizontalAlignment','left', ...
         'String','Compute Nyblom tests for beta', ...
         'Tag','NyblomTest');

      controls.nyblombeta = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 280 320 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.nyblombeta, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg nyblombeta', ...
         'HorizontalAlignment','left', ...
         'String','Compute Nyblom tests for beta under beta restrictions', ...
         'Tag','NyblomBetaTest');

      controls.taylor_nyblom = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 260 320 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.taylor_nyblom, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg taylor_nyblom', ...
         'HorizontalAlignment','left', ...
         'String','Use Hansen-Johansen Taylor expansion of Nyblom test', ...
         'Tag','TaylorNyblomTest');

      controls.fullrec = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 240 325 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.fullrec, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg fullrec', ...
         'HorizontalAlignment','left', ...
         'String','Use full sample short-run estimates for rec. eigenvalues and beta', ...
         'Tag','FullSampleRecursion');

      controls.chowfc = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
	       'Position',[40 220 320 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.chowfc, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg chowfc', ...
         'HorizontalAlignment','left', ...
         'String','Divide Chow test value by critical value in graphs', ...
         'Tag','ChowDivide');

      controls.recalpha = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 200 320 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.recalpha, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg recalpha', ...
         'HorizontalAlignment','left', ...
         'String','Enable recursive estimation of alpha', ...
         'Tag','RecursiveAlpha');
      
      controls.recpi = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 180 320 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.recpi, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg recpi', ...
         'HorizontalAlignment','left', ...
         'String','Enable recursive estimation of Pi (=alpha*beta'')', ...
         'Tag','RecursivePi');

      controls.rectrace = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 160 320 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.rectrace, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg rectrace', ...
         'HorizontalAlignment','left', ...
         'String','Enable recursive estimation of trace test', ...
         'Tag','RecursiveTrace');

      controls.topeig = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 140 330 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.topeig, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg topeig', ...
         'HorizontalAlignment','left', ...
         'String','Enable recursive estimation of companion matrix''s max eigenvalue', ...
         'Tag','TopEig');

      controls.extraccrit = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 120 330 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.extraccrit, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg extraccrit', ...
         'HorizontalAlignment','left', ...
         'String','Let Structural VAR pick conv. criterion for rest. constancy tests', ...
         'Tag','ExtraCCrit');

      controls.recursivetext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 70 230 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Relative start period for recursive analysis:', ...
         'Tag','RecursiveText');

      controls.recursive = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[245 75 110 20], ...
         'Style','edit', ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String',var_ini.T0, ...
         'Callback','optionsdlg recursive', ...
         'Tag','RecursivePopup');

      %
      % Controls on tab dialog Utilities
      %

      controls.txtprinttext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 340+add_edit_context 230 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Text print program:', ...
         'Tag','TxTPrintText');

      if var_ini.edit_context==0;
         controls.txtprintedit = uicontrol('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[40 320 260 22], ...
            'Style','edit', ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'String',var_ini.txtprint, ...
            'Callback','optionsdlg checktxtprint', ...
            'Tag','TxtPrintEdit');
      else;
         controls.txtprintedit = editbox('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[40 320 260 22], ...
            'FontName',get(controls.txtprinttext,'FontName'), ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'String',var_ini.txtprint, ...
            'Callback','optionsdlg checktxtprint', ...
            'Tag','TxtPrintEdit');
      end;

      controls.txtprintbutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[305 320 50 22], ...
         'TooltipString','Browse', ...
         'CData',var_ini.images.browse, ...
         'Visible','off', ...
         'Enable','on', ...
         'Callback','optionsdlg txtprint', ...
         'Tag','TxtPrintButton');

      if ispc==1;
         controls.txtprintrun = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[305 298 50 22], ...
            'TooltipString','Open TxtPrint', ...
            'CData',var_ini.images.txtprint, ...
            'Visible','off', ...
            'Enable','off', ...
            'Callback','optionsdlg txtprintrun', ...
            'Tag','TxtPrintRunButton');
   
         if (isempty(var_ini.txtprint)==0)&(fileexist([getpath(var_ini.txtprint) 'txtprint.exe'])==1);
            set(controls.txtprintrun,'Enable','on');
         end;
      end;

      controls.txtprintcmdtext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 290 200 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Text print command line switches:', ...
         'Tag','TxTPrintCmdText');

      controls.txtprintcmdedit = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[40 270 260 22], ...
         'Style','edit', ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String',var_ini.txtprintcmd, ...
         'Callback','optionsdlg checktxtprintcmd', ...
         'Tag','TxtPrintCmdEdit');

      %
      % display only in stand-alone release
      %
      addutil = 0;
      if iscompiled==1;
         addutil = 200;

         controls.psprinttext = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[40 240+add_edit_context 230 20], ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Style','text', ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'String','PostScript print program:', ...
            'Tag','PSPrintText');

         if var_ini.edit_context==0;
            controls.psprintedit = uicontrol('Units','pixels', ...
               'BackgroundColor',[1 1 1], ...
               'Position',[40 220 260 22], ...
               'Style','edit', ...
               'FontSize',var_ini.gui_fontsize, ...
               'FontName',var_ini.gui_fontname, ...
               'FontWeight',var_ini.gui_fontweight, ...
               'FontAngle',var_ini.gui_fontangle, ...
               'Visible','off', ...
               'HorizontalAlignment','left', ...
               'String',var_ini.psprint, ...
               'Callback','optionsdlg checkpsprint', ...
               'Tag','PSPrintEdit');
         else;
            controls.psprintedit = editbox('Units','pixels', ...
               'BackgroundColor',[1 1 1], ...
               'Position',[40 220 260 22], ...
               'FontName',get(controls.psprinttext,'FontName'), ...
               'FontSize',var_ini.gui_fontsize, ...
               'FontName',var_ini.gui_fontname, ...
               'FontWeight',var_ini.gui_fontweight, ...
               'FontAngle',var_ini.gui_fontangle, ...
               'Visible','off', ...
               'HorizontalAlignment','left', ...
               'String',var_ini.psprint, ...
               'Callback','optionsdlg checkpsprint', ...
               'Tag','PSPrintEdit');
         end;

         controls.psprintbutton = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[305 220 50 22], ...
            'TooltipString','Browse', ...
            'CData',var_ini.images.browse, ...
            'Visible','off', ...
            'Enable','on', ...
            'Callback','optionsdlg psprint', ...
            'Tag','PSPrintButton');

         controls.psprintcmdtext = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[40 190 200 20], ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Style','text', ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'String','PostScript print command line switches:', ...
            'Tag','PSPrintCmdText');

         controls.psprintcmdedit = uicontrol('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[40 170 260 22], ...
            'Style','edit', ...
       	    'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'String',var_ini.psprintcmd, ...
            'Callback','optionsdlg checkpsprintcmd', ...
            'Tag','PSPrintCmdEdit');

         controls.ghostscripttext = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[40 140+add_edit_context 230 20], ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Style','text', ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'String','Ghostscript program:', ...
            'Tag','GhostscriptText');

         if var_ini.edit_context==0;
            controls.ghostscriptedit = uicontrol('Units','pixels', ...
               'BackgroundColor',[1 1 1], ...
               'Position',[40 120 260 22], ...
               'Style','edit', ...
               'FontSize',var_ini.gui_fontsize, ...
               'FontName',var_ini.gui_fontname, ...
               'FontWeight',var_ini.gui_fontweight, ...
               'FontAngle',var_ini.gui_fontangle, ...
               'Visible','off', ...
               'HorizontalAlignment','left', ...
               'String',var_ini.ghostscript, ...
               'Callback','optionsdlg checkghostscript', ...
               'Tag','GhostscriptEdit');
         else;
            controls.ghostscriptedit = editbox('Units','pixels', ...
               'BackgroundColor',[1 1 1], ...
               'Position',[40 120 260 22], ...
               'FontName',get(controls.ghostscripttext,'FontName'), ...
               'FontSize',var_ini.gui_fontsize, ...
               'FontName',var_ini.gui_fontname, ...
               'FontWeight',var_ini.gui_fontweight, ...
               'FontAngle',var_ini.gui_fontangle, ...
               'Visible','off', ...
               'HorizontalAlignment','left', ...
               'String',var_ini.ghostscript, ...
               'Callback','optionsdlg checkghostscript', ...
               'Tag','GhostscriptEdit');
         end;

         controls.ghostscriptbutton = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[305 120 50 22], ...
            'TooltipString','Browse', ...
            'CData',var_ini.images.browse, ...
            'Visible','off', ...
            'Enable','on', ...
            'Callback','optionsdlg ghostscript', ...
            'Tag','GhostscriptButton');

         controls.pstoedittext = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[40 90+add_edit_context 230 20], ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Style','text', ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'String','pstoedit program:', ...
            'Tag','pstoeditText');

         if var_ini.edit_context==0;
            controls.pstoeditedit = uicontrol('Units','pixels', ...
               'BackgroundColor',[1 1 1], ...
               'Position',[40 70 260 22], ...
               'Style','edit', ...
               'FontSize',var_ini.gui_fontsize, ...
               'FontName',var_ini.gui_fontname, ...
               'FontWeight',var_ini.gui_fontweight, ...
               'FontAngle',var_ini.gui_fontangle, ...
               'Visible','off', ...
               'HorizontalAlignment','left', ...
               'String',var_ini.pstoedit, ...
               'Callback','optionsdlg checkpstoedit', ...
               'Tag','pstoeditEdit');
         else;
            controls.pstoeditedit = editbox('Units','pixels', ...
               'BackgroundColor',[1 1 1], ...
               'Position',[40 70 260 22], ...
               'FontName',get(controls.pstoedittext,'FontName'), ...
               'FontSize',var_ini.gui_fontsize, ...
               'FontName',var_ini.gui_fontname, ...
               'FontWeight',var_ini.gui_fontweight, ...
               'FontAngle',var_ini.gui_fontangle, ...
               'Visible','off', ...
               'HorizontalAlignment','left', ...
               'String',var_ini.pstoedit, ...
               'Callback','optionsdlg checkpstoedit', ...
               'Tag','pstoeditEdit');
         end;

         controls.pstoeditbutton = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[305 70 50 22], ...
            'TooltipString','Browse', ...
            'CData',var_ini.images.browse, ...
            'Visible','off', ...
            'Enable','on', ...
            'Callback','optionsdlg pstoedit', ...
            'Tag','pstoeditButton');

      end;





      %
      % Controls on tab dialog Simulation
      %

      controls.simulatedirtext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 340+add_edit_context 230 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Simulation output directory:', ...
         'Tag','SimulateText');

      if var_ini.edit_context==0;
         controls.simulatediredit = uicontrol('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[40 320 260 22], ...
            'Style','edit', ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'String',var_ini.simulatedir, ...
            'Callback','optionsdlg checksimulatedir', ...
            'Tag','SimulateEdit');
      else;
         controls.simulatediredit = editbox('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[40 320 260 22], ...
            'FontName',get(controls.simulatedirtext,'FontName'), ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'String',var_ini.simulatedir, ...
            'Callback','optionsdlg checksimulatedir', ...
            'Tag','SimulateEdit');
      end;

      controls.simulatedirbutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[305 320 50 22], ...
         'TooltipString','Browse', ...
         'CData',var_ini.images.browse, ...
         'Visible','off', ...
         'Enable','on', ...
         'Callback','optionsdlg simulatedir', ...
         'Tag','SimulateButton');

      %
      % make sure the simulate directory exists
      %

      if direxist(var_ini.simulatedir)==0;
         stat = makedirs(var_ini.simulatedir);
      end;

      %
      % bottons for deleting files
      %

      controls.delete_text = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 295 300 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Delete files from simulation output directory:', ...
         'Tag','DeleteText');

      controls.delete_matfile = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 275 100 22], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'Callback','optionsdlg deletefiles', ...
         'HorizontalAlignment','center', ...
         'String','Matlab MAT Files...', ...
         'Tag','.mat');

      controls.delete_txtfile = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[147.5 275 100 22], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'Callback','optionsdlg deletefiles', ...
         'HorizontalAlignment','center', ...
         'String','Text Files...', ...
         'Tag','.txt');

      controls.delete_mfile = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[255 275 100 22], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'Callback','optionsdlg deletefiles', ...
         'HorizontalAlignment','center', ...
         'String','Matlab M Files...', ...
         'Tag','.m');

      %
      % check boxes
      %
      
      controls.parametric = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 250 330 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.parametric, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg parametric', ...
         'HorizontalAlignment','left', ...
         'String','Use parametric bootstrapping', ...
         'Tag','ParametricBootstrap');

      controls.blocktext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[60 220 120 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'HorizontalAlignment','left', ...
         'String','Bootstrap block size:', ...
         'Enable','off', ...
         'Visible','off', ...
         'Tag','BlockText');
         
      controls.blocksize = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[185 225 170 20], ...
         'String','1|2|3|4|5|6|7|8|9|10|11|12', ...
         'Style','popupmenu', ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Callback','optionsdlg blocksize', ...
         'Value',var_ini.blocksize, ...
         'Enable','off', ...
         'Visible','off', ...
         'Tag','BlockPopup');

      if var_ini.parametric==0;
         set(controls.blocktext,'Enable','on');
         set(controls.blocksize,'Enable','on');
      end;

      controls.bootstrap = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 200 330 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.reuse_bootstrap, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg reusebootstrap', ...
         'HorizontalAlignment','left', ...
         'String','Reuse and save bootstrapped residuals', ...
         'Tag','ReuseBootstrap');

      controls.symmetric = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 180 330 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.symmetric, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg symmetric', ...
         'HorizontalAlignment','left', ...
         'String','Use symmetric decomposition of Omega for non-structural models', ...
         'Tag','SymmetricOmega');



      %
      % Simulation state controls
      %

      controls.rstatetext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 145 150 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Random no. generator state:', ...
         'Tag','RStateText');

      controls.rstate = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[185 150 170 20], ...
         'Style','popupmenu', ...
         'Value',var_ini.random_state, ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','optionsdlg rstate', ...
         'String','MatLab default|Replication number|Clock sum|Clock sum+replication number', ...
         'Tag','RStatePopup');

      controls.nReptext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 120 150 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Number of replications:', ...
         'Tag','nRepText');

      controls.nRep = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[185 125 170 20], ...
         'Style','popupmenu', ...
         'Value',var_ini.nRep_value, ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','optionsdlg nRep', ...
         'String','99|999|1,999|2,999|3,999|4,999|9,999|19,999|29,999|39,999|49,999|99,999|199,999|299,999|399,999|499,999|999,999', ...
         'Tag','nRepPopup');

      controls.nDrawtext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 95 150 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Draws per replication:', ...
         'Tag','nDrawText');

      controls.nDraw = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[185 100 170 20], ...
         'Style','popupmenu', ...
         'Value',floor(var_ini.nDraw/100), ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','optionsdlg nDraw', ...
         'String','100|200|300|400|500|600|700|800|900|1,000|1,100|1,200|1,300|1,400|1,500|1,600|1,700|1,800|1,900|2,000|2,500|3,000|4,000|5,000|6,000|7,000|8,000|9,000|10,000', ...
         'Tag','nDrawPopup');

      controls.interpolatetext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 70 150 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Interpolation function:', ...
         'Tag','InterpolateText');

      controls.interpolate = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[185 75 170 20], ...
         'Style','popupmenu', ...
         'Value',var_ini.interpolate_value, ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','optionsdlg interpolate', ...
         'String','Nearest neighborhood|Linear|Cubic spline|Cubic|Kernel density normal|Kernel density Epanechnikov|Kernel density rectangular|Kernel density triangular|Kernel density biweight|Kernel density triweight|Kernel density Laplace|Kernel density logistic', ...
         'Tag','InterpolatePopup');

      %
      % Controls on tab dialog Forecasting
      %

      controls.outofsample = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 340 300 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.outofsample, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg outofsample', ...
         'HorizontalAlignment','left', ...
         'String','Compute out-of-sample forecasts by default', ...
         'Tag','CheckOutOfSample');





      controls.forecasthorizontext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 70 150 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Default forecast horizon:', ...
         'Tag','ForecastHorizonText');

      controls.forecasthorizon = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[185 75 170 20], ...
         'Style','popupmenu', ...
         'Value',var_ini.forecasthorizon, ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','optionsdlg forecasthorizon', ...
         'String','1 year|2 years|3 years|4 years|5 years', ...
         'Tag','ForecastHorizonPopup');


      %
      % Controls on tab dialog TeX
      %

      controls.latextext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 340+add_edit_context 230 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','LaTeX program:', ...
         'Tag','LaTeXText');

      if var_ini.edit_context==0;
         controls.latexedit = uicontrol('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[40 320 260 22], ...
            'Style','edit', ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'String',var_ini.latex, ...
            'Callback','optionsdlg checklatex', ...
            'Tag','LaTeXEdit');
      else;
         controls.latexedit = editbox('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[40 320 260 22], ...
            'FontName',get(controls.latextext,'FontName'), ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'String',var_ini.latex, ...
            'Callback','optionsdlg checklatex', ...
            'Tag','LaTeXEdit');
      end;

      controls.latexbutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[305 320 50 22], ...
         'TooltipString','Browse', ...
         'CData',var_ini.images.browse, ...
         'Visible','off', ...
         'Enable','on', ...
         'Callback','optionsdlg latex', ...
         'Tag','LaTeXButton');

      controls.dviviewertext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 290+add_edit_context 230 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','DVI viewer program:', ...
         'Tag','DVIViewerText');

      if var_ini.edit_context==0;
         controls.dvivieweredit = uicontrol('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[40 270 260 22], ...
            'Style','edit', ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'String',var_ini.dviviewer, ...
            'Callback','optionsdlg checkdviviewer', ...
            'Tag','DVIViewerEdit');
      else;
         controls.dvivieweredit = editbox('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[40 270 260 22], ...
            'FontName',get(controls.dviviewertext,'FontName'), ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'String',var_ini.dviviewer, ...
            'Callback','optionsdlg checkdviviewer', ...
            'Tag','DVIViewerEdit');
      end;

      controls.dviviewerbutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[305 270 50 22], ...
         'TooltipString','Browse', ...
         'CData',var_ini.images.browse, ...
         'Visible','off', ...
         'Enable','on', ...
         'Callback','optionsdlg dviviewer', ...
         'Tag','DVIViewerButton');

      controls.distillertext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 240+add_edit_context 230 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','PostScript to PDF program:', ...
         'Tag','DistillerText');

      if var_ini.edit_context==0;
         controls.distilleredit = uicontrol('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[40 220 260 22], ...
            'Style','edit', ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'String',var_ini.distiller, ...
            'Callback','optionsdlg checkdistiller', ...
            'Tag','DistillerEdit');
      else;
         controls.distilleredit = editbox('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[40 220 260 22], ...
            'FontName',get(controls.latextext,'FontName'), ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'String',var_ini.latex, ...
            'Callback','optionsdlg checkdistiller', ...
            'Tag','DistillerEdit');
      end;

      controls.distillerbutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[305 220 50 22], ...
         'TooltipString','Browse', ...
         'CData',var_ini.images.browse, ...
         'Visible','off', ...
         'Enable','on', ...
         'Callback','optionsdlg distiller', ...
         'Tag','DistillerButton');

      controls.psviewertext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 190+add_edit_context 230 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','PostScript viewer program:', ...
         'Tag','PSViewerText');

      if var_ini.edit_context==0;
         controls.psvieweredit = uicontrol('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[40 170 260 22], ...
            'Style','edit', ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'String',var_ini.psviewer, ...
            'Callback','optionsdlg checkpsviewer', ...
            'Tag','PSViewerEdit');
      else;
         controls.psvieweredit = editbox('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[40 170 260 22], ...
            'FontName',get(controls.psviewertext,'FontName'), ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'String',var_ini.psviewer, ...
            'Callback','optionsdlg checkpsviewer', ...
            'Tag','PSViewerEdit');
      end;

      controls.psviewerbutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[305 170 50 22], ...
         'TooltipString','Browse', ...
         'CData',var_ini.images.browse, ...
         'Visible','off', ...
         'Enable','on', ...
         'Callback','optionsdlg psviewer', ...
         'Tag','PSViewerButton');

      controls.pdfviewertext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 140+add_edit_context 230 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','PDF viewer program:', ...
         'Tag','PDFViewerText');

      if var_ini.edit_context==0;
         controls.pdfvieweredit = uicontrol('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[40 120 260 22], ...
            'Style','edit', ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'String',var_ini.pdfviewer, ...
            'Callback','optionsdlg checkpdfviewer', ...
            'Tag','PDFViewerEdit');
      else;
         controls.pdfvieweredit = editbox('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[40 120 260 22], ...
            'FontName',get(controls.pdfviewertext,'FontName'), ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Visible','off', ...
            'HorizontalAlignment','left', ...
            'String',var_ini.pdfviewer, ...
            'Callback','optionsdlg checkpdfviewer', ...
            'Tag','PDFViewerEdit');
      end;

      controls.pdfviewerbutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[305 120 50 22], ...
         'TooltipString','Browse', ...
         'CData',var_ini.images.browse, ...
         'Visible','off', ...
         'Enable','on', ...
         'Callback','optionsdlg pdfviewer', ...
         'Tag','PDFViewerButton');

      controls.dvipdfm = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 70 300 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.dvipdfm, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg dvipdfm', ...
         'HorizontalAlignment','left', ...
         'String','Use dvipdfm instead of PostScript to PDF program', ...
         'Tag','CheckDVIpdfm');

      if (iswinnt==1)&(iscompiled==1);
         set(controls.dvipdfm,'Position',[40 90 300 20]);
         
         controls.maximizeviewer = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[40 70 300 20], ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Style','checkbox', ...
            'Value',var_ini.maximizeviewer, ...
            'Enable','on', ...
            'Visible','off', ...
            'Callback','optionsdlg maximizeviewer', ...
            'HorizontalAlignment','left', ...
            'String','Maximize PostScript and PDF viewer window', ...
            'Tag','CheckMaximizeViewer');
         
      end;

      %
      % Controls on tab dialog TeX Preamble
      %

      controls.texheadertext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 324 230 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','LaTeX file preamble:', ...
         'Tag','LaTeXHeaderText');

      controls.texheaderbutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[258 337 100 22], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'String','Default Preamble', ...
         'Visible','off', ...
         'Enable','on', ...
         'Callback','optionsdlg defaulttexheader', ...
         'Tag','TeXHeaderButton');

      controls.texheader = editbox('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[40 70 318 251], ...
         'FontName',get(controls.pdfviewertext,'FontName'), ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String',var_ini.texheadertxt, ...
         'Callback','optionsdlg texheader', ...
         'Tag','TeXHeaderEdit');

      %
      % Controls on tab dialog output control
      %

      controls.noprint = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 340 300 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.noprint, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg noprint', ...
         'HorizontalAlignment','left', ...
         'String','Don''t write to output file', ...
         'Tag','CheckNoPrint');

      controls.openmyoutput = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 320 300 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.openmyoutput, ...
         'Enable',noprintenable, ...
         'Visible','off', ...
         'Callback','optionsdlg openmyoutput', ...
         'HorizontalAlignment','left', ...
         'String','Open output file directly after estimation', ...
         'Tag','CheckOpenOutput');

      controls.append = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 300 300 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.append, ...
         'Enable',noprintenable, ...
         'Visible','off', ...
         'Callback','optionsdlg append', ...
         'HorizontalAlignment','left', ...
         'String','Append new results to existing output file', ...
         'Tag','CheckAppend');

      controls.shortdyn = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 280 320 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.shortdyn, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg shortdyn', ...
         'HorizontalAlignment','left', ...
         'String','Write short-run dynamics and the C-matrix to output file', ...
         'Tag','ShortDynamics');

      controls.gctest = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 260 320 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.gctest, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg gctest', ...
         'HorizontalAlignment','left', ...
         'String','Write Granger causality tests to output file', ...
         'Tag','GrangerCausality');

      controls.excludediffs = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 240 320 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.excludediffs, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg excludediffs', ...
         'HorizontalAlignment','left', ...
         'String','Write exclusion tests to output file', ...
         'Tag','ExclusionTestsCheck');

      controls.lstrtest = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 220 320 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.lstrtest, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg lstrtest', ...
         'HorizontalAlignment','left', ...
         'String','Write LSTR1 parameter constancy tests to output file', ...
         'Tag','LSTR');

      controls.chow = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 200 320 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.chow, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg chow', ...
         'HorizontalAlignment','left', ...
         'String','Write Chow tests to output file', ...
         'Tag','ChowTest');

      controls.decimalstext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 160 230 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Write results to output with:', ...
         'Tag','DecimalsText');

      controls.decimals = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[215 165 140 20], ...
         'Style','popupmenu', ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'Value',var_ini.decimals-1, ...
         'Callback','optionsdlg decimals', ...
         'String','2 decimals|3 decimals|4 decimals|5 decimals|6 decimals|7 decimals|8 decimals', ...
         'Tag','DecimalsPopup');

      controls.exportdatatext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 130 230 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Export data to text file with:', ...
         'Tag','ExportDataText');

      controls.exportdata = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[215 135 140 20], ...
         'Style','popupmenu', ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'Value',var_ini.exportdata, ...
         'Callback','optionsdlg exportdata', ...
         'String','4 decimals|5 decimals|6 decimals|7 decimals|8 decimals|9 decimals|10 decimals|11 decimals|12 decimals', ...
         'Tag','ExportDataPopup');

      controls.pdfversiontext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 100 230 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','PDF version for Ghostscript:', ...
         'Tag','PDFVersionText');

      mypdf = 1;
      if strcmp(var_ini.pdfversion,'1.2')==1;
         mypdf = 1;
      elseif strcmp(var_ini.pdfversion,'1.3')==1;
         mypdf = 2;
      elseif strcmp(var_ini.pdfversion,'1.4')==1;
         mypdf = 3;
      end;

      controls.pdfversion = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[215 105 140 20], ...
         'Style','popupmenu', ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'Value',mypdf, ...
         'Callback','optionsdlg pdfversion', ...
         'String','1.2|1.3|1.4', ...
         'Tag','PDFVersionPopup');

      controls.texoutputtext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 70 230 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Output format:', ...
         'Tag','TeXOutputText');

      controls.texoutput = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[215 75 140 20], ...
         'Style','popupmenu', ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'Value',var_ini.texoutputformat, ...
         'Callback','optionsdlg texoutputformat', ...
         'String','Formatted plain text file|Formatted LaTeX file', ...
         'Tag','TeXOutputPopup');

      %
      % Controls on tab dialog Miscellaneous
      %

      controls.pstoolsdirtext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 340+add_edit_context 230 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'Enable','on', ...
         'HorizontalAlignment','left', ...
         'String','PsTools directory:', ...
         'Tag','PsToolsText');

      if var_ini.edit_context==0;
         controls.pstoolsdiredit = uicontrol('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[40 320 260 22], ...
            'Style','edit', ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Visible','off', ...
            'Enable','on', ...
            'HorizontalAlignment','left', ...
            'String',var_ini.pstoolsdir, ...
            'Callback','optionsdlg checkpstoolsdir', ...
            'Tag','PsToolsEdit');
      else;
         controls.pstoolsdiredit = editbox('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[40 320 260 22], ...
            'FontName',get(controls.simulatedirtext,'FontName'), ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Visible','off', ...
            'Enable','on', ...
            'HorizontalAlignment','left', ...
            'String',var_ini.pstoolsdir, ...
            'Callback','optionsdlg checkpstoolsdir', ...
            'Tag','PsToolsEdit');
      end;

      controls.pstoolsdirbutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[305 320 50 22], ...
         'TooltipString','Browse', ...
         'CData',var_ini.images.browse, ...
         'Visible','off', ...
         'Enable','on', ...
         'Callback','optionsdlg pstoolsdir', ...
         'Tag','PsToolsButton');

      controls.loadguiicon = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 290 320 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.loadguiicon, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg loadguiicon', ...
         'HorizontalAlignment','left', ...
         'String','Display a unique icon on certain GUI windows', ...
         'Tag','LoadGUIIconCheck');

      controls.loadicon = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 270 320 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.loadicon, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg loadicon', ...
         'HorizontalAlignment','left', ...
         'String','Display a unique icon on Graphics windows', ...
         'Tag','LoadIconCheck');

      controls.noicon = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 250 320 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.noicon, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg noicon', ...
         'HorizontalAlignment','left', ...
         'String','Hide the icon on certain modal windows', ...
         'Tag','NoIconCheck');

      controls.show_undo = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 230 320 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.show_undo, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg show_undo', ...
         'HorizontalAlignment','left', ...
         'String','Show undo button on graphics toolbar and menu', ...
         'Tag','ShowUndoCheck');


      controls.browsedialog = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 210 320 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.browsedialog, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg browsedialog', ...
         'HorizontalAlignment','left', ...
         'String','Use Windows'' "Browse for Directory" dialog', ...
         'Tag','BrowseDialogCheck');

      controls.opendialog = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 190 320 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',var_ini.opendialog, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','optionsdlg opendialog', ...
         'HorizontalAlignment','left', ...
         'String','Use customized file filters in file open dialog', ...
         'Tag','OpenDialogCheck');

      controls.delaytext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 160 240 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','GUI delay in milliseconds:', ...
         'Tag','DelayText');

      controls.delay = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[285 165 70 20], ...
         'Style','edit', ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','optionsdlg delay', ...
         'String',num2str(var_ini.delay), ...
         'Tag','DelayEdit');







      controls.tempdirtext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 130+add_edit_context 230 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'Enable','on', ...
         'HorizontalAlignment','left', ...
         'String','Temporary directory:', ...
         'Tag','TempDirText');

      if var_ini.edit_context==0;
         controls.tempdiredit = uicontrol('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[40 110 260 22], ...
            'Style','edit', ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Visible','off', ...
            'Enable','on', ...
            'HorizontalAlignment','left', ...
            'String',var_ini.tempdir, ...
            'Callback','optionsdlg checktempdir', ...
            'Tag','TempDirEdit');
      else;
         controls.tempdiredit = editbox('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[40 110 260 22], ...
            'FontName',get(controls.simulatedirtext,'FontName'), ...
            'FontSize',var_ini.gui_fontsize, ...
            'FontName',var_ini.gui_fontname, ...
            'FontWeight',var_ini.gui_fontweight, ...
            'FontAngle',var_ini.gui_fontangle, ...
            'Visible','off', ...
            'Enable','on', ...
            'HorizontalAlignment','left', ...
            'String',var_ini.tempdir, ...
            'Callback','optionsdlg checktempdir', ...
            'Tag','TempDirEdit');
      end;

      controls.tempdirbutton = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[305 110 50 22], ...
         'TooltipString','Browse', ...
         'CData',var_ini.images.browse, ...
         'Visible','off', ...
         'Enable','on', ...
         'Callback','optionsdlg tempdir', ...
         'Tag','TempDirButton');

      controls.maxresptext = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[40 70 240 20], ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'String','Maximum horizon for Number of responses Control:', ...
         'Tag','MaxRespText');

      controls.maxresp = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[285 75 70 20], ...
         'Style','edit', ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Visible','off', ...
         'HorizontalAlignment','left', ...
         'Callback','optionsdlg maxresp', ...
         'String',num2str(var_ini.maxresp), ...
         'Tag','MaxRespEdit');

      %
      % buttons that are always shown
      %

      controls.help = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[10 10 20 20], ...
         'String','?', ...
         'TooltipString','Open the help file', ...
         'FontWeight','bold', ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'ForegroundColor',[0.5 0 0], ...
         'Enable','on', ...
         'Callback','optionsdlg help', ...
         'Tag','HelpButton');

      controls.ok = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'ForegroundColor',[0 0 0], ...
         'Position',[position(3)-245 10 75 20], ...
         'String','OK', ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Enable','on', ...
         'Callback','optionsdlg ok', ...
         'UserData','waiting', ...
         'Tag','OK');

      controls.cancel = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'ForegroundColor',[0 0 0], ...
         'Position',[position(3)-165 10 75 20], ...
         'String','Cancel', ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Callback','optionsdlg cancel', ...
         'Enable','on', ...
         'Tag','Cancel');

      controls.apply = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'ForegroundColor',[0 0 0], ...
         'Position',[position(3)-85 10 75 20], ...
         'String','Apply', ...
         'FontSize',var_ini.gui_fontsize, ...
         'FontName',var_ini.gui_fontname, ...
         'FontWeight',var_ini.gui_fontweight, ...
         'FontAngle',var_ini.gui_fontangle, ...
         'Callback','optionsdlg apply', ...
         'Enable','off', ...
         'Tag','Done');

      set(optionsgui,'UserData',controls,...
         'HandleVisibility','callback');

case 'tab'
   currenttab = get(controls.tab1,'UserData');
   newtab = get(gcbo,'Tag');
   newtab = strrep(newtab,'tab','');
   newtab = mystr2num(newtab);
   if abs(newtab-currenttab)>0;
      if newtab<=5;
         set(controls.tab1,'UserData',newtab);
      elseif (newtab>=6)&(newtab<=10);
         set(controls.tab1,'UserData',newtab-5);
         mytab1 = get(controls.tab1,'String');
         mytab2 = get(controls.tab2,'String');
         mytab3 = get(controls.tab3,'String');
         mytab4 = get(controls.tab4,'String');
         mytab5 = get(controls.tab5,'String');
         set(controls.tab1,'String',get(controls.middle1,'String'));
         set(controls.tab2,'String',get(controls.middle2,'String'));
         set(controls.tab3,'String',get(controls.middle3,'String'));
         set(controls.tab4,'String',get(controls.middle4,'String'));
         set(controls.tab5,'String',get(controls.middle5,'String'));
         set(controls.middle1,'String',mytab1);
         set(controls.middle2,'String',mytab2);
         set(controls.middle3,'String',mytab3);
         set(controls.middle4,'String',mytab4);
         set(controls.middle5,'String',mytab5);
         newtab = newtab-5;
      else;
         set(controls.tab1,'UserData',newtab-10);
         mytab1 = get(controls.tab1,'String');
         mytab2 = get(controls.tab2,'String');
         mytab3 = get(controls.tab3,'String');
         mytab4 = get(controls.tab4,'String');
         mytab5 = get(controls.tab5,'String');
         set(controls.tab1,'String',get(controls.upper1,'String'));
         set(controls.tab2,'String',get(controls.upper2,'String'));
         set(controls.tab3,'String',get(controls.upper3,'String'));
         set(controls.tab4,'String',get(controls.upper4,'String'));
         set(controls.tab5,'String',get(controls.upper5,'String'));
         set(controls.upper1,'String',mytab1);
         set(controls.upper2,'String',mytab2);
         set(controls.upper3,'String',mytab3);
         set(controls.upper4,'String',mytab4);
         set(controls.upper5,'String',mytab5);
         newtab = newtab-10;
      end;
      if (iswinxp==1)&(matlabnumber>=7);
         fixtabs(controls,currenttab,newtab);
      end;
      if newtab==1;
         set(controls.frame3tab1,'Visible','off');
         set(controls.frame3tab2,'Visible','on');
         set(controls.frame3tab3,'Visible','on');
         set(controls.frame3tab4,'Visible','on');
         set(controls.frame3tab5,'Visible','on');
         set(controls.frame1tab2,'Position',[86.4 380 74.4 11]);
         set(controls.frame1tab3,'Position',[161.8 380 74.4 11]);
         set(controls.frame1tab4,'Position',[237.2 380 74.4 11]);
         set(controls.frame1tab5,'Position',[312.6 380 74.4 11]);
         set(controls.tab1,'Position',[10 388 76.4 25]);
         set(controls.tab2,'Position',[86.4 388 74.4 23]);
         set(controls.tab3,'Position',[161.8 388 74.4 23]);
         set(controls.tab4,'Position',[237.2 388 74.4 23]);
         set(controls.tab5,'Position',[312.6 388 74.4 23]);
         set(controls.maxittext,'Visible','off');
         set(controls.maxit,'Visible','off');
         set(controls.convcrittext,'Visible','off');
         set(controls.convcrit,'Visible','off');
         set(controls.method1,'Visible','off');
         set(controls.method2,'Visible','off');
         set(controls.method3,'Visible','off');
         set(controls.identify,'Visible','off');
         set(controls.identifytext,'Visible','off');
         set(controls.tab2axes11,'Visible','off');
         set(controls.tab2axes12,'Visible','off');
         set(controls.tab2axes13,'Visible','off');
         set(controls.tab2axes14,'Visible','off');
         set(controls.tab2axes15,'Visible','off');
         set(controls.tab2axes16,'Visible','off');
         set(controls.tab2axes17,'Visible','off');
         set(controls.tab2axes18,'Visible','off');
         set(controls.tab2axes1text,'Visible','off');
         set(controls.tab2axes21,'Visible','off');
         set(controls.tab2axes22,'Visible','off');
         set(controls.tab2axes23,'Visible','off');
         set(controls.tab2axes24,'Visible','off');
         set(controls.tab2axes25,'Visible','off');
         set(controls.tab2axes26,'Visible','off');
         set(controls.tab2axes27,'Visible','off');
         set(controls.tab2axes28,'Visible','off');
         set(controls.tab2axes2text,'Visible','off');
         set(controls.tab2axes31,'Visible','off');
         set(controls.tab2axes32,'Visible','off');
         set(controls.tab2axes33,'Visible','off');
         set(controls.tab2axes34,'Visible','off');
         set(controls.tab2axes35,'Visible','off');
         set(controls.tab2axes36,'Visible','off');
         set(controls.tab2axes37,'Visible','off');
         set(controls.tab2axes38,'Visible','off');
         set(controls.tab2axes3text,'Visible','off');
         if matlabnumber>=6.0;
            set(controls.tab2axes19,'Visible','off');
            set(controls.tab2axes110,'Visible','off');
            set(controls.tab2axes29,'Visible','off');
            set(controls.tab2axes210,'Visible','off');
            set(controls.tab2axes39,'Visible','off');
            set(controls.tab2axes310,'Visible','off');
         end;
         set(controls.tab9axes11,'Visible','off');
         set(controls.tab9axes12,'Visible','off');
         set(controls.tab9axes13,'Visible','off');
         set(controls.tab9axes14,'Visible','off');
         set(controls.tab9axes15,'Visible','off');
         set(controls.tab9axes16,'Visible','off');
         set(controls.tab9axes17,'Visible','off');
         set(controls.tab9axes18,'Visible','off');
         set(controls.tab9axes1text,'Visible','off');
         if matlabnumber>=6.0;
            set(controls.tab9axes19,'Visible','off');
            set(controls.tab9axes110,'Visible','off');
         end;
         set(controls.maxlagtext,'Visible','off');
         set(controls.maxlag,'Visible','off');
         set(controls.tab1axes11,'Visible','on');
         set(controls.tab1axes12,'Visible','on');
         set(controls.tab1axes13,'Visible','on');
         set(controls.tab1axes14,'Visible','on');
         set(controls.tab1axes15,'Visible','on');
         set(controls.tab1axes16,'Visible','on');
         set(controls.tab1axes17,'Visible','on');
         set(controls.tab1axes18,'Visible','on');
         set(controls.tab1axes1text,'Visible','on');
         if matlabnumber>=6.0;
            set(controls.tab1axes19,'Visible','on');
            set(controls.tab1axes110,'Visible','on');
         end;
         if strcmp(get(controls.tab1,'String'),'General')==1;
            controls.current = 'General';
            set(controls.outofsample,'Visible','off');
            set(controls.forecasthorizon,'Visible','off');
            set(controls.forecasthorizontext,'Visible','off');
            set(controls.openvar,'Visible','on');
            set(controls.dirstructure,'Visible','on');
            set(controls.geometry,'Visible','on');
            set(controls.uselastfile,'Visible','on');
            set(controls.startrun,'Visible','on');
            set(controls.logtab,'Visible','on');
            set(controls.clearlog,'Visible','on');
            set(controls.sillyq,'Visible','on');
            set(controls.editcontext,'Visible','on');
            set(controls.toolbar_bgcolor,'Visible','on');
            set(controls.gui_colors,'Visible','on');
            set(controls.text_colors,'Visible','on');
            set(controls.frame_colors,'Visible','on');
            set(controls.gui_fontbutton,'Visible','on');
            set(controls.gui_font,'Visible','on');
            set(controls.fonttext,'Visible','on');
            set(controls.default_colors,'Visible','on');
            set(controls.external,'Visible','off');
            set(controls.xgrid,'Visible','off');
            set(controls.ygrid,'Visible','off');
            set(controls.zgrid,'Visible','off');
            set(controls.box,'Visible','off');
            set(controls.colors,'Visible','off');
            set(controls.zbuffer,'Visible','off');
            set(controls.ytick,'Visible','off');
            set(controls.xtick,'Visible','off');
            set(controls.axesfont,'Visible','off');
            set(controls.titlefont,'Visible','off');
            set(controls.labelfont,'Visible','off');
            set(controls.axescolor,'Visible','off');
            set(controls.titlecolor,'Visible','off');
            set(controls.labelcolor,'Visible','off');
            set(controls.pagesetup,'Visible','off');
            set(controls.graphicsfmttext,'Visible','off');
            set(controls.graphicsfmt,'Visible','off');
         elseif strcmp(get(controls.tab1,'String'),'Graphics')==1;
            controls.current = 'Graphics';
            set(controls.outofsample,'Visible','off');
            set(controls.forecasthorizon,'Visible','off');
            set(controls.forecasthorizontext,'Visible','off');
            set(controls.openvar,'Visible','off');
            set(controls.dirstructure,'Visible','off');
            set(controls.geometry,'Visible','off');
            set(controls.uselastfile,'Visible','off');
            set(controls.startrun,'Visible','off');
            set(controls.logtab,'Visible','off');
            set(controls.clearlog,'Visible','off');
            set(controls.sillyq,'Visible','off');
            set(controls.editcontext,'Visible','off');
            set(controls.toolbar_bgcolor,'Visible','off');
            set(controls.gui_colors,'Visible','off');
            set(controls.text_colors,'Visible','off');
            set(controls.frame_colors,'Visible','off');
            set(controls.gui_fontbutton,'Visible','off');
            set(controls.gui_font,'Visible','off');
            set(controls.fonttext,'Visible','off');
            set(controls.default_colors,'Visible','off');
            set(controls.external,'Visible','on');
            set(controls.xgrid,'Visible','on');
            set(controls.ygrid,'Visible','on');
            set(controls.zgrid,'Visible','on');
            set(controls.box,'Visible','on');
            set(controls.colors,'Visible','on');
            set(controls.zbuffer,'Visible','on');
            set(controls.ytick,'Visible','on');
            set(controls.xtick,'Visible','on');
            set(controls.axesfont,'Visible','on');
            set(controls.titlefont,'Visible','on');
            set(controls.labelfont,'Visible','on');
            set(controls.axescolor,'Visible','on');
            set(controls.titlecolor,'Visible','on');
            set(controls.labelcolor,'Visible','on');
            set(controls.pagesetup,'Visible','on');
            set(controls.graphicsfmttext,'Visible','on');
            set(controls.graphicsfmt,'Visible','on');
         else;
            controls.current = 'Forecasting';
            set(controls.openvar,'Visible','off');
            set(controls.dirstructure,'Visible','off');
            set(controls.geometry,'Visible','off');
            set(controls.uselastfile,'Visible','off');
            set(controls.startrun,'Visible','off');
            set(controls.logtab,'Visible','off');
            set(controls.clearlog,'Visible','off');
            set(controls.sillyq,'Visible','off');
            set(controls.editcontext,'Visible','off');
            set(controls.toolbar_bgcolor,'Visible','off');
            set(controls.gui_colors,'Visible','off');
            set(controls.text_colors,'Visible','off');
            set(controls.frame_colors,'Visible','off');
            set(controls.gui_fontbutton,'Visible','off');
            set(controls.gui_font,'Visible','off');
            set(controls.fonttext,'Visible','off');
            set(controls.default_colors,'Visible','off');
            set(controls.external,'Visible','off');
            set(controls.xgrid,'Visible','off');
            set(controls.ygrid,'Visible','off');
            set(controls.zgrid,'Visible','off');
            set(controls.box,'Visible','off');
            set(controls.colors,'Visible','off');
            set(controls.zbuffer,'Visible','off');
            set(controls.ytick,'Visible','off');
            set(controls.xtick,'Visible','off');
            set(controls.axesfont,'Visible','off');
            set(controls.titlefont,'Visible','off');
            set(controls.labelfont,'Visible','off');
            set(controls.axescolor,'Visible','off');
            set(controls.titlecolor,'Visible','off');
            set(controls.labelcolor,'Visible','off');
            set(controls.pagesetup,'Visible','off');
            set(controls.graphicsfmttext,'Visible','off');
            set(controls.graphicsfmt,'Visible','off');
            set(controls.outofsample,'Visible','on');
            set(controls.forecasthorizon,'Visible','on');
            set(controls.forecasthorizontext,'Visible','on');
         end;
         set(controls.tab3axes11,'Visible','off');
         set(controls.tab3axes12,'Visible','off');
         set(controls.tab3axes13,'Visible','off');
         set(controls.tab3axes14,'Visible','off');
         set(controls.tab3axes15,'Visible','off');
         set(controls.tab3axes16,'Visible','off');
         set(controls.tab3axes17,'Visible','off');
         set(controls.tab3axes18,'Visible','off');
         set(controls.tab3axes1text,'Visible','off');
         if matlabnumber>=6.0;
            set(controls.tab3axes19,'Visible','off');
            set(controls.tab3axes110,'Visible','off');
         end;
         set(controls.sscorrect,'Visible','off');
         set(controls.bartserial,'Visible','off');
         set(controls.portmanteau,'Visible','off');
         set(controls.lbcorrect,'Visible','off');
         set(controls.omnibus,'Visible','off');
         set(controls.transeig,'Visible','off');
         set(controls.fluctest,'Visible','off');
         set(controls.nyblom,'Visible','off');
         set(controls.nyblombeta,'Visible','off');
         set(controls.taylor_nyblom,'Visible','off');
         set(controls.fullrec,'Visible','off');
         set(controls.chowfc,'Visible','off');
         set(controls.chow,'Visible','off');
         set(controls.recalpha,'Visible','off');
         set(controls.recpi,'Visible','off');
         set(controls.rectrace,'Visible','off');
         set(controls.topeig,'Visible','off');
         set(controls.extraccrit,'Visible','off');
         set(controls.parametric,'Visible','off');
         set(controls.blocktext,'Visible','off');
         set(controls.blocksize,'Visible','off');
         set(controls.bootstrap,'Visible','off');
         set(controls.symmetric,'Visible','off');
         set(controls.akaike,'Visible','off');
         set(controls.restat,'Visible','off');
         set(controls.dummytests,'Visible','off');
         set(controls.rest_march,'Visible','off');
         set(controls.shortdyn,'Visible','off');
         set(controls.gctest,'Visible','off');
         set(controls.excludediffs,'Visible','off');
         set(controls.lstrtest,'Visible','off');
         set(controls.noise_parm,'Visible','off');
         set(controls.noise_parmtxt,'Visible','off');
         set(controls.ms_maxlag,'Visible','off');
         set(controls.ms_maxlagtext,'Visible','off');
         set(controls.lagtest,'Visible','off');
         set(controls.lagtesttext,'Visible','off');
         set(controls.recursivetext,'Visible','off');
         set(controls.recursive,'Visible','off');
         editbox(controls.texheader,'Visible','off');
         set(controls.texheaderbutton,'Visible','off');
         set(controls.texheadertext,'Visible','off');
         set(controls.tracebart,'Visible','off');
         set(controls.betagrad,'Visible','off');
         set(controls.rahbek,'Visible','off');
         set(controls.reestbeta,'Visible','off');
         set(controls.normbeta,'Visible','off');
         set(controls.decompose_det,'Visible','off');
         set(controls.weakexo,'Visible','off');
         set(controls.commoncycles,'Visible','off');
         set(controls.excludestat,'Visible','off');
         set(controls.critvaltext,'Visible','off');
         set(controls.critval,'Visible','off');
         set(controls.tab4axes11,'Visible','off');
         set(controls.tab4axes12,'Visible','off');
         set(controls.tab4axes13,'Visible','off');
         set(controls.tab4axes14,'Visible','off');
         set(controls.tab4axes15,'Visible','off');
         set(controls.tab4axes16,'Visible','off');
         set(controls.tab4axes17,'Visible','off');
         set(controls.tab4axes18,'Visible','off');
         set(controls.tab4axes1text,'Visible','off');
         if matlabnumber>=6.0;
            set(controls.tab4axes19,'Visible','off');
            set(controls.tab4axes110,'Visible','off');
         end;
         set(controls.tab4axes21,'Visible','off');
         set(controls.tab4axes22,'Visible','off');
         set(controls.tab4axes23,'Visible','off');
         set(controls.tab4axes24,'Visible','off');
         set(controls.tab4axes25,'Visible','off');
         set(controls.tab4axes26,'Visible','off');
         set(controls.tab4axes27,'Visible','off');
         set(controls.tab4axes28,'Visible','off');
         set(controls.tab4axes2text,'Visible','off');
         if matlabnumber>=6.0;
            set(controls.tab4axes29,'Visible','off');
            set(controls.tab4axes210,'Visible','off');
         end;
         set(controls.bayes_mcmc,'Visible','off');
         set(controls.bayes_prior,'Visible','off');
         set(controls.aiviewertext,'Visible','off');
         if strcmp(get(controls.aivieweredit,'Type'),'uicontrol')==1;
            set(controls.aivieweredit,'Visible','off');
         else;
            editbox(controls.aivieweredit,'Visible','off');
         end;
         set(controls.aiviewerbutton,'Visible','off');
         set(controls.epsviewertext,'Visible','off');
         if strcmp(get(controls.epsvieweredit,'Type'),'uicontrol')==1;
            set(controls.epsvieweredit,'Visible','off');
         else;
            editbox(controls.epsvieweredit,'Visible','off');
         end;
         set(controls.epsviewerbutton,'Visible','off');
         set(controls.bitmapviewertext,'Visible','off');
         if strcmp(get(controls.bitmapvieweredit,'Type'),'uicontrol')==1;
            set(controls.bitmapvieweredit,'Visible','off');
         else;
            editbox(controls.bitmapvieweredit,'Visible','off');
         end;
         set(controls.bitmapviewerbutton,'Visible','off');
         set(controls.editortext,'Visible','off');
         if strcmp(get(controls.editoredit,'Type'),'uicontrol')==1;
            set(controls.editoredit,'Visible','off');
         else;
            editbox(controls.editoredit,'Visible','off');
         end;
         set(controls.editorbutton,'Visible','off');
         set(controls.helpexetext,'Visible','off');
         if strcmp(get(controls.helpexeedit,'Type'),'uicontrol')==1;
            set(controls.helpexeedit,'Visible','off');
         else;
            editbox(controls.helpexeedit,'Visible','off');
         end;
         if ispc==0;
            set(controls.helpexebutton,'Visible','off');
         end;
         set(controls.txtprinttext,'Visible','off');
         if strcmp(get(controls.txtprintedit,'Type'),'uicontrol')==1;
            set(controls.txtprintedit,'Visible','off');
         else;
            editbox(controls.txtprintedit,'Visible','off');
         end;
         set(controls.txtprintbutton,'Visible','off');
         set(controls.txtprintcmdtext,'Visible','off');
         set(controls.txtprintcmdedit,'Visible','off');
         if ispc==1;
            set(controls.txtprintrun,'Visible','off');
         end;
         if iscompiled==1;
            set(controls.psprinttext,'Visible','off');
            if strcmp(get(controls.psprintedit,'Type'),'uicontrol')==1;
               set(controls.psprintedit,'Visible','off');
            else;
               editbox(controls.psprintedit,'Visible','off');
            end;
            set(controls.psprintbutton,'Visible','off');
            set(controls.psprintcmdtext,'Visible','off');
            set(controls.psprintcmdedit,'Visible','off');
            set(controls.ghostscripttext,'Visible','off');
            if strcmp(get(controls.ghostscriptedit,'Type'),'uicontrol')==1;
               set(controls.ghostscriptedit,'Visible','off');
            else;
               editbox(controls.ghostscriptedit,'Visible','off');
            end;
            set(controls.ghostscriptbutton,'Visible','off');
            set(controls.pstoedittext,'Visible','off');
            if strcmp(get(controls.pstoeditedit,'Type'),'uicontrol')==1;
               set(controls.pstoeditedit,'Visible','off');
            else;
               editbox(controls.pstoeditedit,'Visible','off');
            end;
            set(controls.pstoeditbutton,'Visible','off');
         end;
         set(controls.maxresptext,'Visible','off');
         set(controls.maxresp,'Visible','off');
         set(controls.lambda_paramtext,'Visible','off');
         set(controls.lambda_param,'Visible','off');
         set(controls.lambda_inf_shortrun,'Visible','off');
         set(controls.lambda_dtext,'Visible','off');
         set(controls.lambda_d,'Visible','off');
         set(controls.lambda_inf_deter,'Visible','off');
         set(controls.lambda_alphatext,'Visible','off');
         set(controls.lambda_alpha,'Visible','off');
         set(controls.lambda_inf_alpha,'Visible','off');
         set(controls.lambda_omegatext,'Visible','off');
         set(controls.lambda_inf_omega,'Visible','off');
         set(controls.lambda_omega,'Visible','off');
         set(controls.burn_intext,'Visible','off');
         set(controls.burn_in,'Visible','off');
         set(controls.save_drawstext,'Visible','off');
         set(controls.save_draws,'Visible','off');
         set(controls.save_freqtext,'Visible','off');
         set(controls.save_freq,'Visible','off');
         set(controls.discard_explosive,'Visible','off');
         set(controls.bad_draws,'Visible','off');
         set(controls.pstoolsdirtext,'Visible','off');
         if strcmp(get(controls.pstoolsdiredit,'Type'),'uicontrol')==1;
            set(controls.pstoolsdiredit,'Visible','off');
         else;
            editbox(controls.pstoolsdiredit,'Visible','off');
         end;
         set(controls.pstoolsdirbutton,'Visible','off');
         set(controls.loadicon,'Visible','off');
         set(controls.noicon,'Visible','off');
         set(controls.show_undo,'Visible','off');
         set(controls.loadguiicon,'Visible','off');
         set(controls.browsedialog,'Visible','off');
         set(controls.opendialog,'Visible','off');
         set(controls.delaytext,'Visible','off');
         set(controls.delay,'Visible','off');
         set(controls.tempdirtext,'Visible','off');
         if strcmp(get(controls.tempdiredit,'Type'),'uicontrol')==1;
            set(controls.tempdiredit,'Visible','off');
         else;
            editbox(controls.tempdiredit,'Visible','off');
         end;
         set(controls.tempdirbutton,'Visible','off');
         set(controls.delete_text,'Visible','off');
         set(controls.delete_matfile,'Visible','off');
         set(controls.delete_txtfile,'Visible','off');
         set(controls.delete_mfile,'Visible','off');
         set(controls.rstate,'Visible','off');
         set(controls.rstatetext,'Visible','off');
         set(controls.nRep,'Visible','off');
         set(controls.nReptext,'Visible','off');
         set(controls.nDraw,'Visible','off');
         set(controls.nDrawtext,'Visible','off');
         set(controls.interpolate,'Visible','off');
         set(controls.interpolatetext,'Visible','off');
         set(controls.simulatedirtext,'Visible','off');
         if strcmp(get(controls.simulatediredit,'Type'),'uicontrol')==1;
            set(controls.simulatediredit,'Visible','off');
         else;
            editbox(controls.simulatediredit,'Visible','off');
         end;
         set(controls.simulatedirbutton,'Visible','off');
         set(controls.latextext,'Visible','off');
         if strcmp(get(controls.latexedit,'Type'),'uicontrol')==1;
            set(controls.latexedit,'Visible','off');
         else;
            editbox(controls.latexedit,'Visible','off');
         end;
         set(controls.latexbutton,'Visible','off');
         set(controls.dviviewertext,'Visible','off');
         if strcmp(get(controls.dvivieweredit,'Type'),'uicontrol')==1;
            set(controls.dvivieweredit,'Visible','off');
         else;
            editbox(controls.dvivieweredit,'Visible','off');
         end;
         set(controls.dviviewerbutton,'Visible','off');
         set(controls.distillertext,'Visible','off');
         if strcmp(get(controls.distilleredit,'Type'),'uicontrol')==1;
            set(controls.distilleredit,'Visible','off');
         else;
            editbox(controls.distilleredit,'Visible','off');
         end;
         set(controls.distillerbutton,'Visible','off');
         set(controls.psviewertext,'Visible','off');
         if strcmp(get(controls.psvieweredit,'Type'),'uicontrol')==1;
            set(controls.psvieweredit,'Visible','off');
         else;
            editbox(controls.psvieweredit,'Visible','off');
         end;
         set(controls.psviewerbutton,'Visible','off');
         set(controls.pdfviewertext,'Visible','off');
         if strcmp(get(controls.pdfvieweredit,'Type'),'uicontrol')==1;
            set(controls.pdfvieweredit,'Visible','off');
         else;
            editbox(controls.pdfvieweredit,'Visible','off');
         end;
         set(controls.pdfviewerbutton,'Visible','off');
         set(controls.dvipdfm,'Visible','off');
         if isfield(controls,'maximizeviewer')==1;
            set(controls.maximizeviewer,'Visible','off');
         end;
         set(controls.exportdatatext,'Visible','off');
         set(controls.exportdata,'Visible','off');
         set(controls.decimalstext,'Visible','off');
         set(controls.decimals,'Visible','off');
         set(controls.pdfversion,'Visible','off');
         set(controls.pdfversiontext,'Visible','off');
         set(controls.texoutputtext,'Visible','off');
         set(controls.texoutput,'Visible','off');
         set(controls.noprint,'Visible','off');
         set(controls.openmyoutput,'Visible','off');
         set(controls.append,'Visible','off');
      elseif newtab==2;
         set(controls.frame3tab1,'Visible','on');
         set(controls.frame3tab2,'Visible','off');
         set(controls.frame3tab3,'Visible','on');
         set(controls.frame3tab4,'Visible','on');
         set(controls.frame3tab5,'Visible','on');
         set(controls.frame1tab2,'Position',[85.4 380 76.4 11]);
         set(controls.frame1tab3,'Position',[161.8 380 74.4 11]);
         set(controls.frame1tab4,'Position',[237.2 380 74.4 11]);
         set(controls.frame1tab5,'Position',[312.6 380 74.4 11]);
         set(controls.tab1,'Position',[11 388 74.4 23]);
         set(controls.tab2,'Position',[85.4 388 76.4 25]);
         set(controls.tab3,'Position',[161.8 388 74.4 23]);
         set(controls.tab4,'Position',[237.2 388 74.4 23]);
         set(controls.tab5,'Position',[312.6 388 74.4 23]);
         set(controls.tab1axes11,'Visible','off');
         set(controls.tab1axes12,'Visible','off');
         set(controls.tab1axes13,'Visible','off');
         set(controls.tab1axes14,'Visible','off');
         set(controls.tab1axes15,'Visible','off');
         set(controls.tab1axes16,'Visible','off');
         set(controls.tab1axes17,'Visible','off');
         set(controls.tab1axes18,'Visible','off');
         set(controls.tab1axes1text,'Visible','off');
         if matlabnumber>=6.0;
            set(controls.tab1axes19,'Visible','off');
            set(controls.tab1axes110,'Visible','off');
         end;
         set(controls.tab9axes11,'Visible','off');
         set(controls.tab9axes12,'Visible','off');
         set(controls.tab9axes13,'Visible','off');
         set(controls.tab9axes14,'Visible','off');
         set(controls.tab9axes15,'Visible','off');
         set(controls.tab9axes16,'Visible','off');
         set(controls.tab9axes17,'Visible','off');
         set(controls.tab9axes18,'Visible','off');
         set(controls.tab9axes1text,'Visible','off');
         if matlabnumber>=6.0;
            set(controls.tab9axes19,'Visible','off');
            set(controls.tab9axes110,'Visible','off');
         end;
         set(controls.texoutputtext,'Visible','off');
         set(controls.texoutput,'Visible','off');
         set(controls.exportdatatext,'Visible','off');
         set(controls.exportdata,'Visible','off');
         set(controls.decimalstext,'Visible','off');
         set(controls.decimals,'Visible','off');
         set(controls.pdfversion,'Visible','off');
         set(controls.pdfversiontext,'Visible','off');
         set(controls.outofsample,'Visible','off');
         set(controls.forecasthorizon,'Visible','off');
         set(controls.forecasthorizontext,'Visible','off');
         if strcmp(get(controls.tab2,'String'),'Estimation');
            controls.current = 'Estimation';
            set(controls.latextext,'Visible','off');
            if strcmp(get(controls.latexedit,'Type'),'uicontrol')==1;
               set(controls.latexedit,'Visible','off');
            else;
               editbox(controls.latexedit,'Visible','off');
            end;
            set(controls.latexbutton,'Visible','off');
            set(controls.dviviewertext,'Visible','off');
            if strcmp(get(controls.dvivieweredit,'Type'),'uicontrol')==1;
               set(controls.dvivieweredit,'Visible','off');
            else;
               editbox(controls.dvivieweredit,'Visible','off');
            end;
            set(controls.dviviewerbutton,'Visible','off');
            set(controls.distillertext,'Visible','off');
            if strcmp(get(controls.distilleredit,'Type'),'uicontrol')==1;
               set(controls.distilleredit,'Visible','off');
            else;
               editbox(controls.distilleredit,'Visible','off');
            end;
            set(controls.distillerbutton,'Visible','off');
            set(controls.psviewertext,'Visible','off');
            if strcmp(get(controls.psvieweredit,'Type'),'uicontrol')==1;
               set(controls.psvieweredit,'Visible','off');
            else;
               editbox(controls.psvieweredit,'Visible','off');
            end;
            set(controls.psviewerbutton,'Visible','off');
            set(controls.pdfviewertext,'Visible','off');
            if strcmp(get(controls.pdfvieweredit,'Type'),'uicontrol')==1;
               set(controls.pdfvieweredit,'Visible','off');
            else;
               editbox(controls.pdfvieweredit,'Visible','off');
            end;
            set(controls.pdfviewerbutton,'Visible','off');
            set(controls.dvipdfm,'Visible','off');
            if isfield(controls,'maximizeviewer')==1;
               set(controls.maximizeviewer,'Visible','off');
            end;
            set(controls.maxittext,'Visible','on');
            set(controls.maxit,'Visible','on');
            set(controls.convcrittext,'Visible','on');
            set(controls.convcrit,'Visible','on');
            set(controls.method1,'Visible','on');
            set(controls.method2,'Visible','on');
            set(controls.method3,'Visible','on');
            set(controls.identify,'Visible','on');
            set(controls.identifytext,'Visible','on');
            set(controls.tab2axes11,'Visible','on');
            set(controls.tab2axes12,'Visible','on');
            set(controls.tab2axes13,'Visible','on');
            set(controls.tab2axes14,'Visible','on');
            set(controls.tab2axes15,'Visible','on');
            set(controls.tab2axes16,'Visible','on');
            set(controls.tab2axes17,'Visible','on');
            set(controls.tab2axes18,'Visible','on');
            set(controls.tab2axes21,'Visible','on');
            set(controls.tab2axes22,'Visible','on');
            set(controls.tab2axes23,'Visible','on');
            set(controls.tab2axes24,'Visible','on');
            set(controls.tab2axes25,'Visible','on');
            set(controls.tab2axes26,'Visible','on');
            set(controls.tab2axes27,'Visible','on');
            set(controls.tab2axes28,'Visible','on');
            set(controls.tab2axes2text,'Visible','on');
            set(controls.tab2axes1text,'Visible','on');
            set(controls.tab2axes31,'Visible','on');
            set(controls.tab2axes32,'Visible','on');
            set(controls.tab2axes33,'Visible','on');
            set(controls.tab2axes34,'Visible','on');
            set(controls.tab2axes35,'Visible','on');
            set(controls.tab2axes36,'Visible','on');
            set(controls.tab2axes37,'Visible','on');
            set(controls.tab2axes38,'Visible','on');
            set(controls.tab2axes3text,'Visible','on');
            if matlabnumber>=6.0;
               set(controls.tab2axes19,'Visible','on');
               set(controls.tab2axes110,'Visible','on');
               set(controls.tab2axes29,'Visible','on');
               set(controls.tab2axes210,'Visible','on');
               set(controls.tab2axes39,'Visible','on');
               set(controls.tab2axes310,'Visible','on');
            end;
            set(controls.maxlagtext,'Visible','on');
            set(controls.maxlag,'Visible','on');
            set(controls.tracebart,'Visible','off');
            set(controls.betagrad,'Visible','off');
            set(controls.rahbek,'Visible','off');
            set(controls.reestbeta,'Visible','off');
            set(controls.normbeta,'Visible','off');
            set(controls.decompose_det,'Visible','off');
            set(controls.weakexo,'Visible','off');
            set(controls.commoncycles,'Visible','off');
            set(controls.excludestat,'Visible','off');
            set(controls.critvaltext,'Visible','off');
            set(controls.critval,'Visible','off');
         elseif strcmp(get(controls.tab2,'String'),'Cointegration')==1;
            controls.current = 'Cointegration';
            set(controls.latextext,'Visible','off');
            if strcmp(get(controls.latexedit,'Type'),'uicontrol')==1;
               set(controls.latexedit,'Visible','off');
            else;
               editbox(controls.latexedit,'Visible','off');
            end;
            set(controls.latexbutton,'Visible','off');
            set(controls.dviviewertext,'Visible','off');
            if strcmp(get(controls.dvivieweredit,'Type'),'uicontrol')==1;
               set(controls.dvivieweredit,'Visible','off');
            else;
               editbox(controls.dvivieweredit,'Visible','off');
            end;
            set(controls.dviviewerbutton,'Visible','off');
            set(controls.distillertext,'Visible','off');
            if strcmp(get(controls.distilleredit,'Type'),'uicontrol')==1;
               set(controls.distilleredit,'Visible','off');
            else;
               editbox(controls.distilleredit,'Visible','off');
            end;
            set(controls.distillerbutton,'Visible','off');
            set(controls.psviewertext,'Visible','off');
            if strcmp(get(controls.psvieweredit,'Type'),'uicontrol')==1;
               set(controls.psvieweredit,'Visible','off');
            else;
               editbox(controls.psvieweredit,'Visible','off');
            end;
            set(controls.psviewerbutton,'Visible','off');
            set(controls.pdfviewertext,'Visible','off');
            if strcmp(get(controls.pdfvieweredit,'Type'),'uicontrol')==1;
               set(controls.pdfvieweredit,'Visible','off');
            else;
               editbox(controls.pdfvieweredit,'Visible','off');
            end;
            set(controls.pdfviewerbutton,'Visible','off');
            set(controls.dvipdfm,'Visible','off');
            if isfield(controls,'maximizeviewer')==1;
               set(controls.maximizeviewer,'Visible','off');
            end;
            set(controls.maxittext,'Visible','off');
            set(controls.maxit,'Visible','off');
            set(controls.convcrittext,'Visible','off');
            set(controls.convcrit,'Visible','off');
            set(controls.method1,'Visible','off');
            set(controls.method2,'Visible','off');
            set(controls.method3,'Visible','off');
            set(controls.identify,'Visible','off');
            set(controls.identifytext,'Visible','off');
            set(controls.tab2axes11,'Visible','off');
            set(controls.tab2axes12,'Visible','off');
            set(controls.tab2axes13,'Visible','off');
            set(controls.tab2axes14,'Visible','off');
            set(controls.tab2axes15,'Visible','off');
            set(controls.tab2axes16,'Visible','off');
            set(controls.tab2axes17,'Visible','off');
            set(controls.tab2axes18,'Visible','off');
            set(controls.tab2axes21,'Visible','off');
            set(controls.tab2axes22,'Visible','off');
            set(controls.tab2axes23,'Visible','off');
            set(controls.tab2axes24,'Visible','off');
            set(controls.tab2axes25,'Visible','off');
            set(controls.tab2axes26,'Visible','off');
            set(controls.tab2axes27,'Visible','off');
            set(controls.tab2axes28,'Visible','off');
            set(controls.tab2axes2text,'Visible','off');
            set(controls.tab2axes1text,'Visible','off');
            set(controls.tab2axes31,'Visible','off');
            set(controls.tab2axes32,'Visible','off');
            set(controls.tab2axes33,'Visible','off');
            set(controls.tab2axes34,'Visible','off');
            set(controls.tab2axes35,'Visible','off');
            set(controls.tab2axes36,'Visible','off');
            set(controls.tab2axes37,'Visible','off');
            set(controls.tab2axes38,'Visible','off');
            set(controls.tab2axes3text,'Visible','off');
            if matlabnumber>=6.0;
               set(controls.tab2axes19,'Visible','off');
               set(controls.tab2axes110,'Visible','off');
               set(controls.tab2axes29,'Visible','off');
               set(controls.tab2axes210,'Visible','off');
               set(controls.tab2axes39,'Visible','off');
               set(controls.tab2axes310,'Visible','off');
            end;
            set(controls.maxlagtext,'Visible','off');
            set(controls.maxlag,'Visible','off');
            set(controls.tab1axes11,'Visible','on');
            set(controls.tab1axes12,'Visible','on');
            set(controls.tab1axes13,'Visible','on');
            set(controls.tab1axes14,'Visible','on');
            set(controls.tab1axes15,'Visible','on');
            set(controls.tab1axes16,'Visible','on');
            set(controls.tab1axes17,'Visible','on');
            set(controls.tab1axes18,'Visible','on');
            set(controls.tab1axes1text,'Visible','on');
            if matlabnumber>=6.0;
               set(controls.tab1axes19,'Visible','on');
               set(controls.tab1axes110,'Visible','on');
            end;
            set(controls.tracebart,'Visible','on');
            set(controls.betagrad,'Visible','on');
            set(controls.rahbek,'Visible','on');
            set(controls.reestbeta,'Visible','on');
            set(controls.normbeta,'Visible','on');
            set(controls.decompose_det,'Visible','on');
            set(controls.weakexo,'Visible','on');
            set(controls.commoncycles,'Visible','on');
            set(controls.excludestat,'Visible','on');
            set(controls.critvaltext,'Visible','on');
            set(controls.critval,'Visible','on');
         else;
            controls.current = 'TeX';
            set(controls.tab9axes11,'Visible','on');
            set(controls.tab9axes12,'Visible','on');
            set(controls.tab9axes13,'Visible','on');
            set(controls.tab9axes14,'Visible','on');
            set(controls.tab9axes15,'Visible','on');
            set(controls.tab9axes16,'Visible','on');
            set(controls.tab9axes17,'Visible','on');
            set(controls.tab9axes18,'Visible','on');
            set(controls.tab9axes1text,'Visible','on');
            if matlabnumber>=6.0;
               set(controls.tab9axes19,'Visible','on');
               set(controls.tab9axes110,'Visible','on');
            end;
            set(controls.maxittext,'Visible','off');
            set(controls.maxit,'Visible','off');
            set(controls.convcrittext,'Visible','off');
            set(controls.convcrit,'Visible','off');
            set(controls.method1,'Visible','off');
            set(controls.method2,'Visible','off');
            set(controls.method3,'Visible','off');
            set(controls.identify,'Visible','off');
            set(controls.identifytext,'Visible','off');
            set(controls.tab2axes11,'Visible','off');
            set(controls.tab2axes12,'Visible','off');
            set(controls.tab2axes13,'Visible','off');
            set(controls.tab2axes14,'Visible','off');
            set(controls.tab2axes15,'Visible','off');
            set(controls.tab2axes16,'Visible','off');
            set(controls.tab2axes17,'Visible','off');
            set(controls.tab2axes18,'Visible','off');
            set(controls.tab2axes21,'Visible','off');
            set(controls.tab2axes22,'Visible','off');
            set(controls.tab2axes23,'Visible','off');
            set(controls.tab2axes24,'Visible','off');
            set(controls.tab2axes25,'Visible','off');
            set(controls.tab2axes26,'Visible','off');
            set(controls.tab2axes27,'Visible','off');
            set(controls.tab2axes28,'Visible','off');
            set(controls.tab2axes2text,'Visible','off');
            set(controls.tab2axes1text,'Visible','off');
            set(controls.tab2axes31,'Visible','off');
            set(controls.tab2axes32,'Visible','off');
            set(controls.tab2axes33,'Visible','off');
            set(controls.tab2axes34,'Visible','off');
            set(controls.tab2axes35,'Visible','off');
            set(controls.tab2axes36,'Visible','off');
            set(controls.tab2axes37,'Visible','off');
            set(controls.tab2axes38,'Visible','off');
            set(controls.tab2axes3text,'Visible','off');
            if matlabnumber>=6.0;
               set(controls.tab2axes19,'Visible','off');
               set(controls.tab2axes110,'Visible','off');
               set(controls.tab2axes29,'Visible','off');
               set(controls.tab2axes210,'Visible','off');
               set(controls.tab2axes39,'Visible','off');
               set(controls.tab2axes310,'Visible','off');
            end;
            set(controls.maxlagtext,'Visible','off');
            set(controls.maxlag,'Visible','off');
            set(controls.tab1axes11,'Visible','off');
            set(controls.tab1axes12,'Visible','off');
            set(controls.tab1axes13,'Visible','off');
            set(controls.tab1axes14,'Visible','off');
            set(controls.tab1axes15,'Visible','off');
            set(controls.tab1axes16,'Visible','off');
            set(controls.tab1axes17,'Visible','off');
            set(controls.tab1axes18,'Visible','off');
            set(controls.tab1axes1text,'Visible','off');
            if matlabnumber>=6.0;
               set(controls.tab1axes19,'Visible','off');
               set(controls.tab1axes110,'Visible','off');
            end;
            set(controls.tracebart,'Visible','off');
            set(controls.betagrad,'Visible','off');
            set(controls.rahbek,'Visible','off');
            set(controls.reestbeta,'Visible','off');
            set(controls.normbeta,'Visible','off');
            set(controls.commoncycles,'Visible','off');
            set(controls.excludestat,'Visible','off');
            set(controls.decompose_det,'Visible','off');
            set(controls.weakexo,'Visible','off');
            set(controls.critvaltext,'Visible','off');
            set(controls.critval,'Visible','off');
            set(controls.latextext,'Visible','on');
            if strcmp(get(controls.latexedit,'Type'),'uicontrol')==1;
               set(controls.latexedit,'Visible','on');
            else;
               editbox(controls.latexedit,'Visible','on');
            end;
            set(controls.latexbutton,'Visible','on');
            set(controls.dviviewertext,'Visible','on');
            if strcmp(get(controls.dvivieweredit,'Type'),'uicontrol')==1;
               set(controls.dvivieweredit,'Visible','on');
            else;
               editbox(controls.dvivieweredit,'Visible','on');
            end;
            set(controls.dviviewerbutton,'Visible','on');
            set(controls.distillertext,'Visible','on');
            if strcmp(get(controls.distilleredit,'Type'),'uicontrol')==1;
               set(controls.distilleredit,'Visible','on');
            else;
               editbox(controls.distilleredit,'Visible','on');
            end;
            set(controls.distillerbutton,'Visible','on');
            set(controls.psviewertext,'Visible','on');
            if strcmp(get(controls.psvieweredit,'Type'),'uicontrol')==1;
               set(controls.psvieweredit,'Visible','on');
            else;
               editbox(controls.psvieweredit,'Visible','on');
            end;
            set(controls.psviewerbutton,'Visible','on');
            set(controls.pdfviewertext,'Visible','on');
            if strcmp(get(controls.pdfvieweredit,'Type'),'uicontrol')==1;
               set(controls.pdfvieweredit,'Visible','on');
            else;
               editbox(controls.pdfvieweredit,'Visible','on');
            end;
            set(controls.pdfviewerbutton,'Visible','on');
            set(controls.dvipdfm,'Visible','on');
            if isfield(controls,'maximizeviewer')==1;
               set(controls.maximizeviewer,'Visible','on');
            end;
         end;
         set(controls.openvar,'Visible','off');
         set(controls.dirstructure,'Visible','off');
         set(controls.geometry,'Visible','off');
         set(controls.uselastfile,'Visible','off');
         set(controls.startrun,'Visible','off');
         set(controls.logtab,'Visible','off');
         set(controls.clearlog,'Visible','off');
         set(controls.openmyoutput,'Visible','off');
         set(controls.noprint,'Visible','off');
         set(controls.sillyq,'Visible','off');
         set(controls.editcontext,'Visible','off');
         set(controls.toolbar_bgcolor,'Visible','off');
         set(controls.gui_colors,'Visible','off');
         set(controls.text_colors,'Visible','off');
         set(controls.frame_colors,'Visible','off');
         set(controls.gui_fontbutton,'Visible','off');
         set(controls.gui_font,'Visible','off');
         set(controls.external,'Visible','off');
         set(controls.xgrid,'Visible','off');
         set(controls.ygrid,'Visible','off');
         set(controls.zgrid,'Visible','off');
         set(controls.box,'Visible','off');
         set(controls.colors,'Visible','off');
         set(controls.zbuffer,'Visible','off');
         set(controls.ytick,'Visible','off');
         set(controls.xtick,'Visible','off');
         set(controls.axesfont,'Visible','off');
         set(controls.titlefont,'Visible','off');
         set(controls.labelfont,'Visible','off');
         set(controls.axescolor,'Visible','off');
         set(controls.titlecolor,'Visible','off');
         set(controls.labelcolor,'Visible','off');
         set(controls.append,'Visible','off');
         set(controls.fonttext,'Visible','off');
         set(controls.default_colors,'Visible','off');
         set(controls.pagesetup,'Visible','off');
         set(controls.graphicsfmttext,'Visible','off');
         set(controls.graphicsfmt,'Visible','off');
         set(controls.tab3axes11,'Visible','off');
         set(controls.tab3axes12,'Visible','off');
         set(controls.tab3axes13,'Visible','off');
         set(controls.tab3axes14,'Visible','off');
         set(controls.tab3axes15,'Visible','off');
         set(controls.tab3axes16,'Visible','off');
         set(controls.tab3axes17,'Visible','off');
         set(controls.tab3axes18,'Visible','off');
         set(controls.tab3axes1text,'Visible','off');
         if matlabnumber>=6.0;
            set(controls.tab3axes19,'Visible','off');
            set(controls.tab3axes110,'Visible','off');
         end;
         set(controls.sscorrect,'Visible','off');
         set(controls.bartserial,'Visible','off');
         set(controls.portmanteau,'Visible','off');
         set(controls.lbcorrect,'Visible','off');
         set(controls.omnibus,'Visible','off');
         set(controls.transeig,'Visible','off');
         set(controls.fluctest,'Visible','off');
         set(controls.nyblom,'Visible','off');
         set(controls.nyblombeta,'Visible','off');
         set(controls.taylor_nyblom,'Visible','off');
         set(controls.fullrec,'Visible','off');
         set(controls.chowfc,'Visible','off');
         set(controls.chow,'Visible','off');
         set(controls.recalpha,'Visible','off');
         set(controls.recpi,'Visible','off');
         set(controls.rectrace,'Visible','off');
         set(controls.topeig,'Visible','off');
         set(controls.extraccrit,'Visible','off');
         set(controls.parametric,'Visible','off');
         set(controls.blocktext,'Visible','off');
         set(controls.blocksize,'Visible','off');
         set(controls.bootstrap,'Visible','off');
         set(controls.symmetric,'Visible','off');
         set(controls.akaike,'Visible','off');
         set(controls.restat,'Visible','off');
         set(controls.dummytests,'Visible','off');
         set(controls.rest_march,'Visible','off');
         set(controls.shortdyn,'Visible','off');
         set(controls.gctest,'Visible','off');
         set(controls.excludediffs,'Visible','off');
         set(controls.lstrtest,'Visible','off');
         set(controls.noise_parm,'Visible','off');
         set(controls.noise_parmtxt,'Visible','off');
         set(controls.ms_maxlag,'Visible','off');
         set(controls.ms_maxlagtext,'Visible','off');
         set(controls.lagtest,'Visible','off');
         set(controls.lagtesttext,'Visible','off');
         set(controls.recursivetext,'Visible','off');
         set(controls.recursive,'Visible','off');
         editbox(controls.texheader,'Visible','off');
         set(controls.texheaderbutton,'Visible','off');
         set(controls.texheadertext,'Visible','off');
         set(controls.tab4axes11,'Visible','off');
         set(controls.tab4axes12,'Visible','off');
         set(controls.tab4axes13,'Visible','off');
         set(controls.tab4axes14,'Visible','off');
         set(controls.tab4axes15,'Visible','off');
         set(controls.tab4axes16,'Visible','off');
         set(controls.tab4axes17,'Visible','off');
         set(controls.tab4axes18,'Visible','off');
         set(controls.tab4axes1text,'Visible','off');
         if matlabnumber>=6.0;
            set(controls.tab4axes19,'Visible','off');
            set(controls.tab4axes110,'Visible','off');
         end;
         set(controls.tab4axes21,'Visible','off');
         set(controls.tab4axes22,'Visible','off');
         set(controls.tab4axes23,'Visible','off');
         set(controls.tab4axes24,'Visible','off');
         set(controls.tab4axes25,'Visible','off');
         set(controls.tab4axes26,'Visible','off');
         set(controls.tab4axes27,'Visible','off');
         set(controls.tab4axes28,'Visible','off');
         set(controls.tab4axes2text,'Visible','off');
         if matlabnumber>=6.0;
            set(controls.tab4axes29,'Visible','off');
            set(controls.tab4axes210,'Visible','off');
         end;
         set(controls.bayes_mcmc,'Visible','off');
         set(controls.bayes_prior,'Visible','off');
         set(controls.aiviewertext,'Visible','off');
         if strcmp(get(controls.aivieweredit,'Type'),'uicontrol')==1;
            set(controls.aivieweredit,'Visible','off');
         else;
            editbox(controls.aivieweredit,'Visible','off');
         end;
         set(controls.aiviewerbutton,'Visible','off');
         set(controls.epsviewertext,'Visible','off');
         if strcmp(get(controls.epsvieweredit,'Type'),'uicontrol')==1;
            set(controls.epsvieweredit,'Visible','off');
         else;
            editbox(controls.epsvieweredit,'Visible','off');
         end;
         set(controls.epsviewerbutton,'Visible','off');
         set(controls.bitmapviewertext,'Visible','off');
         if strcmp(get(controls.bitmapvieweredit,'Type'),'uicontrol')==1;
            set(controls.bitmapvieweredit,'Visible','off');
         else;
            editbox(controls.bitmapvieweredit,'Visible','off');
         end;
         set(controls.bitmapviewerbutton,'Visible','off');
         set(controls.editortext,'Visible','off');
         if strcmp(get(controls.editoredit,'Type'),'uicontrol')==1;
            set(controls.editoredit,'Visible','off');
         else;
            editbox(controls.editoredit,'Visible','off');
         end;
         set(controls.editorbutton,'Visible','off');
         set(controls.helpexetext,'Visible','off');
         if strcmp(get(controls.helpexeedit,'Type'),'uicontrol')==1;
            set(controls.helpexeedit,'Visible','off');
         else;
            editbox(controls.helpexeedit,'Visible','off');
         end;
         if ispc==0;
            set(controls.helpexebutton,'Visible','off');
         end;
         set(controls.txtprinttext,'Visible','off');
         if strcmp(get(controls.txtprintedit,'Type'),'uicontrol')==1;
            set(controls.txtprintedit,'Visible','off');
         else;
            editbox(controls.txtprintedit,'Visible','off');
         end;
         set(controls.txtprintbutton,'Visible','off');
         set(controls.txtprintcmdtext,'Visible','off');
         set(controls.txtprintcmdedit,'Visible','off');
         if ispc==1;
            set(controls.txtprintrun,'Visible','off');
         end;
         if iscompiled==1;
            set(controls.psprinttext,'Visible','off');
            if strcmp(get(controls.psprintedit,'Type'),'uicontrol')==1;
               set(controls.psprintedit,'Visible','off');
            else;
               editbox(controls.psprintedit,'Visible','off');
            end;
            set(controls.psprintbutton,'Visible','off');
            set(controls.psprintcmdtext,'Visible','off');
            set(controls.psprintcmdedit,'Visible','off');
            set(controls.ghostscripttext,'Visible','off');
            if strcmp(get(controls.ghostscriptedit,'Type'),'uicontrol')==1;
               set(controls.ghostscriptedit,'Visible','off');
            else;
               editbox(controls.ghostscriptedit,'Visible','off');
            end;
            set(controls.ghostscriptbutton,'Visible','off');
            set(controls.pstoedittext,'Visible','off');
            if strcmp(get(controls.pstoeditedit,'Type'),'uicontrol')==1;
               set(controls.pstoeditedit,'Visible','off');
            else;
               editbox(controls.pstoeditedit,'Visible','off');
            end;
            set(controls.pstoeditbutton,'Visible','off');
         end;
         set(controls.maxresptext,'Visible','off');
         set(controls.maxresp,'Visible','off');
         set(controls.save_freqtext,'Visible','off');
         set(controls.save_freq,'Visible','off');
         set(controls.discard_explosive,'Visible','off');
         set(controls.bad_draws,'Visible','off');
         set(controls.lambda_paramtext,'Visible','off');
         set(controls.lambda_param,'Visible','off');
         set(controls.lambda_inf_shortrun,'Visible','off');
         set(controls.lambda_dtext,'Visible','off');
         set(controls.lambda_d,'Visible','off');
         set(controls.lambda_inf_deter,'Visible','off');
         set(controls.lambda_alphatext,'Visible','off');
         set(controls.lambda_alpha,'Visible','off');
         set(controls.lambda_inf_alpha,'Visible','off');
         set(controls.lambda_omegatext,'Visible','off');
         set(controls.lambda_inf_omega,'Visible','off');
         set(controls.lambda_omega,'Visible','off');
         set(controls.burn_intext,'Visible','off');
         set(controls.burn_in,'Visible','off');
         set(controls.save_drawstext,'Visible','off');
         set(controls.save_draws,'Visible','off');
         set(controls.pstoolsdirtext,'Visible','off');
         if strcmp(get(controls.pstoolsdiredit,'Type'),'uicontrol')==1;
            set(controls.pstoolsdiredit,'Visible','off');
         else;
            editbox(controls.pstoolsdiredit,'Visible','off');
         end;
         set(controls.pstoolsdirbutton,'Visible','off');
         set(controls.loadicon,'Visible','off');
         set(controls.noicon,'Visible','off');
         set(controls.show_undo,'Visible','off');
         set(controls.browsedialog,'Visible','off');
         set(controls.opendialog,'Visible','off');
         set(controls.loadguiicon,'Visible','off');
         set(controls.delaytext,'Visible','off');
         set(controls.delay,'Visible','off');
         set(controls.tempdirtext,'Visible','off');
         if strcmp(get(controls.tempdiredit,'Type'),'uicontrol')==1;
            set(controls.tempdiredit,'Visible','off');
         else;
            editbox(controls.tempdiredit,'Visible','off');
         end;
         set(controls.tempdirbutton,'Visible','off');
         set(controls.delete_text,'Visible','off');
         set(controls.delete_matfile,'Visible','off');
         set(controls.delete_txtfile,'Visible','off');
         set(controls.delete_mfile,'Visible','off');
         set(controls.rstate,'Visible','off');
         set(controls.rstatetext,'Visible','off');
         set(controls.nRep,'Visible','off');
         set(controls.nReptext,'Visible','off');
         set(controls.nDraw,'Visible','off');
         set(controls.nDrawtext,'Visible','off');
         set(controls.interpolate,'Visible','off');
         set(controls.interpolatetext,'Visible','off');
         set(controls.simulatedirtext,'Visible','off');
         if strcmp(get(controls.simulatediredit,'Type'),'uicontrol')==1;
            set(controls.simulatediredit,'Visible','off');
         else;
            editbox(controls.simulatediredit,'Visible','off');
         end;
         set(controls.simulatedirbutton,'Visible','off');
      elseif newtab==3;
         set(controls.frame3tab1,'Visible','on');
         set(controls.frame3tab2,'Visible','on');
         set(controls.frame3tab3,'Visible','off');
         set(controls.frame3tab4,'Visible','on');
         set(controls.frame3tab5,'Visible','on');
         set(controls.frame1tab2,'Position',[86.4 380 74.4 11]);
         set(controls.frame1tab3,'Position',[160.8 380 76.4 11]);
         set(controls.frame1tab4,'Position',[237.2 380 74.4 11]);
         set(controls.frame1tab5,'Position',[312.6 380 74.4 11]);
         set(controls.tab1,'Position',[11 388 74.4 23]);
         set(controls.tab2,'Position',[86.4 388 74.4 23]);
         set(controls.tab3,'Position',[160.8 388 76.4 25]);
         set(controls.tab4,'Position',[237.2 388 74.4 23]);
         set(controls.tab5,'Position',[312.6 388 74.4 23]);
         set(controls.tab1axes11,'Visible','off');
         set(controls.tab1axes12,'Visible','off');
         set(controls.tab1axes13,'Visible','off');
         set(controls.tab1axes14,'Visible','off');
         set(controls.tab1axes15,'Visible','off');
         set(controls.tab1axes16,'Visible','off');
         set(controls.tab1axes17,'Visible','off');
         set(controls.tab1axes18,'Visible','off');
         set(controls.tab1axes1text,'Visible','off');
         if matlabnumber>=6.0;
            set(controls.tab1axes19,'Visible','off');
            set(controls.tab1axes110,'Visible','off');
         end;
         set(controls.tab9axes11,'Visible','off');
         set(controls.tab9axes12,'Visible','off');
         set(controls.tab9axes13,'Visible','off');
         set(controls.tab9axes14,'Visible','off');
         set(controls.tab9axes15,'Visible','off');
         set(controls.tab9axes16,'Visible','off');
         set(controls.tab9axes17,'Visible','off');
         set(controls.tab9axes18,'Visible','off');
         set(controls.tab9axes1text,'Visible','off');
         if matlabnumber>=6.0;
            set(controls.tab9axes19,'Visible','off');
            set(controls.tab9axes110,'Visible','off');
         end;
         set(controls.maxittext,'Visible','off');
         set(controls.maxit,'Visible','off');
         set(controls.convcrittext,'Visible','off');
         set(controls.convcrit,'Visible','off');
         set(controls.method1,'Visible','off');
         set(controls.method2,'Visible','off');
         set(controls.method3,'Visible','off');
         set(controls.identify,'Visible','off');
         set(controls.identifytext,'Visible','off');
         set(controls.tab2axes11,'Visible','off');
         set(controls.tab2axes12,'Visible','off');
         set(controls.tab2axes13,'Visible','off');
         set(controls.tab2axes14,'Visible','off');
         set(controls.tab2axes15,'Visible','off');
         set(controls.tab2axes16,'Visible','off');
         set(controls.tab2axes17,'Visible','off');
         set(controls.tab2axes18,'Visible','off');
         set(controls.tab2axes1text,'Visible','off');
         set(controls.tab2axes21,'Visible','off');
         set(controls.tab2axes22,'Visible','off');
         set(controls.tab2axes23,'Visible','off');
         set(controls.tab2axes24,'Visible','off');
         set(controls.tab2axes25,'Visible','off');
         set(controls.tab2axes26,'Visible','off');
         set(controls.tab2axes27,'Visible','off');
         set(controls.tab2axes28,'Visible','off');
         set(controls.tab2axes2text,'Visible','off');
         set(controls.tab2axes31,'Visible','off');
         set(controls.tab2axes32,'Visible','off');
         set(controls.tab2axes33,'Visible','off');
         set(controls.tab2axes34,'Visible','off');
         set(controls.tab2axes35,'Visible','off');
         set(controls.tab2axes36,'Visible','off');
         set(controls.tab2axes37,'Visible','off');
         set(controls.tab2axes38,'Visible','off');
         set(controls.tab2axes3text,'Visible','off');
         if matlabnumber>=6.0;
            set(controls.tab2axes19,'Visible','off');
            set(controls.tab2axes110,'Visible','off');
            set(controls.tab2axes29,'Visible','off');
            set(controls.tab2axes210,'Visible','off');
            set(controls.tab2axes39,'Visible','off');
            set(controls.tab2axes310,'Visible','off');
         end;
         set(controls.maxlagtext,'Visible','off');
         set(controls.maxlag,'Visible','off');
         set(controls.openvar,'Visible','off');
         set(controls.dirstructure,'Visible','off');
         set(controls.geometry,'Visible','off');
         set(controls.uselastfile,'Visible','off');
         set(controls.startrun,'Visible','off');
         set(controls.logtab,'Visible','off');
         set(controls.clearlog,'Visible','off');
         set(controls.openmyoutput,'Visible','off');
         set(controls.noprint,'Visible','off');
         set(controls.sillyq,'Visible','off');
         set(controls.external,'Visible','off');
         set(controls.editcontext,'Visible','off');
         set(controls.toolbar_bgcolor,'Visible','off');
         set(controls.gui_colors,'Visible','off');
         set(controls.text_colors,'Visible','off');
         set(controls.frame_colors,'Visible','off');
         set(controls.gui_fontbutton,'Visible','off');
         set(controls.gui_font,'Visible','off');
         set(controls.xgrid,'Visible','off');
         set(controls.ygrid,'Visible','off');
         set(controls.zgrid,'Visible','off');
         set(controls.box,'Visible','off');
         set(controls.colors,'Visible','off');
         set(controls.zbuffer,'Visible','off');
         set(controls.ytick,'Visible','off');
         set(controls.xtick,'Visible','off');
         set(controls.axesfont,'Visible','off');
         set(controls.titlefont,'Visible','off');
         set(controls.labelfont,'Visible','off');
         set(controls.axescolor,'Visible','off');
         set(controls.titlecolor,'Visible','off');
         set(controls.labelcolor,'Visible','off');
         set(controls.append,'Visible','off');
         set(controls.fonttext,'Visible','off');
         set(controls.default_colors,'Visible','off');
         set(controls.pagesetup,'Visible','off');
         set(controls.graphicsfmttext,'Visible','off');
         set(controls.graphicsfmt,'Visible','off');
         set(controls.tracebart,'Visible','off');
         set(controls.betagrad,'Visible','off');
         set(controls.rahbek,'Visible','off');
         set(controls.reestbeta,'Visible','off');
         set(controls.normbeta,'Visible','off');
         set(controls.decompose_det,'Visible','off');
         set(controls.weakexo,'Visible','off');
         set(controls.commoncycles,'Visible','off');
         set(controls.excludestat,'Visible','off');
         set(controls.critvaltext,'Visible','off');
         set(controls.critval,'Visible','off');
         set(controls.shortdyn,'Visible','off');
         set(controls.gctest,'Visible','off');
         set(controls.excludediffs,'Visible','off');
         set(controls.lstrtest,'Visible','off');
         set(controls.chow,'Visible','off');
         set(controls.outofsample,'Visible','off');
         set(controls.forecasthorizon,'Visible','off');
         set(controls.forecasthorizontext,'Visible','off');
         if strcmp(get(controls.tab3,'String'),'Statistics')==1;
            controls.current = 'Statistics';
            set(controls.tab3axes11,'Visible','on');
            set(controls.tab3axes12,'Visible','on');
            set(controls.tab3axes13,'Visible','on');
            set(controls.tab3axes14,'Visible','on');
            set(controls.tab3axes15,'Visible','on');
            set(controls.tab3axes16,'Visible','on');
            set(controls.tab3axes17,'Visible','on');
            set(controls.tab3axes18,'Visible','on');
            set(controls.tab3axes1text,'Visible','on');
            if matlabnumber>=6.0;
               set(controls.tab3axes19,'Visible','on');
               set(controls.tab3axes110,'Visible','on');
            end;
            set(controls.sscorrect,'Visible','on');
            set(controls.bartserial,'Visible','on');
            set(controls.portmanteau,'Visible','on');
            set(controls.lbcorrect,'Visible','on');
            set(controls.omnibus,'Visible','on');
            set(controls.akaike,'Visible','on');
            set(controls.restat,'Visible','on');
            set(controls.dummytests,'Visible','on');
            set(controls.rest_march,'Visible','on');
            set(controls.noise_parm,'Visible','on');
            set(controls.noise_parmtxt,'Visible','on');
            set(controls.ms_maxlag,'Visible','on');
            set(controls.ms_maxlagtext,'Visible','on');
            set(controls.lagtest,'Visible','on');
            set(controls.lagtesttext,'Visible','on');
            set(controls.transeig,'Visible','off');
            set(controls.fluctest,'Visible','off');
            set(controls.nyblom,'Visible','off');
            set(controls.nyblombeta,'Visible','off');
            set(controls.taylor_nyblom,'Visible','off');
            set(controls.fullrec,'Visible','off');
            set(controls.recalpha,'Visible','off');
            set(controls.recpi,'Visible','off');
            set(controls.rectrace,'Visible','off');
            set(controls.topeig,'Visible','off');
            set(controls.extraccrit,'Visible','off');
            set(controls.chowfc,'Visible','off');
            set(controls.recursivetext,'Visible','off');
            set(controls.recursive,'Visible','off');
            editbox(controls.texheader,'Visible','off');
            set(controls.texheaderbutton,'Visible','off');
            set(controls.texheadertext,'Visible','off');
         elseif strcmp(get(controls.tab3,'String'),'Recursion')==1;
            controls.current = 'Recursion';
            set(controls.tab3axes11,'Visible','off');
            set(controls.tab3axes12,'Visible','off');
            set(controls.tab3axes13,'Visible','off');
            set(controls.tab3axes14,'Visible','off');
            set(controls.tab3axes15,'Visible','off');
            set(controls.tab3axes16,'Visible','off');
            set(controls.tab3axes17,'Visible','off');
            set(controls.tab3axes18,'Visible','off');
            set(controls.tab3axes1text,'Visible','off');
            if matlabnumber>=6.0;
               set(controls.tab3axes19,'Visible','off');
               set(controls.tab3axes110,'Visible','off');
            end;
            set(controls.sscorrect,'Visible','off');
            set(controls.bartserial,'Visible','off');
            set(controls.portmanteau,'Visible','off');
            set(controls.lbcorrect,'Visible','off');
            set(controls.omnibus,'Visible','off');
            set(controls.akaike,'Visible','off');
            set(controls.restat,'Visible','off');
            set(controls.dummytests,'Visible','off');
            set(controls.rest_march,'Visible','off');
            set(controls.noise_parm,'Visible','off');
            set(controls.noise_parmtxt,'Visible','off');
            set(controls.ms_maxlag,'Visible','off');
            set(controls.ms_maxlagtext,'Visible','off');
            set(controls.lagtest,'Visible','off');
            set(controls.lagtesttext,'Visible','off');
            set(controls.tab1axes11,'Visible','on');
            set(controls.tab1axes12,'Visible','on');
            set(controls.tab1axes13,'Visible','on');
            set(controls.tab1axes14,'Visible','on');
            set(controls.tab1axes15,'Visible','on');
            set(controls.tab1axes16,'Visible','on');
            set(controls.tab1axes17,'Visible','on');
            set(controls.tab1axes18,'Visible','on');
            set(controls.tab1axes1text,'Visible','on');
            if matlabnumber>=6.0;
               set(controls.tab1axes19,'Visible','on');
               set(controls.tab1axes110,'Visible','on');
            end;
            set(controls.transeig,'Visible','on');
            set(controls.fluctest,'Visible','on');
            set(controls.nyblom,'Visible','on');
            set(controls.nyblombeta,'Visible','on');
            set(controls.taylor_nyblom,'Visible','on');
            set(controls.fullrec,'Visible','on');
            set(controls.chowfc,'Visible','on');
            set(controls.recalpha,'Visible','on');
            set(controls.recpi,'Visible','on');
            set(controls.rectrace,'Visible','on');
            set(controls.topeig,'Visible','on');
            set(controls.extraccrit,'Visible','on');
            set(controls.recursivetext,'Visible','on');
            set(controls.recursive,'Visible','on');
            editbox(controls.texheader,'Visible','off');
            set(controls.texheaderbutton,'Visible','off');
            set(controls.texheadertext,'Visible','off');
         else;
            controls.current = 'TeX Preamble';
            set(controls.tab3axes11,'Visible','off');
            set(controls.tab3axes12,'Visible','off');
            set(controls.tab3axes13,'Visible','off');
            set(controls.tab3axes14,'Visible','off');
            set(controls.tab3axes15,'Visible','off');
            set(controls.tab3axes16,'Visible','off');
            set(controls.tab3axes17,'Visible','off');
            set(controls.tab3axes18,'Visible','off');
            set(controls.tab3axes1text,'Visible','off');
            if matlabnumber>=6.0;
               set(controls.tab3axes19,'Visible','off');
               set(controls.tab3axes110,'Visible','off');
            end;
            set(controls.sscorrect,'Visible','off');
            set(controls.bartserial,'Visible','off');
            set(controls.portmanteau,'Visible','off');
            set(controls.lbcorrect,'Visible','off');
            set(controls.omnibus,'Visible','off');
            set(controls.akaike,'Visible','off');
            set(controls.restat,'Visible','off');
            set(controls.dummytests,'Visible','off');
            set(controls.rest_march,'Visible','off');
            set(controls.noise_parm,'Visible','off');
            set(controls.noise_parmtxt,'Visible','off');
            set(controls.ms_maxlag,'Visible','off');
            set(controls.ms_maxlagtext,'Visible','off');
            set(controls.lagtest,'Visible','off');
            set(controls.lagtesttext,'Visible','off');
            set(controls.tab1axes11,'Visible','on');
            set(controls.tab1axes12,'Visible','on');
            set(controls.tab1axes13,'Visible','on');
            set(controls.tab1axes14,'Visible','on');
            set(controls.tab1axes15,'Visible','on');
            set(controls.tab1axes16,'Visible','on');
            set(controls.tab1axes17,'Visible','on');
            set(controls.tab1axes18,'Visible','on');
            set(controls.tab1axes1text,'Visible','on');
            if matlabnumber>=6.0;
               set(controls.tab1axes19,'Visible','on');
               set(controls.tab1axes110,'Visible','on');
            end;
            set(controls.transeig,'Visible','off');
            set(controls.fluctest,'Visible','off');
            set(controls.nyblom,'Visible','off');
            set(controls.nyblombeta,'Visible','off');
            set(controls.taylor_nyblom,'Visible','off');
            set(controls.fullrec,'Visible','off');
            set(controls.chowfc,'Visible','off');
            set(controls.recalpha,'Visible','off');
            set(controls.recpi,'Visible','off');
            set(controls.rectrace,'Visible','off');
            set(controls.topeig,'Visible','off');
            set(controls.extraccrit,'Visible','off');
            set(controls.recursivetext,'Visible','off');
            set(controls.recursive,'Visible','off');
            editbox(controls.texheader,'Visible','on');
            set(controls.texheaderbutton,'Visible','on');
            set(controls.texheadertext,'Visible','on');
         end;
         set(controls.tab4axes11,'Visible','off');
         set(controls.tab4axes12,'Visible','off');
         set(controls.tab4axes13,'Visible','off');
         set(controls.tab4axes14,'Visible','off');
         set(controls.tab4axes15,'Visible','off');
         set(controls.tab4axes16,'Visible','off');
         set(controls.tab4axes17,'Visible','off');
         set(controls.tab4axes18,'Visible','off');
         set(controls.tab4axes1text,'Visible','off');
         if matlabnumber>=6.0;
            set(controls.tab4axes19,'Visible','off');
            set(controls.tab4axes110,'Visible','off');
         end;
         set(controls.tab4axes21,'Visible','off');
         set(controls.tab4axes22,'Visible','off');
         set(controls.tab4axes23,'Visible','off');
         set(controls.tab4axes24,'Visible','off');
         set(controls.tab4axes25,'Visible','off');
         set(controls.tab4axes26,'Visible','off');
         set(controls.tab4axes27,'Visible','off');
         set(controls.tab4axes28,'Visible','off');
         set(controls.tab4axes2text,'Visible','off');
         if matlabnumber>=6.0;
            set(controls.tab4axes29,'Visible','off');
            set(controls.tab4axes210,'Visible','off');
         end;
         set(controls.bayes_mcmc,'Visible','off');
         set(controls.bayes_prior,'Visible','off');
         set(controls.aiviewertext,'Visible','off');
         if strcmp(get(controls.aivieweredit,'Type'),'uicontrol')==1;
            set(controls.aivieweredit,'Visible','off');
         else;
            editbox(controls.aivieweredit,'Visible','off');
         end;
         set(controls.aiviewerbutton,'Visible','off');
         set(controls.epsviewertext,'Visible','off');
         if strcmp(get(controls.epsvieweredit,'Type'),'uicontrol')==1;
            set(controls.epsvieweredit,'Visible','off');
         else;
            editbox(controls.epsvieweredit,'Visible','off');
         end;
         set(controls.epsviewerbutton,'Visible','off');
         set(controls.bitmapviewertext,'Visible','off');
         if strcmp(get(controls.bitmapvieweredit,'Type'),'uicontrol')==1;
            set(controls.bitmapvieweredit,'Visible','off');
         else;
            editbox(controls.bitmapvieweredit,'Visible','off');
         end;
         set(controls.bitmapviewerbutton,'Visible','off');
         set(controls.editortext,'Visible','off');
         if strcmp(get(controls.editoredit,'Type'),'uicontrol')==1;
            set(controls.editoredit,'Visible','off');
         else;
            editbox(controls.editoredit,'Visible','off');
         end;
         set(controls.editorbutton,'Visible','off');
         set(controls.helpexetext,'Visible','off');
         if strcmp(get(controls.helpexeedit,'Type'),'uicontrol')==1;
            set(controls.helpexeedit,'Visible','off');
         else;
            editbox(controls.helpexeedit,'Visible','off');
         end;
         if ispc==0;
            set(controls.helpexebutton,'Visible','off');
         end;
         set(controls.txtprinttext,'Visible','off');
         if strcmp(get(controls.txtprintedit,'Type'),'uicontrol')==1;
            set(controls.txtprintedit,'Visible','off');
         else;
            editbox(controls.txtprintedit,'Visible','off');
         end;
         set(controls.txtprintbutton,'Visible','off');
         set(controls.latextext,'Visible','off');
         if strcmp(get(controls.latexedit,'Type'),'uicontrol')==1;
            set(controls.latexedit,'Visible','off');
         else;
            editbox(controls.latexedit,'Visible','off');
         end;
         set(controls.latexbutton,'Visible','off');
         set(controls.dviviewertext,'Visible','off');
         if strcmp(get(controls.dvivieweredit,'Type'),'uicontrol')==1;
            set(controls.dvivieweredit,'Visible','off');
         else;
            editbox(controls.dvivieweredit,'Visible','off');
         end;
         set(controls.dviviewerbutton,'Visible','off');
         set(controls.distillertext,'Visible','off');
         if strcmp(get(controls.distilleredit,'Type'),'uicontrol')==1;
            set(controls.distilleredit,'Visible','off');
         else;
            editbox(controls.distilleredit,'Visible','off');
         end;
         set(controls.distillerbutton,'Visible','off');
         set(controls.psviewertext,'Visible','off');
         if strcmp(get(controls.psvieweredit,'Type'),'uicontrol')==1;
            set(controls.psvieweredit,'Visible','off');
         else;
            editbox(controls.psvieweredit,'Visible','off');
         end;
         set(controls.psviewerbutton,'Visible','off');
         set(controls.pdfviewertext,'Visible','off');
         if strcmp(get(controls.pdfvieweredit,'Type'),'uicontrol')==1;
            set(controls.pdfvieweredit,'Visible','off');
         else;
            editbox(controls.pdfvieweredit,'Visible','off');
         end;
         set(controls.pdfviewerbutton,'Visible','off');
         set(controls.dvipdfm,'Visible','off');
         if isfield(controls,'maximizeviewer')==1;
            set(controls.maximizeviewer,'Visible','off');
         end;
         set(controls.texoutputtext,'Visible','off');
         set(controls.texoutput,'Visible','off');
         set(controls.exportdatatext,'Visible','off');
         set(controls.exportdata,'Visible','off');
         set(controls.decimalstext,'Visible','off');
         set(controls.decimals,'Visible','off');
         set(controls.pdfversion,'Visible','off');
         set(controls.pdfversiontext,'Visible','off');
         set(controls.txtprintcmdtext,'Visible','off');
         set(controls.txtprintcmdedit,'Visible','off');
         if ispc==1;
            set(controls.txtprintrun,'Visible','off');
         end;
         if iscompiled==1;
            set(controls.psprinttext,'Visible','off');
            if strcmp(get(controls.psprintedit,'Type'),'uicontrol')==1;
               set(controls.psprintedit,'Visible','off');
            else;
               editbox(controls.psprintedit,'Visible','off');
            end;
            set(controls.psprintbutton,'Visible','off');
            set(controls.psprintcmdtext,'Visible','off');
            set(controls.psprintcmdedit,'Visible','off');
            set(controls.ghostscripttext,'Visible','off');
            if strcmp(get(controls.ghostscriptedit,'Type'),'uicontrol')==1;
               set(controls.ghostscriptedit,'Visible','off');
            else;
               editbox(controls.ghostscriptedit,'Visible','off');
            end;
            set(controls.ghostscriptbutton,'Visible','off');
            set(controls.pstoedittext,'Visible','off');
            if strcmp(get(controls.pstoeditedit,'Type'),'uicontrol')==1;
               set(controls.pstoeditedit,'Visible','off');
            else;
               editbox(controls.pstoeditedit,'Visible','off');
            end;
            set(controls.pstoeditbutton,'Visible','off');
         end;
         set(controls.delete_text,'Visible','off');
         set(controls.delete_matfile,'Visible','off');
         set(controls.delete_txtfile,'Visible','off');
         set(controls.delete_mfile,'Visible','off');
         set(controls.rstate,'Visible','off');
         set(controls.rstatetext,'Visible','off');
         set(controls.parametric,'Visible','off');
         set(controls.blocktext,'Visible','off');
         set(controls.blocksize,'Visible','off');
         set(controls.bootstrap,'Visible','off');
         set(controls.symmetric,'Visible','off');
         set(controls.nRep,'Visible','off');
         set(controls.nReptext,'Visible','off');
         set(controls.nDraw,'Visible','off');
         set(controls.nDrawtext,'Visible','off');
         set(controls.interpolate,'Visible','off');
         set(controls.interpolatetext,'Visible','off');
         set(controls.maxresptext,'Visible','off');
         set(controls.maxresp,'Visible','off');
         set(controls.save_freqtext,'Visible','off');
         set(controls.save_freq,'Visible','off');
         set(controls.discard_explosive,'Visible','off');
         set(controls.bad_draws,'Visible','off');
         set(controls.lambda_paramtext,'Visible','off');
         set(controls.lambda_param,'Visible','off');
         set(controls.lambda_inf_shortrun,'Visible','off');
         set(controls.lambda_dtext,'Visible','off');
         set(controls.lambda_d,'Visible','off');
         set(controls.lambda_inf_deter,'Visible','off');
         set(controls.lambda_alphatext,'Visible','off');
         set(controls.lambda_alpha,'Visible','off');
         set(controls.lambda_inf_alpha,'Visible','off');
         set(controls.lambda_omegatext,'Visible','off');
         set(controls.lambda_inf_omega,'Visible','off');
         set(controls.lambda_omega,'Visible','off');
         set(controls.burn_intext,'Visible','off');
         set(controls.burn_in,'Visible','off');
         set(controls.save_drawstext,'Visible','off');
         set(controls.save_draws,'Visible','off');
         set(controls.pstoolsdirtext,'Visible','off');
         if strcmp(get(controls.pstoolsdiredit,'Type'),'uicontrol')==1;
            set(controls.pstoolsdiredit,'Visible','off');
         else;
            editbox(controls.pstoolsdiredit,'Visible','off');
         end;
         set(controls.pstoolsdirbutton,'Visible','off');
         set(controls.loadicon,'Visible','off');
         set(controls.noicon,'Visible','off');
         set(controls.show_undo,'Visible','off');
         set(controls.browsedialog,'Visible','off');
         set(controls.opendialog,'Visible','off');
         set(controls.loadguiicon,'Visible','off');
         set(controls.delaytext,'Visible','off');
         set(controls.delay,'Visible','off');
         set(controls.tempdirtext,'Visible','off');
         if strcmp(get(controls.tempdiredit,'Type'),'uicontrol')==1;
            set(controls.tempdiredit,'Visible','off');
         else;
            editbox(controls.tempdiredit,'Visible','off');
         end;
         set(controls.tempdirbutton,'Visible','off');
         set(controls.simulatedirtext,'Visible','off');
         if strcmp(get(controls.simulatediredit,'Type'),'uicontrol')==1;
            set(controls.simulatediredit,'Visible','off');
         else;
            editbox(controls.simulatediredit,'Visible','off');
         end;
         set(controls.simulatedirbutton,'Visible','off');
      elseif newtab==4;
         set(controls.frame3tab1,'Visible','on');
         set(controls.frame3tab2,'Visible','on');
         set(controls.frame3tab3,'Visible','on');
         set(controls.frame3tab4,'Visible','off');
         set(controls.frame3tab5,'Visible','on');
         set(controls.frame1tab2,'Position',[86.4 380 74.4 11]);
         set(controls.frame1tab3,'Position',[161.8 380 74.4 11]);
         set(controls.frame1tab4,'Position',[236.2 380 76.4 11]);
         set(controls.frame1tab5,'Position',[312.6 380 74.4 11]);
         set(controls.tab1,'Position',[11 388 74.4 23]);
         set(controls.tab2,'Position',[86.4 388 74.4 23]);
         set(controls.tab3,'Position',[161.8 388 74.4 23]);
         set(controls.tab4,'Position',[236.2 388 76.4 25]);
         set(controls.tab5,'Position',[312.6 388 74.4 23]);
         set(controls.tab1axes11,'Visible','off');
         set(controls.tab1axes12,'Visible','off');
         set(controls.tab1axes13,'Visible','off');
         set(controls.tab1axes14,'Visible','off');
         set(controls.tab1axes15,'Visible','off');
         set(controls.tab1axes16,'Visible','off');
         set(controls.tab1axes17,'Visible','off');
         set(controls.tab1axes18,'Visible','off');
         set(controls.tab1axes1text,'Visible','off');
         if matlabnumber>=6.0;
            set(controls.tab1axes19,'Visible','off');
            set(controls.tab1axes110,'Visible','off');
         end;
         set(controls.maxittext,'Visible','off');
         set(controls.maxit,'Visible','off');
         set(controls.convcrittext,'Visible','off');
         set(controls.convcrit,'Visible','off');
         set(controls.method1,'Visible','off');
         set(controls.method2,'Visible','off');
         set(controls.method3,'Visible','off');
         set(controls.identify,'Visible','off');
         set(controls.identifytext,'Visible','off');
         set(controls.tab2axes11,'Visible','off');
         set(controls.tab2axes12,'Visible','off');
         set(controls.tab2axes13,'Visible','off');
         set(controls.tab2axes14,'Visible','off');
         set(controls.tab2axes15,'Visible','off');
         set(controls.tab2axes16,'Visible','off');
         set(controls.tab2axes17,'Visible','off');
         set(controls.tab2axes18,'Visible','off');
         set(controls.tab2axes1text,'Visible','off');
         set(controls.tab2axes21,'Visible','off');
         set(controls.tab2axes22,'Visible','off');
         set(controls.tab2axes23,'Visible','off');
         set(controls.tab2axes24,'Visible','off');
         set(controls.tab2axes25,'Visible','off');
         set(controls.tab2axes26,'Visible','off');
         set(controls.tab2axes27,'Visible','off');
         set(controls.tab2axes28,'Visible','off');
         set(controls.tab2axes2text,'Visible','off');
         set(controls.tab2axes31,'Visible','off');
         set(controls.tab2axes32,'Visible','off');
         set(controls.tab2axes33,'Visible','off');
         set(controls.tab2axes34,'Visible','off');
         set(controls.tab2axes35,'Visible','off');
         set(controls.tab2axes36,'Visible','off');
         set(controls.tab2axes37,'Visible','off');
         set(controls.tab2axes38,'Visible','off');
         set(controls.tab2axes3text,'Visible','off');
         if matlabnumber>=6.0;
            set(controls.tab2axes19,'Visible','off');
            set(controls.tab2axes110,'Visible','off');
            set(controls.tab2axes29,'Visible','off');
            set(controls.tab2axes210,'Visible','off');
            set(controls.tab2axes39,'Visible','off');
            set(controls.tab2axes310,'Visible','off');
         end;
         set(controls.maxlagtext,'Visible','off');
         set(controls.maxlag,'Visible','off');
         set(controls.openvar,'Visible','off');
         set(controls.dirstructure,'Visible','off');
         set(controls.geometry,'Visible','off');
         set(controls.uselastfile,'Visible','off');
         set(controls.startrun,'Visible','off');
         set(controls.logtab,'Visible','off');
         set(controls.clearlog,'Visible','off');
         set(controls.sillyq,'Visible','off');
         set(controls.editcontext,'Visible','off');
         set(controls.toolbar_bgcolor,'Visible','off');
         set(controls.gui_colors,'Visible','off');
         set(controls.text_colors,'Visible','off');
         set(controls.frame_colors,'Visible','off');
         set(controls.gui_fontbutton,'Visible','off');
         set(controls.gui_font,'Visible','off');
         set(controls.external,'Visible','off');
         set(controls.xgrid,'Visible','off');
         set(controls.ygrid,'Visible','off');
         set(controls.zgrid,'Visible','off');
         set(controls.box,'Visible','off');
         set(controls.colors,'Visible','off');
         set(controls.zbuffer,'Visible','off');
         set(controls.ytick,'Visible','off');
         set(controls.xtick,'Visible','off');
         set(controls.axesfont,'Visible','off');
         set(controls.titlefont,'Visible','off');
         set(controls.labelfont,'Visible','off');
         set(controls.axescolor,'Visible','off');
         set(controls.titlecolor,'Visible','off');
         set(controls.labelcolor,'Visible','off');
         set(controls.fonttext,'Visible','off');
         set(controls.default_colors,'Visible','off');
         set(controls.pagesetup,'Visible','off');
         set(controls.graphicsfmttext,'Visible','off');
         set(controls.graphicsfmt,'Visible','off');
         set(controls.tab3axes11,'Visible','off');
         set(controls.tab3axes12,'Visible','off');
         set(controls.tab3axes13,'Visible','off');
         set(controls.tab3axes14,'Visible','off');
         set(controls.tab3axes15,'Visible','off');
         set(controls.tab3axes16,'Visible','off');
         set(controls.tab3axes17,'Visible','off');
         set(controls.tab3axes18,'Visible','off');
         set(controls.tab3axes1text,'Visible','off');
         if matlabnumber>=6.0;
            set(controls.tab3axes19,'Visible','off');
            set(controls.tab3axes110,'Visible','off');
         end;
         set(controls.bayes_mcmc,'Visible','off');
         set(controls.bayes_prior,'Visible','off');
         set(controls.sscorrect,'Visible','off');
         set(controls.bartserial,'Visible','off');
         set(controls.portmanteau,'Visible','off');
         set(controls.lbcorrect,'Visible','off');
         set(controls.omnibus,'Visible','off');
         set(controls.transeig,'Visible','off');
         set(controls.fluctest,'Visible','off');
         set(controls.nyblom,'Visible','off');
         set(controls.nyblombeta,'Visible','off');
         set(controls.taylor_nyblom,'Visible','off');
         set(controls.fullrec,'Visible','off');
         set(controls.chowfc,'Visible','off');
         set(controls.recalpha,'Visible','off');
         set(controls.recpi,'Visible','off');
         set(controls.rectrace,'Visible','off');
         set(controls.topeig,'Visible','off');
         set(controls.extraccrit,'Visible','off');
         set(controls.parametric,'Visible','off');
         set(controls.blocktext,'Visible','off');
         set(controls.blocksize,'Visible','off');
         set(controls.bootstrap,'Visible','off');
         set(controls.symmetric,'Visible','off');
         set(controls.akaike,'Visible','off');
         set(controls.restat,'Visible','off');
         set(controls.dummytests,'Visible','off');
         set(controls.rest_march,'Visible','off');
         set(controls.noise_parm,'Visible','off');
         set(controls.noise_parmtxt,'Visible','off');
         set(controls.ms_maxlag,'Visible','off');
         set(controls.ms_maxlagtext,'Visible','off');
         set(controls.lagtest,'Visible','off');
         set(controls.lagtesttext,'Visible','off');
         set(controls.recursivetext,'Visible','off');
         set(controls.recursive,'Visible','off');
         editbox(controls.texheader,'Visible','off');
         set(controls.texheaderbutton,'Visible','off');
         set(controls.texheadertext,'Visible','off');
         set(controls.tracebart,'Visible','off');
         set(controls.betagrad,'Visible','off');
         set(controls.rahbek,'Visible','off');
         set(controls.reestbeta,'Visible','off');
         set(controls.normbeta,'Visible','off');
         set(controls.decompose_det,'Visible','off');
         set(controls.weakexo,'Visible','off');
         set(controls.commoncycles,'Visible','off');
         set(controls.excludestat,'Visible','off');
         set(controls.critvaltext,'Visible','off');
         set(controls.critval,'Visible','off');
         set(controls.maxresptext,'Visible','off');
         set(controls.maxresp,'Visible','off');
         set(controls.save_freqtext,'Visible','off');
         set(controls.save_freq,'Visible','off');
         set(controls.discard_explosive,'Visible','off');
         set(controls.bad_draws,'Visible','off');
         set(controls.save_drawstext,'Visible','off');
         set(controls.save_draws,'Visible','off');
         set(controls.lambda_paramtext,'Visible','off');
         set(controls.lambda_param,'Visible','off');
         set(controls.lambda_inf_shortrun,'Visible','off');
         set(controls.lambda_dtext,'Visible','off');
         set(controls.lambda_d,'Visible','off');
         set(controls.lambda_inf_deter,'Visible','off');
         set(controls.lambda_alphatext,'Visible','off');
         set(controls.lambda_alpha,'Visible','off');
         set(controls.lambda_inf_alpha,'Visible','off');
         set(controls.lambda_omegatext,'Visible','off');
         set(controls.lambda_inf_omega,'Visible','off');
         set(controls.lambda_omega,'Visible','off');
         set(controls.burn_intext,'Visible','off');
         set(controls.burn_in,'Visible','off');
         set(controls.pstoolsdirtext,'Visible','off');
         if strcmp(get(controls.pstoolsdiredit,'Type'),'uicontrol')==1;
            set(controls.pstoolsdiredit,'Visible','off');
         else;
            editbox(controls.pstoolsdiredit,'Visible','off');
         end;
         set(controls.pstoolsdirbutton,'Visible','off');
         set(controls.loadicon,'Visible','off');
         set(controls.noicon,'Visible','off');
         set(controls.show_undo,'Visible','off');
         set(controls.browsedialog,'Visible','off');
         set(controls.opendialog,'Visible','off');
         set(controls.loadguiicon,'Visible','off');
         set(controls.delaytext,'Visible','off');
         set(controls.delay,'Visible','off');
         set(controls.tempdirtext,'Visible','off');
         if strcmp(get(controls.tempdiredit,'Type'),'uicontrol')==1;
            set(controls.tempdiredit,'Visible','off');
         else;
            editbox(controls.tempdiredit,'Visible','off');
         end;
         set(controls.tempdirbutton,'Visible','off');
         set(controls.delete_text,'Visible','off');
         set(controls.delete_matfile,'Visible','off');
         set(controls.delete_txtfile,'Visible','off');
         set(controls.delete_mfile,'Visible','off');
         set(controls.rstate,'Visible','off');
         set(controls.rstatetext,'Visible','off');
         set(controls.nRep,'Visible','off');
         set(controls.nReptext,'Visible','off');
         set(controls.nDraw,'Visible','off');
         set(controls.nDrawtext,'Visible','off');
         set(controls.interpolate,'Visible','off');
         set(controls.interpolatetext,'Visible','off');
         set(controls.simulatedirtext,'Visible','off');
         if strcmp(get(controls.simulatediredit,'Type'),'uicontrol')==1;
            set(controls.simulatediredit,'Visible','off');
         else;
            editbox(controls.simulatediredit,'Visible','off');
         end;
         set(controls.simulatedirbutton,'Visible','off');
         set(controls.latextext,'Visible','off');
         if strcmp(get(controls.latexedit,'Type'),'uicontrol')==1;
            set(controls.latexedit,'Visible','off');
         else;
            editbox(controls.latexedit,'Visible','off');
         end;
         set(controls.latexbutton,'Visible','off');
         set(controls.dviviewertext,'Visible','off');
         if strcmp(get(controls.dvivieweredit,'Type'),'uicontrol')==1;
            set(controls.dvivieweredit,'Visible','off');
         else;
            editbox(controls.dvivieweredit,'Visible','off');
         end;
         set(controls.dviviewerbutton,'Visible','off');
         set(controls.distillertext,'Visible','off');
         if strcmp(get(controls.distilleredit,'Type'),'uicontrol')==1;
            set(controls.distilleredit,'Visible','off');
         else;
            editbox(controls.distilleredit,'Visible','off');
         end;
         set(controls.distillerbutton,'Visible','off');
         set(controls.psviewertext,'Visible','off');
         if strcmp(get(controls.psvieweredit,'Type'),'uicontrol')==1;
            set(controls.psvieweredit,'Visible','off');
         else;
            editbox(controls.psvieweredit,'Visible','off');
         end;
         set(controls.psviewerbutton,'Visible','off');
         set(controls.pdfviewertext,'Visible','off');
         if strcmp(get(controls.pdfvieweredit,'Type'),'uicontrol')==1;
            set(controls.pdfvieweredit,'Visible','off');
         else;
            editbox(controls.pdfvieweredit,'Visible','off');
         end;
         set(controls.pdfviewerbutton,'Visible','off');
         set(controls.dvipdfm,'Visible','off');
         if isfield(controls,'maximizeviewer')==1;
            set(controls.maximizeviewer,'Visible','off');
         end;
         set(controls.outofsample,'Visible','off');
         set(controls.forecasthorizon,'Visible','off');
         set(controls.forecasthorizontext,'Visible','off');
         if strcmp(get(controls.tab4,'String'),'Viewers')==1;
            controls.current = 'Viewers';
            set(controls.openmyoutput,'Visible','off');
            set(controls.noprint,'Visible','off');
            set(controls.append,'Visible','off');
            set(controls.shortdyn,'Visible','off');
            set(controls.gctest,'Visible','off');
            set(controls.excludediffs,'Visible','off');
            set(controls.lstrtest,'Visible','off');
            set(controls.chow,'Visible','off');
            set(controls.texoutputtext,'Visible','off');
            set(controls.texoutput,'Visible','off');
            set(controls.exportdatatext,'Visible','off');
            set(controls.exportdata,'Visible','off');
            set(controls.decimalstext,'Visible','off');
            set(controls.decimals,'Visible','off');
            set(controls.pdfversion,'Visible','off');
            set(controls.pdfversiontext,'Visible','off');
            set(controls.tab9axes11,'Visible','off');
            set(controls.tab9axes12,'Visible','off');
            set(controls.tab9axes13,'Visible','off');
            set(controls.tab9axes14,'Visible','off');
            set(controls.tab9axes15,'Visible','off');
            set(controls.tab9axes16,'Visible','off');
            set(controls.tab9axes17,'Visible','off');
            set(controls.tab9axes18,'Visible','off');
            set(controls.tab9axes1text,'Visible','off');
            if matlabnumber>=6.0;
               set(controls.tab9axes19,'Visible','off');
               set(controls.tab9axes110,'Visible','off');
            end;
            set(controls.tab4axes11,'Visible','on');
            set(controls.tab4axes12,'Visible','on');
            set(controls.tab4axes13,'Visible','on');
            set(controls.tab4axes14,'Visible','on');
            set(controls.tab4axes15,'Visible','on');
            set(controls.tab4axes16,'Visible','on');
            set(controls.tab4axes17,'Visible','on');
            set(controls.tab4axes18,'Visible','on');
            set(controls.tab4axes1text,'Visible','on');
            if matlabnumber>=6.0;
               set(controls.tab4axes19,'Visible','on');
               set(controls.tab4axes110,'Visible','on');
            end;
            set(controls.tab4axes21,'Visible','on');
            set(controls.tab4axes22,'Visible','on');
            set(controls.tab4axes23,'Visible','on');
            set(controls.tab4axes24,'Visible','on');
            set(controls.tab4axes25,'Visible','on');
            set(controls.tab4axes26,'Visible','on');
            set(controls.tab4axes27,'Visible','on');
            set(controls.tab4axes28,'Visible','on');
            set(controls.tab4axes2text,'Visible','on');
            if matlabnumber>=6.0;
               set(controls.tab4axes29,'Visible','on');
               set(controls.tab4axes210,'Visible','on');
            end;
            set(controls.aiviewertext,'Visible','on');
            if strcmp(get(controls.aivieweredit,'Type'),'uicontrol')==1;
               set(controls.aivieweredit,'Visible','on');
            else;
               editbox(controls.aivieweredit,'Visible','on');
            end;
            set(controls.aiviewerbutton,'Visible','on');
            set(controls.epsviewertext,'Visible','on');
            if strcmp(get(controls.epsvieweredit,'Type'),'uicontrol')==1;
               set(controls.epsvieweredit,'Visible','on');
            else;
               editbox(controls.epsvieweredit,'Visible','on');
            end;
            set(controls.epsviewerbutton,'Visible','on');
            set(controls.bitmapviewertext,'Visible','on');
            if strcmp(get(controls.bitmapvieweredit,'Type'),'uicontrol')==1;
               set(controls.bitmapvieweredit,'Visible','on');
            else;
               editbox(controls.bitmapvieweredit,'Visible','on');
            end;
            set(controls.bitmapviewerbutton,'Visible','on');
            set(controls.editortext,'Visible','on');
            if strcmp(get(controls.editoredit,'Type'),'uicontrol')==1;
               set(controls.editoredit,'Visible','on');
            else;
               editbox(controls.editoredit,'Visible','on');
            end;
            set(controls.editorbutton,'Visible','on');
            set(controls.helpexetext,'Visible','on');
            if strcmp(get(controls.helpexeedit,'Type'),'uicontrol')==1;
               set(controls.helpexeedit,'Visible','on');
            else;
               editbox(controls.helpexeedit,'Visible','on');
            end;
            if ispc==0;
               set(controls.helpexebutton,'Visible','on');
            end;
            set(controls.txtprinttext,'Visible','off');
            if strcmp(get(controls.txtprintedit,'Type'),'uicontrol')==1;
               set(controls.txtprintedit,'Visible','off');
            else;
               editbox(controls.txtprintedit,'Visible','off');
            end;
            set(controls.txtprintbutton,'Visible','off');
            set(controls.txtprintcmdtext,'Visible','off');
            set(controls.txtprintcmdedit,'Visible','off');
            if ispc==1;
               set(controls.txtprintrun,'Visible','off');
            end;
            if iscompiled==1;
               set(controls.psprinttext,'Visible','off');
               if strcmp(get(controls.psprintedit,'Type'),'uicontrol')==1;
                  set(controls.psprintedit,'Visible','off');
               else;
                  editbox(controls.psprintedit,'Visible','off');
               end;
               set(controls.psprintbutton,'Visible','off');
               set(controls.psprintcmdtext,'Visible','off');
               set(controls.psprintcmdedit,'Visible','off');
               set(controls.ghostscripttext,'Visible','off');
               if strcmp(get(controls.ghostscriptedit,'Type'),'uicontrol')==1;
                  set(controls.ghostscriptedit,'Visible','off');
               else;
                  editbox(controls.ghostscriptedit,'Visible','off');
               end;
               set(controls.ghostscriptbutton,'Visible','off');
               set(controls.pstoedittext,'Visible','off');
               if strcmp(get(controls.pstoeditedit,'Type'),'uicontrol')==1;
                  set(controls.pstoeditedit,'Visible','off');
               else;
                  editbox(controls.pstoeditedit,'Visible','off');
               end;
               set(controls.pstoeditbutton,'Visible','off');
            end;
         elseif strcmp(get(controls.tab4,'String'),'Utilities')==1;
            controls.current = 'Utilities';
            set(controls.tab4axes11,'Visible','off');
            set(controls.tab4axes12,'Visible','off');
            set(controls.tab4axes13,'Visible','off');
            set(controls.tab4axes14,'Visible','off');
            set(controls.tab4axes15,'Visible','off');
            set(controls.tab4axes16,'Visible','off');
            set(controls.tab4axes17,'Visible','off');
            set(controls.tab4axes18,'Visible','off');
            set(controls.tab4axes1text,'Visible','off');
            if matlabnumber>=6.0;
               set(controls.tab4axes19,'Visible','off');
               set(controls.tab4axes110,'Visible','off');
            end;
            set(controls.tab4axes21,'Visible','off');
            set(controls.tab4axes22,'Visible','off');
            set(controls.tab4axes23,'Visible','off');
            set(controls.tab4axes24,'Visible','off');
            set(controls.tab4axes25,'Visible','off');
            set(controls.tab4axes26,'Visible','off');
            set(controls.tab4axes27,'Visible','off');
            set(controls.tab4axes28,'Visible','off');
            set(controls.tab4axes2text,'Visible','off');
            if matlabnumber>=6.0;
               set(controls.tab4axes29,'Visible','off');
               set(controls.tab4axes210,'Visible','off');
            end;
            set(controls.aiviewertext,'Visible','off');
            if strcmp(get(controls.aivieweredit,'Type'),'uicontrol')==1;
               set(controls.aivieweredit,'Visible','off');
            else;
               editbox(controls.aivieweredit,'Visible','off');
            end;
            set(controls.aiviewerbutton,'Visible','off');
            set(controls.epsviewertext,'Visible','off');
            if strcmp(get(controls.epsvieweredit,'Type'),'uicontrol')==1;
               set(controls.epsvieweredit,'Visible','off');
            else;
               editbox(controls.epsvieweredit,'Visible','off');
            end;
            set(controls.epsviewerbutton,'Visible','off');
            set(controls.bitmapviewertext,'Visible','off');
            if strcmp(get(controls.bitmapvieweredit,'Type'),'uicontrol')==1;
               set(controls.bitmapvieweredit,'Visible','off');
            else;
               editbox(controls.bitmapvieweredit,'Visible','off');
            end;
            set(controls.bitmapviewerbutton,'Visible','off');
            set(controls.editortext,'Visible','off');
            if strcmp(get(controls.editoredit,'Type'),'uicontrol')==1;
               set(controls.editoredit,'Visible','off');
            else;
               editbox(controls.editoredit,'Visible','off');
            end;
            set(controls.editorbutton,'Visible','off');
            set(controls.helpexetext,'Visible','off');
            if strcmp(get(controls.helpexeedit,'Type'),'uicontrol')==1;
               set(controls.helpexeedit,'Visible','off');
            else;
               editbox(controls.helpexeedit,'Visible','off');
            end;
            if ispc==0;
               set(controls.helpexebutton,'Visible','off');
            end;
            set(controls.openmyoutput,'Visible','off');
            set(controls.noprint,'Visible','off');
            set(controls.append,'Visible','off');
            set(controls.shortdyn,'Visible','off');
            set(controls.gctest,'Visible','off');
            set(controls.excludediffs,'Visible','off');
            set(controls.lstrtest,'Visible','off');
            set(controls.chow,'Visible','off');
            set(controls.texoutputtext,'Visible','off');
            set(controls.texoutput,'Visible','off');
            set(controls.pdfversion,'Visible','off');
            set(controls.pdfversiontext,'Visible','off');
            set(controls.exportdatatext,'Visible','off');
            set(controls.exportdata,'Visible','off');
            set(controls.decimalstext,'Visible','off');
            set(controls.decimals,'Visible','off');
            set(controls.tab9axes11,'Visible','on');
            set(controls.tab9axes12,'Visible','on');
            set(controls.tab9axes13,'Visible','on');
            set(controls.tab9axes14,'Visible','on');
            set(controls.tab9axes15,'Visible','on');
            set(controls.tab9axes16,'Visible','on');
            set(controls.tab9axes17,'Visible','on');
            set(controls.tab9axes18,'Visible','on');
            set(controls.tab9axes1text,'Visible','on');
            if matlabnumber>=6.0;
               set(controls.tab9axes19,'Visible','on');
               set(controls.tab9axes110,'Visible','on');
            end;
            set(controls.txtprinttext,'Visible','on');
            if strcmp(get(controls.txtprintedit,'Type'),'uicontrol')==1;
               set(controls.txtprintedit,'Visible','on');
            else;
               editbox(controls.txtprintedit,'Visible','on');
            end;
            set(controls.txtprintbutton,'Visible','on');
            set(controls.txtprintcmdtext,'Visible','on');
            set(controls.txtprintcmdedit,'Visible','on');
            if ispc==1;
               set(controls.txtprintrun,'Visible','on');
            end;
            if iscompiled==1;
               set(controls.psprinttext,'Visible','on');
               if strcmp(get(controls.psprintedit,'Type'),'uicontrol')==1;
                  set(controls.psprintedit,'Visible','on');
               else;
                  editbox(controls.psprintedit,'Visible','on');
               end;
               set(controls.psprintbutton,'Visible','on');
               set(controls.psprintcmdtext,'Visible','on');
               set(controls.psprintcmdedit,'Visible','on');
               set(controls.ghostscripttext,'Visible','on');
               if strcmp(get(controls.ghostscriptedit,'Type'),'uicontrol')==1;
                  set(controls.ghostscriptedit,'Visible','on');
               else;
                  editbox(controls.ghostscriptedit,'Visible','on');
               end;
               set(controls.ghostscriptbutton,'Visible','on');
               set(controls.pstoedittext,'Visible','on');
               if strcmp(get(controls.pstoeditedit,'Type'),'uicontrol')==1;
                  set(controls.pstoeditedit,'Visible','on');
               else;
                  editbox(controls.pstoeditedit,'Visible','on');
               end;
               set(controls.pstoeditbutton,'Visible','on');
            end;
         else;
            controls.current = 'Output Control';
            set(controls.tab4axes11,'Visible','off');
            set(controls.tab4axes12,'Visible','off');
            set(controls.tab4axes13,'Visible','off');
            set(controls.tab4axes14,'Visible','off');
            set(controls.tab4axes15,'Visible','off');
            set(controls.tab4axes16,'Visible','off');
            set(controls.tab4axes17,'Visible','off');
            set(controls.tab4axes18,'Visible','off');
            set(controls.tab4axes1text,'Visible','off');
            if matlabnumber>=6.0;
               set(controls.tab4axes19,'Visible','off');
               set(controls.tab4axes110,'Visible','off');
            end;
            set(controls.tab4axes21,'Visible','off');
            set(controls.tab4axes22,'Visible','off');
            set(controls.tab4axes23,'Visible','off');
            set(controls.tab4axes24,'Visible','off');
            set(controls.tab4axes25,'Visible','off');
            set(controls.tab4axes26,'Visible','off');
            set(controls.tab4axes27,'Visible','off');
            set(controls.tab4axes28,'Visible','off');
            set(controls.tab4axes2text,'Visible','off');
            if matlabnumber>=6.0;
               set(controls.tab4axes29,'Visible','off');
               set(controls.tab4axes210,'Visible','off');
            end;
            set(controls.aiviewertext,'Visible','off');
            if strcmp(get(controls.aivieweredit,'Type'),'uicontrol')==1;
               set(controls.aivieweredit,'Visible','off');
            else;
               editbox(controls.aivieweredit,'Visible','off');
            end;
            set(controls.aiviewerbutton,'Visible','off');
            set(controls.epsviewertext,'Visible','off');
            if strcmp(get(controls.epsvieweredit,'Type'),'uicontrol')==1;
               set(controls.epsvieweredit,'Visible','off');
            else;
               editbox(controls.epsvieweredit,'Visible','off');
            end;
            set(controls.epsviewerbutton,'Visible','off');
            set(controls.bitmapviewertext,'Visible','off');
            if strcmp(get(controls.bitmapvieweredit,'Type'),'uicontrol')==1;
               set(controls.bitmapvieweredit,'Visible','off');
            else;
               editbox(controls.bitmapvieweredit,'Visible','off');
            end;
            set(controls.bitmapviewerbutton,'Visible','off');
            set(controls.editortext,'Visible','off');
            if strcmp(get(controls.editoredit,'Type'),'uicontrol')==1;
               set(controls.editoredit,'Visible','off');
            else;
               editbox(controls.editoredit,'Visible','off');
            end;
            set(controls.editorbutton,'Visible','off');
            set(controls.helpexetext,'Visible','off');
            if strcmp(get(controls.helpexeedit,'Type'),'uicontrol')==1;
               set(controls.helpexeedit,'Visible','off');
            else;
               editbox(controls.helpexeedit,'Visible','off');
            end;
            if ispc==0;
               set(controls.helpexebutton,'Visible','off');
            end;
            set(controls.tab9axes11,'Visible','off');
            set(controls.tab9axes12,'Visible','off');
            set(controls.tab9axes13,'Visible','off');
            set(controls.tab9axes14,'Visible','off');
            set(controls.tab9axes15,'Visible','off');
            set(controls.tab9axes16,'Visible','off');
            set(controls.tab9axes17,'Visible','off');
            set(controls.tab9axes18,'Visible','off');
            set(controls.tab9axes1text,'Visible','off');
            if matlabnumber>=6.0;
               set(controls.tab9axes19,'Visible','off');
               set(controls.tab9axes110,'Visible','off');
            end;
            set(controls.txtprinttext,'Visible','off');
            if strcmp(get(controls.txtprintedit,'Type'),'uicontrol')==1;
               set(controls.txtprintedit,'Visible','off');
            else;
               editbox(controls.txtprintedit,'Visible','off');
            end;
            set(controls.txtprintbutton,'Visible','off');
            set(controls.txtprintcmdtext,'Visible','off');
            set(controls.txtprintcmdedit,'Visible','off');
            if ispc==1;
               set(controls.txtprintrun,'Visible','off');
            end;
            if iscompiled==1;
               set(controls.psprinttext,'Visible','off');
               if strcmp(get(controls.psprintedit,'Type'),'uicontrol')==1;
                  set(controls.psprintedit,'Visible','off');
               else;
                  editbox(controls.psprintedit,'Visible','off');
               end;
               set(controls.psprintbutton,'Visible','off');
               set(controls.psprintcmdtext,'Visible','off');
               set(controls.psprintcmdedit,'Visible','off');
               set(controls.ghostscripttext,'Visible','off');
               if strcmp(get(controls.ghostscriptedit,'Type'),'uicontrol')==1;
                  set(controls.ghostscriptedit,'Visible','off');
               else;
                  editbox(controls.ghostscriptedit,'Visible','off');
               end;
               set(controls.ghostscriptbutton,'Visible','off');
               set(controls.pstoedittext,'Visible','off');
               if strcmp(get(controls.pstoeditedit,'Type'),'uicontrol')==1;
                  set(controls.pstoeditedit,'Visible','off');
               else;
                  editbox(controls.pstoeditedit,'Visible','off');
               end;
               set(controls.pstoeditbutton,'Visible','off');
            end;
            set(controls.tab1axes11,'Visible','on');
            set(controls.tab1axes12,'Visible','on');
            set(controls.tab1axes13,'Visible','on');
            set(controls.tab1axes14,'Visible','on');
            set(controls.tab1axes15,'Visible','on');
            set(controls.tab1axes16,'Visible','on');
            set(controls.tab1axes17,'Visible','on');
            set(controls.tab1axes18,'Visible','on');
            set(controls.tab1axes1text,'Visible','on');
            if matlabnumber>=6.0;
               set(controls.tab1axes19,'Visible','on');
               set(controls.tab1axes110,'Visible','on');
            end;
            set(controls.openmyoutput,'Visible','on');
            set(controls.noprint,'Visible','on');
            set(controls.append,'Visible','on');
            set(controls.shortdyn,'Visible','on');
            set(controls.gctest,'Visible','on');
            set(controls.excludediffs,'Visible','on');
            set(controls.lstrtest,'Visible','on');
            set(controls.chow,'Visible','on');
            set(controls.texoutputtext,'Visible','on');
            set(controls.texoutput,'Visible','on');
            set(controls.pdfversion,'Visible','on');
            set(controls.pdfversiontext,'Visible','on');
            set(controls.exportdatatext,'Visible','on');
            set(controls.exportdata,'Visible','on');
            set(controls.decimalstext,'Visible','on');
            set(controls.decimals,'Visible','on');
         end;
      elseif newtab==5;
         set(controls.frame3tab1,'Visible','on');
         set(controls.frame3tab2,'Visible','on');
         set(controls.frame3tab3,'Visible','on');
         set(controls.frame3tab4,'Visible','on');
         set(controls.frame3tab5,'Visible','off');
         set(controls.frame1tab2,'Position',[86.4 380 74.4 11]);
         set(controls.frame1tab3,'Position',[161.8 380 74.4 11]);
         set(controls.frame1tab4,'Position',[237.2 380 74.4 11]);
         set(controls.frame1tab5,'Position',[311.6 380 75.4 11]);
         set(controls.tab1,'Position',[11 388 74.4 23]);
         set(controls.tab2,'Position',[86.4 388 74.4 23]);
         set(controls.tab3,'Position',[161.8 388 74.4 23]);
         set(controls.tab4,'Position',[237.2 388 74.4 23]);
         set(controls.tab5,'Position',[311.6 388 77.4 25]);
         set(controls.tab1axes11,'Visible','off');
         set(controls.tab1axes12,'Visible','off');
         set(controls.tab1axes13,'Visible','off');
         set(controls.tab1axes14,'Visible','off');
         set(controls.tab1axes15,'Visible','off');
         set(controls.tab1axes16,'Visible','off');
         set(controls.tab1axes17,'Visible','off');
         set(controls.tab1axes18,'Visible','off');
         set(controls.tab1axes1text,'Visible','off');
         if matlabnumber>=6.0;
            set(controls.tab1axes19,'Visible','off');
            set(controls.tab1axes110,'Visible','off');
         end;
         set(controls.tab9axes11,'Visible','off');
         set(controls.tab9axes12,'Visible','off');
         set(controls.tab9axes13,'Visible','off');
         set(controls.tab9axes14,'Visible','off');
         set(controls.tab9axes15,'Visible','off');
         set(controls.tab9axes16,'Visible','off');
         set(controls.tab9axes17,'Visible','off');
         set(controls.tab9axes18,'Visible','off');
         set(controls.tab9axes1text,'Visible','off');
         if matlabnumber>=6.0;
            set(controls.tab9axes19,'Visible','off');
            set(controls.tab9axes110,'Visible','off');
         end;
         set(controls.bayes_mcmc,'Visible','off');
         set(controls.bayes_prior,'Visible','off');
         set(controls.maxittext,'Visible','off');
         set(controls.maxit,'Visible','off');
         set(controls.convcrittext,'Visible','off');
         set(controls.convcrit,'Visible','off');
         set(controls.method1,'Visible','off');
         set(controls.method2,'Visible','off');
         set(controls.method3,'Visible','off');
         set(controls.identify,'Visible','off');
         set(controls.identifytext,'Visible','off');
         set(controls.tab2axes11,'Visible','off');
         set(controls.tab2axes12,'Visible','off');
         set(controls.tab2axes13,'Visible','off');
         set(controls.tab2axes14,'Visible','off');
         set(controls.tab2axes15,'Visible','off');
         set(controls.tab2axes16,'Visible','off');
         set(controls.tab2axes17,'Visible','off');
         set(controls.tab2axes18,'Visible','off');
         set(controls.tab2axes1text,'Visible','off');
         set(controls.tab2axes21,'Visible','off');
         set(controls.tab2axes22,'Visible','off');
         set(controls.tab2axes23,'Visible','off');
         set(controls.tab2axes24,'Visible','off');
         set(controls.tab2axes25,'Visible','off');
         set(controls.tab2axes26,'Visible','off');
         set(controls.tab2axes27,'Visible','off');
         set(controls.tab2axes28,'Visible','off');
         set(controls.tab2axes2text,'Visible','off');
         set(controls.tab2axes31,'Visible','off');
         set(controls.tab2axes32,'Visible','off');
         set(controls.tab2axes33,'Visible','off');
         set(controls.tab2axes34,'Visible','off');
         set(controls.tab2axes35,'Visible','off');
         set(controls.tab2axes36,'Visible','off');
         set(controls.tab2axes37,'Visible','off');
         set(controls.tab2axes38,'Visible','off');
         set(controls.tab2axes3text,'Visible','off');
         if matlabnumber>=6.0;
            set(controls.tab2axes19,'Visible','off');
            set(controls.tab2axes110,'Visible','off');
            set(controls.tab2axes29,'Visible','off');
            set(controls.tab2axes210,'Visible','off');
            set(controls.tab2axes39,'Visible','off');
            set(controls.tab2axes310,'Visible','off');
         end;
         set(controls.maxlagtext,'Visible','off');
         set(controls.maxlag,'Visible','off');
         set(controls.openvar,'Visible','off');
         set(controls.dirstructure,'Visible','off');
         set(controls.geometry,'Visible','off');
         set(controls.uselastfile,'Visible','off');
         set(controls.startrun,'Visible','off');
         set(controls.logtab,'Visible','off');
         set(controls.clearlog,'Visible','off');
         set(controls.openmyoutput,'Visible','off');
         set(controls.noprint,'Visible','off');
         set(controls.sillyq,'Visible','off');
         set(controls.editcontext,'Visible','off');
         set(controls.toolbar_bgcolor,'Visible','off');
         set(controls.gui_colors,'Visible','off');
         set(controls.text_colors,'Visible','off');
         set(controls.frame_colors,'Visible','off');
         set(controls.gui_fontbutton,'Visible','off');
         set(controls.gui_font,'Visible','off');
         set(controls.external,'Visible','off');
         set(controls.xgrid,'Visible','off');
         set(controls.ygrid,'Visible','off');
         set(controls.zgrid,'Visible','off');
         set(controls.box,'Visible','off');
         set(controls.colors,'Visible','off');
         set(controls.zbuffer,'Visible','off');
         set(controls.ytick,'Visible','off');
         set(controls.xtick,'Visible','off');
         set(controls.axesfont,'Visible','off');
         set(controls.titlefont,'Visible','off');
         set(controls.labelfont,'Visible','off');
         set(controls.axescolor,'Visible','off');
         set(controls.titlecolor,'Visible','off');
         set(controls.labelcolor,'Visible','off');
         set(controls.append,'Visible','off');
         set(controls.fonttext,'Visible','off');
         set(controls.default_colors,'Visible','off');
         set(controls.pagesetup,'Visible','off');
         set(controls.graphicsfmttext,'Visible','off');
         set(controls.graphicsfmt,'Visible','off');
         set(controls.tab3axes11,'Visible','off');
         set(controls.tab3axes12,'Visible','off');
         set(controls.tab3axes13,'Visible','off');
         set(controls.tab3axes14,'Visible','off');
         set(controls.tab3axes15,'Visible','off');
         set(controls.tab3axes16,'Visible','off');
         set(controls.tab3axes17,'Visible','off');
         set(controls.tab3axes18,'Visible','off');
         set(controls.tab3axes1text,'Visible','off');
         if matlabnumber>=6.0;
            set(controls.tab3axes19,'Visible','off');
            set(controls.tab3axes110,'Visible','off');
         end;
         set(controls.sscorrect,'Visible','off');
         set(controls.bartserial,'Visible','off');
         set(controls.portmanteau,'Visible','off');
         set(controls.lbcorrect,'Visible','off');
         set(controls.omnibus,'Visible','off');
         set(controls.transeig,'Visible','off');
         set(controls.fluctest,'Visible','off');
         set(controls.nyblom,'Visible','off');
         set(controls.nyblombeta,'Visible','off');
         set(controls.taylor_nyblom,'Visible','off');
         set(controls.fullrec,'Visible','off');
         set(controls.chowfc,'Visible','off');
         set(controls.chow,'Visible','off');
         set(controls.recalpha,'Visible','off');
         set(controls.recpi,'Visible','off');
         set(controls.rectrace,'Visible','off');
         set(controls.topeig,'Visible','off');
         set(controls.extraccrit,'Visible','off');
         set(controls.akaike,'Visible','off');
         set(controls.restat,'Visible','off');
         set(controls.dummytests,'Visible','off');
         set(controls.rest_march,'Visible','off');
         set(controls.shortdyn,'Visible','off');
         set(controls.gctest,'Visible','off');
         set(controls.excludediffs,'Visible','off');
         set(controls.lstrtest,'Visible','off');
         set(controls.noise_parm,'Visible','off');
         set(controls.noise_parmtxt,'Visible','off');
         set(controls.ms_maxlag,'Visible','off');
         set(controls.ms_maxlagtext,'Visible','off');
         set(controls.lagtest,'Visible','off');
         set(controls.lagtesttext,'Visible','off');
         set(controls.recursivetext,'Visible','off');
         set(controls.recursive,'Visible','off');
         editbox(controls.texheader,'Visible','off');
         set(controls.texheaderbutton,'Visible','off');
         set(controls.texheadertext,'Visible','off');
         set(controls.tracebart,'Visible','off');
         set(controls.betagrad,'Visible','off');
         set(controls.rahbek,'Visible','off');
         set(controls.reestbeta,'Visible','off');
         set(controls.normbeta,'Visible','off');
         set(controls.decompose_det,'Visible','off');
         set(controls.weakexo,'Visible','off');
         set(controls.commoncycles,'Visible','off');
         set(controls.excludestat,'Visible','off');
         set(controls.critvaltext,'Visible','off');
         set(controls.critval,'Visible','off');
         set(controls.tab4axes11,'Visible','off');
         set(controls.tab4axes12,'Visible','off');
         set(controls.tab4axes13,'Visible','off');
         set(controls.tab4axes14,'Visible','off');
         set(controls.tab4axes15,'Visible','off');
         set(controls.tab4axes16,'Visible','off');
         set(controls.tab4axes17,'Visible','off');
         set(controls.tab4axes18,'Visible','off');
         set(controls.tab4axes1text,'Visible','off');
         if matlabnumber>=6.0;
            set(controls.tab4axes19,'Visible','off');
            set(controls.tab4axes110,'Visible','off');
         end;
         set(controls.tab4axes21,'Visible','off');
         set(controls.tab4axes22,'Visible','off');
         set(controls.tab4axes23,'Visible','off');
         set(controls.tab4axes24,'Visible','off');
         set(controls.tab4axes25,'Visible','off');
         set(controls.tab4axes26,'Visible','off');
         set(controls.tab4axes27,'Visible','off');
         set(controls.tab4axes28,'Visible','off');
         set(controls.tab4axes2text,'Visible','off');
         if matlabnumber>=6.0;
            set(controls.tab4axes29,'Visible','off');
            set(controls.tab4axes210,'Visible','off');
         end;
         set(controls.aiviewertext,'Visible','off');
         if strcmp(get(controls.aivieweredit,'Type'),'uicontrol')==1;
            set(controls.aivieweredit,'Visible','off');
         else;
            editbox(controls.aivieweredit,'Visible','off');
         end;
         set(controls.aiviewerbutton,'Visible','off');
         set(controls.epsviewertext,'Visible','off');
         if strcmp(get(controls.epsvieweredit,'Type'),'uicontrol')==1;
            set(controls.epsvieweredit,'Visible','off');
         else;
            editbox(controls.epsvieweredit,'Visible','off');
         end;
         set(controls.epsviewerbutton,'Visible','off');
         set(controls.bitmapviewertext,'Visible','off');
         if strcmp(get(controls.bitmapvieweredit,'Type'),'uicontrol')==1;
            set(controls.bitmapvieweredit,'Visible','off');
         else;
            editbox(controls.bitmapvieweredit,'Visible','off');
         end;
         set(controls.bitmapviewerbutton,'Visible','off');
         set(controls.editortext,'Visible','off');
         if strcmp(get(controls.editoredit,'Type'),'uicontrol')==1;
            set(controls.editoredit,'Visible','off');
         else;
            editbox(controls.editoredit,'Visible','off');
         end;
         set(controls.editorbutton,'Visible','off');
         set(controls.helpexetext,'Visible','off');
         if strcmp(get(controls.helpexeedit,'Type'),'uicontrol')==1;
            set(controls.helpexeedit,'Visible','off');
         else;
            editbox(controls.helpexeedit,'Visible','off');
         end;
         if ispc==0;
            set(controls.helpexebutton,'Visible','off');
         end;
         set(controls.txtprinttext,'Visible','off');
         if strcmp(get(controls.txtprintedit,'Type'),'uicontrol')==1;
            set(controls.txtprintedit,'Visible','off');
         else;
            editbox(controls.txtprintedit,'Visible','off');
         end;
         set(controls.txtprintbutton,'Visible','off');
         set(controls.txtprintcmdtext,'Visible','off');
         set(controls.txtprintcmdedit,'Visible','off');
         if ispc==1;
            set(controls.txtprintrun,'Visible','off');
         end;
         if iscompiled==1;
            set(controls.psprinttext,'Visible','off');
            if strcmp(get(controls.psprintedit,'Type'),'uicontrol')==1;
               set(controls.psprintedit,'Visible','off');
            else;
               editbox(controls.psprintedit,'Visible','off');
            end;
            set(controls.psprintbutton,'Visible','off');
            set(controls.psprintcmdtext,'Visible','off');
            set(controls.psprintcmdedit,'Visible','off');
            set(controls.ghostscripttext,'Visible','off');
            if strcmp(get(controls.ghostscriptedit,'Type'),'uicontrol')==1;
               set(controls.ghostscriptedit,'Visible','off');
            else;
               editbox(controls.ghostscriptedit,'Visible','off');
            end;
            set(controls.ghostscriptbutton,'Visible','off');
            set(controls.pstoedittext,'Visible','off');
            if strcmp(get(controls.pstoeditedit,'Type'),'uicontrol')==1;
               set(controls.pstoeditedit,'Visible','off');
            else;
               editbox(controls.pstoeditedit,'Visible','off');
            end;
            set(controls.pstoeditbutton,'Visible','off');
         end;
         set(controls.latextext,'Visible','off');
         if strcmp(get(controls.latexedit,'Type'),'uicontrol')==1;
            set(controls.latexedit,'Visible','off');
         else;
            editbox(controls.latexedit,'Visible','off');
         end;
         set(controls.latexbutton,'Visible','off');
         set(controls.dviviewertext,'Visible','off');
         if strcmp(get(controls.dvivieweredit,'Type'),'uicontrol')==1;
            set(controls.dvivieweredit,'Visible','off');
         else;
            editbox(controls.dvivieweredit,'Visible','off');
         end;
         set(controls.dviviewerbutton,'Visible','off');
         set(controls.distillertext,'Visible','off');
         if strcmp(get(controls.distilleredit,'Type'),'uicontrol')==1;
            set(controls.distilleredit,'Visible','off');
         else;
            editbox(controls.distilleredit,'Visible','off');
         end;
         set(controls.distillerbutton,'Visible','off');
         set(controls.psviewertext,'Visible','off');
         if strcmp(get(controls.psvieweredit,'Type'),'uicontrol')==1;
            set(controls.psvieweredit,'Visible','off');
         else;
            editbox(controls.psvieweredit,'Visible','off');
         end;
         set(controls.psviewerbutton,'Visible','off');
         set(controls.pdfviewertext,'Visible','off');
         if strcmp(get(controls.pdfvieweredit,'Type'),'uicontrol')==1;
            set(controls.pdfvieweredit,'Visible','off');
         else;
            editbox(controls.pdfvieweredit,'Visible','off');
         end;
         set(controls.pdfviewerbutton,'Visible','off');
         set(controls.dvipdfm,'Visible','off');
         if isfield(controls,'maximizeviewer')==1;
            set(controls.maximizeviewer,'Visible','off');
         end;
         set(controls.texoutputtext,'Visible','off');
         set(controls.texoutput,'Visible','off');
         set(controls.exportdatatext,'Visible','off');
         set(controls.exportdata,'Visible','off');
         set(controls.decimalstext,'Visible','off');
         set(controls.decimals,'Visible','off');
         set(controls.pdfversion,'Visible','off');
         set(controls.pdfversiontext,'Visible','off');
         set(controls.outofsample,'Visible','off');
         set(controls.forecasthorizon,'Visible','off');
         set(controls.forecasthorizontext,'Visible','off');
         if strcmp(get(controls.tab5,'String'),'Bayesian')==1;
            controls.current = 'Bayesian';
            set(controls.maxresptext,'Visible','off');
            set(controls.maxresp,'Visible','off');
            set(controls.pstoolsdirtext,'Visible','off');
            if strcmp(get(controls.pstoolsdiredit,'Type'),'uicontrol')==1;
               set(controls.pstoolsdiredit,'Visible','off');
            else;
               editbox(controls.pstoolsdiredit,'Visible','off');
            end;
            set(controls.pstoolsdirbutton,'Visible','off');
            set(controls.loadicon,'Visible','off');
            set(controls.noicon,'Visible','off');
            set(controls.show_undo,'Visible','off');
            set(controls.browsedialog,'Visible','off');
            set(controls.opendialog,'Visible','off');
            set(controls.loadguiicon,'Visible','off');
            set(controls.delaytext,'Visible','off');
            set(controls.delay,'Visible','off');
            set(controls.tempdirtext,'Visible','off');
            if strcmp(get(controls.tempdiredit,'Type'),'uicontrol')==1;
               set(controls.tempdiredit,'Visible','off');
            else;
               editbox(controls.tempdiredit,'Visible','off');
            end;
            set(controls.tempdirbutton,'Visible','off');
            set(controls.delete_text,'Visible','off');
            set(controls.delete_matfile,'Visible','off');
            set(controls.delete_txtfile,'Visible','off');
            set(controls.delete_mfile,'Visible','off');
            set(controls.rstate,'Visible','off');
            set(controls.rstatetext,'Visible','off');
            set(controls.nRep,'Visible','off');
            set(controls.parametric,'Visible','off');
            set(controls.blocktext,'Visible','off');
            set(controls.blocksize,'Visible','off');
            set(controls.bootstrap,'Visible','off');
            set(controls.symmetric,'Visible','off');
            set(controls.nReptext,'Visible','off');
            set(controls.nDraw,'Visible','off');
            set(controls.nDrawtext,'Visible','off');
            set(controls.interpolate,'Visible','off');
            set(controls.interpolatetext,'Visible','off');
               set(controls.simulatedirtext,'Visible','off');
            if strcmp(get(controls.simulatediredit,'Type'),'uicontrol')==1;
               set(controls.simulatediredit,'Visible','off');
            else;
               editbox(controls.simulatediredit,'Visible','off');
            end;
            set(controls.simulatedirbutton,'Visible','off');
            set(controls.bayes_mcmc,'Visible','on');
            set(controls.bayes_prior,'Visible','on');
            set(controls.save_freqtext,'Visible','on');
            set(controls.save_freq,'Visible','on');
            set(controls.discard_explosive,'Visible','on');
            set(controls.bad_draws,'Visible','on');
            set(controls.save_drawstext,'Visible','on');
            set(controls.save_draws,'Visible','on');
            set(controls.lambda_paramtext,'Visible','on');
            set(controls.lambda_param,'Visible','on');
            set(controls.lambda_inf_shortrun,'Visible','on');
            set(controls.lambda_dtext,'Visible','on');
            set(controls.lambda_d,'Visible','on');
            set(controls.lambda_inf_deter,'Visible','on');
            set(controls.lambda_alphatext,'Visible','on');
            set(controls.lambda_alpha,'Visible','on');
            set(controls.lambda_inf_alpha,'Visible','on');
            set(controls.lambda_omegatext,'Visible','on');
            set(controls.lambda_inf_omega,'Visible','on');
            set(controls.lambda_omega,'Visible','on');
            set(controls.burn_intext,'Visible','on');
            set(controls.burn_in,'Visible','on');
         elseif strcmp(get(controls.tab5,'String'),'Simulation')==1;
            controls.current = 'Simulation';
            set(controls.tab1axes11,'Visible','on');
            set(controls.tab1axes12,'Visible','on');
            set(controls.tab1axes13,'Visible','on');
            set(controls.tab1axes14,'Visible','on');
            set(controls.tab1axes15,'Visible','on');
            set(controls.tab1axes16,'Visible','on');
            set(controls.tab1axes17,'Visible','on');
            set(controls.tab1axes18,'Visible','on');
            set(controls.tab1axes1text,'Visible','on');
            if matlabnumber>=6.0;
               set(controls.tab1axes19,'Visible','on');
               set(controls.tab1axes110,'Visible','on');
            end;
            set(controls.maxresptext,'Visible','off');
            set(controls.maxresp,'Visible','off');
            set(controls.pstoolsdirtext,'Visible','off');
            if strcmp(get(controls.pstoolsdiredit,'Type'),'uicontrol')==1;
               set(controls.pstoolsdiredit,'Visible','off');
            else;
               editbox(controls.pstoolsdiredit,'Visible','off');
            end;
            set(controls.save_freqtext,'Visible','off');
            set(controls.save_freq,'Visible','off');
            set(controls.discard_explosive,'Visible','off');
            set(controls.bad_draws,'Visible','off');
            set(controls.save_drawstext,'Visible','off');
            set(controls.save_draws,'Visible','off');
            set(controls.lambda_paramtext,'Visible','off');
            set(controls.lambda_param,'Visible','off');
            set(controls.lambda_inf_shortrun,'Visible','off');
            set(controls.lambda_dtext,'Visible','off');
            set(controls.lambda_d,'Visible','off');
            set(controls.lambda_inf_deter,'Visible','off');
            set(controls.lambda_alphatext,'Visible','off');
            set(controls.lambda_alpha,'Visible','off');
            set(controls.lambda_inf_alpha,'Visible','off');
            set(controls.lambda_omegatext,'Visible','off');
            set(controls.lambda_inf_omega,'Visible','off');
            set(controls.lambda_omega,'Visible','off');
            set(controls.burn_intext,'Visible','off');
            set(controls.burn_in,'Visible','off');
            set(controls.pstoolsdirbutton,'Visible','off');
            set(controls.loadicon,'Visible','off');
            set(controls.noicon,'Visible','off');
            set(controls.show_undo,'Visible','off');
            set(controls.browsedialog,'Visible','off');
            set(controls.opendialog,'Visible','off');
            set(controls.loadguiicon,'Visible','off');
            set(controls.delaytext,'Visible','off');
            set(controls.delay,'Visible','off');
            set(controls.tempdirtext,'Visible','off');
            if strcmp(get(controls.tempdiredit,'Type'),'uicontrol')==1;
               set(controls.tempdiredit,'Visible','off');
            else;
               editbox(controls.tempdiredit,'Visible','off');
            end;
            set(controls.tempdirbutton,'Visible','off');
            set(controls.delete_text,'Visible','on');
            set(controls.delete_matfile,'Visible','on');
            set(controls.delete_txtfile,'Visible','on');
            set(controls.delete_mfile,'Visible','on');
            set(controls.rstate,'Visible','on');
            set(controls.rstatetext,'Visible','on');
            set(controls.nRep,'Visible','on');
            set(controls.parametric,'Visible','on');
            set(controls.blocktext,'Visible','on');
            set(controls.blocksize,'Visible','on');
            set(controls.bootstrap,'Visible','on');
            set(controls.symmetric,'Visible','on');
            set(controls.nReptext,'Visible','on');
            set(controls.nDraw,'Visible','on');
            set(controls.nDrawtext,'Visible','on');
            set(controls.interpolate,'Visible','on');
            set(controls.interpolatetext,'Visible','on');
               set(controls.simulatedirtext,'Visible','on');
            if strcmp(get(controls.simulatediredit,'Type'),'uicontrol')==1;
               set(controls.simulatediredit,'Visible','on');
            else;
               editbox(controls.simulatediredit,'Visible','on');
            end;
            set(controls.simulatedirbutton,'Visible','on');
         else;
            controls.current = 'Miscellaneous';
            set(controls.tab1axes11,'Visible','on');
            set(controls.tab1axes12,'Visible','on');
            set(controls.tab1axes13,'Visible','on');
            set(controls.tab1axes14,'Visible','on');
            set(controls.tab1axes15,'Visible','on');
            set(controls.tab1axes16,'Visible','on');
            set(controls.tab1axes17,'Visible','on');
            set(controls.tab1axes18,'Visible','on');
            set(controls.tab1axes1text,'Visible','on');
            if matlabnumber>=6.0;
               set(controls.tab1axes19,'Visible','on');
               set(controls.tab1axes110,'Visible','on');
            end;
            set(controls.save_freqtext,'Visible','off');
            set(controls.save_freq,'Visible','off');
            set(controls.discard_explosive,'Visible','off');
            set(controls.bad_draws,'Visible','off');
            set(controls.save_drawstext,'Visible','off');
            set(controls.save_draws,'Visible','off');
            set(controls.lambda_paramtext,'Visible','off');
            set(controls.lambda_param,'Visible','off');
            set(controls.lambda_inf_shortrun,'Visible','off');
            set(controls.lambda_dtext,'Visible','off');
            set(controls.lambda_d,'Visible','off');
            set(controls.lambda_inf_deter,'Visible','off');
            set(controls.lambda_alphatext,'Visible','off');
            set(controls.lambda_alpha,'Visible','off');
            set(controls.lambda_inf_alpha,'Visible','off');
            set(controls.lambda_omegatext,'Visible','off');
            set(controls.lambda_inf_omega,'Visible','off');
            set(controls.lambda_omega,'Visible','off');
            set(controls.burn_intext,'Visible','off');
            set(controls.burn_in,'Visible','off');
            set(controls.delete_text,'Visible','off');
            set(controls.delete_matfile,'Visible','off');
            set(controls.delete_txtfile,'Visible','off');
            set(controls.delete_mfile,'Visible','off');
            set(controls.rstate,'Visible','off');
            set(controls.rstatetext,'Visible','off');
            set(controls.nRep,'Visible','off');
            set(controls.parametric,'Visible','off');
            set(controls.blocktext,'Visible','off');
            set(controls.blocksize,'Visible','off');
            set(controls.bootstrap,'Visible','off');
            set(controls.symmetric,'Visible','off');
            set(controls.nReptext,'Visible','off');
            set(controls.nDraw,'Visible','off');
            set(controls.nDrawtext,'Visible','off');
            set(controls.interpolate,'Visible','off');
            set(controls.interpolatetext,'Visible','off');
            set(controls.simulatedirtext,'Visible','off');
            if strcmp(get(controls.simulatediredit,'Type'),'uicontrol')==1;
               set(controls.simulatediredit,'Visible','off');
            else;
               editbox(controls.simulatediredit,'Visible','off');
            end;
            set(controls.simulatedirbutton,'Visible','off');
            set(controls.maxresptext,'Visible','on');
            set(controls.maxresp,'Visible','on');
            if (iscompiled==1)&(iswinnt==1);
               set(controls.pstoolsdirtext,'Visible','on');
               if strcmp(get(controls.pstoolsdiredit,'Type'),'uicontrol')==1;
                  set(controls.pstoolsdiredit,'Visible','on');
               else;
                  editbox(controls.pstoolsdiredit,'Visible','on');
               end;
               set(controls.pstoolsdirbutton,'Visible','on');
               set(controls.loadicon,'Visible','on');
               set(controls.noicon,'Visible','on');
               set(controls.loadguiicon,'Visible','on');
               set(controls.delaytext,'Visible','on');
               set(controls.delay,'Visible','on');
               if matlabnumber<6.5;
                  set(controls.browsedialog,'Visible','on');
                  set(controls.opendialog,'Visible','on');
               end;
            end;
            if iscompiled==1;
               set(controls.show_undo,'Visible','on');
            end;
            set(controls.tempdirtext,'Visible','on');
            if strcmp(get(controls.tempdiredit,'Type'),'uicontrol')==1;
               set(controls.tempdiredit,'Visible','on');
            else;
               editbox(controls.tempdiredit,'Visible','on');
            end;
            set(controls.tempdirbutton,'Visible','on');
            %
         end;
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'deletefiles'
   ext = get(gcbo,'Tag');
   simdir_struc = dir(var_ini.simulatedir);
   files = '';
   my_bytes = 0;
   for i=1:size(simdir_struc,1);
      if (simdir_struc(i).isdir==0)&(strcmp(lower(getext(simdir_struc(i).name)),ext)==1);
         files = strvcat(files,simdir_struc(i).name);
         my_bytes = my_bytes+simdir_struc(i).bytes;
      end;
      if (simdir_struc(i).isdir==0)&strcmp(ext,'.txt')==1;
         if strcmp(lower(getext(simdir_struc(i).name)),'.ltx')==1
            files = strvcat(files,simdir_struc(i).name);
            my_bytes = my_bytes+simdir_struc(i).bytes;
         end;
      end;
   end;
   if strcmp(ext,'.mat')==1;
      file_type = 'Matlab MAT Files';
   elseif strcmp(ext,'.txt')==1;
      file_type = 'Text Files';
   else;
      file_type = 'Matlab M Files';
   end;
   %
   if isempty(files)==0;
      %
      % List all files with the selected extension in the simulation output directory
      %
      thisdelete = list_files_dlg('init',files,['Delete ' file_type],'File List',35,[file_type ' in "' var_ini.simulatedir '" (' num2str(my_bytes,'%0.0f') ' bytes):'],'deletebig_image');
      list_controls = get(thisdelete,'UserData');
      action = lower(list_controls.string);
      del_values = get(list_controls.allfiles,'Value');
      set(list_controls.cancel,'UserData','done');
      killguipid(thisdelete);
      if (strcmp(action,'ok')==1)&(size(del_values,2)>0);
         %
         % deleting files
         %
         mywait = waitdlg(' ','delete',['Delete ' file_type],600);
         waitf = get(mywait,'UserData');
         %
         for i=1:size(del_values,2);
             new_val = del_values(1,i);
             file = [var_ini.simulatedir strtrim(files(new_val,:))];
             if fileexist(file)==1;
                this_text = strvcat(' ',['Deleting ' file_type ' in "' var_ini.simulatedir '". Current file is:'],' ',['  ' getfilename(file)],' ','Please hold!');
                set(waitf.text,'String',this_text);
                delete_file_fcn(file);
             end;
         end;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
      end;
   else;
      txt_str = ['There are no ' file_type ' in the directory "' var_ini.simulatedir '". Unable to delete any files!'];
      about(txt_str,'information',['File Delete - ' file_type],120,500);
   end;
case 'reusebootstrap'
   new_reuse_bootstrap = get(controls.bootstrap,'Value');
   if abs(new_reuse_bootstrap-var_ini.reuse_bootstrap)>0;
      set(controls.apply,'Enable','on');
      var_ini.reuse_bootstrap = new_reuse_bootstrap;
   end;
   set(optionsgui,'UserData',controls);
case 'show_undo'
   new_show_undo = get(controls.show_undo,'Value');
   if abs(new_show_undo-var_ini.show_undo)>0;
      set(controls.apply,'Enable','on');
      var_ini.show_undo = new_show_undo;
   end;
   set(optionsgui,'UserData',controls);
case 'parametric'
   new_parametric = get(controls.parametric,'Value');
   if abs(new_parametric-var_ini.parametric)>0;
      set(controls.apply,'Enable','on');
      var_ini.parametric = new_parametric;
   end;
   if var_ini.parametric==1;
      set(controls.blocktext,'Enable','off');
      set(controls.blocksize,'Enable','off','Value',1);
      var_ini.blocksize = 1;
   else;
      set(controls.blocktext,'Enable','on');
      set(controls.blocksize,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'blocksize'
   new_blocksize = get(controls.blocksize,'Value');
   if abs(new_blocksize-var_ini.blocksize)>0;
      set(controls.apply,'Enable','on');
      var_ini.blocksize = new_blocksize;
   end;
   set(optionsgui,'UserData',controls);
case 'symmetric'
   new_symmetric = get(controls.symmetric,'Value');
   if abs(new_symmetric-var_ini.symmetric)>0;
      set(controls.apply,'Enable','on');
      var_ini.symmetric = new_symmetric;
   end;
   set(optionsgui,'UserData',controls);
case 'guicolors'
   var_ini.previous.gui_light_color = var_ini.gui_light_color;
   var_ini.previous.gui_shade_color = var_ini.gui_shade_color;
   var_ini.previous.gui_dark_color = var_ini.gui_dark_color;
   color_mat = [var_ini.gui_foreground_color;var_ini.gui_light_color;var_ini.gui_shade_color;var_ini.gui_dark_color;var_ini.progress_facecolor;var_ini.progress_startfacecolor;var_ini.progress_edgecolor;var_ini.progress_bgcolor];
   text_mat = strvcat('GUI text color','GUI light color','GUI shade color','GUI dark color','Progressbar ending face color','Progressbar starting face color','Progressbar edge color','Progressbar background color');
   %
   % open a GUI with the colors and the appropriate text
   %
   col_gui = gui_colors_fcn('init',var_ini,'GUI Colors','Change Colors',330,400,color_mat,text_mat);
   gui_controls = get(col_gui,'UserData');
   t_m = get(gui_controls.apply,'UserData');
   killguipid(col_gui);
   %
   % check if there has been any changes
   %
   if max(abs(var_ini.gui_foreground_color-t_m.color_mat(1,1:3)))>0;
      var_ini.gui_foreground_color = t_m.color_mat(1,1:3);
      set(controls.apply,'Enable','on');
   end;
   if max(abs(var_ini.gui_light_color-t_m.color_mat(2,1:3)))>0;
      var_ini.gui_light_color = t_m.color_mat(2,1:3);
      set(controls.apply,'Enable','on');
   end;
   if max(abs(var_ini.gui_shade_color-t_m.color_mat(3,1:3)))>0;
      var_ini.gui_shade_color = t_m.color_mat(3,1:3);
      set(controls.apply,'Enable','on');
   end;
   if max(abs(var_ini.gui_dark_color-t_m.color_mat(4,1:3)))>0;
      var_ini.gui_dark_color = t_m.color_mat(4,1:3);
      set(controls.apply,'Enable','on');
   end;
   if max(abs(var_ini.progress_facecolor-t_m.color_mat(5,1:3)))>0;
      var_ini.progress_facecolor = t_m.color_mat(5,1:3);
      set(controls.apply,'Enable','on');
   end;
   if max(abs(var_ini.progress_startfacecolor-t_m.color_mat(6,1:3)))>0;
      var_ini.progress_startfacecolor = t_m.color_mat(6,1:3);
      set(controls.apply,'Enable','on');
   end;
   if max(abs(var_ini.progress_edgecolor-t_m.color_mat(7,1:3)))>0;
      var_ini.progress_edgecolor = t_m.color_mat(7,1:3);
      set(controls.apply,'Enable','on');
   end;
   if max(abs(var_ini.progress_bgcolor-t_m.color_mat(8,1:3)))>0;
      var_ini.progress_bgcolor = t_m.color_mat(8,1:3);
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'textcolors'
   color_mat = [var_ini.text_color;var_ini.text_backgroundcolor];
   text_mat = strvcat('Text color','Background color');
   %
   % open a GUI with the colors and the appropriate text
   %
   col_gui = gui_colors_fcn('init',var_ini,'Text Colors','Change Colors',150,400,color_mat,text_mat);
   gui_controls = get(col_gui,'UserData');
   t_m = get(gui_controls.apply,'UserData');
   killguipid(col_gui);
   %
   % check if there has been any changes
   %
   if max(abs(var_ini.text_color-t_m.color_mat(1,1:3)))>0;
      var_ini.text_color = t_m.color_mat(1,1:3);
      set(controls.apply,'Enable','on');
   end;
   if max(abs(var_ini.text_backgroundcolor-t_m.color_mat(2,1:3)))>0;
      var_ini.text_backgroundcolor = t_m.color_mat(2,1:3);
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'framecolors'
   var_ini.previous.frame_light_color = var_ini.frame_light_color;
   var_ini.previous.frame_shade_color = var_ini.frame_shade_color;
   var_ini.previous.frame_dark_color = var_ini.frame_dark_color;
   color_mat = [var_ini.frame_color;var_ini.frame_light_color;var_ini.frame_shade_color;var_ini.frame_dark_color];
   text_mat = strvcat('Frame color','Frame light color','Frame shade color','Frame dark color');
   %
   % open a GUI with the colors and the appropriate text
   %
   col_gui = gui_colors_fcn('init',var_ini,'Frame Colors','Change Colors',210,400,color_mat,text_mat);
   gui_controls = get(col_gui,'UserData');
   t_m = get(gui_controls.apply,'UserData');
   killguipid(col_gui);
   %
   % check if there has been any changes
   %
   if max(abs(var_ini.frame_color-t_m.color_mat(1,1:3)))>0;
      var_ini.frame_color = t_m.color_mat(1,1:3);
      set(controls.apply,'Enable','on');
   end;
   if max(abs(var_ini.frame_light_color-t_m.color_mat(2,1:3)))>0;
      var_ini.frame_light_color = t_m.color_mat(2,1:3);
      set(controls.apply,'Enable','on');
   end;
   if max(abs(var_ini.frame_shade_color-t_m.color_mat(3,1:3)))>0;
      var_ini.frame_shade_color = t_m.color_mat(3,1:3);
      set(controls.apply,'Enable','on');
   end;
   if max(abs(var_ini.frame_dark_color-t_m.color_mat(4,1:3)))>0;
      var_ini.frame_dark_color = t_m.color_mat(4,1:3);
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'defaultcolors'
   new_colors = 0;
   if max(abs(var_ini.gui_light_color-[1 1 1]))>0;
      new_colors = 1;
   end;
   var_ini.gui_light_color = [1 1 1];
   if max(abs(var_ini.gui_shade_color-[0.5 0.5 0.5]))>0;
      new_colors = 1;
   end;
   var_ini.gui_shade_color = [0.5 0.5 0.5];
   if max(abs(var_ini.gui_dark_color))>0;
      new_colors = 1;
   end;
   var_ini.gui_dark_color = [0 0 0];
   if max(abs(var_ini.gui_foreground_color)-[0 0 0.4])>0;
      new_colors = 1;
   end;
   var_ini.gui_foreground_color = [0 0 0.4];
   if max(abs(var_ini.text_backgroundcolor-[1 1 1]))>0;
      new_colors = 1;
   end;
   var_ini.text_backgroundcolor = [1 1 1];
   if max(abs(var_ini.text_color))>0;
      new_colors = 1;
   end;
   var_ini.text_color = [0 0 0];
   if (iswinxp==1)&(matlabnumber>=7);
      if max(abs(var_ini.frame_color-[0 0 0.7]))>0;
         new_colors = 1;
      end;
      var_ini.frame_color = [0 0 0.7];
   else;
      if max(abs(var_ini.frame_color-[0.50196 0 0]))>0;
         new_colors = 1;
      end;
      var_ini.frame_color = [0.50196 0 0];
   end;
   if max(abs(var_ini.frame_light_color-[1 1 1]))>0;
      new_colors = 1;
   end;
   var_ini.frame_light_color = [1 1 1];
   if max(abs(var_ini.frame_shade_color-[0.5 0.5 0.5]))>0;
      new_colors = 1;
   end;
   var_ini.frame_shade_color = [0.5 0.5 0.5];
   if max(abs(var_ini.frame_dark_color))>0;
      new_colors = 1;
   end;
   var_ini.frame_dark_color = [0 0 0];
   if max(abs(var_ini.progress_facecolor-[0.65098 0.82353 1]))>0;
      new_colors = 1;
   end;
   var_ini.progress_facecolor = (1/255)*[166 210 255];
   if max(abs(var_ini.progress_facecolor-[0 0.14118 0.40784]))>0;
      new_colors = 1;
   end;
   var_ini.progress_facecolor = (1/255)*[0 36 104];
   
   if max(var_ini.progress_edgecolor)>0;
      new_colors = 1;
   end;
   var_ini.progress_edgecolor = [0 0 0];
   if max(abs(var_ini.progress_bgcolor-[1 1 1]))>0;
      new_colors = 1;
   end;
   var_ini.progress_bgcolor = [1 1 1];
   if new_colors==1;
      set(controls.apply,'Enable','on');
   end;
case 'toolbar_bgcolor'
   new_use_bgcolor = get(controls.toolbar_bgcolor,'Value');
   if abs(new_use_bgcolor-var_ini.use_toolbar_bgcolor)>0;
      set(controls.apply,'Enable','on');
      var_ini.use_toolbar_bgcolor = new_use_bgcolor;
   end;
   set(optionsgui,'UserData',controls);
case 'lambda_deter'
   hyp_gui = deterprior_dlg('init',var_ini);
   lambda_controls = get(hyp_gui,'UserData');
   tm = get(lambda_controls.apply,'UserData');
   new_ini = tm.ini;
   if abs(new_ini.lambda_d-var_ini.lambda_d)>0;
      var_ini.lambda_d = new_ini.lambda_d;
      set(controls.apply,'Enable','on');
   end;
   killguipid(hyp_gui);
%   set(optionsgui,'UserData',controls);
case 'lambda_inf_deter'
   newprior_inf_deter = get(controls.lambda_inf_deter,'Value');
   if abs(newprior_inf_deter-var_ini.prior_inf_deter)>0;
      var_ini.prior_inf_deter = newprior_inf_deter;
      set(controls.apply,'Enable','on');
      if var_ini.prior_inf_deter==1;
         set(controls.lambda_d,'Enable','on');
      else;
         set(controls.lambda_d,'Enable','off');
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'lambda_alpha'
   hyp_gui = alphaprior_dlg('init',var_ini);
   lambda_controls = get(hyp_gui,'UserData');
   tm = get(lambda_controls.apply,'UserData');
   new_ini = tm.ini;
   if abs(new_ini.lambda_alpha-var_ini.lambda_alpha)>0;
      var_ini.lambda_alpha = new_ini.lambda_alpha;
      set(controls.apply,'Enable','on');
   end;
   killguipid(hyp_gui);
%   set(optionsgui,'UserData',controls);
case 'lambda_omega'
   hyp_gui = omegaprior_dlg('init',var_ini);
   lambda_controls = get(hyp_gui,'UserData');
   tm = get(lambda_controls.apply,'UserData');
   new_ini = tm.ini;
   if abs(new_ini.amat_type-var_ini.amat_type)>0;
      var_ini.amat_type = new_ini.amat_type;
      set(controls.apply,'Enable','on');
   end;
   if var_ini.amat_type==0;
      if abs(new_ini.lambda_a-var_ini.lambda_a)>0;
         var_ini.lambda_a = new_ini.lambda_a;
         set(controls.apply,'Enable','on');
      end;
      if abs(new_ini.q_df-var_ini.q_df)>0;
         var_ini.q_df = new_ini.q_df;
         set(controls.apply,'Enable','on');
      end;
   end;
   if abs(new_ini.amat_lag-var_ini.amat_lag)>0;
      var_ini.amat_lag = new_ini.amat_lag;
      set(controls.apply,'Enable','on');
   end;
   killguipid(hyp_gui);
case 'lambda_inf_omega'
   newprior_inf_omega = get(controls.lambda_inf_omega,'Value');
   if abs(newprior_inf_omega-var_ini.prior_inf_omega)>0;
      var_ini.prior_inf_omega = newprior_inf_omega;
      set(controls.apply,'Enable','on');
   end;
   if var_ini.prior_inf_omega==1;
      set(controls.lambda_omega,'Enable','on');
   else;
      set(controls.lambda_omega,'Enable','off');
   end;
   set(optionsgui,'UserData',controls);
case 'lambda_inf_alpha'
   newprior_inf_alpha = get(controls.lambda_inf_alpha,'Value');
   if abs(newprior_inf_alpha-var_ini.prior_inf_alpha)>0;
      var_ini.prior_inf_alpha = newprior_inf_alpha;
      set(controls.apply,'Enable','on');
      if var_ini.prior_inf_alpha==1;
         set(controls.lambda_alpha,'Enable','on');
      else;
         set(controls.lambda_alpha,'Enable','off');
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'lambda_param'
   h = lambda_dlg('init',var_ini);
   lambda_controls = get(h,'UserData');
   tm = get(lambda_controls.apply,'UserData');
   new_var_ini = tm.ini;
   if abs(new_var_ini.lambda_b-var_ini.lambda_b)>0;
      var_ini.lambda_b = new_var_ini.lambda_b;
      set(controls.apply,'Enable','on');
   end;
   if abs(new_var_ini.lambda_l-var_ini.lambda_l)>0;
      var_ini.lambda_l = new_var_ini.lambda_l;
      set(controls.apply,'Enable','on');
   end;
   if abs(new_var_ini.lambda_theta-var_ini.lambda_theta)>0;
      var_ini.lambda_theta = new_var_ini.lambda_theta;
      set(controls.apply,'Enable','on');
   end;
   if abs(new_var_ini.lambda_e-var_ini.lambda_e)>0;
      var_ini.lambda_e = new_var_ini.lambda_e;
      set(controls.apply,'Enable','on');
   end;
   killguipid(h);
%   set(optionsgui,'UserData',controls);
case 'lambda_inf_shortrun'
   newprior_inf_shortrun = get(controls.lambda_inf_shortrun,'Value');
   if abs(newprior_inf_shortrun-var_ini.prior_inf_shortrun)>0;
      var_ini.prior_inf_shortrun = newprior_inf_shortrun;
      set(controls.apply,'Enable','on');
      if var_ini.prior_inf_shortrun==1;
         set(controls.lambda_param,'Enable','on');
      else;
         set(controls.lambda_param,'Enable','off');
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'pagesetup'
   curr_fig = get(0,'CurrentFigure');
   %
   % old values
   %
   oldfiginfo.inverthardcopy = get(curr_fig,'InvertHardcopy');
   oldfiginfo.paperorientation = get(curr_fig,'PaperOrientation');
   oldfiginfo.papertype = get(curr_fig,'PaperType');
   oldfiginfo.paperunits = get(curr_fig,'PaperUnits');
   oldfiginfo.paperpositionmode = get(curr_fig,'PaperPositionMode');
   h = pagesetup_fcn(curr_fig,var_ini.center_value,var_ini.fill_value,var_ini.crop_image);
   pagesetup = get(h,'UserData');
   figinfo = get(pagesetup.apply,'UserData');
   new_center_value = get(pagesetup.center,'Value');
   new_fill_value = get(pagesetup.fill,'Value');
   applied = get(pagesetup.apply,'Enable');
   if iscompiled==1;
      new_crop_image = get(pagesetup.cropimage,'Value');
   end;
   set(curr_fig,'InvertHardcopy',figinfo.inverthardcopy, ...
      'PaperOrientation',figinfo.paperorientation, ...
      'PaperType',figinfo.papertype, ...
      'PaperUnits',figinfo.paperunits, ...
      'PaperPositionMode',figinfo.paperpositionmode);
   if strcmp(figinfo.paperorientation,'portrait')==1;
      var_ini.landscape = 0;
   else;
      var_ini.landscape = 1;
   end;
   %
   % reset controls
   %
   if (strcmp(figinfo.paperorientation,oldfiginfo.paperorientation)==0)|(strcmp(figinfo.papertype,oldfiginfo.papertype)==0)|(strcmp(figinfo.paperunits,oldfiginfo.paperunits)==0)|(strcmp(figinfo.paperpositionmode,oldfiginfo.paperpositionmode)==0)|(strcmp(figinfo.inverthardcopy,oldfiginfo.inverthardcopy)==0);
      var_ini.paperposmode = figinfo.paperpositionmode;
      var_ini.paperunits = figinfo.paperunits;
      var_ini.papertype = figinfo.papertype;
      set(controls.apply,'Enable','on');
   end;
   if strcmp(figinfo.inverthardcopy,'on')==1;
      var_ini.invert_hardcopy = 1;
   else;
      var_ini.invert_hardcopy = 0;
   end;
   %
   % make sure Apply is disabled
   %
   if strcmp(applied,'off')==1;
      if isequal(var_ini.center_value,new_center_value)==0;
         var_ini.center_value = new_center_value;
         set(controls.apply,'Enable','on');
      end;
      if isequal(var_ini.fill_value,new_fill_value)==0;
         var_ini.fill_value = new_fill_value;
         set(controls.apply,'Enable','on');
      end;
      if (iscompiled==1)&(isequal(var_ini.crop_image,new_crop_image)==0);
         var_ini.crop_image = new_crop_image;
         set(controls.apply,'Enable','on');
      end;
   end;
   set(optionsgui,'UserData',controls);
   set(pagesetup.page,'UserData','done');
   killguipid(h);
case 'axescolor'
   newaxes_color = uisetcolor(var_ini.axes_color,'Select Axes Color');
   if (isnumeric(newaxes_color)==1)&(size(newaxes_color,2)==3);
      if isalmostequal(newaxes_color,var_ini.axes_color)==0;
         var_ini.axes_color = newaxes_color;
         set(controls.apply,'Enable','on');
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'titlecolor'
   newtitle_color = uisetcolor(var_ini.title_color,'Select Title Color');
   if (isnumeric(newtitle_color)==1)&(size(newtitle_color,2)==3);
      if isalmostequal(newtitle_color,var_ini.title_color)==0;
         var_ini.title_color = newtitle_color;
         set(controls.apply,'Enable','on');
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'labelcolor'
   newlabel_color = uisetcolor(var_ini.label_color,'Select Label Color');
   if (isnumeric(newlabel_color)==1)&(size(newlabel_color,2)==3);
      if isalmostequal(newlabel_color,var_ini.label_color)==0;
         var_ini.label_color = newlabel_color;
         set(controls.apply,'Enable','on');
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'axesfont'
   my_axes.FontName = var_ini.axes_fontname;
   my_axes.FontSize = var_ini.axes_fontsize;
   my_axes.FontWeight = var_ini.axes_fontweight;
   my_axes.FontAngle = var_ini.axes_fontangle;
   my_axes.FontUnits = var_ini.axes_fontunits;
   axesfont = uisetfont(my_axes,'Select Axes Font');
   if isnumeric(axesfont)==0;
      if (ischar(axesfont.FontName)==1)&(strcmp(axesfont.FontName,my_axes.FontName)==0);
         var_ini.axes_fontname = axesfont.FontName;
         set(controls.apply,'Enable','on');
      end;
      if (isnumeric(axesfont.FontSize)==1)&(isequal(axesfont.FontSize,my_axes.FontSize)==0);
         var_ini.axes_fontsize = axesfont.FontSize;
         set(controls.apply,'Enable','on');
      end;
      if (ischar(axesfont.FontWeight)==1)&(strcmp(axesfont.FontWeight,my_axes.FontWeight)==0);
         var_ini.axes_fontweight = axesfont.FontWeight;
         set(controls.apply,'Enable','on');
      end;
      if (ischar(axesfont.FontAngle)==1)&(strcmp(axesfont.FontAngle,my_axes.FontAngle)==0);
         var_ini.axes_fontangle = axesfont.FontAngle;
         set(controls.apply,'Enable','on');
      end;
      if (ischar(axesfont.FontUnits)==1)&(strcmp(axesfont.FontUnits,my_axes.FontUnits)==0);
         var_ini.axes_fontunits = axesfont.FontUnits;
         set(controls.apply,'Enable','on');
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'titlefont'
   my_title.FontName = var_ini.title_fontname;
   my_title.FontSize = var_ini.title_fontsize;
   my_title.FontWeight = var_ini.title_fontweight;
   my_title.FontAngle = var_ini.title_fontangle;
   my_title.FontUnits = var_ini.title_fontunits;
   titlefont = uisetfont(my_title,'Select Title Font');
   if isnumeric(titlefont)==0;
      if (ischar(titlefont.FontName)==1)&(strcmp(titlefont.FontName,my_title.FontName)==0);
         var_ini.title_fontname = titlefont.FontName;
         set(controls.apply,'Enable','on');
      end;
      if (isnumeric(titlefont.FontSize)==1)&(isequal(titlefont.FontSize,my_title.FontSize)==0);
         var_ini.title_fontsize = titlefont.FontSize;
         set(controls.apply,'Enable','on');
      end;
      if (ischar(titlefont.FontWeight)==1)&(strcmp(titlefont.FontWeight,my_title.FontWeight)==0);
         var_ini.title_fontweight = titlefont.FontWeight;
         set(controls.apply,'Enable','on');
      end;
      if (ischar(titlefont.FontAngle)==1)&(strcmp(titlefont.FontAngle,my_title.FontAngle)==0);
         var_ini.title_fontangle = titlefont.FontAngle;
         set(controls.apply,'Enable','on');
      end;
      if (ischar(titlefont.FontUnits)==1)&(strcmp(titlefont.FontUnits,my_title.FontUnits)==0);
         var_ini.title_fontunits = titlefont.FontUnits;
         set(controls.apply,'Enable','on');
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'labelfont'
   my_label.FontName = var_ini.label_fontname;
   my_label.FontSize = var_ini.label_fontsize;
   my_label.FontWeight = var_ini.label_fontweight;
   my_label.FontAngle = var_ini.label_fontangle;
   my_label.FontUnits = var_ini.label_fontunits;
   labelfont = uisetfont(my_label,'Select Label Font');
   if isnumeric(labelfont)==0;
      if (ischar(labelfont.FontName)==1)&(strcmp(labelfont.FontName,my_label.FontName)==0);
         var_ini.label_fontname = labelfont.FontName;
         set(controls.apply,'Enable','on');
      end;
      if (isnumeric(labelfont.FontSize)==1)&(isequal(labelfont.FontSize,my_label.FontSize)==0);
         var_ini.label_fontsize = labelfont.FontSize;
         set(controls.apply,'Enable','on');
      end;
      if (ischar(labelfont.FontWeight)==1)&(strcmp(labelfont.FontWeight,my_label.FontWeight)==0);
         var_ini.label_fontweight = labelfont.FontWeight;
         set(controls.apply,'Enable','on');
      end;
      if (ischar(labelfont.FontAngle)==1)&(strcmp(labelfont.FontAngle,my_label.FontAngle)==0);
         var_ini.label_fontangle = labelfont.FontAngle;
         set(controls.apply,'Enable','on');
      end;
      if (ischar(labelfont.FontUnits)==1)&(strcmp(labelfont.FontUnits,my_label.FontUnits)==0);
         var_ini.label_fontunits = labelfont.FontUnits;
         set(controls.apply,'Enable','on');
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'gui_font'
   new_gui_font = get(controls.gui_font,'Value');
   if abs(new_gui_font-var_ini.gui_font)>0;
      var_ini.gui_font = new_gui_font;
      set(controls.apply,'Enable','on');
      if var_ini.gui_font==1;
         set(controls.gui_fontbutton,'Enable','off');
         set(controls.fonttext,'Enable','off');
      else;
         set(controls.gui_fontbutton,'Enable','on');
         set(controls.fonttext,'Enable','on');
      end;
   end;
case 'gui_fontbutton'
   my_gui.FontName = var_ini.gui_fontname;
   my_gui.FontSize = var_ini.gui_fontsize;
   my_gui.FontWeight = var_ini.gui_fontweight;
   my_gui.FontAngle = var_ini.gui_fontangle;
   my_gui.FontsUnits = 'points';
   gui_fonts = uisetfont(my_gui,'Select GUI Controls Font');
   if isnumeric(gui_fonts)==0;
      if (ischar(gui_fonts.FontName)==1)&(strcmp(gui_fonts.FontName,my_gui.FontName)==0);
         var_ini.gui_fontname = gui_fonts.FontName;
         set(controls.apply,'Enable','on');
         var_ini.new_font = 1;
      end;
      if (isnumeric(gui_fonts.FontSize)==1)&(isequal(gui_fonts.FontSize,my_gui.FontSize)==0);
         var_ini.gui_fontsize = gui_fonts.FontSize;
         set(controls.apply,'Enable','on');
         var_ini.new_font = 1;
      end;
      if (ischar(gui_fonts.FontWeight)==1)&(strcmp(gui_fonts.FontWeight,my_gui.FontWeight)==0);
         var_ini.gui_fontweight = gui_fonts.FontWeight;
         set(controls.apply,'Enable','on');
         var_ini.new_font = 1;
      end;
      if (ischar(gui_fonts.FontAngle)==1)&(strcmp(gui_fonts.FontAngle,my_gui.FontAngle)==0);
         var_ini.gui_fontangle = gui_fonts.FontAngle;
         set(controls.apply,'Enable','on');
         var_ini.new_font = 1;
      end;
      %
      % we need to do something about this below. should be applied upon clicking the Apply button
      %
      if var_ini.new_font==1;
         %
         % store the old font names
         %
         var_ini.oldfont.fontname = my_gui.FontName;
         var_ini.oldfont.fontsize = my_gui.FontSize;
         var_ini.oldfont.fontweight = my_gui.FontWeight;
         var_ini.oldfont.fontangle = my_gui.FontAngle;
%         all_obj = findobj(optionsgui,'FontName',my_gui.FontName,'FontSize',my_gui.FontSize,'FontWeight',my_gui.FontWeight,'FontAngle',my_gui.FontAngle);
%         if isempty(all_obj)==0;
%            set(all_obj,'FontName',var_ini.gui_fontname,'FontSize',var_ini.gui_fontsize,'FontWeight',var_ini.gui_fontweight,'FontAngle',var_ini.gui_fontangle);
%         end;
      end;
   end;
case 'fonttext'
   my_text.FontName = var_ini.text_fontname;
   my_text.FontSize = var_ini.text_fontsize;
   my_text.FontWeight = var_ini.text_fontweight;
   my_text.FontAngle = var_ini.text_fontangle;
   my_text.FontUnits = var_ini.text_fontunits;
   textfont = uisetfont(my_text,'Select Text Font');
   if isnumeric(textfont)==0;
      if (ischar(textfont.FontName)==1)&(strcmp(textfont.FontName,my_text.FontName)==0);
         var_ini.text_fontname = textfont.FontName;
         set(controls.apply,'Enable','on');
      end;
      if (isnumeric(textfont.FontSize)==1)&(isequal(textfont.FontSize,my_text.FontSize)==0);
         var_ini.text_fontsize = textfont.FontSize;
         set(controls.apply,'Enable','on');
      end;
      if (ischar(textfont.FontWeight)==1)&(strcmp(textfont.FontWeight,my_text.FontWeight)==0);
         var_ini.text_fontweight = textfont.FontWeight;
         set(controls.apply,'Enable','on');
      end;
      if (ischar(textfont.FontAngle)==1)&(strcmp(textfont.FontAngle,my_text.FontAngle)==0);
         var_ini.text_fontangle = textfont.FontAngle;
         set(controls.apply,'Enable','on');
      end;
      if (ischar(textfont.FontUnits)==1)&(strcmp(textfont.FontUnits,my_text.FontUnits)==0);
         var_ini.text_fontunits = textfont.FontUnits;
         set(controls.apply,'Enable','on');
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'rstate'
   newrandom_state = get(controls.rstate,'Value');
   if abs(newrandom_state-var_ini.random_state)>0;
      set(controls.apply,'Enable','on');
      var_ini.random_state = newrandom_state;
   end;
   set(optionsgui,'UserData',controls);
case 'nRep'
   var_ini.nRep_value = get(controls.nRep,'Value');
   repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
   newnRep = repvalues(var_ini.nRep_value);
   if abs(newnRep-var_ini.nRep)>0;
      set(controls.apply,'Enable','on');
      var_ini.nRep = newnRep;
   end;
   set(optionsgui,'UserData',controls);
case 'interpolate'
   var_ini.interpolate_value = get(controls.interpolate,'Value');
   interpol_vec = strvcat('nearest','linear','spline','cubic','knorm','kepan','krect','ktria','kbiwe','ktriw','klapl','klogi');
   newinterpolate = strtrim(interpol_vec(var_ini.interpolate_value,:));
   if strcmp(var_ini.interpolate,newinterpolate)==0;
      set(controls.apply,'Enable','on');
      var_ini.interpolate = newinterpolate;
   end;
   set(optionsgui,'UserData',controls);
case 'nDraw'
   T_str = get(controls.nDraw,'String');
   T_val = strtrim(T_str(get(controls.nDraw,'Value'),:));
   newnDraw = mystr2num(strrep(T_val,',',''));
   if abs(newnDraw-var_ini.nDraw)>0;
      set(controls.apply,'Enable','on');
      var_ini.nDraw = newnDraw;
   end;
   set(optionsgui,'UserData',controls);
case 'maxit'
   newmaxitv = get(controls.maxit,'Value');
   newmaxit = var_ini.maxitvec(1,newmaxitv);
   if abs(newmaxit-var_ini.maxit)>0;
      set(controls.apply,'Enable','on');
      var_ini.maxit = newmaxit;
   end;
   set(optionsgui,'UserData',controls);
case 'convcrit'
   newconvcrit = get(controls.convcrit,'Value');
   if abs(newconvcrit-var_ini.convcrit)>0;
      set(controls.apply,'Enable','on');
      var_ini.convcrit = newconvcrit;
   end;
   set(optionsgui,'UserData',controls);
case 'box'
   newbox = get(controls.box,'Value');
   if abs(newbox-var_ini.box)>0;
      set(controls.apply,'Enable','on');
      var_ini.box = newbox;
   end;
   set(optionsgui,'UserData',controls);
case 'delay'
   newdelay = get(controls.delay,'String');
   newdelay = mystr2num(strrep(newdelay,' ',''));
   checkvalue = 0;
   if isempty(newdelay)==1;
      checkvalue = 1;
   else;
      if newdelay>=0;
         if (round(newdelay)-newdelay)==0;
            var_ini.delay = round(newdelay);
            set(controls.apply,'Enable','on');
         else;
            checkvalue = 1;
         end;
      else;
         checkvalue = 1;
      end;
   end;
   if checkvalue==1;
      txt = ['The GUI delay value in milliseconds you entered, ' get(controls.delay,'String') ', is not valid. This parameter must be a nonnegative integer.'];
      txt = strvcat(txt,' ','Please enter another value!');
      about(txt,'warning','Warning - GUI Delay',120,500);
      set(controls.delay,'String',num2str(var_ini.delay));
   end;
   set(optionsgui,'UserData',controls);
case 'maxresp'
   newmaxresp = get(controls.maxresp,'String');
   newmaxresp = mystr2num(strrep(newmaxresp,' ',''));
   checkvalue = 0;
   if isempty(newmaxresp)==1;
      checkvalue = 1;
   else;
      if newmaxresp>1;
         if (round(newmaxresp)-newmaxresp)==0;
            var_ini.maxresp = round(newmaxresp);
            set(controls.apply,'Enable','on');
         else;
            checkvalue = 1;
         end;
      else;
         checkvalue = 1;
      end;
   end;
   if checkvalue==1;
      txt = ['The Maximum horizon you selected for the Number of responses Control, ' get(controls.maxresp,'String') ', is not valid. Please enter another value!'];
      about(txt,'warning','Warning - Illegal Number of Responses',120,500);
      set(controls.maxresp,'String',num2str(var_ini.maxresp));
   end;
   set(optionsgui,'UserData',controls);
case 'maxlag'
   newmaxlag = get(controls.maxlag,'String');
   newmaxlag = mystr2num(strrep(newmaxlag,' ',''));
   checkvalue = 0;
   if isempty(newmaxlag)==1;
      checkvalue = 1;
   else;
      if newmaxlag>=1;
         if (round(newmaxlag)-newmaxlag)==0;
            if abs(var_ini.maxlag-newmaxlag)>0;
               var_ini.maxlag = round(newmaxlag);
               set(controls.apply,'Enable','on');
            end;
         else;
            checkvalue = 1;
         end;
      else;
         checkvalue = 1;
      end;
   end;
   if checkvalue==1;
      txt = ['The Maximum number of lags you selected for the Lag order Control, ' get(controls.maxlag,'String') ', is not valid. It must be a positive integer. Please enter another value!'];
      about(txt,'warning','Warning - Illegal Lag Order',120,500);
      set(controls.maxlag,'String',num2str(var_ini.maxlag));
   end;
   set(optionsgui,'UserData',controls);
case 'ms_maxlag'
   newmaxlag = get(controls.ms_maxlag,'String');
   newmaxlag = mystr2num(strtrim(newmaxlag));
   checkvalue = 0;
   if isempty(newmaxlag)==1;
      checkvalue = 1;
   else;
      if newmaxlag>=1;
         if (round(newmaxlag)-newmaxlag)==0;
            if abs(newmaxlag-var_ini.ms_maxlag)>0;
               var_ini.ms_maxlag = round(newmaxlag);
               set(controls.apply,'Enable','on');
            end;
         else;
            checkvalue = 1;
         end;
      else;
         checkvalue = 1;
      end;
   end;
   if checkvalue==1;
      txt = ['The Maximum lag order you selected for the "Model Selection" function, ' get(controls.ms_maxlag,'String') ', is not valid. It must be a positive integer. Please enter another value!'];
      about(txt,'warning','Warning - Illegal Lag Order',120,500);
      set(controls.ms_maxlag,'String',num2str(var_ini.ms_maxlag));
   end;
   set(optionsgui,'UserData',controls);
case 'noise_parm'
   newnoise_parm = get(controls.noise_parm,'String');
   newnoise_parm = mystr2num(strtrim(newnoise_parm));
   checkvalue = 0;
   if isempty(newnoise_parm)==1;
      checkvalue = 1;
   else;
      if (newnoise_parm>=0)&(newnoise_parm<=1);
         if isequal(var_ini.noise_parm,newnoise_parm)==0;
            if strcmp(num2str(var_ini.noise_parm,'%0.8f'),num2str(newnoise_parm,'%0.8f'))==0;
               var_ini.noise_parm = newnoise_parm;
               set(controls.apply,'Enable','on');
            else;
               txt = ['The value you selected for the noise parameter for certain Wald tests, ' strtrim(get(controls.noise_parm,'String')) ', is not sufficiently different from the previous value, ' num2str(var_ini.noise_parm,'%0.8f') '. Structural VAR only allows up to 8 decimals for this parameter. Please enter another value!'];
               about(txt,'warning','Warning - Noise Parameter Value',120,500);
            end;
         end;
      else;
         checkvalue = 1;
      end;
   end;
   if checkvalue==1;
      txt = ['The value you selected for the noise parameter for certain Wald tests, ' strtrim(get(controls.noise_parm,'String')) ', is not valid. Only values between 0 and 1 are treated as valid. Please enter another value!'];
      about(txt,'warning','Warning - Illegal Noise Parameter Value',120,500);
   end;
   set(controls.noise_parm,'String',num2str(var_ini.noise_parm,'%0.8f'));
   set(optionsgui,'UserData',controls);
case 'xgrid'
   newxgrid = get(controls.xgrid,'Value');
   if abs(newxgrid-var_ini.xgrid)>0;
      var_ini.xgrid = newxgrid;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'ygrid'
   newygrid = get(controls.ygrid,'Value');
   if abs(newygrid-var_ini.ygrid)>0;
      var_ini.ygrid = newygrid;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'zgrid'
   newzgrid = get(controls.zgrid,'Value');
   if abs(newzgrid-var_ini.zgrid)>0;
      var_ini.zgrid = newzgrid;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'external'
   newexternal = get(controls.external,'Value');
   if abs(newexternal-var_ini.external)>0;
      var_ini.external = newexternal;
      set(controls.apply,'Enable','on');
      if var_ini.external==1;
         set(controls.graphicsfmttext,'Enable','on');
         set(controls.graphicsfmt,'Enable','on');
      else;
         set(controls.graphicsfmttext,'Enable','off');
         set(controls.graphicsfmt,'Enable','off');
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'zbuffer'
   newz_buffer = get(controls.zbuffer,'Value');
   if abs(newz_buffer-var_ini.z_buffer)>0;
      var_ini.z_buffer = newz_buffer;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'ytick'
   newytick = get(controls.ytick,'Value');
   if abs(newytick-var_ini.ytick)>0;
      var_ini.ytick = newytick;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'xtick'
   newxtick = get(controls.xtick,'Value');
   if abs(newxtick-var_ini.xtick)>0;
      var_ini.xtick = newxtick;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'colors'
   newcolors = get(controls.colors,'Value');
   if abs(newcolors-var_ini.colors)>0;
      var_ini.colors = newcolors;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'bartserial'
   newbartserial = get(controls.bartserial,'Value');
   if abs(newbartserial-var_ini.bartserial)>0;
      var_ini.bartserial = newbartserial;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'sscorrect'
   newsscorrect = get(controls.sscorrect,'Value');
   if abs(newsscorrect-var_ini.sscorrect)>0;
      var_ini.sscorrect = newsscorrect;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'omnibus'
   newomnibus = get(controls.omnibus,'Value');
   if abs(newomnibus-var_ini.omnibus)>0;
      var_ini.omnibus = newomnibus;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'transeig'
   newtranseig = get(controls.transeig,'Value');
   if abs(newtranseig-var_ini.transeig)>0;
      var_ini.transeig = newtranseig;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'fluctest'
   newfluctest = get(controls.fluctest,'Value');
   if abs(newfluctest-var_ini.fluctest)>0;
      var_ini.fluctest = newfluctest;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'tracebart'
   newtracebart = get(controls.tracebart,'Value');
   if abs(newtracebart-var_ini.tracebart)>0;
      var_ini.tracebart = newtracebart;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'betagrad'
   newbetagrad = get(controls.betagrad,'Value');
   if abs(newbetagrad-var_ini.betagrad)>0;
      var_ini.betagrad = newbetagrad;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'rahbek'
   newrahbek = get(controls.rahbek,'Value');
   if abs(newrahbek-var_ini.rahbek)>0;
      var_ini.rahbek = newrahbek;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'reestbeta'
   newreestbeta = get(controls.reestbeta,'Value');
   if abs(newreestbeta-var_ini.reestbeta)>0;
      var_ini.reestbeta = newreestbeta;
      set(controls.apply,'Enable','on');
      if var_ini.reestbeta==0;
         set(controls.method1,'String','''3-step'' Classical Gaussian ML (beta, reduced form, B matrix)');
         set(controls.method2,'String','''2-step'' Classical Gaussian ML (beta, reduced form and B matrix)');
      else;
         set(controls.method1,'String','''2-step'' Classical Gaussian ML (beta and reduced form, B matrix)');
         set(controls.method2,'String','Full Information Classical Gaussian ML');
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'normbeta'
   newnormbeta = get(controls.normbeta,'Value');
   if abs(newnormbeta-var_ini.normbeta)>0;
      var_ini.normbeta = newnormbeta;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'decompose_det'
   newdecompose_det = get(controls.decompose_det,'Value');
   if abs(newdecompose_det-var_ini.decompose_det)>0;
      var_ini.decompose_det = newdecompose_det;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'fullrec'
   newfullrec = get(controls.fullrec,'Value');
   if abs(newfullrec-var_ini.fullrec)>0;
      var_ini.fullrec = newfullrec;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'chowfc'
   newchowfc = get(controls.chowfc,'Value');
   if abs(newchowfc-var_ini.chowfc)>0;
      var_ini.chowfc = newchowfc;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'chow'
   newchow = get(controls.chow,'Value');
   if abs(newchow-var_ini.chow)>0;
      var_ini.chow = newchow;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'loadguiicon'
   newloadguiicon = get(controls.loadguiicon,'Value');
   if abs(newloadguiicon-var_ini.loadguiicon)>0;
      var_ini.loadguiicon = newloadguiicon;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'loadicon'
   newloadicon = get(controls.loadicon,'Value');
   if abs(newloadicon-var_ini.loadicon)>0;
      var_ini.loadicon = newloadicon;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'noicon'
   newnoicon = get(controls.noicon,'Value');
   if abs(newnoicon-var_ini.noicon)>0;
      var_ini.noicon = newnoicon;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'browsedialog'
   newbrowsedialog = get(controls.browsedialog,'Value');
   if abs(newbrowsedialog-var_ini.browsedialog)>0;
      var_ini.browsedialog = newbrowsedialog;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'opendialog'
   newopendialog = get(controls.opendialog,'Value');
   if abs(newopendialog-var_ini.opendialog)>0;
      var_ini.opendialog = newopendialog;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'recalpha'
   newrecalpha = get(controls.recalpha,'Value');
   if abs(newrecalpha-var_ini.recalpha)>0;
      var_ini.recalpha = newrecalpha;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'recpi'
   newrecpi = get(controls.recpi,'Value');
   if abs(newrecpi-var_ini.recpi)>0;
      var_ini.recpi = newrecpi;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'rectrace'
   newrectrace = get(controls.rectrace,'Value');
   if abs(newrectrace-var_ini.rectrace)>0;
      var_ini.rectrace = newrectrace;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'topeig'
   newtopeig = get(controls.topeig,'Value');
   if abs(newtopeig-var_ini.topeig)>0;
      var_ini.topeig = newtopeig;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'extraccrit'
   newextraccrit = get(controls.extraccrit,'Value');
   if abs(newextraccrit-var_ini.extraccrit)>0;
      var_ini.extraccrit = newextraccrit;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'taylor_nyblom'
   newtaylor_nyblom = get(controls.taylor_nyblom,'Value');
   if abs(newtaylor_nyblom-var_ini.taylor_nyblom)>0;
      var_ini.taylor_nyblom = newtaylor_nyblom;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'nyblom'
   newnyblom = get(controls.nyblom,'Value');
   if abs(newnyblom-var_ini.nyblom)>0;
      var_ini.nyblom = newnyblom;
      set(controls.apply,'Enable','on');
   end;
   if var_ini.nyblom==0;
      var_ini.nyblombeta = 0;
      set(controls.nyblombeta,'Value',0);
   end;
   set(optionsgui,'UserData',controls);
case 'nyblombeta'
   newnyblombeta = get(controls.nyblombeta,'Value');
   if abs(newnyblombeta-var_ini.nyblombeta)>0;
      var_ini.nyblombeta = newnyblombeta;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'akaike'
   newakaike = get(controls.akaike,'Value');
   if abs(newakaike-var_ini.akaike)>0;
      var_ini.akaike = newakaike;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'restat'
   newrestat = get(controls.restat,'Value');
   if abs(newrestat-var_ini.restat)>0;
      var_ini.restat = newrestat;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'dummytests'
   newdummytests = get(controls.dummytests,'Value');
   if abs(newdummytests-var_ini.dummytests)>0;
      var_ini.dummytests = newdummytests;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'rest_march'
   newrest_march = get(controls.rest_march,'Value');
   if abs(newrest_march-var_ini.rest_march)>0;
      var_ini.rest_march = newrest_march;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'shortdyn'
   newshortdyn = get(controls.shortdyn,'Value');
   if abs(newshortdyn-var_ini.shortdyn)>0;
      var_ini.shortdyn = newshortdyn;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'weakexo'
   newweakexo = get(controls.weakexo,'Value');
   if abs(newweakexo-var_ini.weakexo)>0;
      var_ini.weakexo = newweakexo;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'excludediffs'
   newexcludediffs = get(controls.excludediffs,'Value');
   if abs(newexcludediffs-var_ini.excludediffs)>0;
      var_ini.excludediffs = newexcludediffs;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'gctest'
   newgctest = get(controls.gctest,'Value');
   if abs(newgctest-var_ini.gctest)>0;
      var_ini.gctest = newgctest;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'commoncycles'
   newcommoncycles = get(controls.commoncycles,'Value');
   if abs(newcommoncycles-var_ini.commoncycles)>0;
      var_ini.commoncycles = newcommoncycles;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'excludestat'
   newexcludestat = get(controls.excludestat,'Value');
   if abs(newexcludestat-var_ini.excludestat)>0;
      var_ini.excludestat = newexcludestat;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'burn_in'
   newb_val = get(controls.burn_in,'Value');
   str_burnin = get(controls.burn_in,'String');
   newburn_in = mystr2num(strrep(strtrim(str_burnin(newb_val,:)),',',''));
   if abs(newburn_in-var_ini.burn_in)>0;
      var_ini.burn_in = newburn_in;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'save_draws'
   news_val = get(controls.save_draws,'Value');
   str_draws = get(controls.save_draws,'String');
   newsave_draws = mystr2num(strrep(strtrim(str_draws(news_val,:)),',',''));
   if abs(newsave_draws-var_ini.save_draws)>0;
      var_ini.save_draws = newsave_draws;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'bad_draws'
   newbad_draws = get(controls.bad_draws,'Value');
   if abs(newbad_draws-var_ini.bad_draws)>0;
      var_ini.bad_draws = newbad_draws;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'discard_explosive'
   newdiscard_explosive = get(controls.discard_explosive,'Value');
   if abs(newdiscard_explosive-var_ini.discard_explosive)>0;
      var_ini.discard_explosive = newdiscard_explosive;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'save_freq'
   newsave_freq = get(controls.save_freq,'Value');
   if abs(newsave_freq-var_ini.save_freq)>0;
      var_ini.save_freq = newsave_freq;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'lagtest'
   newlagtest = get(controls.lagtest,'Value')-1;
   if abs(newlagtest-var_ini.lagtest)>0;
      var_ini.lagtest = newlagtest;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'lstrtest'
   newlstr = get(controls.lstrtest,'Value');
   if abs(newlstr-var_ini.lstrtest)>0;
      var_ini.lstrtest = newlstr;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'append'
   newappend = get(controls.append,'Value');
   if abs(newappend-var_ini.append)>0;
      var_ini.append = newappend;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'openvar'
   newopenvar = get(controls.openvar,'Value');
   if abs(newopenvar-var_ini.openvar)>0;
      var_ini.openvar = newopenvar;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'portmanteau'
   newportmanteau = get(controls.portmanteau,'Value');
   if abs(newportmanteau-var_ini.portmanteau)>0;
      var_ini.portmanteau = newportmanteau;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'lbcorrect'
   newlbcorrect = get(controls.lbcorrect,'Value');
   if abs(newlbcorrect-var_ini.lbcorrect)>0;
      var_ini.lbcorrect = newlbcorrect;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'uselastfile'
   newuselastfile = get(controls.uselastfile,'Value');
   if abs(newuselastfile-var_ini.uselastfile)>0;
      var_ini.uselastfile = newuselastfile;
      if var_ini.uselastfile==1;
         set(controls.startrun,'Enable','on');
      else;
         set(controls.startrun,'Enable','off');
         startrun = 0;
         set(controls.startrun,'Value',startrun);
      end;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'startrun'
   newstartrun = get(controls.startrun,'Value');
   if abs(newstartrun-var_ini.startrun)>0;
      var_ini.startrun = newstartrun;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'logtab'
   newlogtab = get(controls.logtab,'Value');
   if abs(newlogtab-var_ini.logtab)>0;
      var_ini.logtab = newlogtab;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'clearlog'
   newclearlog = get(controls.clearlog,'Value');
   if abs(newclearlog-var_ini.clearlog)>0;
      var_ini.clearlog = newclearlog;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'outofsample'
   newoutofsample = get(controls.outofsample,'Value');
   if abs(newoutofsample-var_ini.outofsample)>0;
      var_ini.outofsample = newoutofsample;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'forecasthorizon'
   newforecasthorizon = get(controls.forecasthorizon,'Value');
   if abs(newforecasthorizon-var_ini.forecasthorizon)>0;
      var_ini.forecasthorizon = newforecasthorizon;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'noprint'
   newnoprint = get(controls.noprint,'Value');
   if abs(newnoprint-var_ini.noprint)>0;
      var_ini.noprint = newnoprint;
      set(controls.apply,'Enable','on');
   end;
   if var_ini.noprint==1;
      set(controls.openmyoutput,'Enable','off');
      set(controls.append,'Enable','off');
   else;
      set(controls.openmyoutput,'Enable','on');
      set(controls.append,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'openmyoutput'
   newopenmyoutput = get(controls.openmyoutput,'Value');
   if abs(newopenmyoutput-var_ini.openmyoutput)>0;
      var_ini.openmyoutput = newopenmyoutput;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'editcontext'
   newedit_context = get(controls.editcontext,'Value');
   if abs(newedit_context-var_ini.edit_context)>0;
      var_ini.edit_context = newedit_context;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'sillyq'
   newsillyq = get(controls.sillyq,'Value');
   if abs(newsillyq-var_ini.sillyq)>0;
      var_ini.sillyq = newsillyq;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'geometry'
   newgeometryvalue = get(controls.geometry,'Value');
   if newgeometryvalue==1;
      var_ini.geometry = [var_ini.position(1,1) var_ini.position(1,2)];
   else;
      var_ini.geometry = [0 0];
   end;
   if abs(newgeometryvalue-var_ini.geometryvalue)>0;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'identify'
   newidentify = get(controls.identify,'Value');
   if abs(newidentify-var_ini.identify)>0;
      var_ini.identify = newidentify;
      set(controls.apply,'Enable','on');
   end;
case 'method'
   whichobj = gco;
   set(whichobj,'Value',1);
   if whichobj==controls.method1;
      set(controls.method2,'Value',0);
      set(controls.method3,'Value',0);
      newmethod = [1 0 0];
   elseif whichobj==controls.method2;
      set(controls.method1,'Value',0);
      set(controls.method3,'Value',0);
      newmethod = [0 1 0];
   else;
      set(controls.method1,'Value',0);
      set(controls.method2,'Value',0);
      newmethod = [0 0 1];
   end;
   if strcmp(num2str(newmethod),num2str(var_ini.method))==0;
      set(controls.apply,'Enable','on');
      var_ini.method = newmethod;
   end;
   set(optionsgui,'UserData',controls);
case 'dirstructure'
   newdirstructure = get(controls.dirstructure,'Value');
   if abs(newdirstructure-var_ini.dirstructure)>0;
      var_ini.dirstructure = newdirstructure;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'critval'
   newcritvalnum = get(controls.critval,'Value');
   if newcritvalnum==1;
      newcritval = 1;
   elseif newcritvalnum==2;
      newcritval = 2;
   elseif newcritvalnum==3;
      newcritval = 5;
   elseif newcritvalnum==4;
      newcritval = 10;
   elseif newcritvalnum==5;
      newcritval = 20;
   else;
      newcritval = 100;
   end;
   if abs(newcritval-var_ini.critval)>0;
      var_ini.critval = newcritval;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'dvipdfm'
   newdvipdfm = get(controls.dvipdfm,'Value');
   if abs(newdvipdfm-var_ini.dvipdfm)>0;
      var_ini.dvipdfm = newdvipdfm;
      set(controls.apply,'Enable','on');
   end;
case 'maximizeviewer'
   newmaximizeviewer = get(controls.maximizeviewer,'Value');
   if abs(newmaximizeviewer-var_ini.maximizeviewer)>0;
      var_ini.maximizeviewer = newmaximizeviewer;
      set(controls.apply,'Enable','on');
   end;
case 'texoutputformat'
   newtexoutputformat = get(controls.texoutput,'Value');
   if abs(newtexoutputformat-var_ini.texoutputformat)>0;
      var_ini.texoutputformat = newtexoutputformat;
      set(controls.apply,'Enable','on');
   end;
case 'exportdata'
   newexportdata = get(controls.exportdata,'Value');
   if abs(newexportdata-var_ini.exportdata)>0;
      var_ini.exportdata = newexportdata;
      set(controls.apply,'Enable','on');
   end;
case 'decimals'
   newdecimals = get(controls.decimals,'Value')+1;
   if abs(newdecimals-var_ini.decimals)>0;
      var_ini.decimals = newdecimals;
      set(controls.apply,'Enable','on');
   end;
case 'pdfversion'
   newpdfvalue = get(controls.pdfversion,'Value');
   if newpdfvalue==1;
      newpdfversion = '1.2';
   elseif newpdfvalue==2;
      newpdfversion = '1.3';
   else;
      newpdfversion = '1.4';
   end;
   if strcmp(var_ini.pdfversion,newpdfversion)==0;
      var_ini.pdfversion = newpdfversion;
      set(controls.apply,'Enable','on');
   end;
case 'texheader'
   newtexheadertxt = get(controls.texheader,'String');
   if size(newtexheadertxt,1)==1;
      newtexheadertxt = strtrim(newtexheadertxt);
   end;
   if isempty(newtexheadertxt)==0;
      texheader = '';
      for i=1:size(newtexheadertxt,1);
         newtexheadertxt_i = strtrim(newtexheadertxt(i,:));
         if isempty(newtexheadertxt_i)==0;
            texheader = [texheader newtexheadertxt_i '|'];
         end;
      end;
      texheadertxt = texheader;
      texheadertxt = texheadertxt(1,1:size(texheadertxt,2)-1);
      texheadertxt = vecstr(strrep(texheadertxt,'|',' '));
      if strcmp(texheader,var_ini.texheader)==0;
         var_ini.texheader = texheader;
         var_ini.texheadertxt = texheadertxt;
         set(controls.apply,'Enable','on');
      end;
      set(controls.texheader,'String',texheadertxt);
   else;
      set(controls.texheader,'String',var_ini.texheadertxt);
   end;
case 'defaulttexheader'
   texheader = '\documentclass[12pt]{article}|\usepackage[T1]{fontenc}|\usepackage[ansinew]{inputenc}|\usepackage{amsmath,amssymb}|';
   texheadertxt = texheader;
   texheadertxt = texheadertxt(1,1:size(texheadertxt,2)-1);
   texheadertxt = vecstr(strrep(texheadertxt,'|',' '));
   set(controls.texheader,'String',texheadertxt);
   optionsdlg('texheader');
   var_ini = get(controls.cancel,'UserData');
   oldvar_ini = var_ini.oldvar;

case 'graphicsfmt'
   graphicsvalue = get(controls.graphicsfmt,'Value');
   if graphicsvalue==1;
      newgraphicsfmt = 'eps';
   elseif graphicsvalue==2;
      newgraphicsfmt = 'ai';
   elseif graphicsvalue==3;
      newgraphicsfmt = 'bmp';
   elseif graphicsvalue==4;
      newgraphicsfmt = 'jpg';
   elseif graphicsvalue==5;
      newgraphicsfmt = 'tif';
   elseif graphicsvalue==6;
      newgraphicsfmt = 'png';
   elseif graphicsvalue==7;
      newgraphicsfmt = 'pcx';
   elseif graphicsvalue==8;
      newgraphicsfmt = 'pbm';
   elseif graphicsvalue==9;
      newgraphicsfmt = 'pgm';
   elseif graphicsvalue==10;
      newgraphicsfmt = 'ppm';
   elseif graphicsvalue==11;
      newgraphicsfmt = 'emf';
   elseif graphicsvalue==12;
      newgraphicsfmt = 'fig';
   end;
   if strcmp(var_ini.graphicsfmt,newgraphicsfmt)==0;
      var_ini.graphicsfmt = newgraphicsfmt;
      set(controls.apply,'Enable','on');
   end;
   set(optionsgui,'UserData',controls);
case 'checkaiviewer'
   newaiviewer = get(controls.aivieweredit,'String');
   newaiviewer = strtrim(newaiviewer);
   if strcmp(newaiviewer,'')==0;
      if appexist(newaiviewer)==1;
         if strcmp(lower(newaiviewer),lower(var_ini.aiviewer))==0;
            if ispc==1;
               var_ini.aiviewer = lower(newaiviewer);
            else;
               var_ini.aiviewer = newaiviewer;
            end;
            set(controls.apply,'Enable','on');
         else;
            set(controls.aivieweredit,'String',var_ini.aiviewer);
         end;
      else;
         var_ini.aiviewer = oldvar_ini.aiviewer;
         if strcmp(var_ini.aiviewer,'')==0;
            if appexist(var_ini.aiviewer)==0;
               var_ini.aiviewer = '';
            end;
         end;
         set(controls.aivieweredit,'String',var_ini.aiviewer);
      end;
   else;
      if strcmp(newaiviewer,var_ini.aiviewer)==0;
         var_ini.aiviewer = '';
         set(controls.apply,'Enable','on');
      end;
      set(controls.aivieweredit,'String',var_ini.aiviewer);
   end;
   set(optionsgui,'UserData',controls);
case 'aiviewer'
   if strcmp(var_ini.aiviewer,'')==1;
      if ispc==1;
         file = strcat(pwd,'\','*.exe');
      elseif strcmp(computer,'MAC2')==1;
         file = strcat(pwd,'\','*.exe');
      else;
         file = strcat(pwd,'/','*.exe');
      end;
   else;
      file = var_ini.aiviewer;
   end;
   if matlabnumber>=6.0;
      thisfile = getfilename(file);
      file = cell(1,2);
      file{1,1} = thisfile;
      file{1,2} = 'Applications (*.exe)';
   end;
   [aiexe,aipath] = uigetfile(file,'Open');
   drawnow;
   if isnumeric(aiexe)==0;
      newaiviewer = strcat(aipath,aiexe);
      if appexist(newaiviewer)==1;
         if strcmp(lower(newaiviewer),lower(var_ini.aiviewer))==0;
            if ispc==1;
               var_ini.aiviewer = lower(newaiviewer);
            else;
               var_ini.aiviewer = newaiviewer;
            end;
            set(controls.aivieweredit,'String',var_ini.aiviewer);
            set(controls.apply,'Enable','on');
         end;
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'checkepsviewer'
   newepsviewer = get(controls.epsvieweredit,'String');
   newepsviewer = strtrim(newepsviewer);
   if strcmp(newepsviewer,'')==0;
      if appexist(newepsviewer)==1;
         if strcmp(lower(newepsviewer),lower(var_ini.epsviewer))==0;
            if ispc==1;
               var_ini.epsviewer = lower(newepsviewer);
            else;
               var_ini.epsviewer = newepsviewer;
            end;
            set(controls.apply,'Enable','on');
         else;
            set(controls.epsvieweredit,'String',var_ini.epsviewer);
         end;
      else;
         var_ini.epsviewer = oldvar_ini.epsviewer;
         if strcmp(var_ini.epsviewer,'')==0;
            if appexist(var_ini.epsviewer)==0;
               var_ini.epsviewer = '';
            end;
         end;
         set(controls.epsvieweredit,'String',var_ini.epsviewer);
      end;
   else;
      if strcmp(newepsviewer,var_ini.epsviewer)==0;
         var_ini.epsviewer = '';
         set(controls.apply,'Enable','on');
      end;
      set(controls.epsvieweredit,'String',var_ini.epsviewer);
   end;
   set(optionsgui,'UserData',controls);
case 'epsviewer'
   if strcmp(var_ini.epsviewer,'')==1;
      if ispc==1;
         file = strcat(pwd,'\','*.exe');
      elseif strcmp(computer,'MAC2')==1;
         file = strcat(pwd,'\','*.exe');
      else;
         file = strcat(pwd,'/','*.exe');
      end;
   else;
      file = var_ini.epsviewer;
   end;
   if matlabnumber>=6.0;
      thisfile = getfilename(file);
      file = cell(1,2);
      file{1,1} = thisfile;
      file{1,2} = 'Applications (*.exe)';
   end;
   [epsexe,epspath] = uigetfile(file,'Open');
   drawnow;
   if isnumeric(epsexe)==0;
      newepsviewer = strcat(epspath,epsexe);
      if appexist(newepsviewer)==1;
         if strcmp(lower(newepsviewer),lower(var_ini.epsviewer))==0;
            if ispc==1;
               var_ini.epsviewer = lower(newepsviewer);
            else;
               var_ini.epsviewer = newepsviewer;
            end;
            set(controls.epsvieweredit,'String',var_ini.epsviewer);
            set(controls.apply,'Enable','on');
         end;
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'checkbitmapviewer'
   newbitmapviewer = get(controls.bitmapvieweredit,'String');
   newbitmapviewer = strtrim(newbitmapviewer);
   if strcmp(newbitmapviewer,'')==0;
      if appexist(newbitmapviewer)==1;
         if strcmp(lower(newbitmapviewer),lower(var_ini.bitmapviewer))==0;
            if ispc==1;
               var_ini.bitmapviewer = lower(newbitmapviewer);
            else;
               var_ini.bitmapviewer = newbitmapviewer;
            end;
            set(controls.apply,'Enable','on');
         else;
            set(controls.bitmapvieweredit,'String',var_ini.bitmapviewer);
         end;
      else;
         var_ini.bitmapviewer = oldvar_ini.bitmapviewer;
         if strcmp(var_ini.bitmapviewer,'')==0;
            if appexist(var_ini.bitmapviewer)==0;
               var_ini.bitmapviewer = '';
            end;
         end;
         set(controls.bitmapvieweredit,'String',var_ini.bitmapviewer);
      end;
   else;
      if strcmp(newbitmapviewer,var_ini.bitmapviewer)==0;
         var_ini.bitmapviewer = '';
         set(controls.apply,'Enable','on');
      end;
      set(controls.bitmapvieweredit,'String',var_ini.bitmapviewer);
   end;
   set(optionsgui,'UserData',controls);
case 'bitmapviewer'
   if strcmp(var_ini.bitmapviewer,'')==1;
      if ispc==1;
         file = strcat(pwd,'\','*.exe');
      elseif strcmp(computer,'MAC2')==1;
         file = strcat(pwd,'\','*.exe');
      else;
         file = strcat(pwd,'/','*.exe');
      end;
   else;
      file = var_ini.bitmapviewer;
   end;
   if matlabnumber>=6.0;
      thisfile = getfilename(file);
      file = cell(1,2);
      file{1,1} = thisfile;
      file{1,2} = 'Applications (*.exe)';
   end;
   [bitmapexe,bitmappath] = uigetfile(file,'Open');
   drawnow;
   if isnumeric(bitmapexe)==0;
      newbitmapviewer = strcat(bitmappath,bitmapexe);
      if appexist(newbitmapviewer)==1;
         if strcmp(lower(newbitmapviewer),lower(var_ini.bitmapviewer))==0;
            if ispc==1;
               var_ini.bitmapviewer = lower(newbitmapviewer);
            else;
               var_ini.bitmapviewer = newbitmapviewer;
            end;
            set(controls.bitmapvieweredit,'String',var_ini.bitmapviewer);
            set(controls.apply,'Enable','on');
         end;
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'checkeditor'
   neweditor = get(controls.editoredit,'String');
   neweditor = strtrim(neweditor);
   if strcmp(neweditor,'')==0;
      if appexist(neweditor)==1;
         if strcmp(lower(neweditor),lower(var_ini.editor))==0;
            if ispc==1;
               var_ini.editor = lower(neweditor);
            else;
               var_ini.editor = neweditor;
            end;
            set(controls.apply,'Enable','on');
         else;
            set(controls.editoredit,'String',var_ini.editor);
         end;
      else;
         if isempty(oldvar_ini.editor)==0;
            if appexist(oldvar_ini.editor)==1;
               var_ini.editor = oldvar_ini.editor;
            else;
               if ispc==1;
                  var_ini.editor = 'notepad.exe';
               else;
                  var_ini.editor = '';
               end;
               oldvar_ini.editor = var_ini.editor;
            end;
         else;
            if ispc==1;
               var_ini.editor = 'notepad.exe';
            else;
               var_ini.editor = '';
            end;
         end;
         set(controls.editoredit,'String',var_ini.editor);
      end;
   else;
      if strcmp(neweditor,var_ini.editor)==0;
         if ispc==1;
            var_ini.editor = 'notepad.exe';
         else;
            var_ini.editor = '';
         end;
         set(controls.apply,'Enable','on');
      end;
      set(controls.editoredit,'String',var_ini.editor);
   end;
   set(optionsgui,'UserData',controls);
case 'editor'
   if strcmp(var_ini.editor,'')==1;
      if ispc==1;
         file = strcat(pwd,'\','*.exe');
      elseif strcmp(computer,'MAC2')==1;
         file = strcat(pwd,'\','*.exe');
      else;
         file = strcat(pwd,'/','*.exe');
      end;
   else;
      file = var_ini.editor;
   end;
   if matlabnumber>=6.0;
      thisfile = getfilename(file);
      file = cell(1,2);
      file{1,1} = thisfile;
      file{1,2} = 'Applications (*.exe)';
   end;
   [bitmapexe,bitmappath] = uigetfile(file,'Open');
   drawnow;
   if isnumeric(bitmapexe)==0;
      neweditor = strcat(bitmappath,bitmapexe);
      if appexist(neweditor)==1;
         if strcmp(lower(neweditor),lower(var_ini.editor))==0;
            if ispc==1;
               var_ini.editor = lower(neweditor);
            else;
               var_ini.editor = neweditor;
            end;
            set(controls.editoredit,'String',var_ini.editor);
            set(controls.apply,'Enable','on');
         end;
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'checkhelpexe'
   newhelpexe = get(controls.helpexeedit,'String');
   newhelpexe = strtrim(newhelpexe);
   if strcmp(newhelpexe,'')==0;
      ispace = 0;
      for i=1:size(newhelpexe,2);
         if strcmp(newhelpexe(1,i),' ')==1;
            ispace = i;
            checkhelpexe = newhelpexe(1,1:ispace-1);
            if strcmp(getext(checkhelpexe),'.exe')==1;
               i = size(newhelpexe,2)+1;
            end;
         end;
      end;
      if ispace>1;
         checknewhelpexe = newhelpexe(1,1:ispace-1);
      else;
         checknewhelpexe = newhelpexe;
      end;
      if appexist(checknewhelpexe)==1;
         if strcmp(lower(newhelpexe),lower(var_ini.helpexe))==0;
            if ispc==1;
               var_ini.helpexe = lower(newhelpexe);
            else;
               var_ini.helpexe = newhelpexe;
            end;
            set(controls.apply,'Enable','on');
         else;
            set(controls.helpexeedit,'String',var_ini.helpexe);
         end;
      else;
         var_ini.helpexe = oldvar_ini.helpexe;
         if strcmp(var_ini.helpexe,'')==0;
            if appexist(var_ini.helpexe)==0;
               if ispc==1;
                  var_ini.helpexe = 'winhlp32.exe';
               else;
                  var_ini.helpexe = '';
               end;
            end;
         end;
         set(controls.helpexeedit,'String',var_ini.helpexe);
      end;
   else;
      if strcmp(newhelpexe,var_ini.helpexe)==0;
         var_ini.helpexe = '';
         set(controls.apply,'Enable','on');
      end;
      set(controls.helpexeedit,'String',var_ini.helpexe);
   end;
   set(optionsgui,'UserData',controls);
case 'helpexe'
   if strcmp(var_ini.helpexe,'')==1;
      if ispc==1;
         file = strcat(pwd,'\','*.exe');
      elseif strcmp(computer,'MAC2')==1;
         file = strcat(pwd,'\','*.exe');
      else;
         file = strcat(pwd,'/','*.exe');
      end;
   else;
      file = var_ini.helpexe;
   end;
   if matlabnumber>=6.0;
      thisfile = getfilename(file);
      file = cell(1,2);
      file{1,1} = thisfile;
      file{1,2} = 'Applications (*.exe)';
   end;
   [bitmapexe,bitmappath] = uigetfile(file,'Open');
   drawnow;
   if isnumeric(bitmapexe)==0;
      newhelpexe = strcat(bitmappath,bitmapexe);
      if appexist(newhelpexe)==1;
         if strcmp(lower(newhelpexe),lower(var_ini.helpexe))==0;
            if ispc==1;
               var_ini.helpexe = lower(newhelpexe);
            else;
               var_ini.helpexe = newhelpexe;
            end;
            set(controls.helpexeedit,'String',var_ini.helpexe);
            set(controls.apply,'Enable','on');
         end;
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'winhelpexe'
   newvalue = get(controls.helpexeedit,'Value');
   if newvalue==1;
      newhelpexe = 'winhlp32.exe';
   elseif newvalue==2;
      newhelpexe = 'hh.exe';
   else;
      newhelpexe = 'browser';
   end;
   if strcmp(newhelpexe,lower(getfilename(var_ini.helpexe)))==0;
      var_ini.helpexe = newhelpexe;
      set(controls.apply,'Enable','on');
   end;
case 'checkpstoedit'
   newpstoedit = get(controls.pstoeditedit,'String');
   newpstoedit = strtrim(newpstoedit);
   if isempty(newpstoedit)==0;
      check = findstr('pstoedit',getfilename(newpstoedit));
      if isempty(check)==1;
         newpstoedit = '';
      end;
   end;
   if strcmp(newpstoedit,'')==0;
      ispace = 0;
      for i=1:size(newpstoedit,2);
         if strcmp(newpstoedit(1,i),' ')==1;
            ispace = i;
            checkpstoedit = newpstoedit(1,1:ispace-1);
            if strcmp(getext(checkpstoedit),'.exe')==1;
               i = size(newpstoedit,2)+1;
            end;
         end;
      end;
      if ispace>1;
         checknewpstoedit = newpstoedit(1,1:ispace-1);
      else;
         checknewpstoedit = newpstoedit;
      end;
      if appexist(checknewpstoedit)==1;
         if strcmp(lower(newpstoedit),lower(var_ini.pstoedit))==0;
            if ispc==1;
               var_ini.pstoedit = lower(newpstoedit);
            else;
               var_ini.pstoedit = newpstoedit;
            end;
            set(controls.apply,'Enable','on');
         else;
            set(controls.pstoeditedit,'String',var_ini.pstoedit);
         end;
      else;
         var_ini.pstoedit = oldvar_ini.pstoedit;
         set(controls.pstoeditedit,'String',var_ini.pstoedit);
      end;
   else;
      if strcmp(newpstoedit,var_ini.pstoedit)==0;
         var_ini.pstoedit = '';
         set(controls.apply,'Enable','on');
      end;
      set(controls.pstoeditedit,'String',var_ini.pstoedit);
   end;
   if iscompiled==1;
      graphicsstr = get(controls.graphicsfmt,'String');
      if size(graphicsstr,1)==10;
         if appexist(var_ini.pstoedit)==1;
            var_ini.graphicsstr = strvcat(graphicsstr,'Enhanced metafile (*.emf)');
         end;
         set(controls.graphicsfmt,'String',var_ini.graphicsstr);
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'pstoedit'
   if strcmp(var_ini.pstoedit,'')==1;
      if ispc==1;
         file = strcat(pwd,'\','pstoedit.exe');
      elseif strcmp(computer,'MAC2')==1;
         file = strcat(pwd,'\','pstoedit.exe');
      else;
         file = strcat(pwd,'/','pstoedit.exe');
      end;
   else;
      file = var_ini.pstoedit;
   end;
   [bitmapexe,bitmappath] = uigetfile(file,'Open');
   drawnow;
   if isnumeric(bitmapexe)==0;
      newpstoedit = strcat(bitmappath,bitmapexe);
      check = findstr('pstoedit',getfilename(newpstoedit));
      if isempty(check)==1;
         newpstoedit = '';
      end;
      if appexist(newpstoedit)==1;
         if strcmp(lower(newpstoedit),lower(var_ini.pstoedit))==0;
            if ispc==1;
               var_ini.pstoedit = lower(newpstoedit);
            else;
               var_ini.pstoedit = newpstoedit;
            end;
            set(controls.pstoeditedit,'String',var_ini.pstoedit);
            set(controls.apply,'Enable','on');
         end;
      end;
   end;
   if iscompiled==1;
      graphicsstr = get(controls.graphicsfmt,'String');
      if size(graphicsstr,1)==10;
         if appexist(var_ini.pstoedit)==1;
            var_ini.graphicsstr = strvcat(graphicsstr,'Enhanced metafile (*.emf)');
         end;
         set(controls.graphicsfmt,'String',var_ini.graphicsstr);
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'checkghostscript'
   newghostscript = get(controls.ghostscriptedit,'String');
   newghostscript = strtrim(newghostscript);
   if isempty(newghostscript)==0;
      check = findstr('gs',getfilename(newghostscript));
      if isempty(check)==1;
         newghostscript = '';
      end;
   end;
   if strcmp(newghostscript,'')==0;
      ispace = 0;
      for i=1:size(newghostscript,2);
         if strcmp(newghostscript(1,i),' ')==1;
            ispace = i;
            checkghostscript = newghostscript(1,1:ispace-1);
            if strcmp(getext(checkghostscript),'.exe')==1;
               i = size(newghostscript,2)+1;
            end;
         end;
      end;
      if ispace>1;
         checknewghostscript = newghostscript(1,1:ispace-1);
      else;
         checknewghostscript = newghostscript;
      end;
      if appexist(checknewghostscript)==1;
         if strcmp(lower(newghostscript),lower(var_ini.ghostscript))==0;
            if ispc==1;
               var_ini.ghostscript = lower(newghostscript);
            else;
               var_ini.ghostscript = newghostscript;
            end;
            set(controls.apply,'Enable','on');
         else;
            set(controls.ghostscriptedit,'String',var_ini.ghostscript);
         end;
      else;
         var_ini.ghostscript = oldvar_ini.ghostscript;
         set(controls.ghostscriptedit,'String',var_ini.ghostscript);
      end;
   else;
      if strcmp(newghostscript,var_ini.ghostscript)==0;
         var_ini.ghostscript = '';
         set(controls.apply,'Enable','on');
      end;
      set(controls.ghostscriptedit,'String',var_ini.ghostscript);
   end;
   if iscompiled==1;
      graphicsstr = get(controls.graphicsfmt,'String');
      if size(graphicsstr,1)==3;
         if appexist(var_ini.ghostscript)==1;
            graphicsstr = strvcat(graphicsstr,'JPEG (*.jpg)');
            graphicsstr = strvcat(graphicsstr,'Tagged Image Format (*.tif)');
            graphicsstr = strvcat(graphicsstr,'Portable Network Graphics (*.png)');
            graphicsstr = strvcat(graphicsstr,'Paintbrush 24-bit (*.pcx)');
            graphicsstr = strvcat(graphicsstr,'Portable Bitmap (*.pbm)');
            graphicsstr = strvcat(graphicsstr,'Portable Graymap (*.pgm)');
            var_ini.graphicsstr = strvcat(graphicsstr,'Portable Pixmap (*.ppm)');
            if ispstoedit==1;
               var_ini.graphicsstr = strvcat(var_ini.graphicsstr,'Enhanced metafile (*.emf)');
            end;
            set(controls.graphicsfmt,'String',var_ini.graphicsstr);
         end;
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'ghostscript'
   if strcmp(var_ini.ghostscript,'')==1;
      if ispc==1;
         file = strcat(pwd,'\','gs*.exe');
      elseif strcmp(computer,'MAC2')==1;
         file = strcat(pwd,'\','gs*.exe');
      else;
         file = strcat(pwd,'/','gs*.exe');
      end;
   else;
      file = var_ini.ghostscript;
   end;
   [bitmapexe,bitmappath] = uigetfile(file,'Open');
   drawnow;
   if isnumeric(bitmapexe)==0;
      newghostscript = strcat(bitmappath,bitmapexe);
      check = findstr('gs',getfilename(newghostscript));
      if isempty(check)==1;
         newghostscript = '';
      end;
      if appexist(newghostscript)==1;
         if strcmp(lower(newghostscript),lower(var_ini.ghostscript))==0;
            if ispc==1;
               var_ini.ghostscript = lower(newghostscript);
            else;
               var_ini.ghostscript = newghostscript;
            end;
            set(controls.ghostscriptedit,'String',var_ini.ghostscript);
            set(controls.apply,'Enable','on');
         end;
      end;
   end;
   if iscompiled==1;
      graphicsstr = get(controls.graphicsfmt,'String');
      if size(graphicsstr,1)==3;
         if appexist(var_ini.ghostscript)==1;
            graphicsstr = strvcat(graphicsstr,'JPEG (*.jpg)');
            graphicsstr = strvcat(graphicsstr,'Tagged Image Format (*.tif)');
            graphicsstr = strvcat(graphicsstr,'Portable Network Graphics (*.png)');
            graphicsstr = strvcat(graphicsstr,'Paintbrush 24-bit (*.pcx)');
            graphicsstr = strvcat(graphicsstr,'Portable Bitmap (*.pbm)');
            graphicsstr = strvcat(graphicsstr,'Portable Graymap (*.pgm)');
            var_ini.graphicsstr = strvcat(graphicsstr,'Portable Pixmap (*.ppm)');
            if ispstoedit==1;
               var_ini.graphicsstr = strvcat(var_ini.graphicsstr,'Enhanced metafile (*.emf)');
            end;
            set(controls.graphicsfmt,'String',var_ini.graphicsstr);
         end;
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'checkpsprintcmd'
   newpsprintcmd = get(controls.psprintcmdedit,'String');
   %
   % remove any spaces around command line string
   %
   newpsprintcmd = strtrim(newpsprintcmd);
   if strcmp(newpsprintcmd,var_ini.psprintcmd)==0;
      var_ini.psprintcmd = newpsprintcmd;
      set(controls.apply,'Enable','on');
   end;
   set(controls.psprintcmdedit,'String',var_ini.psprintcmd);
   set(optionsgui,'UserData',controls);
case 'checkpsprint'
   newpsprint = get(controls.psprintedit,'String');
   newpsprint = strtrim(newpsprint);
   if strcmp(newpsprint,'')==0;
      ispace = 0;
      for i=1:size(newpsprint,2);
         if strcmp(newpsprint(1,i),' ')==1;
            ispace = i;
            checkpsprint = newpsprint(1,1:ispace-1);
            if strcmp(getext(checkpsprint),'.exe')==1;
               i = size(newpsprint,2)+1;
            end;
         end;
      end;
      if ispace>1;
         checknewpsprint = newpsprint(1,1:ispace-1);
      else;
         checknewpsprint = newpsprint;
      end;
      if appexist(checknewpsprint)==1;
         if strcmp(lower(newpsprint),lower(var_ini.psprint))==0;
            if ispc==1;
               var_ini.psprint = lower(newpsprint);
            else;
               var_ini.psprint = newpsprint;
            end;
            set(controls.apply,'Enable','on');
         else;
            set(controls.psprintedit,'String',var_ini.psprint);
         end;
      else;
         var_ini.psprint = oldvar_ini.psprint;
         set(controls.psprintedit,'String',var_ini.psprint);
      end;
   else;
      if strcmp(newpsprint,var_ini.psprint)==0;
         var_ini.psprint = '';
         set(controls.apply,'Enable','on');
      end;
      set(controls.psprintedit,'String',var_ini.psprint);
   end;
   set(optionsgui,'UserData',controls);
case 'psprint'
   if strcmp(var_ini.psprint,'')==1;
      if ispc==1;
         file = strcat(pwd,'\','*.exe');
      elseif strcmp(computer,'MAC2')==1;
         file = strcat(pwd,'\','*.exe');
      else;
         file = strcat(pwd,'/','*.exe');
      end;
   else;
      file = var_ini.psprint;
   end;
   if matlabnumber>=6.0;
      thisfile = getfilename(file);
      file = cell(1,2);
      file{1,1} = thisfile;
      file{1,2} = 'Applications (*.exe)';
   end;
   [bitmapexe,bitmappath] = uigetfile(file,'Open');
   drawnow;
   if isnumeric(bitmapexe)==0;
      newpsprint = strcat(bitmappath,bitmapexe);
      if appexist(newpsprint)==1;
         if strcmp(lower(newpsprint),lower(var_ini.psprint))==0;
            if ispc==1;
               var_ini.psprint = lower(newpsprint);
            else;
               var_ini.psprint = newpsprint;
            end;
            set(controls.psprintedit,'String',var_ini.psprint);
            set(controls.apply,'Enable','on');
         end;
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'checktxtprintcmd'
   newtxtprintcmd = get(controls.txtprintcmdedit,'String');
   %
   % remove any spaces around command line string
   %
   newtxtprintcmd = strtrim(newtxtprintcmd);
   if strcmp(newtxtprintcmd,var_ini.txtprintcmd)==0;
      var_ini.txtprintcmd = newtxtprintcmd;
      set(controls.apply,'Enable','on');
   end;
   set(controls.txtprintcmdedit,'String',var_ini.txtprintcmd);
   set(optionsgui,'UserData',controls);
case 'checktxtprint'
   newtxtprint = get(controls.txtprintedit,'String');
   newtxtprint = strtrim(newtxtprint);
   if strcmp(newtxtprint,'')==0;
      ispace = 0;
      for i=1:size(newtxtprint,2);
         if strcmp(newtxtprint(1,i),' ')==1;
            ispace = i;
            checktxtprint = newtxtprint(1,1:ispace-1);
            if strcmp(getext(checktxtprint),'.exe')==1;
               i = size(newtxtprint,2)+1;
            end;
         end;
      end;
      if ispace>1;
         checknewtxtprint = newtxtprint(1,1:ispace-1);
      else;
         checknewtxtprint = newtxtprint;
      end;
      if appexist(checknewtxtprint)==1;
         if strcmp(lower(newtxtprint),lower(var_ini.txtprint))==0;
            if ispc==1;
               var_ini.txtprint = lower(newtxtprint);
            else;
               var_ini.txtprint = newtxtprint;
            end;
            set(controls.apply,'Enable','on');
         else;
            set(controls.txtprintedit,'String',var_ini.txtprint);
         end;
      else;
         var_ini.txtprint = oldvar_ini.txtprint;
         set(controls.txtprintedit,'String',var_ini.txtprint);
      end;
   else;
      if strcmp(newtxtprint,var_ini.txtprint)==0;
         var_ini.txtprint = '';
         set(controls.apply,'Enable','on');
      end;
      set(controls.txtprintedit,'String',var_ini.txtprint);
   end;
   %
   if (isempty(var_ini.txtprint)==0)&(ispc==1)&(fileexist([getpath(var_ini.txtprint) 'txtprint.exe'])==1);
      set(controls.txtprintrun,'Enable','on');
   end;
   %
   set(optionsgui,'UserData',controls);
case 'txtprint'
   if strcmp(var_ini.txtprint,'')==1;
      if ispc==1;
         file = strcat(pwd,'\','*.exe');
      elseif strcmp(computer,'MAC2')==1;
         file = strcat(pwd,'\','*.exe');
      else;
         file = strcat(pwd,'/','*.exe');
      end;
   else;
      file = var_ini.txtprint;
   end;
   if matlabnumber>=6.0;
      thisfile = getfilename(file);
      file = cell(1,2);
      file{1,1} = thisfile;
      file{1,2} = 'Applications (*.exe)';
   end;
   [bitmapexe,bitmappath] = uigetfile(file,'Open');
   drawnow;
   if isnumeric(bitmapexe)==0;
      newtxtprint = strcat(bitmappath,bitmapexe);
      if appexist(newtxtprint)==1;
         if strcmp(lower(newtxtprint),lower(var_ini.txtprint))==0;
            if ispc==1;
               var_ini.txtprint = lower(newtxtprint);
            else;
               var_ini.txtprint = newtxtprint;
            end;
            set(controls.txtprintedit,'String',var_ini.txtprint);
            set(controls.apply,'Enable','on');
         end;
      end;
   end;
   %
   if (isempty(var_ini.txtprint)==0)&(ispc==1)&(fileexist([getpath(var_ini.txtprint) 'txtprint.exe'])==1);
      set(controls.txtprintrun,'Enable','on');
   end;
   %
   set(optionsgui,'UserData',controls);
case 'txtprintrun'
   prog = fixcmd([fix_path(var_ini.txtprint) ' &']);
   dos(prog);
case 'checklatex'
   newlatex = get(controls.latexedit,'String');
   newlatex = strtrim(newlatex);
   if strcmp(newlatex,'')==0;
      ispace = 0;
      for i=1:size(newlatex,2);
         if strcmp(newlatex(1,i),' ')==1;
            ispace = i;
            checklatex = newlatex(1,1:ispace-1);
            if strcmp(getext(checklatex),'.exe')==1;
               i = size(newlatex,2)+1;
            end;
         end;
      end;
      if ispace>1;
         checknewlatex = newlatex(1,1:ispace-1);
      else;
         checknewlatex = newlatex;
      end;
      if appexist(checknewlatex)==1;
         if strcmp(lower(newlatex),lower(var_ini.latex))==0;
            if ispc==1;
               var_ini.latex = lower(newlatex);
            else;
               var_ini.latex = newlatex;
            end;
            set(controls.apply,'Enable','on');
         else;
            set(controls.latexedit,'String',var_ini.latex);
         end;
      else;
         var_ini.latex = oldvar_ini.latex;
         set(controls.latexedit,'String',var_ini.latex);
      end;
   else;
      if strcmp(newlatex,var_ini.latex)==0;
         var_ini.latex = '';
         set(controls.apply,'Enable','on');
      end;
      set(controls.latexedit,'String',var_ini.latex);
   end;
   set(optionsgui,'UserData',controls);
case 'latex'
   if strcmp(var_ini.latex,'')==1;
      if ispc==1;
         file = strcat(pwd,'\','*.exe');
      elseif strcmp(computer,'MAC2')==1;
         file = strcat(pwd,'\','*.exe');
      else;
         file = strcat(pwd,'/','*.exe');
      end;
   else;
      file = var_ini.latex;
   end;
   if matlabnumber>=6.0;
      thisfile = getfilename(file);
      file = cell(1,2);
      file{1,1} = thisfile;
      file{1,2} = 'Applications (*.exe)';
   end;
   [bitmapexe,bitmappath] = uigetfile(file,'Open');
   drawnow;
   if isnumeric(bitmapexe)==0;
      newlatex = strcat(bitmappath,bitmapexe);
      if appexist(newlatex)==1;
         if strcmp(lower(newlatex),lower(var_ini.latex))==0;
            if ispc==1;
               var_ini.latex = lower(newlatex);
            else;
               var_ini.latex = newlatex;
            end;
            set(controls.latexedit,'String',var_ini.latex);
            set(controls.apply,'Enable','on');
         end;
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'checkpdfviewer'
   newpdfviewer = get(controls.pdfvieweredit,'String');
   newpdfviewer = strtrim(newpdfviewer);
   if strcmp(newpdfviewer,'')==0;
      ispace = 0;
      for i=1:size(newpdfviewer,2);
         if strcmp(newpdfviewer(1,i),' ')==1;
            ispace = i;
            checkpdfviewer = newpdfviewer(1,1:ispace-1);
            if strcmp(getext(checkpdfviewer),'.exe')==1;
               i = size(newpdfviewer,2)+1;
            end;
         end;
      end;
      if ispace>1;
         checknewpdfviewer = newpdfviewer(1,1:ispace-1);
      else;
         checknewpdfviewer = newpdfviewer;
      end;
      if appexist(checknewpdfviewer)==1;
         if strcmp(lower(newpdfviewer),lower(var_ini.pdfviewer))==0;
            if ispc==1;
               var_ini.pdfviewer = lower(newpdfviewer);
            else;
               var_ini.pdfviewer = newpdfviewer;
            end;
            set(controls.apply,'Enable','on');
         else;
            set(controls.pdfvieweredit,'String',var_ini.pdfviewer);
         end;
      else;
         var_ini.pdfviewer = oldvar_ini.pdfviewer;
         set(controls.pdfvieweredit,'String',var_ini.pdfviewer);
      end;
   else;
      if strcmp(newpdfviewer,var_ini.pdfviewer)==0;
         var_ini.pdfviewer = '';
         set(controls.apply,'Enable','on');
      end;
      set(controls.pdfvieweredit,'String',var_ini.pdfviewer);
   end;
   set(optionsgui,'UserData',controls);
case 'pdfviewer'
   if strcmp(var_ini.pdfviewer,'')==1;
      if ispc==1;
         file = strcat(pwd,'\','*.exe');
      elseif strcmp(computer,'MAC2')==1;
         file = strcat(pwd,'\','*.exe');
      else;
         file = strcat(pwd,'/','*.exe');
      end;
   else;
      file = var_ini.pdfviewer;
   end;
   if matlabnumber>=6.0;
      thisfile = getfilename(file);
      file = cell(1,2);
      file{1,1} = thisfile;
      file{1,2} = 'Applications (*.exe)';
   end;
   [bitmapexe,bitmappath] = uigetfile(file,'Open');
   drawnow;
   if isnumeric(bitmapexe)==0;
      newpdfviewer = strcat(bitmappath,bitmapexe);
      if appexist(newpdfviewer)==1;
         if strcmp(lower(newpdfviewer),lower(var_ini.pdfviewer))==0;
            if ispc==1;
               var_ini.pdfviewer = lower(newpdfviewer);
            else;
               var_ini.pdfviewer = newpdfviewer;
            end;
            set(controls.pdfvieweredit,'String',var_ini.pdfviewer);
            set(controls.apply,'Enable','on');
         end;
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'checkpsviewer'
   newpsviewer = get(controls.psvieweredit,'String');
   newpsviewer = strtrim(newpsviewer);
   if strcmp(newpsviewer,'')==0;
      ispace = 0;
      for i=1:size(newpsviewer,2);
         if strcmp(newpsviewer(1,i),' ')==1;
            ispace = i;
            checkpsviewer = newpsviewer(1,1:ispace-1);
            if strcmp(getext(checkpsviewer),'.exe')==1;
               i = size(newpsviewer,2)+1;
            end;
         end;
      end;
      if ispace>1;
         checknewpsviewer = newpsviewer(1,1:ispace-1);
      else;
         checknewpsviewer = newpsviewer;
      end;
      if appexist(checknewpsviewer)==1;
         if strcmp(lower(newpsviewer),lower(var_ini.psviewer))==0;
            if ispc==1;
               var_ini.psviewer = lower(newpsviewer);
            else;
               var_ini.psviewer = newpsviewer;
            end;
            set(controls.apply,'Enable','on');
         else;
            set(controls.psvieweredit,'String',var_ini.psviewer);
         end;
      else;
         var_ini.psviewer = oldvar_ini.psviewer;
         set(controls.psvieweredit,'String',var_ini.psviewer);
      end;
   else;
      if strcmp(newpsviewer,var_ini.psviewer)==0;
         var_ini.psviewer = '';
         set(controls.apply,'Enable','on');
      end;
      set(controls.psvieweredit,'String',var_ini.psviewer);
   end;
   set(optionsgui,'UserData',controls);
case 'psviewer'
   if strcmp(var_ini.psviewer,'')==1;
      if ispc==1;
         file = strcat(pwd,'\','*.exe');
      elseif strcmp(computer,'MAC2')==1;
         file = strcat(pwd,'\','*.exe');
      else;
         file = strcat(pwd,'/','*.exe');
      end;
   else;
      file = var_ini.psviewer;
   end;
   if matlabnumber>=6.0;
      thisfile = getfilename(file);
      file = cell(1,2);
      file{1,1} = thisfile;
      file{1,2} = 'Applications (*.exe)';
   end;
   [bitmapexe,bitmappath] = uigetfile(file,'Open');
   drawnow;
   if isnumeric(bitmapexe)==0;
      newpsviewer = strcat(bitmappath,bitmapexe);
      if appexist(newpsviewer)==1;
         if strcmp(lower(newpsviewer),lower(var_ini.psviewer))==0;
            if ispc==1;
               var_ini.psviewer = lower(newpsviewer);
            else;
               var_ini.psviewer = newpsviewer;
            end;
            set(controls.psvieweredit,'String',var_ini.psviewer);
            set(controls.apply,'Enable','on');
         end;
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'checkdistiller'
   newdistiller = get(controls.distilleredit,'String');
   newdistiller = strtrim(newdistiller);
   if strcmp(newdistiller,'')==0;
      ispace = 0;
      for i=1:size(newdistiller,2);
         if strcmp(newdistiller(1,i),' ')==1;
            ispace = i;
            checkdistiller = newdistiller(1,1:ispace-1);
            if strcmp(getext(checkdistiller),'.exe')==1;
               i = size(newdistiller,2)+1;
            end;
         end;
      end;
      if ispace>1;
         checknewdistiller = newdistiller(1,1:ispace-1);
      else;
         checknewdistiller = newdistiller;
      end;
      if appexist(checknewdistiller)==1;
         if strcmp(lower(newdistiller),lower(var_ini.distiller))==0;
            if ispc==1;
               var_ini.distiller = lower(newdistiller);
            else;
               var_ini.distiller = newdistiller;
            end;
            set(controls.apply,'Enable','on');
         else;
            set(controls.distilleredit,'String',var_ini.distiller);
         end;
      else;
         var_ini.distiller = oldvar_ini.distiller;
         set(controls.distilleredit,'String',var_ini.distiller);
      end;
   else;
      if strcmp(newdistiller,var_ini.distiller)==0;
         var_ini.distiller = '';
         set(controls.apply,'Enable','on');
      end;
      set(controls.distilleredit,'String',var_ini.distiller);
   end;
   set(optionsgui,'UserData',controls);
case 'distiller'
   if strcmp(var_ini.distiller,'')==1;
      if ispc==1;
         file = strcat(pwd,'\','*.exe');
      elseif strcmp(computer,'MAC2')==1;
         file = strcat(pwd,'\','*.exe');
      else;
         file = strcat(pwd,'/','*.exe');
      end;
   else;
      file = var_ini.distiller;
   end;
   if matlabnumber>=6.0;
      thisfile = getfilename(file);
      file = cell(1,2);
      file{1,1} = thisfile;
      file{1,2} = 'Applications (*.exe)';
   end;
   [bitmapexe,bitmappath] = uigetfile(file,'Open');
   drawnow;
   if isnumeric(bitmapexe)==0;
      newdistiller = strcat(bitmappath,bitmapexe);
      if appexist(newdistiller)==1;
         if strcmp(lower(newdistiller),lower(var_ini.distiller))==0;
            if ispc==1;
               var_ini.distiller = lower(newdistiller);
            else;
               var_ini.distiller = newdistiller;
            end;
            set(controls.distilleredit,'String',var_ini.distiller);
            set(controls.apply,'Enable','on');
         end;
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'checkdviviewer'
   newdviviewer = get(controls.dvivieweredit,'String');
   newdviviewer = strtrim(newdviviewer);
   if strcmp(newdviviewer,'')==0;
      ispace = 0;
      for i=1:size(newdviviewer,2);
         if strcmp(newdviviewer(1,i),' ')==1;
            ispace = i;
            checkdviviewer = newdviviewer(1,1:ispace-1);
            if strcmp(getext(checkdviviewer),'.exe')==1;
               i = size(newdviviewer,2)+1;
            end;
         end;
      end;
      if ispace>1;
         checknewdviviewer = newdviviewer(1,1:ispace-1);
      else;
         checknewdviviewer = newdviviewer;
      end;
      if appexist(checknewdviviewer)==1;
         if strcmp(lower(newdviviewer),lower(var_ini.dviviewer))==0;
            if ispc==1;
               var_ini.dviviewer = lower(newdviviewer);
            else;
               var_ini.dviviewer = newdviviewer;
            end;
            set(controls.apply,'Enable','on');
         else;
            set(controls.dvivieweredit,'String',var_ini.dviviewer);
         end;
      else;
         var_ini.dviviewer = oldvar_ini.dviviewer;
         set(controls.dvivieweredit,'String',var_ini.dviviewer);
      end;
   else;
      if strcmp(newdviviewer,var_ini.dviviewer)==0;
         var_ini.dviviewer = '';
         set(controls.apply,'Enable','on');
      end;
      set(controls.dvivieweredit,'String',var_ini.dviviewer);
   end;
   set(optionsgui,'UserData',controls);
case 'dviviewer'
   if strcmp(var_ini.dviviewer,'')==1;
      if ispc==1;
         file = strcat(pwd,'\','*.exe');
      elseif strcmp(computer,'MAC2')==1;
         file = strcat(pwd,'\','*.exe');
      else;
         file = strcat(pwd,'/','*.exe');
      end;
   else;
      file = var_ini.dviviewer;
   end;
   if matlabnumber>=6.0;
      thisfile = getfilename(file);
      file = cell(1,2);
      file{1,1} = thisfile;
      file{1,2} = 'Applications (*.exe)';
   end;
   [bitmapexe,bitmappath] = uigetfile(file,'Open');
   drawnow;
   if isnumeric(bitmapexe)==0;
      newdviviewer = strcat(bitmappath,bitmapexe);
      if appexist(newdviviewer)==1;
         if strcmp(lower(newdviviewer),lower(var_ini.dviviewer))==0;
            if ispc==1;
               var_ini.dviviewer = lower(newdviviewer);
            else;
               var_ini.dviviewer = newdviviewer;
            end;
            set(controls.dvivieweredit,'String',var_ini.dviviewer);
            set(controls.apply,'Enable','on');
         end;
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'checksimulatedir'
   newsimulatedir = get(controls.simulatediredit,'String');
   if isempty(strtrim(newsimulatedir))==1;
      set(controls.simulatediredit,'String',var_ini.simulatedir);
      set(optionsgui,'UserData',controls);
      return;
   end;
   newsimulatedir = newsimulatedir(1,:);
   newsimulatedir = strrep(newsimulatedir,'*','');
   newsimulatedir = strrep(newsimulatedir,'''','');
   newsimulatedir = strrep(newsimulatedir,'"','');
   newsimulatedir = strrep(newsimulatedir,'#','');
   newsimulatedir = strrep(newsimulatedir,'(','');
   newsimulatedir = strrep(newsimulatedir,')','');
   newsimulatedir = strrep(newsimulatedir,'[','');
   newsimulatedir = strrep(newsimulatedir,']','');
   newsimulatedir = strrep(newsimulatedir,'{','');
   newsimulatedir = strrep(newsimulatedir,'}','');
   newsimulatedir = strrep(newsimulatedir,'`','');
   newsimulatedir = strrep(newsimulatedir,'','');
   newsimulatedir = strrep(newsimulatedir,'[','');
   newsimulatedir = strrep(newsimulatedir,'<','');
   newsimulatedir = strrep(newsimulatedir,'>','');
   newsimulatedir = strrep(newsimulatedir,'|','');
   newsimulatedir = strrep(newsimulatedir,';','');
   newsimulatedir = strrep(newsimulatedir,'?','');
   newsimulatedir = strrep(newsimulatedir,'!','');
   if ispc==1;
      newsimulatedir = strrep(newsimulatedir,'/','\');
   else;
      newsimulatedir = strrep(newsimulatedir,'\','/');
      if isunix==1;
         newsimulatedir = strrep(newsimulatedir,':','');
      end;
   end;
   if isempty(newsimulatedir)==1;
      set(controls.simulatediredit,'String',var_ini.simulatedir);
   else;
      if strcmp(newsimulatedir(1,size(newsimulatedir,2)),'\')==1;
         newsimulatedir = newsimulatedir(1,1:size(newsimulatedir,2)-1);
      end;
      check_path = getpath(newsimulatedir);
      if isempty(check_path)==1;
         set(controls.simulatediredit,'String',var_ini.simulatedir);
      else;
         %
         % check if we're dealing with an old or new directory
         %
         checkdir = dir(newsimulatedir);
         if size(checkdir,1)>0;
            %
            % old directory
            %
            if ispc==1;
               newsimulatedir = lower(newsimulatedir);
               if strcmp(newsimulatedir(1,size(newsimulatedir,2)),'\')==0;
                  newsimulatedir = [newsimulatedir '\'];
               end;
            end;
            if strcmp(var_ini.simulatedir,newsimulatedir)==0;
               var_ini.simulatedir = newsimulatedir;
               set(controls.simulatediredit,'String',var_ini.simulatedir);
               set(controls.apply,'Enable','on');
            else;
               set(controls.simulatediredit,'String',var_ini.simulatedir);
            end;
         else;
            %
            % new directory
            %
            if ispc==1;
               newsimulatedir = lower(newsimulatedir);
               if strcmp(newsimulatedir(1,size(newsimulatedir,2)),'\')==0;
                  newsimulatedir = [newsimulatedir '\'];
               end;
            end;
            %
            % are we dealing with a valid path
            %
            checkdir = dir(check_path);
            if size(checkdir,1)>0;
               mystatus = 0;
               mystatus = makedirs(newsimulatedir,0);
               if mystatus>0;
                  var_ini.simulatedir = newsimulatedir;
                  set(controls.simulatediredit,'String',var_ini.simulatedir);
                  set(controls.apply,'Enable','on');
               else;
                  set(controls.simulatediredit,'String',var_ini.simulatedir);
               end;
            else;
               set(controls.simulatediredit,'String',var_ini.simulatedir);
            end;
         end;
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'simulatedir'
   newsimulatedir = uigetdir_fcn(var_ini.simulatedir);
   if (ischar(newsimulatedir)==1)&(isempty(newsimulatedir)==0);
      if ispc==1;
         newsimulatedir = lower(newsimulatedir);
         if strcmp(newsimulatedir(1,size(newsimulatedir,2)),'\')==0;
            newsimulatedir = [newsimulatedir '\'];
         end;
      end;
      if strcmp(newsimulatedir,var_ini.simulatedir)==0;
         var_ini.simulatedir = newsimulatedir;
         set(controls.simulatediredit,'String',var_ini.simulatedir);
         set(controls.apply,'Enable','on');
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'checkpstoolsdir'
   newpstoolsdir = get(controls.pstoolsdiredit,'String');
   if isempty(strtrim(newpstoolsdir))==1;
      var_ini.pstoolsdir = '';
      set(controls.pstoolsdiredit,'String',var_ini.pstoolsdir);
      set(controls.apply,'Enable','on');
   else;
      newpstoolsdir = newpstoolsdir(1,:);
      newpstoolsdir = strrep(newpstoolsdir,'*','');
      newpstoolsdir = strrep(newpstoolsdir,'''','');
      newpstoolsdir = strrep(newpstoolsdir,'"','');
      newpstoolsdir = strrep(newpstoolsdir,'#','');
      newpstoolsdir = strrep(newpstoolsdir,'(','');
      newpstoolsdir = strrep(newpstoolsdir,')','');
      newpstoolsdir = strrep(newpstoolsdir,'[','');
      newpstoolsdir = strrep(newpstoolsdir,']','');
      newpstoolsdir = strrep(newpstoolsdir,'{','');
      newpstoolsdir = strrep(newpstoolsdir,'}','');
      newpstoolsdir = strrep(newpstoolsdir,'`','');
      newpstoolsdir = strrep(newpstoolsdir,'','');
      newpstoolsdir = strrep(newpstoolsdir,'[','');
      newpstoolsdir = strrep(newpstoolsdir,'<','');
      newpstoolsdir = strrep(newpstoolsdir,'>','');
      newpstoolsdir = strrep(newpstoolsdir,'|','');
      newpstoolsdir = strrep(newpstoolsdir,';','');
      newpstoolsdir = strrep(newpstoolsdir,'?','');
      newpstoolsdir = strrep(newpstoolsdir,'!','');
      if ispc==1;
         newpstoolsdir = strrep(newpstoolsdir,'/','\');
      else;
         newpstoolsdir = strrep(newpstoolsdir,'\','/');
         if isunix==1;
            newpstoolsdir = strrep(newpstoolsdir,':','');
         end;
      end;
      if isempty(newpstoolsdir)==1;
         set(controls.pstoolsdiredit,'String',var_ini.pstoolsdir);
      else;
         if strcmp(newpstoolsdir(1,size(newpstoolsdir,2)),'\')==1;
            newpstoolsdir = newpstoolsdir(1,1:size(newpstoolsdir,2)-1);
         end;
         check_path = getpath(newpstoolsdir);
         if isempty(check_path)==1;
            set(controls.pstoolsdiredit,'String',var_ini.pstoolsdir);
         else;
            %
            % check if we're dealing with an old or new directory
            %
            checkdir = dir(newpstoolsdir);
            if size(checkdir,1)>0;
               %
               % old directory
               %
               if ispc==1;
                  newpstoolsdir = lower(newpstoolsdir);
                  if strcmp(newpstoolsdir(1,size(newpstoolsdir,2)),'\')==0;
                     newpstoolsdir = [newpstoolsdir '\'];
                  end;
               end;
               if strcmp(var_ini.pstoolsdir,newpstoolsdir)==0;
                  filecheck = [newpstoolsdir 'pslist.exe'];
                  if appexist(filecheck)==1;
                     var_ini.pstoolsdir = newpstoolsdir;
                     set(controls.pstoolsdiredit,'String',var_ini.pstoolsdir);
                     set(controls.apply,'Enable','on');
                  else;
                     txt = ['Unable to locate the "PsTools" executables in ' newpstoolsdir '.'];
                     about(txt,'error','PsTools not found...',120,500);
                     set(controls.pstoolsdiredit,'String',var_ini.pstoolsdir);
                  end;
               else;
                  set(controls.pstoolsdiredit,'String',var_ini.pstoolsdir);
               end;
            else;
               %
               % new directory
               %
               if ispc==1;
                  newpstoolsdir = lower(newpstoolsdir);
                  if strcmp(newpstoolsdir(1,size(newpstoolsdir,2)),'\')==0;
                     newpstoolsdir = [newpstoolsdir '\'];
                  end;
               end;
               %
               % are we dealing with a valid path
               %
               checkdir = dir(check_path);
               if size(checkdir,1)>0;
                  mystatus = 0;
                  mystatus = makedirs(newpstoolsdir,0);
                  if mystatus>0;
                     filecheck = [newpstoolsdir 'pslist.exe'];
                     if appexist(filecheck)==1;
                        var_ini.pstoolsdir = newpstoolsdir;
                        set(controls.pstoolsdiredit,'String',var_ini.pstoolsdir);
                        set(controls.apply,'Enable','on');
                     else;
                        txt = ['Unable to locate the "PsTools" executables in ' newpstoolsdir '.'];
                        about(txt,'error','PsTools not found...',120,500);
                        set(controls.pstoolsdiredit,'String',var_ini.pstoolsdir);
                     end;
                  else;
                     set(controls.pstoolsdiredit,'String',var_ini.pstoolsdir);
                  end;
               else;
                  set(controls.pstoolsdiredit,'String',var_ini.pstoolsdir);
               end;
            end;
         end;
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'pstoolsdir'
   if strcmp(var_ini.pstoolsdir,'')==0;
      pstoolsdir = var_ini.pstoolsdir;
   else;
      pstoolsdir = pwd;
   end;
   newpstoolsdir = uigetdir_fcn(pstoolsdir);
   if (ischar(newpstoolsdir)==1)&(isempty(newpstoolsdir)==0);
      if ispc==1;
         newpstoolsdir = lower(newpstoolsdir);
         if strcmp(newpstoolsdir(1,size(newpstoolsdir,2)),'\')==0;
            newpstoolsdir = [newpstoolsdir '\'];
         end;
      end;
      if strcmp(newpstoolsdir,var_ini.pstoolsdir)==0;
         filecheck = [newpstoolsdir 'pslist.exe'];
         if appexist(filecheck)==1;
            var_ini.pstoolsdir = newpstoolsdir;
            set(controls.pstoolsdiredit,'String',var_ini.pstoolsdir);
            set(controls.apply,'Enable','on');
         else;
            txt = ['Unable to locate the "PsTools" executables in ' newpstoolsdir '.'];
            about(txt,'error','PsTools not found...',120,500);
            set(controls.pstoolsdiredit,'String',var_ini.pstoolsdir);
         end;
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'checktempdir'
   newtempdir = get(controls.tempdiredit,'String');
   if isempty(strtrim(newtempdir))==1;
      var_ini.tempdir = tempdir;
      set(controls.tempdiredit,'String',var_ini.tempdir);
      set(controls.apply,'Enable','on');
   else;
      newtempdir = newtempdir(1,:);
      newtempdir = strrep(newtempdir,'*','');
      newtempdir = strrep(newtempdir,'''','');
      newtempdir = strrep(newtempdir,'"','');
      newtempdir = strrep(newtempdir,'#','');
      newtempdir = strrep(newtempdir,'(','');
      newtempdir = strrep(newtempdir,')','');
      newtempdir = strrep(newtempdir,'[','');
      newtempdir = strrep(newtempdir,']','');
      newtempdir = strrep(newtempdir,'{','');
      newtempdir = strrep(newtempdir,'}','');
      newtempdir = strrep(newtempdir,'`','');
      newtempdir = strrep(newtempdir,'','');
      newtempdir = strrep(newtempdir,'[','');
      newtempdir = strrep(newtempdir,'<','');
      newtempdir = strrep(newtempdir,'>','');
      newtempdir = strrep(newtempdir,'|','');
      newtempdir = strrep(newtempdir,';','');
      newtempdir = strrep(newtempdir,'?','');
      newtempdir = strrep(newtempdir,'!','');
      if ispc==1;
         newtempdir = strrep(newtempdir,'/','\');
      else;
         newtempdir = strrep(newtempdir,'\','/');
         if isunix==1;
            newtempdir = strrep(newtempdir,':','');
         end;
      end;
      if isempty(newtempdir)==1;
         set(controls.tempdiredit,'String',var_ini.tempdir);
      else;
         if strcmp(newtempdir(1,size(newtempdir,2)),'\')==1;
            newtempdir = newtempdir(1,1:size(newtempdir,2)-1);
         end;
         check_path = getpath(newtempdir);
         if isempty(check_path)==1;
            set(controls.tempdiredit,'String',var_ini.tempdir);
         else;
            %
            % check if we're dealing with an old or new directory
            %
            checkdir = dir(newtempdir);
            if size(checkdir,1)>0;
               %
               % old directory
               %
               if ispc==1;
                  newtempdir = lower(newtempdir);
                  if strcmp(newtempdir(1,size(newtempdir,2)),'\')==0;
                     newtempdir = [newtempdir '\'];
                  end;
               end;
               if strcmp(var_ini.tempdir,newtempdir)==0;
                  var_ini.tempdir = newtempdir;
                  set(controls.tempdiredit,'String',var_ini.tempdir);
                  set(controls.apply,'Enable','on');
               else;
                  set(controls.tempdiredit,'String',var_ini.tempdir);
               end;
            else;
               %
               % new directory
               %
               if ispc==1;
                  newtempdir = lower(newtempdir);
                  if strcmp(newtempdir(1,size(newtempdir,2)),'\')==0;
                     newtempdir = [newtempdir '\'];
                  end;
               end;
               %
               % are we dealing with a valid path
               %
               checkdir = dir(check_path);
               if size(checkdir,1)>0;
                  mystatus = 0;
                  mystatus = makedirs(newtempdir,0);
                  if mystatus>0;
                     var_ini.tempdir = newtempdir;
                     set(controls.tempdiredit,'String',var_ini.tempdir);
                     set(controls.apply,'Enable','on');
                  else;
                     set(controls.tempdiredit,'String',var_ini.tempdir);
                  end;
               else;
                  set(controls.tempdiredit,'String',var_ini.tempdir);
               end;
            end;
         end;
      end;
   end;
   set(optionsgui,'UserData',controls);

case 'tempdir'
   if strcmp(var_ini.tempdir,'')==0;
      newtempdir = var_ini.tempdir;
   else;
      newtempdir = pwd;
   end;
   newtempdir = uigetdir_fcn(newtempdir);
   if (ischar(newtempdir)==1)&(isempty(newtempdir)==0);
      if ispc==1;
         newtempdir = lower(newtempdir);
         if strcmp(newtempdir(1,size(newtempdir,2)),'\')==0;
            newtempdir = [newtempdir '\'];
         end;
      end;
      if strcmp(newtempdir,var_ini.tempdir)==0;
         var_ini.tempdir = newtempdir;
         set(controls.tempdiredit,'String',var_ini.tempdir);
         set(controls.apply,'Enable','on');
      end;
   end;
   set(optionsgui,'UserData',controls);
case 'recursive'
   newT0 = get(controls.recursive,'String');
   newT0 = strrep(newT0,',','.');
   newT0 = mystr2num(strrep(newT0,' ',''));
   checkvalue = 0;
   if isempty(newT0)==1;
      checkvalue = 1;
   else;
      if newT0>=0;
         if newT0<=0.95;
            if abs(var_ini.T0-newT0)>1.0e-09;
               var_ini.T0 = newT0;
               set(controls.apply,'Enable','on');
            else;
               set(controls.recursive,'String',num2str(var_ini.T0));
            end;
         else;
            checkvalue = 1;
         end;
      else;
         checkvalue = 1;
      end;
   end;
   if checkvalue==1;
      txt = ['The relative start period you selected for recursive analysis, ' get(controls.recursive,'String') ', is not valid. It must be a real number between 0 and 0.95. Please enter another value!'];
      about(txt,'warning','Warning - Illegal Relative Start Period',120,500);
      set(controls.recursive,'String',num2str(var_ini.T0));
   end;
   set(optionsgui,'UserData',controls);
case 'apply'
   if iscompiled==1;
      if appexist(var_ini.ghostscript)==1;
         if appexist(var_ini.pstoedit)==0;
            graphicsstr = get(controls.graphicsfmt,'String');
            if size(graphicsstr,1)>10;
               graphicsstr = graphicsstr(1:10,:);
               if get(controls.graphicsfmt,'Value')>10;
                  set(controls.graphicsfmt,'Value',1);
                  var_ini.graphicsfmt = 'eps';
               end;
               set(controls.graphicsfmt,'String',graphicsstr);
            end;
         end;
      else;
         graphicsstr = get(controls.graphicsfmt,'String');
         if size(graphicsstr,1)>3;
            graphicsstr = graphicsstr(1:3,:);
            if get(controls.graphicsfmt,'Value')>3;
               set(controls.graphicsfmt,'Value',1);
               var_ini.graphicsfmt = 'eps';
            end;
            set(controls.graphicsfmt,'String',graphicsstr);
         end;
      end;
   end;
   if var_ini.gui_font==1;
      var_ini.gui_fontweight = 'normal';
      var_ini.gui_fontangle = 'normal';
      [fn,fs] = getuifont;
      var_ini.gui_fontname = fn;
      var_ini.gui_fontsize = fs;
      var_ini.text_fontsize = 10;
      var_ini.text_fontname = get(0,'FixedWidthFontName');
      var_ini.text_fontweight = 'normal';
      var_ini.text_fontangle = 'normal';
      var_ini.text_fontunits = 'points';
   end;
   all_obj = findobj(optionsgui,'FontName',var_ini.oldfont.fontname,'FontSize',var_ini.oldfont.fontsize,'FontWeight',var_ini.oldfont.fontweight,'FontAngle',var_ini.oldfont.fontangle);
   if isempty(all_obj)==0;
      set(all_obj,'FontName',var_ini.gui_fontname,'FontSize',var_ini.gui_fontsize,'FontWeight',var_ini.gui_fontweight,'FontAngle',var_ini.gui_fontangle);
      var_ini.oldfont.fontname = var_ini.gui_fontname;
      var_ini.oldfont.fontsize = var_ini.gui_fontsize;
      var_ini.oldfont.fontweight = var_ini.gui_fontweight;
      var_ini.oldfont.fontangle = var_ini.gui_fontangle;
      txt_obj = findobj(optionsgui,'Type','uicontrol','Tag','FrameText')';
      if isempty(txt_obj)==0;
         for i=1:size(txt_obj,2);
            pos = get(txt_obj(1,i),'Position');
            ext = get(txt_obj(1,i),'Extent');
            ud = get(txt_obj(1,i),'UserData');
            set(txt_obj(1,i),'Position',[pos(1) ud+((15-ext(1,4))/2) ext(1,3:4)]);
         end;
         set(txt_obj,'ForegroundColor',var_ini.frame_color);
      end;
   else;
      txt_obj = findobj(optionsgui,'Type','uicontrol','Tag','FrameText');
      if isempty(txt_obj)==0;
         set(txt_obj,'ForegroundColor',var_ini.frame_color);
      end;
   end;
   if max(abs(var_ini.gui_light_color-var_ini.previous.gui_light_color))>0;
      l_obj = findobj(optionsgui,'Type','axes','Tag','gui','XColor',var_ini.previous.gui_light_color);
      if isempty(l_obj)==0;
         set(l_obj,'XColor',var_ini.gui_light_color,'YColor',var_ini.gui_light_color,'ZColor',var_ini.gui_light_color);
      end;
      %
      % Fix some frames
      %
      if max(abs(get(controls.frame1tab1,'ForegroundColor')-var_ini.previous.gui_light_color))==0;
         set(controls.frame1tab1,'ForegroundColor',var_ini.gui_light_color);
      end;
      if max(abs(get(controls.frame2tab1,'ForegroundColor')-var_ini.previous.gui_light_color))==0;
         set(controls.frame2tab1,'ForegroundColor',var_ini.gui_light_color);
      end;
      if max(abs(get(controls.frame3tab1,'ForegroundColor')-var_ini.previous.gui_light_color))==0;
         set(controls.frame3tab1,'ForegroundColor',var_ini.gui_light_color);
      end;
      if max(abs(get(controls.frame1tab2,'ForegroundColor')-var_ini.previous.gui_light_color))==0;
         set(controls.frame1tab2,'ForegroundColor',var_ini.gui_light_color);
      end;
      if max(abs(get(controls.frame3tab2,'ForegroundColor')-var_ini.previous.gui_light_color))==0;
         set(controls.frame3tab2,'ForegroundColor',var_ini.gui_light_color);
      end;
      if max(abs(get(controls.frame1tab3,'ForegroundColor')-var_ini.previous.gui_light_color))==0;
         set(controls.frame1tab3,'ForegroundColor',var_ini.gui_light_color);
      end;
      if max(abs(get(controls.frame3tab3,'ForegroundColor')-var_ini.previous.gui_light_color))==0;
         set(controls.frame3tab3,'ForegroundColor',var_ini.gui_light_color);
      end;
      if max(abs(get(controls.frame1tab4,'ForegroundColor')-var_ini.previous.gui_light_color))==0;
         set(controls.frame1tab4,'ForegroundColor',var_ini.gui_light_color);
      end;
      if max(abs(get(controls.frame3tab4,'ForegroundColor')-var_ini.previous.gui_light_color))==0;
         set(controls.frame3tab4,'ForegroundColor',var_ini.gui_light_color);
      end;
      if max(abs(get(controls.frame1tab5,'ForegroundColor')-var_ini.previous.gui_light_color))==0;
         set(controls.frame1tab5,'ForegroundColor',var_ini.gui_light_color);
      end;
      if max(abs(get(controls.frame3tab5,'ForegroundColor')-var_ini.previous.gui_light_color))==0;
         set(controls.frame3tab5,'ForegroundColor',var_ini.gui_light_color);
      end;
      var_ini.previous.gui_light_color = var_ini.gui_light_color;
   end;
   if max(abs(var_ini.gui_shade_color-var_ini.previous.gui_shade_color))>0;
      l_obj = findobj(optionsgui,'Type','axes','Tag','gui','XColor',var_ini.previous.gui_shade_color);
      if isempty(l_obj)==0;
         set(l_obj,'XColor',var_ini.gui_shade_color,'YColor',var_ini.gui_shade_color,'ZColor',var_ini.gui_shade_color);
      end;
      var_ini.previous.gui_shade_color = var_ini.gui_shade_color;
   end;
   if max(abs(var_ini.gui_dark_color-var_ini.previous.gui_dark_color))>0;
      l_obj = findobj(optionsgui,'Type','axes','Tag','gui','XColor',var_ini.previous.gui_dark_color);
      if isempty(l_obj)==0;
         set(l_obj,'XColor',var_ini.gui_dark_color,'YColor',var_ini.gui_dark_color,'ZColor',var_ini.gui_dark_color);
      end;
      var_ini.previous.gui_dark_color = var_ini.gui_dark_color;
   end;
   %
   if max(abs(var_ini.frame_light_color-var_ini.previous.frame_light_color))>0;
      l_obj = findobj(optionsgui,'Type','axes','Tag','frame','XColor',var_ini.previous.frame_light_color);
      if isempty(l_obj)==0;
         set(l_obj,'XColor',var_ini.frame_light_color,'YColor',var_ini.frame_light_color,'ZColor',var_ini.frame_light_color);
      end;
      var_ini.previous.frame_light_color = var_ini.frame_light_color;
   end;
   if max(abs(var_ini.frame_shade_color-var_ini.previous.frame_shade_color))>0;
      l_obj = findobj(optionsgui,'Type','axes','Tag','frame','XColor',var_ini.previous.frame_shade_color);
      if isempty(l_obj)==0;
         set(l_obj,'XColor',var_ini.frame_shade_color,'YColor',var_ini.frame_shade_color,'ZColor',var_ini.frame_shade_color);
      end;
      var_ini.previous.frame_shade_color = var_ini.frame_shade_color;
   end;
   if max(abs(var_ini.frame_dark_color-var_ini.previous.frame_dark_color))>0;
      l_obj = findobj(optionsgui,'Type','axes','Tag','frame','XColor',var_ini.previous.frame_dark_color);
      if isempty(l_obj)==0;
         set(l_obj,'XColor',var_ini.frame_dark_color,'YColor',var_ini.frame_dark_color,'ZColor',var_ini.frame_dark_color);
      end;
      var_ini.previous.frame_dark_color = var_ini.frame_dark_color;
   end;
   %
   % write to ini-file
   %
   write_stat = write_inifile(var_ini);
   set(controls.apply,'Enable','off');
   set(optionsgui,'UserData',controls);
case 'cancel'
   prev = var_ini.previous;
   all_obj = findobj(optionsgui,'FontName',var_ini.oldfont.fontname,'FontSize',var_ini.oldfont.fontsize,'FontWeight',var_ini.oldfont.fontweight,'FontAngle',var_ini.oldfont.fontangle);
   var_ini = oldvar_ini;
   var_ini.previous = prev;
   if isempty(all_obj)==0;
      set(all_obj,'FontName',var_ini.gui_fontname,'FontSize',var_ini.gui_fontsize,'FontWeight',var_ini.gui_fontweight,'FontAngle',var_ini.gui_fontangle);
   end;
   if var_ini.gui_font==1;
      set(controls.gui_fontbutton,'Enable','off');
      set(controls.fonttext,'Enable','off');
      set(controls.gui_font,'Value',1);
   else;
      set(controls.gui_fontbutton,'Enable','on');
      set(controls.fonttext,'Enable','on');
      set(controls.gui_font,'Value',0);
   end;
   %
   % fix GUI colors
   %
   if max(abs(var_ini.gui_light_color-var_ini.previous.gui_light_color))>0;
      l_obj = findobj(optionsgui,'Type','axes','Tag','gui','XColor',var_ini.previous.gui_light_color);
      if isempty(l_obj)==0;
         set(l_obj,'XColor',var_ini.gui_light_color,'YColor',var_ini.gui_light_color,'ZColor',var_ini.gui_light_color);
      end;
      %
      % Fix some frames
      %
      if max(abs(get(controls.frame1tab1,'ForegroundColor')-var_ini.previous.gui_light_color))==0;
         set(controls.frame1tab1,'ForegroundColor',var_ini.gui_light_color);
      end;
      if max(abs(get(controls.frame2tab1,'ForegroundColor')-var_ini.previous.gui_light_color))==0;
         set(controls.frame2tab1,'ForegroundColor',var_ini.gui_light_color);
      end;
      if max(abs(get(controls.frame3tab1,'ForegroundColor')-var_ini.previous.gui_light_color))==0;
         set(controls.frame3tab1,'ForegroundColor',var_ini.gui_light_color);
      end;
      if max(abs(get(controls.frame1tab2,'ForegroundColor')-var_ini.previous.gui_light_color))==0;
         set(controls.frame1tab2,'ForegroundColor',var_ini.gui_light_color);
      end;
      if max(abs(get(controls.frame3tab2,'ForegroundColor')-var_ini.previous.gui_light_color))==0;
         set(controls.frame3tab2,'ForegroundColor',var_ini.gui_light_color);
      end;
      if max(abs(get(controls.frame1tab3,'ForegroundColor')-var_ini.previous.gui_light_color))==0;
         set(controls.frame1tab3,'ForegroundColor',var_ini.gui_light_color);
      end;
      if max(abs(get(controls.frame3tab3,'ForegroundColor')-var_ini.previous.gui_light_color))==0;
         set(controls.frame3tab3,'ForegroundColor',var_ini.gui_light_color);
      end;
      if max(abs(get(controls.frame1tab4,'ForegroundColor')-var_ini.previous.gui_light_color))==0;
         set(controls.frame1tab4,'ForegroundColor',var_ini.gui_light_color);
      end;
      if max(abs(get(controls.frame3tab4,'ForegroundColor')-var_ini.previous.gui_light_color))==0;
         set(controls.frame3tab4,'ForegroundColor',var_ini.gui_light_color);
      end;
      if max(abs(get(controls.frame1tab5,'ForegroundColor')-var_ini.previous.gui_light_color))==0;
         set(controls.frame1tab5,'ForegroundColor',var_ini.gui_light_color);
      end;
      if max(abs(get(controls.frame3tab5,'ForegroundColor')-var_ini.previous.gui_light_color))==0;
         set(controls.frame3tab5,'ForegroundColor',var_ini.gui_light_color);
      end;
      var_ini.previous.gui_light_color = var_ini.gui_light_color;
   end;
   if max(abs(var_ini.gui_shade_color-var_ini.previous.gui_shade_color))>0;
      l_obj = findobj(optionsgui,'Type','axes','Tag','gui','XColor',var_ini.previous.gui_shade_color);
      if isempty(l_obj)==0;
         set(l_obj,'XColor',var_ini.gui_shade_color,'YColor',var_ini.gui_shade_color,'ZColor',var_ini.gui_shade_color);
      end;
      var_ini.previous.gui_shade_color = var_ini.gui_shade_color;
   end;
   if max(abs(var_ini.gui_dark_color-var_ini.previous.gui_dark_color))>0;
      l_obj = findobj(optionsgui,'Type','axes','Tag','gui','XColor',var_ini.previous.gui_dark_color);
      if isempty(l_obj)==0;
         set(l_obj,'XColor',var_ini.gui_dark_color,'YColor',var_ini.gui_dark_color,'ZColor',var_ini.gui_dark_color);
      end;
      var_ini.previous.gui_dark_color = var_ini.gui_dark_color;
   end;
   if max(abs(var_ini.frame_light_color-var_ini.previous.frame_light_color))>0;
      l_obj = findobj(optionsgui,'Type','axes','Tag','frame','XColor',var_ini.previous.frame_light_color);
      if isempty(l_obj)==0;
         set(l_obj,'XColor',var_ini.frame_light_color,'YColor',var_ini.frame_light_color,'ZColor',var_ini.frame_light_color);
      end;
      var_ini.previous.frame_light_color = var_ini.frame_light_color;
   end;
   if max(abs(var_ini.frame_shade_color-var_ini.previous.frame_shade_color))>0;
      l_obj = findobj(optionsgui,'Type','axes','Tag','frame','XColor',var_ini.previous.frame_shade_color);
      if isempty(l_obj)==0;
         set(l_obj,'XColor',var_ini.frame_shade_color,'YColor',var_ini.frame_shade_color,'ZColor',var_ini.frame_shade_color);
      end;
      var_ini.previous.frame_shade_color = var_ini.frame_shade_color;
   end;
   if max(abs(var_ini.frame_dark_color-var_ini.previous.frame_dark_color))>0;
      l_obj = findobj(optionsgui,'Type','axes','Tag','frame','XColor',var_ini.previous.frame_dark_color);
      if isempty(l_obj)==0;
         set(l_obj,'XColor',var_ini.frame_dark_color,'YColor',var_ini.frame_dark_color,'ZColor',var_ini.frame_dark_color);
      end;
      var_ini.previous.frame_dark_color = var_ini.frame_dark_color;
   end;
   %
   if strcmp(var_ini.interpolate,'nearest')==1;
      interpolate_value = 1;
   elseif strcmp(var_ini.interpolate,'linear')==1;
      interpolate_value = 2;
   elseif strcmp(var_ini.interpolate,'spline')==1;
      interpolate_value = 3;
   elseif strcmp(var_ini.interpolate,'cubic')==1;
      interpolate_value = 4;
   elseif strcmp(var_ini.interpolate,'knorm')==1;
      interpolate_value = 5;
   elseif strcmp(var_ini.interpolate,'kepan')==1;
      interpolate_value = 6;
   elseif strcmp(var_ini.interpolate,'krect')==1;
      interpolate_value = 7;
   elseif strcmp(var_ini.interpolate,'ktria')==1;
      interpolate_value = 8;
   elseif strcmp(var_ini.interpolate,'kbiwe')==1;
      interpolate_value = 9;
   elseif strcmp(var_ini.interpolate,'ktriw')==1;
      interpolate_value = 10;
   elseif strcmp(var_ini.interpolate,'klapl')==1;
      interpolate_value = 11;
   elseif strcmp(var_ini.interpolate,'klogi')==1;
      interpolate_value = 12;
   end;
   %
   if var_ini.geometry==[0 0];
      var_ini.geometryvalue = 0;
   else;
      var_ini.geometryvalue = 1;
   end;
   for i = 1:size(var_ini.maxitvec,2);
      if var_ini.maxit==var_ini.maxitvec(1,i);
         maxitv = i;
         break;
      end;
   end;
   if strcmp(var_ini.graphicsfmt,'eps')==1;
      graphicsvalue = 1;
   elseif strcmp(var_ini.graphicsfmt,'ai')==1;
      graphicsvalue = 2;
   elseif strcmp(var_ini.graphicsfmt,'pbm')==1;
      graphicsvalue = 3;
   elseif strcmp(var_ini.graphicsfmt,'jpg')==1;
      graphicsvalue = 4;
   elseif strcmp(var_ini.graphicsfmt,'tif')==1;
      graphicsvalue = 5;
   elseif strcmp(var_ini.graphicsfmt,'png')==1;
      graphicsvalue = 6;
   elseif strcmp(var_ini.graphicsfmt,'bmp')==1;
      graphicsvalue = 7;
   elseif strcmp(var_ini.graphicsfmt,'pcx')==1;
      graphicsvalue = 8;
   elseif strcmp(var_ini.graphicsfmt,'pgm')==1;
      graphicsvalue = 9;
   elseif strcmp(var_ini.graphicsfmt,'ppm')==1;
      graphicsvalue = 10;
   elseif strcmp(var_ini.graphicsfmt,'emf')==1;
      graphicsvalue = 11;
   elseif strcmp(var_ini.graphicsfmt,'fig')==1;
      graphicsvalue = 12;
   end;
   if var_ini.critval==1;
      critvalnum = 1;
   elseif var_ini.critval==2;
      critvalnum = 2;
   elseif var_ini.critval==5;
      critvalnum = 3;
   elseif var_ini.critval==10;
      critvalnum = 4;
   elseif var_ini.critval==20;
      critvalnum = 5;
   else;
      critvalnum = 6;
   end;
   set(controls.maxit,'Value',maxitv);
   set(controls.apply,'Enable','off');
   set(controls.convcrit,'Value',var_ini.convcrit);
   set(controls.method1,'Value',var_ini.method(1,1));
   set(controls.method2,'Value',var_ini.method(1,2));
   set(controls.method3,'Value',var_ini.method(1,3));
   set(controls.identify,'Value',var_ini.identify);
   if var_ini.reestbeta==0;
      set(controls.method1,'String','''3-step'' Classical Gaussian ML (beta, reduced form, B matrix)');
      set(controls.method2,'String','''2-step'' Classical Gaussian ML (beta, reduced form and B matrix)');
   else;
      set(controls.method1,'String','''2-step'' Classical Gaussian ML (beta and reduced form, B matrix)');
      set(controls.method2,'String','Full Information Classical Gaussian ML');
   end;
   set(controls.maxlag,'String',num2str(var_ini.maxlag));
   set(controls.noise_parm,'String',num2str(var_ini.noise_parm,'%0.8f'));
   set(controls.ms_maxlag,'String',num2str(var_ini.ms_maxlag));
   set(controls.openvar,'Value',var_ini.openvar);
   set(controls.geometry,'Value',var_ini.geometryvalue);
   set(controls.uselastfile,'Value',var_ini.uselastfile);
   if var_ini.uselastfile==1;
      set(controls.startrun,'Enable','on');
   else;
      set(controls.startrun,'Enable','off');
      startrun = 0;
   end;
   set(controls.startrun,'Value',var_ini.startrun);
   set(controls.logtab,'Value',var_ini.logtab);
   set(controls.clearlog,'Value',var_ini.clearlog);
   set(controls.outofsample,'Value',var_ini.outofsample);
   set(controls.forecasthorizon,'Value',var_ini.forecasthorizon);
   set(controls.openmyoutput,'Value',var_ini.openmyoutput);
   set(controls.noprint,'Value',var_ini.noprint);
   if var_ini.noprint==1;
      set(controls.openmyoutput,'Enable','off');
      set(controls.append,'Enable','off');
   else;
      set(controls.openmyoutput,'Enable','on');
      set(controls.append,'Enable','on');
   end;
   set(controls.sillyq,'Value',var_ini.sillyq);
   set(controls.editcontext,'Value',var_ini.edit_context);
   set(controls.toolbar_bgcolor,'Value',var_ini.use_toolbar_bgcolor);
   set(controls.external,'Value',var_ini.external);
   set(controls.graphicsfmt,'Value',var_ini.graphicsvalue);
   set(controls.aivieweredit,'String',var_ini.aiviewer);
   set(controls.epsvieweredit,'String',var_ini.epsviewer);
   set(controls.bitmapvieweredit,'String',var_ini.bitmapviewer);
   set(controls.sscorrect,'Value',var_ini.sscorrect);
   set(controls.bartserial,'Value',var_ini.bartserial);
   set(controls.append,'Value',var_ini.append);
   set(controls.colors,'Value',var_ini.colors);
   set(controls.zbuffer,'Value',var_ini.z_buffer);
   set(controls.ytick,'value',var_ini.ytick);
   set(controls.xtick,'value',var_ini.xtick);
   set(controls.xgrid,'Value',var_ini.xgrid);
   set(controls.ygrid,'Value',var_ini.ygrid);
   set(controls.zgrid,'Value',var_ini.zgrid);
   set(controls.box,'Value',var_ini.box);
   set(controls.omnibus,'Value',var_ini.omnibus);
   set(controls.tracebart,'Value',var_ini.tracebart);
   set(controls.betagrad,'Value',var_ini.betagrad);
   set(controls.rahbek,'Value',var_ini.rahbek);
   set(controls.reestbeta,'Value',var_ini.reestbeta);
   set(controls.normbeta,'Value',var_ini.normbeta);
   set(controls.decompose_det,'Value',var_ini.decompose_det);
   set(controls.transeig,'Value',var_ini.transeig);
   set(controls.fluctest,'Value',var_ini.fluctest);
   set(controls.nyblom,'Value',var_ini.nyblom);
   set(controls.nyblombeta,'Value',var_ini.nyblombeta);
   set(controls.taylor_nyblom,'Value',var_ini.taylor_nyblom);
   set(controls.fullrec,'Value',var_ini.fullrec);
   set(controls.chowfc,'Value',var_ini.chowfc);
   set(controls.chow,'Value',var_ini.chow);
   set(controls.recalpha,'Value',var_ini.recalpha);
   set(controls.recpi,'Value',var_ini.recpi);
   set(controls.rectrace,'Value',var_ini.rectrace);
   set(controls.topeig,'Value',var_ini.topeig);
   set(controls.extraccrit,'Value',var_ini.extraccrit);
   set(controls.parametric,'Value',var_ini.parametric);
   if var_ini.parametric==1;
      set(controls.blocktext,'Enable','off');
      set(controls.blocksize,'Enable','off','Value',1);
      var_ini.blocksize = 1;
   else;
      set(controls.blocktext,'Enable','on');
      set(controls.blocksize,'Enable','on','Value',var_ini.blocksize);
   end;
   set(controls.bootstrap,'Value',var_ini.reuse_bootstrap);
   set(controls.symmetric,'Value',var_ini.symmetric);
   set(controls.akaike,'Value',var_ini.akaike);
   set(controls.restat,'Value',var_ini.restat);
   set(controls.dummytests,'Value',var_ini.dummytests);
   set(controls.rest_march,'Value',var_ini.rest_march);
   set(controls.shortdyn,'Value',var_ini.shortdyn);
   set(controls.weakexo,'Value',var_ini.weakexo);
   set(controls.gctest,'Value',var_ini.gctest);
   set(controls.excludediffs,'Value',var_ini.excludediffs);
   set(controls.commoncycles,'Value',var_ini.commoncycles);
   set(controls.excludestat,'Value',var_ini.excludestat);
   set(controls.lstrtest,'Value',var_ini.lstrtest);
   set(controls.lagtest,'Value',var_ini.lagtest+1);
   %
   if var_ini.prior_inf_shortrun==1;
      set(controls.lambda_param,'Enable','on');
   else;
      set(controls.lambda_param,'Enable','off');
   end;
   set(controls.lambda_inf_shortrun,'Value',var_ini.prior_inf_shortrun);
   %
   if var_ini.prior_inf_deter==1;
      set(controls.lambda_d,'Enable','on');
   else;
      set(controls.lambda_d,'Enable','off');
   end;
   set(controls.lambda_inf_deter,'Value',var_ini.prior_inf_deter);
   %
   if var_ini.prior_inf_alpha==1;
      set(controls.lambda_alpha,'Enable','on');
   else;
      set(controls.lambda_alpha,'Enable','off');
   end;
   set(controls.lambda_inf_alpha,'Value',var_ini.prior_inf_alpha);
   set(controls.lambda_inf_omega,'Value',var_ini.prior_inf_omega);
   if var_ini.prior_inf_omega==1;
      set(controls.lambda_omega,'Enable','on');
   else;
      set(controls.lambda_omega,'Enable','off');
   end;
   %
   b_str = get(controls.burn_in,'String');
   for i=1:size(b_str,1);
      bs_val = mystr2num(strtrim(strrep(b_str(i,:),',','')));
      if bs_val==var_ini.burn_in;
         b_val = i;
         break;
      end;
   end;
   set(controls.burn_in,'Value',b_val);
   %
   s_str = get(controls.save_draws,'String');
   for i=1:size(s_str,1);
      ss_val = mystr2num(strtrim(strrep(s_str(i,:),',','')));
      if ss_val==var_ini.save_draws;
         s_val = i;
         break;
      end;
   end;
   set(controls.save_draws,'Value',s_val);
   set(controls.save_freq,'Value',var_ini.save_freq);
   set(controls.discard_explosive,'Value',var_ini.discard_explosive);
   set(controls.bad_draws,'Value',var_ini.bad_draws);
   set(controls.critval,'Value',critvalnum);
   set(controls.dirstructure,'Value',var_ini.dirstructure);
   set(controls.editoredit,'String',var_ini.editor);
   if ispc==1;
      if strcmp(lower(getfilename(var_ini.helpexe)),'winhlp32.exe')==1;
         set(controls.helpexeedit,'Value',1);
      elseif strcmp(lower(getfilename(var_ini.helpexe)),'hh.exe')==1;
         set(controls.helpexeedit,'Value',2);
      else;
         set(controls.helpexeedit,'Value',3);
      end;
   else;
      set(controls.helpexeedit,'String',var_ini.helpexe);
   end;
   set(controls.txtprintedit,'String',var_ini.txtprint);
   if (isempty(var_ini.txtprint)==0)&(ispc==1)&(fileexist([getpath(var_ini.txtprint) 'txtprint.exe'])==1);
      set(controls.txtprintrun,'Enable','on');
   end;
   set(controls.latexedit,'String',var_ini.latex);
   set(controls.dvivieweredit,'String',var_ini.dviviewer);
   set(controls.distilleredit,'String',var_ini.distiller);
   set(controls.psvieweredit,'String',var_ini.psviewer);
   set(controls.pdfvieweredit,'String',var_ini.pdfviewer);
   set(controls.dvipdfm,'Value',var_ini.dvipdfm);
   if isfield(controls,'maximizeviewer')==1;
      set(controls.maximizeviewer,'Value',var_ini.maximizeviewer);
   end;
   if strcmp(var_ini.pdfversion,'1.2')==1;
      mypdf = 1;
   elseif strcmp(var_ini.pdfversion,'1.2')==1;
      mypdf = 2;
   else;
      mypdf = 3;
   end;
   set(controls.pdfversion,'Value',mypdf);
   set(controls.exportdata,'Value',var_ini.exportdata);
   set(controls.decimals,'Value',var_ini.decimals-1);
   set(controls.texoutput,'Value',var_ini.texoutputformat);
   set(controls.texheader,'String',var_ini.texheadertxt);
   set(controls.txtprintcmdedit,'String',var_ini.txtprintcmd);
   if iscompiled==1;
      set(controls.psprintedit,'String',var_ini.psprint);
      set(controls.psprintcmdedit,'String',var_ini.psprintcmd);
      set(controls.ghostscriptedit,'String',var_ini.ghostscript);
      set(controls.pstoeditedit,'String',var_ini.pstoedit);
   end;
   set(controls.recursive,'String',num2str(var_ini.T0));
   set(controls.portmanteau,'Value',var_ini.portmanteau);
   set(controls.lbcorrect,'Value',var_ini.lbcorrect);
   if var_ini.external==1;
      set(controls.graphicsfmttext,'Enable','on');
      set(controls.graphicsfmt,'Enable','on');
   else;
      set(controls.graphicsfmttext,'Enable','off');
      set(controls.graphicsfmt,'Enable','off');
   end;
   set(controls.rstate,'Value',var_ini.random_state);
   var_ini.nRep_value = 1;
   repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
   for i=1:size(repvalues,2);
      if var_ini.nRep==repvalues(1,i);
         var_ini.nRep_value = i;
         break;
      end;
   end;
   set(controls.nRep,'Value',var_ini.nRep_value);
   set(controls.nDraw,'Value',floor(var_ini.nDraw/100));
   set(controls.interpolate,'Value',interpolate_value);
   set(controls.simulatediredit,'String',var_ini.simulatedir);
   set(controls.delay,'String',num2str(var_ini.delay));
   set(controls.maxresp,'String',num2str(var_ini.maxresp));
   set(controls.loadicon,'Value',var_ini.loadicon);
   set(controls.noicon,'Value',var_ini.noicon);
   set(controls.show_undo,'Value',var_ini.show_undo);
   set(controls.loadguiicon,'Value',var_ini.loadguiicon);
   set(controls.pstoolsdiredit,'String',var_ini.pstoolsdir);
   set(controls.tempdiredit,'String',var_ini.tempdir);
   set(controls.browsedialog,'Value',var_ini.browsedialog);
   set(controls.opendialog,'Value',var_ini.opendialog);
   %
   if iscompiled==1;
      if appexist(var_ini.ghostscript)==1;
         if appexist(var_ini.pstoedit)==0;
            var_ini.graphicsstr = get(controls.graphicsfmt,'String');
            if size(var_ini.graphicsstr,1)>10;
               var_ini.graphicsstr = var_ini.graphicsstr(1:10,:);
               if get(controls.graphicsfmt,'Value')>10;
                  set(controls.graphicsfmt,'Value',1);
                  var_ini.graphicsfmt = 'eps';
               end;
               set(controls.graphicsfmt,'String',var_ini.graphicsstr);
            end;
         end;
      else;
         var_ini.graphicsstr = get(controls.graphicsfmt,'String');
         if size(var_ini.graphicsstr,1)>3;
            var_ini.graphicsstr = var_ini.graphicsstr(1:3,:);
            if get(controls.graphicsfmt,'Value')>3;
               set(controls.graphicsfmt,'Value',1);
               var_ini.graphicsfmt = 'eps';
            end;
            set(controls.graphicsfmt,'String',var_ini.graphicsstr);
         end;
      end;
   end;
   if var_ini.landscape==1;
      orientstr = 'landscape';
   else;
      orientstr = 'portrait';
   end;
   if var_ini.invert_hardcopy==1;
      inv_hardcopy = 'on';
   else;
      inv_hardcopy = 'off';
   end;
   set(gcf,'PaperPositionMode',var_ini.paperposmode, ...
      'PaperType',var_ini.papertype, ...
      'PaperUnits',var_ini.paperunits, ...
      'InvertHardcopy',inv_hardcopy, ...
      'PaperOrientation',orientstr);
   set(optionsgui,'UserData',controls);
case 'help'
   help_fcn(strrep(controls.current,' ','_'));
case 'ok'
   set(controls.ok,'UserData','done');
   %
   % check if we need to shut down a seticon process
   %
   pid = get(controls.loadguiicon,'UserData');
   delete(optionsgui);
   drawnow;
   if (isempty(pid)==0)&(pid>-1)&(ispid('seticon',pid)==1)&(appexist([var_ini.pstoolsdir 'pskill.exe'])==1);
      pid_prog = ['bin\runwindow.exe ' fix_path([var_ini.pstoolsdir 'pskill.exe']) ' ' num2str(pid,'%0.0f') '>' fix_path([var_ini.tempdir 'killpid.txt'])];
      dos(pid_prog);
      if ispid('seticon',pid)==1;
         pid_prog = ['bin\runwindow.exe ' fix_path([var_ini.pstoolsdir 'pskill.exe']) ' ' num2str(pid,'%0.0f')];
         dos(pid_prog);
      end;
   end;
end;

if strcmp(selector,'init')==1;
   if (iswinnt==1)&(iscompiled==1)&(var_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(optionsgui,'Name') ' ' fix_filepath([pwd '\icons\preferences.ico'])];
      dos(prog);
      if (strcmp(var_ini.pstoolsdir,'')==0)&(appexist([var_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(controls.loadguiicon,'UserData',pid);
      end;
   end;
   set(optionsgui,'Visible','on');
   drawnow;
   refresh(optionsgui);
   if (iswinnt==1)&(iscompiled==1)&(matlabnumber<7);
      drawnow;
      prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(optionsgui,'Name') ' 3'];
      dos(prog);
      drawnow;
   elseif matlabnumber>=7;
      uicontrol(controls.ok);
   end;
end;

if strcmp(selector,'ok')==0;
   var_ini.oldvar = oldvar_ini;
   if ishandle(controls.cancel)==1;
      set(controls.cancel,'UserData',var_ini);
      if strcmp(selector,'cancel')==1
         optionsdlg('apply');
      end;
   end;
end;

if thisexit==0;
   waitfor(controls.ok,'UserData','done');
end;

%
% end of optionsdlg.m
%
